	SUBROUTINE CPB_DSCR ( iscor, mxt, mxd, ndpth, npts,
     +			      itrc, dtrace, rmiss, prbs, nprbs,
     +			      trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CPB_DSCR								*
C*									*
C* This subroutine computes the terms in the decomposition of the	*
C* Brier score, depending on the value of ISCOR.			*
C*									*
C* ISCOR = 1 -> Reliability = SUM [ n(r) * ( f(r) - p(r) )**2 ]		*
C* ISCOR = 2 -> Resolution  = SUM [ n(r) * ( p(r) - pbar )**2 ]		*
C* ISCOR = 3 -> Uncertainty = pbar * ( 1 - pbar )			*
C*              pbar = SUM [ n(r) * p(r) ]				*
C*									*
C* where n(r) is the number of events in category r divided by the	*
C* total number of events over all categories, p(r) is the number of	*
C* events in category r observed to exceed the threshold divided by	*
C* the total number of events in category r, f(r) is the forecast	*
C* probability of exceeding the threshold associated with the risk	*
C* category r, and the summation is over risk categories, r.		*
C*									*
C*									*
C* This subroutine also computes the Brier Skill Score against the	*
C* sample climatology:							*
C*									*
C* ISCOR = 4 -> BSSc = ( resolution - reliability ) / uncertainty	*
C*									*
C* The trace data begins with the total number of events, followed by	*
C* the fraction of that number falling within the risk categories in	*
C* order of ascending risk, starting with the second risk category.	*
C* The entries following those are the fractions of the total count	*
C* for each risk category that were accompanied by the occurrence of 	*
C* the event.  For this set of fractions, the first risk category is	*
C* included.								*
C*									*
C* CPB_DSCR ( ISCOR, MXT, MXD, NDPTH, NPTS, ITRC, DTRACE,		*
C*	     RMISS, PRBS, NPRBS, TRCDAT, TRCMIN, TRCMAX, IRET )		*
C*									*
C* Input parameters:							*
C*	ISCOR		INTEGRE		Score type			*
C*					1 = reliability			*
C*					2 = resolution			*
C*					3 = uncertainty			*
C*					4 = BSS against sample climo	*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		# of values per trace point	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	PRBS (NPRBS)	REAL		Forcast probabilities		*
C*	NPRBS		INTEGER		# of probabilities 		*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = Computation not possible	*
C**									*
C* Log:									*
C* K. Brill/HPC		 8/05						*
C* K. Brill/HPC		10/05	Check for divide by 0 for ISCOR = 4	*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL		prbs (*)
C*
	REAL*8		rnttl, rnc, pr, nr, fr, rel, scr, snp, snp2
	REAL*8		dfp
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
C*
	nrisk = ndpth / 2
	IF ( nprbs .ne. nrisk ) THEN
	    iret = -1
	    RETURN
	END IF
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    rnttl  = dtrace (itrc,1,ip)
	    IF ( ok .and. rnttl .gt. 0.0 ) THEN
	        icntz = 0
		rel = 0.0
		snp = 0.0
		snp2 = 0.0
		DO irisk = 1, nrisk
		    IF ( irisk .eq. 1 ) THEN
			rnc = rnttl
			DO i = 2, nrisk
			    rnc = rnc - dtrace (itrc,i,ip)
			END DO
		    ELSE
			rnc = dtrace (itrc,irisk,ip)
		    END IF
		    IF ( rnc .le. 0.0 ) THEN
			icntz = icntz + 1
		    ELSE
		        nr = rnc / rnttl
		        fr = prbs (irisk)
			indx = nrisk + irisk
			pr = dtrace (itrc,indx,ip) / rnc
			dfp = fr - pr
			rel = rel + nr * ( dfp * dfp )
			snp = snp + nr * pr
			snp2 = snp2 + nr * pr * pr
		    END IF
		END DO
		IF ( icntz .eq. nrisk ) THEN
		    trcdat (ip) = rmiss
		ELSE
		    IF ( iscor .eq. 1 ) THEN
			scr = rel
		    ELSE IF ( iscor .eq. 2 ) THEN
			scr = snp2 - snp * snp
		    ELSE IF ( iscor .eq. 3 ) THEN
			scr = snp * ( 1. - snp )
		    ELSE IF ( iscor .eq. 4 ) THEN
			dfp = snp * ( 1. - snp )
			IF ( dfp .gt. 0.0 ) THEN
			    scr = ( snp2 - snp * snp - rel ) / dfp
			ELSE
			    scr = rmiss
			END IF
		    ELSE
			scr = rmiss
		    END IF
C*
		    trcdat (ip) = scr
C*
		    IF ( trcdat (ip) .lt. trcmin ) trcmin = trcdat (ip)
		    IF ( trcdat (ip) .gt. trcmax ) trcmax = trcdat (ip)
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
