	SUBROUTINE CPB_UREF ( icmp, mxt, mxd, ndpth, npts, itrc, dtrace,
     +			      rmiss, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CPB_UREF								*
C*									*
C* This subroutine computes the Brier score for the sample climatology. *
C* The result is the same as the uncertainty term in the algebraic	*
C* decomposition of the Brier score.  This subroutine works for the	*
C* PBS statistic type.							*
C*									*
C* If p(r) is the number of events in category r observed to exceed the *
C* threshold divided by	the total number of events, N, then the sample	*
C* climatological probabiliity is given by:				*
C*									*
C*                   Pc = SUM [ p(r) * N ] / N				*
C*									*
C* where the summation is over r risk categories.			*
C*									*
C* The reference Brier score obtained by forecasting this sample	*
C* climatological probability, Pc, is					*
C*									*
C*                   BSref = Pc * ( 1 - Pc )				*
C*									*
C* This subroutine will return Pc if ICMP = 1.				*
C*									*
C* The trace data begins with the total number of events, followed by	*
C* the number falling within the risk categories in order of ascending  *
C* risk, starting with the second risk category.  The entries following *
C* those are the counts for each risk category that were accompanied by *
C* the occurrence of the event.  For this set of counts, the first risk *
C* category is included.						*
C*									*
C* CPB_UREF ( ICMP, MXT, MXD, NDPTH, NPTS, ITRC, DTRACE,		*
C*	      RMISS, TRCDAT, TRCMIN, TRCMAX, IRET )			*
C*									*
C* Input parameters:							*
C*	ICMP		INTEGER		Computation flag:		*
C*					  0 = compute BS for climo	*
C*					  1 = compute climatological	*
C*					      frequency			*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		# of values per trace point	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = Computation not possible	*
C**									*
C* Log:									*
C* K. Brill/HPC		 5/05						*
C* K. Brill/HPC      20070209	Add ICMP to compute climo frequency	*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		rnttl, pc, sum
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
C*
	nrisk = ndpth / 2
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    ok = .true.
	    iok = 0
	    DO WHILE  ( iok .lt. ndpth .and. ok )
		iok = iok + 1
		ok = ( dtrace (itrc,iok,ip) .gt. -1.E30 )
	    END DO
	    rnttl  = dtrace (itrc,1,ip)
	    IF ( ok .and. rnttl .gt. 0.0 ) THEN
		sum = 0.0
		DO i = nrisk+1, ndpth
		    sum = sum + dtrace (itrc,i,ip)
		END DO
		pc = sum / rnttl
		IF ( icmp .eq. 1 ) THEN
		    trcdat (ip) = pc
		ELSE
		    trcdat (ip) = pc * ( 1. - pc )
		END IF
		IF ( trcdat (ip) .lt. trcmin ) trcmin = trcdat (ip)
		IF ( trcdat (ip) .gt. trcmax ) trcmax = trcdat (ip)
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
