	SUBROUTINE CS_2AFC ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_2AFC								*
C*									*
C* This subroutine computes the two-alternative forced choice test.     *
C* This score is also equivalent to the area under the three-point      *
C* ROC curve, determined by the trapezium rule.                         *
C*									*
C* Reference:                                                           *   
C*									*
C* Mason, S. J., and A. P. Weigel, 2009:  A generic forecast            *
C*     verification framework for administrative purposes.  MON. WEA.   *
C*     REV., 137, 331--349.                                             *
C*									*
C* CS_2AFC ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/IMSG      20170823						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, h, o, tn
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn .gt. 0.0 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. 0.0 ) THEN
		alfa = o / tn
		P = h / o
		B = f / o
                a = alfa * P
                b = alfa * ( B - P )
                c = alfa * ( 1 - P )
                d = 1 - alfa * ( B + 1 - P )
		dn = ( a + c ) * ( b + d )
		IF ( dn .ne. 0.0 ) THEN
		    td = a * d + .5 * ( a * b + c * d )
                    td = td / dn
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
