	SUBROUTINE CS_BIAS ( ityp, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_BIAS								*
C*									*
C* This subroutine computes the BIAS given the count, forecast sum,	*
C* and observation sum.							*
C*									*
C* CS_BIAS ( ITYP, MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	ITYP		INTEGER		Type of computation:		*
C*					0 - Scalar bias			*
C*					1 - u component bias		*
C*					2 - v component bias		*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		10/98	Changes for vector components		*
C* K. Brill/EMC		 1/99	Check for division by zero		*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		c, f, o, td
	INTEGER		ind (3)
C*-----------------------------------------------------------------------
	iret = 0
C*
	IF ( ityp .eq. 1 ) THEN
	    ind (1) = 1
	    ind (2) = 2
	    ind (3) = 4
	ELSE IF ( ityp .eq. 2 ) THEN
	    ind (1) = 1
	    ind (2) = 3
	    ind (3) = 5
	ELSE
	    DO i = 1, 3
		ind (i) = i
	    END DO
	END IF
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c  = dtrace (itrc,ind(1),ip)
	    f  = dtrace (itrc,ind(2),ip)
	    o  = dtrace (itrc,ind(3),ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 .and.
     +		 c  .ne. 0.0 ) THEN
		f = f / c
		o = o / c
		td =  f - o
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
