	SUBROUTINE CS_CCPR ( iscr, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     prmnam, trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_CCPR								*
C*									*
C* This subroutine computes the CPR value for the performance measure	*
C* referenced by ISCR.	The CPR is the critical performance ratio giving*
C* the fraction of area added or subtracted in changing bias that is	*
C* hit area for the performance measure to show improvement.		*
C*									*
C* CS_CCPR ( ISCR, MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     PRMNAM, TRCDAT, TRCMIN, TRCMAX, IRET )			*
C*									*
C* Input parameters:							*
C*      ISCR  		INTEGER		Computational index:		*
C*					1 = CPR for POD 	        *
C*					2 = CPR for EDS                 *
C*					3 = CPR for TSS         	*
C*					4 = CPR for PC                  *
C*					5 = CPR for POFD                *
C*					6 = CPR for FAR                 *
C*					7 = CPR for TS                  *
C*					8 = CPR for ETS                 *
C*					9 = CPR for HSS                 *
C*					10 = CPR for CSS                *
C*					11 = CPR for ORSS               *
C*					12 = CPR for CMR                *
C*					13 = CPR for PA                 *
C*					14 = CPR for TSDHDF             *
C*					15 = CPR for ETSDHDF            *
C*					16 = CPR for TSDHDA             *
C*					17 = CPR for ETSDHDA            *
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*      PRMNAM		CHAR*20		Trace label string		*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -2 = ISCR is not valid		*
C**									*
C* Log:									*
C* K. Brill/HPC      20080410						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	CHARACTER*(*)   prmnam
C*
	REAL*8		f, h, o, tn
C*-----------------------------------------------------------------------
	iret = 0
	IF ( iscr .eq. 1 ) THEN
	    prmnam = 'POD_CPR'
	ELSE IF ( iscr .eq. 2 ) THEN
	    prmnam = 'EDS_CPR'
	ELSE IF ( iscr .eq. 3 ) THEN
	    prmnam = 'TSS_CPR'
	ELSE IF ( iscr .eq. 4 ) THEN
	    prmnam = 'PC_CPR'
	ELSE IF ( iscr .eq. 5 ) THEN
	    prmnam = 'POFD_CPR'
	ELSE IF ( iscr .eq. 6 ) THEN
	    prmnam = 'FAR_CPR'
	ELSE IF ( iscr .eq. 7 ) THEN
	    prmnam = 'TS_CPR'
	ELSE IF ( iscr .eq. 8 ) THEN
	    prmnam = 'ETS_CPR'
	ELSE IF ( iscr .eq. 9 ) THEN
	    prmnam = 'HSS_CPR'
	ELSE IF ( iscr .eq. 10 ) THEN
	    prmnam = 'CSS_CPR'
	ELSE IF ( iscr .eq. 11 ) THEN
	    prmnam = 'ORSS_CPR'
	ELSE IF ( iscr .eq. 12 ) THEN
	    prmnam = 'CMR_CPR'
	ELSE IF ( iscr .eq. 13 ) THEN
	    prmnam = 'PA_CPR'
	ELSE IF ( iscr .eq. 14 ) THEN
	    prmnam = 'TSDHDF_CPR'
	ELSE IF ( iscr .eq. 15 ) THEN
	    prmnam = 'ETSDHDF_CPR'
	ELSE IF ( iscr .eq. 16 ) THEN
	    prmnam = 'TSDHDA_CPR'
	ELSE IF ( iscr .eq. 17 ) THEN
	    prmnam = 'ETSDHDA_CPR'
	ELSE
	    iret = -2
	    RETURN
	END IF
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn  .gt. 0.0 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. 0.0 ) THEN
		alfa = o / tn
		P = h / o
		B = f / o
		cpr = rmiss
		IF ( iscr .eq. 1 ) THEN
		    cpr = 0.0
		ELSE IF ( iscr .eq. 2 ) THEN
		    cpr = 0.0
		ELSE IF ( iscr .eq. 3 ) THEN
		    cpr = alfa
		ELSE IF ( iscr .eq. 4 ) THEN
		    cpr = .50
		ELSE IF ( iscr .eq. 5 ) THEN
		    cpr = 1.0
		ELSE IF ( iscr .eq. 6 .and. B .gt. 0.0 ) THEN
		    cpr = P / B
		ELSE IF ( iscr .eq. 7 ) THEN
		    cpr = P / ( B + 1 )
		ELSE IF ( iscr .eq. 8 .or. iscr .eq. 9 ) THEN
		    dn = ( B + 1.0 - 2.0 * alfa * B )
		    IF ( dn .ne. 0.0 ) THEN
			cpr = ( P + alfa - 2.0 * alfa * P ) / dn
		    END IF
		ELSE IF ( iscr .eq. 10 ) THEN
		    dn = B * ( 1.0 - alfa * B )
		    IF ( dn .ne. 0.0 ) THEN
			cpr = P + alfa * alfa * B * B
			cpr = cpr - 2.0 * alfa * P * B
			cpr = cpr / dn
		    END IF
		ELSE IF ( iscr .eq. 11 ) THEN
		    dn = B - P * P - alfa * B * B - alfa * B
		    dn = dn + 2.0 * alfa * B * P
		    IF ( dn .ne. 0.0 ) THEN
			cpr = P * ( 1.0 - P ) * ( 1.0 - alfa ) / dn
		    END IF
		ELSE IF ( iscr .eq. 12 ) THEN
		    dn = 1.0 - alfa * B
		    IF ( dn .ne. 0.0 ) THEN
			cpr = alfa * ( 1.0 - P ) / dn
		    END IF
		ELSE IF ( iscr .eq. 13 .and. B .gt. 0.0 ) THEN
		    cpr = P / B
		ELSE IF ( iscr .eq. 14 .or. iscr .eq. 15 ) THEN
		    IF ( B .gt. 0.0 .and. P .lt. 1.0 ) THEN
			cpr = ( P - 1.0 ) * ALOG ( 1.0 - P ) / B
		    END IF
		ELSE IF ( iscr .eq. 16 .or. iscr .eq. 17 ) THEN
		    IF ( P .lt. 1.0 ) THEN
			dn = B - P + ( P - 1.0 ) * ALOG ( 1.0 - P )
			IF ( dn .ne. 0.0 ) THEN
			    cpr = ( P - 1.0 ) * ALOG ( 1.0 - P ) / dn
			END IF
		    END IF
		END IF
		IF ( cpr .ne. rmiss ) THEN
		    IF ( cpr .lt. trcmin ) trcmin = cpr
		    IF ( cpr .gt. trcmax ) trcmax = cpr
		    trcdat (ip) = cpr
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
