	SUBROUTINE CS_TSBA ( iscr, mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CS_TSBA								*
C*									*
C* This subroutine computes dHdF and dHdA bias adjusted threat score	*
C* and equitable threat score values.					*
C*									*
C* CS_TSBA ( ISCR, MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*      ISCR  		INTEGER		Computational index:		*
C*					1 - dHdF Threat score		*
C*					2 - dHdF Eq. Threat score	*
C*					3 - dHdA Threat score		*
C*					4 - dHdA Eq. Threat score	*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -2 = ISCR is not valid		*
C**									*
C* Log:									*
C* K. Brill/HPC      20080410						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		f, h, o, tn
C*-----------------------------------------------------------------------
	iret = 0
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn  .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 ) THEN
		alfa = o / tn
		P = h / o
		B = f / o
		IF ( iscr .eq. 1 .and. B .ne. 0.0 ) THEN
		    dn = 1. + ( 1. - P ) ** ( 1. / B )
		    td = 1. - ( 1. - P ) ** ( 1. / B )
		    td = td / dn
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE IF ( iscr .eq. 2 .and. B .ne. 0.0 ) THEN
		    dn = 1. - alfa + ( 1. - P ) ** ( 1. / B )
		    td = 1. - alfa - ( 1. - P ) ** ( 1. / B )
		    td = td / dn
		    IF ( td .lt. trcmin ) trcmin = td
		    IF ( td .gt. trcmax ) trcmax = td
		    trcdat (ip) = td
		ELSE IF ( iscr .eq. 3 .and. B .ne. 0.0 ) THEN
		    IF ( P .lt. 1 ) THEN
			u = -ALOG ( 1. - P ) / ( B - P )
			wu = WEW_B ( u, en )
			ou = 1. / u
			dn = 1. + ou * wu
			td = 1. - ou * wu
			td = td / dn
		        IF ( td .lt. trcmin ) trcmin = td
		        IF ( td .gt. trcmax ) trcmax = td
		        trcdat (ip) = td
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		ELSE IF ( iscr .eq. 4 .and. B .ne. 0.0 ) THEN
		    IF ( P .lt. 1 ) THEN
			u = -ALOG ( 1. - P ) / ( B - P )
			wu = WEW_B ( u, en )
			ou = 1. / u
			dn = 1. - alfa + ou * wu
			td = 1. - alfa - ou * wu
			td = td / dn
		        IF ( td .lt. trcmin ) trcmin = td
		        IF ( td .gt. trcmax ) trcmax = td
		        trcdat (ip) = td
		    ELSE
			trcdat (ip) = rmiss
		    END IF
		ELSE IF ( B .ne. 0.0 ) THEN
		    iret = -2
		    RETURN
		ELSE
		    trcdat (ip) = rmiss
		END IF
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
