	SUBROUTINE CV_VBIS ( mxt, mxd, npts, itrc, dtrace, rmiss,
     +			     trcdat, trcmin, trcmax, iret )
C************************************************************************
C* CV_VBIS								*
C*									*
C* This subroutine computes the vector BIAS for forcast and obs data.	*
C*									*
C* CV_VBIS ( MXT, MXD, NPTS, ITRC, DTRACE, RMISS,			*
C*	     TRCDAT, TRCMIN, TRCMAX, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Output trace			*
C*	TRCMIN		REAL		Minimum output trace value	*
C*	TRCMAX		REAL		Maximum output trace value	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		12/01						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
C*
	REAL*8		c, v2, v3, v4, v5, td
C*-----------------------------------------------------------------------
	iret = 0
C*
	trcmin = 1.1E30
	trcmax = -1.1E30
	DO ip = 1, npts
	    c  = dtrace (itrc,1,ip)
	    v2  = dtrace (itrc,2,ip)
	    v3  = dtrace (itrc,3,ip)
	    v4  = dtrace (itrc,4,ip)
	    v5  = dtrace (itrc,5,ip)
	    IF ( c  .gt. -1.E30 .and.
     +		 v2  .gt. -1.E30 .and.
     +		 v3  .gt. -1.E30 .and.
     +		 v4  .gt. -1.E30 .and.
     +		 v5  .gt. -1.E30 .and.
     +		 c    .gt. 0.0 ) THEN
		v2 = v2 / c
		v3 = v3 / c
		v4 = v4 / c
		v5 = v5 / c
		td =  SQRT ( v2*v2 - 2. * v2*v4 + v4*v4 +
     +			     v3*v3 - 2. * v3*v5 + v5*v5 )
		IF ( td .lt. trcmin ) trcmin = td
		IF ( td .gt. trcmax ) trcmax = td
		trcdat (ip) = td
	    ELSE
		trcdat (ip) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
