	SUBROUTINE PLT_CATT ( mp, mt, ntrc, trc, xpts, npts, wrka, wrkb,
     +			      bscr, bssk, reli, reso, uncr, sclm, ntro,
     +			      rplbl, xplbl, nplbl, dxmin, iret )
C************************************************************************
C* PLT_CATT								*
C*									*
C* This subroutine computes the trace data for an attributes diagram.	*
C*									*
C* There are two traces output for each trace input.  They are the	*
C* reliability curves followed by the frequency of use traces (usually	*
C* drawn as histograms).						*
C*									*
C* PLT_CATT  ( MP, MT, NTRC, TRC, XPTS, NPTS, WRKA, BSCR, BSSK, RELI, 	*
C*             RESO, UNCR, SCLM, NTRO, RPLBL, XPLBL, NPLBL, DXMIN,	*
C*	       IRET )							*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	NTRC		INTEGER		Number of traces input		*
C*									*
C* Input and Output parameters:						*
C*	TRC (MP,MT)	REAL		Trace data			*
C*	XPTS (MP,MT)	REAL		x coordinates of trace points	*
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*	WRKA (MP)	REAL*8		Work scratch array		*
C*	WRKB (MP        REAL		Work scratch array		*
C*									*
C* Output parameters:							*
C*	BSCR (MT)	REAL		Brier Scores BS for traces	*
C*	BSSK (MT)	REAL		Brier Skill Scores for traces	*
C*	RELI (MT)	REAL		Reliability components of BS	*
C*	RESO (MT)	REAL		Resolution components of BS	*
C*	UNCR (MT)	REAL		Uncertainty components of BS	*
C*	SCLM (MT)	REAL		Sample climatology		*
C*	NTRO		INTEGER		Number of traces output		*
C*	RPLBL (MP)	REAL		X axis labels			*
C*	XPLBL (MP)	REAL		X positions of axis labels	*
C*	NPLBL (MP)	REAL		Number of X axis labels		*
C*	DXMIN		REAL		Minimum X label spacing		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC      20070122						*
C* K. Brill/WPC      20130320	Added return code -46			*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999. )
C*
	REAL		trc (mp,mt), xpts (mp,mt), wrkb (*)
	REAL		rplbl (*), xplbl (*)
	REAL		bscr (*), bssk (*), reli (*), reso (*), uncr (*)
	REAL		sclm (*)
	REAL*8		wrka (*)
	INTEGER		npts (*)
C*
	REAL*8		xcpb
C*
        LOGICAL         SAME
        SAME ( x, y ) = ( ABS ( x - y ) .lt. .00005 )
C*-----------------------------------------------------------------------
	iret = 0
	ntro = 2 * ntrc
	IF ( ntro .gt. mt ) THEN
	    iret = -32
	    RETURN
	END IF
C
C*	Compute the Scores first.  This requires a 1.0 value
C*      inserted as the first element.
C
	DO it = 1, ntrc
	    npn = npts (it)
	    nov2 = npn / 2
	    IF ( nov2 * 2 .ne. npn )  THEN
		iret = -33
		RETURN
	    END IF
	    DO i = 2, npn
		wrka (i) = trc (i,it)
	    END DO
	    wrka (1) = 1.0
	    CALL CPB_SCR ( 0, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                     xpts (1,it), nov2, xcpb, zmn, zmx, ier )
	    bscr (it) = xcpb
	    CALL CPB_DSCR ( 4, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      xpts (1,it), nov2, xcpb, zmn, zmx, ier2 )
	    bssk (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_DSCR ( 1, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      xpts (1,it), nov2, xcpb, zmn, zmx, ier2 )
	    reli (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_DSCR ( 2, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      xpts (1,it), nov2, xcpb, zmn, zmx, ier2 )
	    reso (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_DSCR ( 3, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      xpts (1,it), nov2, xcpb, zmn, zmx, ier2 )
	    uncr (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_UREF ( 1, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      xcpb, zmn, zmx, ier2 )
	    sclm (it) = xcpb
	    ier = ier + ier2
	    IF ( ier .ne. 0 ) THEN
		iret = -34
		RETURN
	    END IF
	END DO
C
C*	Separate out the frequency of use & reliability traces.
C
C*      Start by making the merged forecast probability array.
C
	CALL PLT_XMRG ( mp, mt, xpts, npts, ntrc, wrkb, nmrg, iret )
	IF ( iret .eq. -36 ) iret = -46
	IF ( iret .ne. 0 ) RETURN
C
C*	Scan the merged array and set the limit for all values
C*      less than or equal to 1.
C
	i = 1
	DO WHILE ( wrkb (i) .le. 1.00 .and. i .le. nmrg )
	    i = i + 1
	END DO
	nmrg = i - 1
C*	
	it = 0
	DO i = ntrc+1, ntro
	    it = it + 1
	    bscr (i) = bscr (it)
	    bssk (i) = bssk (it)
	    reli (i) = reli (it)
	    reso (i) = reso (it)
	    uncr (i) = uncr (it)
	    sclm (i) = sclm (it)
C*
	    nrel1 = ( npts (it) / 2 ) + 1
C
C*	    Store the forecast use fractions in the scratch array.
C*          Move the conditional probabilty of an observation given
C*          a forecast to the front of the trc(*,*) array.
C
	    iow = 0
	    DO j = nrel1, npts(it)
		iow = iow + 1
		wrka (iow) = trc (iow,it)
C
C*		Compute conditional probability of an observation
C*		given a forecast.
C
		IF ( trc (iow,it) .gt. 0 ) THEN
		    trc (iow,it) = trc (j,it) / trc (iow,it)
		ELSE
		    trc (iow,it) = RMISSD
		END IF
	    END DO
C
C*	    Now populate the frequency of use array at values
C*	    that match the merged forecast prob array values; otherwise
C*          the frequency of use is zero.
C
	    jj = 1
	    DO j = 1, nmrg
		IF ( jj .le. npts (it) ) THEN
		    IF ( SAME ( wrkb(j), xpts (jj,it) ) ) THEN
		        trc (j,i) = wrka (jj)
		        jj = jj + 1
		    ELSE
		        trc (j,i) = 0.0
		    END IF
		END IF
	    END DO
	    DO j = 1, nmrg
		xpts (j,i) = wrkb (j)
	    END DO
	    npts (i) = nmrg
	    npts (it) = npts (it) / 2
	END DO
	dxmin = 1.E31
	DO j = 1, nmrg
	    rplbl (j) = wrkb (j)
	    xplbl (j) = wrkb (j)
	    IF ( j .gt. 1 ) THEN
		dx = xplbl (j) - xplbl (j-1)
		IF ( dx .lt. dxmin ) dxmin = dx
	    END IF
	END DO
	nplbl = nmrg
C*
	RETURN
	END
