	SUBROUTINE PLT_CDIF ( itype, prfct, mxpts, npts, trc,
     +			      ymin, ymax, iret )
C************************************************************************
C* PLT_CDIF								*
C*									*
C* This subroutine computes the simple difference, percentage		*
C* difference, or skill score between the first two traces in TRC	*
C* according to								*
C*									*
C*   diff   =  trace1 - trace2						*
C*									*
C*   OR									*
C*									*
C*		      ( trace1 - trace2 )				*
C*   % diff =  ----------------------------------- * 100		*
C*			   |trace2|					*
C*									*
C*   OR									*
C*									*
C*  		            ( trace1 - trace2 )				*
C*   skill score =  -----------------------------------			*
C*			    ( prfct  - trace2 )				*
C*									*
C*									*
C* The result is stored in TRC (*,1).					*
C*									*
C* PLT_CDIF  ( ITYPE, PRFCT, MXPTS, NPTS, TRC, YMIN, YMAX, IRET )	*
C*									*
C* Input parameters:							*
C*	ITYPE		INTEGER		Type of difference		*
C*					 1 = simple difference		*
C*					 2 = % difference		*
C*					 3 = skill score		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	MXPTS		INTEGER		Maximum 1st dimension of TRC	*
C*	NPTS (*)	INTEGER		Number of points in traces	*
C*									*
C* Input and output paramters:						*
C*	TRC (MXPTS,*)	REAL		Trace data			*
C*									*
C* Output parameters:							*
C*	YMIN		REAL		Minimum diff or % diff		*
C*	YMAX		REAL		Maximum diff or % diff		*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-21 = different # of trc pts	*
C**									*
C* Log:									*
C* K. Brill		 1/99						*
C* K. Brill/HPC		 2/03	Added skill score computation		*
C* K. Brill/HPC      20081023	Use ABS in denom for % diff		*
C************************************************************************
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C!			  Missing value fuzziness
C*
	REAL		trc (MXPTS,*)
	INTEGER		npts (*)
C*
	LOGICAL ERMISS
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
	IF ( npts (1) .ne. npts (2) ) THEN
	    iret = -21
	    RETURN
	END IF
	ymin = 1.1E31
	ymax = -1.1E31
	DO i = 1, npts (1)
	    t1 = trc (i,1)
	    t2 = trc (i,2)
	    t3 = prfct - t2
	    IF ( .not. ERMISS (t1) .and. .not. ERMISS (t2) ) THEN
		trc (i,1) = ( t1 - t2 )
		IF ( .not. ERMISS (prfct) .and.
     +		     t3 .ne. .0 .and. itype .eq. 3 ) THEN
		    trc (i,1) = trc (i,1) / t3
		ELSE IF ( t2 .ne. .0 .and. itype .eq. 2 ) THEN
		    trc (i,1) = trc (i,1) * 100. / ABS (t2)
		ELSE IF ( itype .eq. 2 ) THEN
		    trc (i,1) = RMISSD
		ELSE IF ( itype .eq. 3 ) THEN
		    trc (i,1) = RMISSD
		END IF
	    ELSE
		trc (i,1) = RMISSD
	    END IF
	    IF ( .not. ERMISS ( trc (i,1 ) ) ) THEN
		IF ( trc (i,1) .gt. ymax ) ymax = trc (i,1)
		IF ( trc (i,1) .lt. ymin ) ymin = trc (i,1)
	    END IF
	END DO
C*
	RETURN
	END
