	SUBROUTINE PLT_CRPR ( mp, mt, ntrc, trc, xpts, npts, wrka, wrkb,
     +			      crps, rssk, reli, reso, uncr, cpot, ntro,
     +			      rplbl, xplbl, nplbl, dxmin, iret )
C************************************************************************
C* PLT_CRPR								*
C*									*
C* This subroutine computes the trace data for a CRPS reliability       *
C* diagram.	                                                        *
C*									*
C* There is one trace output for each trace input.  Each trace is a     *
C* quantile reliability curve.                                          *
C*									*
C* PLT_CRPR  ( MP, MT, NTRC, TRC, XPTS, NPTS, WRKA, CRPS, RSSK, RELI, 	*
C*             RESO, UNCR, CPOT, NTRO, RPLBL, XPLBL, NPLBL, DXMIN,	*
C*	       IRET )							*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	NTRC		INTEGER		Number of traces input		*
C*									*
C* Input and Output parameters:						*
C*	TRC (MP,MT)	REAL		Trace data			*
C*	XPTS (MP,MT)	REAL		x coordinates of trace points	*
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*	WRKA (MP)	REAL*8		Work scratch array		*
C*	WRKB (MP        REAL		Work scratch array		*
C*									*
C* Output parameters:							*
C*	CRPS (MT)	REAL		CRPS for traces	                *
C*	RSSK (MT)	REAL		Reli skill versus CRPSpot    	*
C*	RELI (MT)	REAL		Reliability components of CRPS	*
C*	RESO (MT)	REAL		Resolution components of CRPS	*
C*	UNCR (MT)	REAL		Uncertainty components of CRPS	*
C*	CPOT (MT)	REAL		Potential CRPS                  *
C*	NTRO		INTEGER		Number of traces output		*
C*	RPLBL (MP)	REAL		X axis labels			*
C*	XPLBL (MP)	REAL		X positions of axis labels	*
C*	NPLBL (MP)	REAL		Number of X axis labels		*
C*	DXMIN		REAL		Minimum X label spacing		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/IMSG     20160718	Created from PLT_CATT			*
C* K. Brill/IMSG     20170406   Modify XPTS to plot a interval midpts   *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999. )
C*
	REAL		trc (mp,mt), xpts (mp,mt), wrkb (*)
	REAL		rplbl (*), xplbl (*)
	REAL		crps (*), rssk (*), reli (*), reso (*), uncr (*)
	REAL		cpot (*)
	REAL*8		wrka (*)
	INTEGER		npts (*)
C*
	REAL*8		alfa, beta, xcpb, denom
C*
        LOGICAL         SAME
        SAME ( x, y ) = ( ABS ( x - y ) .lt. .00005 )
C*-----------------------------------------------------------------------
	iret = 0
	ntro = ntrc
	IF ( ntro .gt. mt ) THEN
	    iret = -32
	    RETURN
	END IF
C
C*	Compute the Scores first.
C
        nchk = 0
	DO it = 1, ntrc
	    npn = npts (it)
            icmx = 1 + ( npn - 6 ) / 2
            ncal = 0
	    DO i = 1, npn
		wrka (i) = trc (i,it)
                IF ( i .gt. 1 .and. i .le. icmx ) THEN
                    ncal = ncal + 1
C
C*                  The first x point (x=0) is skipped to build the
C*                  correct calibration array (see icmp = 2307 section
C*                  of rdtdtrc.f.
C
                    IF ( it .gt. 1 ) THEN
                        IF ( xpts (i,it) .ne. wrkb (ncal) ) THEN
                            WRITE (6,*) ' WARNING -- ',
     +                      ' CRPS traces have differing calibrations.'
                            WRITE (6,*)
     +                          ' Calibration of first trace used.'
                        END IF
                    ELSE
                        wrkb (ncal) = xpts (i,it)
                    END IF
                END IF
	    END DO
            IF ( nchk .ne. 0 ) THEN
                IF ( nchk .ne. ncal ) THEN
                    iret = -50
                    RETURN
                END IF
            ELSE
                nchk = ncal
            END IF
	    CALL CPB_CRPS ( 1, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                     wrkb, ncal, xcpb, zmn, zmx, ier )
	    crps (it) = xcpb
	    CALL CPB_CRPS ( 6, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      wrkb, ncal, xcpb, zmn, zmx, ier2 )
	    rssk (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_CRPS ( 3, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      wrkb, ncal, xcpb, zmn, zmx, ier2 )
	    reli (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_CRPS ( 4, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      wrkb, ncal, xcpb, zmn, zmx, ier2 )
	    reso (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_CRPS ( 5, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      wrkb, ncal, xcpb, zmn, zmx, ier2 )
	    uncr (it) = xcpb
	    ier = ier + ier2
	    CALL CPB_CRPS ( 2, 1, npn, npn, 1, 1, wrka, RMISSD,
     +                      wrkb, ncal, xcpb, zmn, zmx, ier2 )
	    cpot (it) = xcpb
	    ier = ier + ier2
	    IF ( ier .ne. 0 ) THEN
		iret = -48
		RETURN
	    END IF
	END DO
C
C*      Reset wrkb array to the x axis plot point values:
C
        nxp = ncal + 1
        DO WHILE ( nxp .gt. 1 )
            wrkb ( nxp ) = wrkb ( nxp - 1 )
            nxp = nxp - 1
        END DO
        wrkb (1) = 0.0
        nxp = ncal + 1
C*	
	DO it = 1, ntrc
	    npn = npts (it)
C
C*          Compute the frequencies for plotting.
C
            wrka (1) =  trc ( npn-2, it )
            wrka (nxp) = trc ( npn-1, it )
            inc = ( npn - 4 ) / 2
	    DO i = 2, nxp-1
                alfa = trc (i+1,it)
                ib = i + inc
                beta = trc (ib+1 ,it)
                denom = alfa + beta
                IF ( denom .gt. 0.0 ) THEN
                    wrka (i) = beta / denom
                ELSE
                    wrka (i) = 0.0
                END IF
            END DO
C
C*          Reset the trace values to obs frequencies.
C
	    npts (it) = nxp
            DO i = 1, nxp
                trc (i,it) = wrka (i)
            END DO
	END DO
C
C*      Set x-axis labels.
C
	dxmin = 1.E31
	DO j = 1, nxp
	    rplbl (j) = wrkb (j)
	    xplbl (j) = wrkb (j)
	    IF ( j .gt. 1 ) THEN
		dx = xplbl (j) - xplbl (j-1)
		IF ( dx .lt. dxmin ) dxmin = dx
	    END IF
	END DO
	nplbl = nxp
C
C*      Reset x points for plotting (values apply to mid-
C*      points of intervals).
C
	DO it = 1, ntrc
	    npn = npts (it)
            xpts(1,it) = xpts(2,it)
            DO j = 2, npn-1
                xpts (j,it) = .5 * ( xpts (j+1,it) + xpts (j,it) )
            END DO
        END DO
C*
	RETURN
	END
