	SUBROUTINE PLT_DRIV ( lungc, iplot, itrcs, ntrcs, method,
     +                        mdsply, iopcod, nopcod,
     +			      ismwnd, ismort, itype, lags, iret )
C************************************************************************
C* PLT_DRIV								*
C*									*
C* This subroutine drives the VSDB graphics software.			*
C*									*
C* This subroutine calls RDTD routines.  It is assumed that RDTD_INI	*
C* and RDTD_FND have already been called to load the RDTD data 		*
C* structure.								*
C*									*
C* The value of MDSPLY overrides the value of ITYPE when MDSPLY is	*
C* greater than 1.							*
C*									*
C* For a scatter plot, the first element of ITRCS is the number of the	*
C* trace providing abscissa values, the second element of ITRCS is the	*
C* number of the trace providing ordinate values.			*
C*									*
C* LAG is the intra-trace data combination count to be passed into	*
C* RDTD_TRC.								*
C*									*
C*									*
C* PLT_DRIV  ( LUNGC, IPLOT, ITRCS, NTRCS, METHOD, MDSPLY,		*
C*	       IOPCOD, NOPCOD, ISMWND, ISMORT, ITYPE, LAGS, IRET )	*
C*									*
C* Input parameters:							*
C*	LUNGC		INTEGER		Unit # for graphics cntrl file	*
C*	IPLOT		INTEGER		Plot number			*
C*	ITRCS (NTRCS)	INTEGER		Trace numbers (plt relative)	*
C*	NTRCS		INTEGER		Number of trace numbers		*
C*	METHOD		INTEGER		Display method:			*
C*					  1 - display plot as defined	*
C*					  2 - arbitrary traces & opcodes*
C*					      (an opcode for each trc)	*
C*					  3 - compute difference	*
C*					      between two traces for a	*
C*					      single opcode and display *
C*					  4 - compute % difference	*
C*					      between two traces for a	*
C*					      single opcode and display *
C*					  5 - compute skill score = 	*
C*					      (score - ref score) / 	*
C*					      (perf score - ref score)  *
C*					  6 - Statistical significance  *
C* 					      of difference between two *
C*					      time series.	 	*
C*	MDSPLY		INTEGER		Display type from user		*
C*					  1 - as defined		*
C*					  2 - make scatter plot		*
C*					  3 - make histogram		*
C*					  4 - force display as line plot*
C*					  5 - make ROC curve plot	*
C*					      METHOD must be 1 or 2 for *
C*					      time series plot		*
C*     					  6 - make attribute diagram    *
C*					      METHOD must be 1 or 2 for *
C*					      time series plot; comp	*
C*					      code must be 1360		*
C*     					  7 - make CRPS Reli diagram    *
C*					      METHOD must be 1 or 2 for *
C*					      time series plot; comp	*
C*					      code must be 2307		*
C*	IOPCOD (NOPCOD)	INTEGER		Operation code for RDTD_TRC	*
C*	NOPCOD		INTEGER		Number of Op Codes		*
C*	ISMWND		INTEGER		Running average window size	*
C*	ISMORT		INTEGER		Running avg window orientation	*
C*					  < 0 - window ends on points	*
C*					  = 0 - window centered on pts	*
C*					  > 0 - window starts on pts	*
C*	ITYPE		INTEGER		Type of plot			*
C*					  0 - print trace statistics 	*
C*					  1 - time series		*
C*					  2 - scatter plot		*
C*					  3 - skill score vs thrshlds	*
C*					  4 - bins			*
C*	LAGS (NOPCOD)	INTEGER		Intra-trace data combo counts	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +3 = cnts bins/thrshlds differ	*
C*					 +2 = # of bins/thrshlds diffrs	*
C*				 	  0 = normal return 		*
C*					 -3 = invalid plot type		*
C*					 -4 = invalid method		*
C*					 -5 = invalid scatter plot	*
C*					 -6 = RDTD error		*
C*					 -7 = final type is invalid	*
C*					 -8 = too many traces		*
C*					-20 = % diff scatter plot	*
C*					-22 = smooth window too big	*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 2/98	Generalized METHOD = 4			*
C* K. Brill/EMC		 4/98	Clean up / bug fixes			*
C* K. Brill/EMC		 8/98	METHOD=6				*
C* K. Brill/EMC		10/98	Add MDSPLY, simplify METHOD, ITYPE=0	*
C* K. Brill/EMC		11/98	Use nxcnt in data count loop		*
C* K. Brill/EMC		 1/99	Add smoothing; METHOD = 3; LAG; text	*
C*				dump					*
C* K. Brill/EMC		 4/99	Added code for trace averages		*
C* K. Brill/HPC		 2/00	Use errmsg for RDTD_TRC error print	*
C* K. Brill/HPC		 7/00	Get threshold cnts depending on OP code	*
C* K. Brill/HPC		 3/01	Changes for right-side y axis		*
C* K. Brill/HPC		 5/01	Add PLT_CRPF call			*
C* K. Brill/HPC		 2/03	Added Skill Score computation		*
C* K. Brill/HPC		 5/03	Add CALL PLT_GREF			*
C* K. Brill/HPC		 5/03	Change trace average to use data count	*
C*				as weight (count=1 for time series)	*
C* K. Brill/HPC		 6/03	Remove dumtrc from ERMISS--wrong type	*
C* K. Brill/HPC		 9/03	Changes for ROC curve display		*
C* K. Brill/HPC		12/03	Change to avoid using labels from a	*
C*				trace with all points missing		*
C* K. Brill/HPC		 3/04	Detect RDTD_TRC return iptyp = 14 for	*
C*				Talagrand diagrams			*
C* K. Brill/HPC		 5/04	rename tala to dorhd & talagd to dornkh *
C* K. Brill/HPC		 5/04	Allow different comp codes for method=5 *
C* K. Brill/HPC		 5/05   Detect iptyp = 24 for dpth fld trace	*
C* K. Brill/HPC		11/05	Initialize dorhd and dodd2 to false	*
C* K. Brill/HPC		 3/06	Initialize nxcnt before calling RDTD_TRC*
C*				for the means				*
C* K. Brill/HPC      20061201   Changes for significance test # 1	*
C* K. Brill/HPC	     20061222   Increase prmnam from 16 to 20 chars	*
C* K. Brill/HPC      20070302   Changes for attribute diagram		*
C* K. Brill/HPC	     20070619   CALL PLT_STRT rather than PLT_INIT	*
C*				before PLT_ZSIG with idvtx = 1		*
C* K. Brill/HPC      20080630   Add ipcnt to RDTD_TRC calling sequence  *
C* K. Brill/HPC      20081105   Allow individual combo lag #  per trace	*
C* K. Brill/HPC      20090514   Stat type returned in RDTD_TRC and	*
C*				passed to PLT_MLBL & PLT_GLBL		*
C* K. Brill/HPC	     20100728   Make avg & cno REAL*8 for trc pt avgs	*
C* K. Brill/HPC      20120316   Make changes for box-whisker displays   *
C* K. Brill/HPC      20120423   Box-whisker text output; close txt LUNs	*
C* K. Brill/HPC	     20120501   Fix single trace abort (knmucc = 0)	*
C* K. Brill/HPC      20120518   BXWSKR invalidity error for methods 3-5 *
C* K. Brill/HPC      20120626   Finalize calls to PLT_ERRO for box-whskr*
C* K. Brill/HPC      20130314   Detect box-whskr user error # 9		*
C* K. Brill/IMSG     20150827   Plot obs counts for iptype = 4 also     *
C* K. Brill/IMSG     20160720   Changes for quantile reliability diagram*
C* K. Brill/IMSG     20160722   Fix BARWTH calculation for IPTYPE = 8   *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( MXTRC = MXTRCS, MXPTS = MXDPTS )
	PARAMETER	( RMISSD = -9999., RDIFFD = 0.1 )
C*
	INTEGER		itrcs (*), iopcod (*), lags (*)
C*
	REAL*8		dumtrc (MXPTS), avg, cno
	REAL		dumpts (MXPTS)
	REAL		trc ( MXPTS, MXTRC ), cnt ( MXPTS, 2 )
	REAL		xpts ( MXPTS, MXTRC )
	REAL		xmin ( MXTRC), xmax ( MXTRC )
	REAL		ymin ( MXTRC), ymax ( MXTRC )
	REAL		rlbl ( MXPTS ), rplbl ( MXPTS ), xplbl ( MXPTS )
	REAL		avgs ( MXTRC ), bscr (MXTRC), bssk (MXTRC),
     +			reli ( MXTRC ), reso (MXTRC), uncr (MXTRC),
     +			sclm ( MXTRC )
	INTEGER		npts ( MXTRC )
	CHARACTER*24	clbl ( MXPTS ), cplbl ( MXPTS ), cstat
	CHARACTER*20	prmnam ( MXTRC ), prmdum
	CHARACTER*32	errmsg, ctmsv
	CHARACTER*1	cltyp, dltyp
	LOGICAL		stats, rfphg, dorhd, dodd2, libw, pltct
	LOGICAL		ERMISS
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*-----------------------------------------------------------------------
	iret = 0
	cstat = ' '
        ipcnt = -4
	stats = .true.
	rfphg = .false.
	dorhd = .false.
	dodd2 = .false.
	DO i = 1, MXTRC
	    avgs (i) = RMISSD
	    bscr (i) = RMISSD
	    bssk (i) = RMISSD
	    reli (i) = RMISSD
	    reso (i) = RMISSD
	    uncr (i) = RMISSD
	END DO
C
C*	Initialize common blocks.
C
	libw = .true.
	CALL PLT_INIT ( MXTRC, libw, ier )
C
C*	Get the data.
C
	numtrc = 0
	ibxplt = iplot
C*
        IF ( method .ge. 1 .and. method .le. 6 ) THEN
	    iptype = itype
	    nplbl = 0
	    icomp = iopcod (1)
	    numtrc = ntrcs
	    lbrk = 1
	    nbrk = 0
	    IF ( numtrc .gt. MXTRC ) THEN
		iret = -8
		RETURN
	    END IF
	    DO i = 1, ntrcs
		npts (i) = MXPTS
		itrc = itrcs (i)
		IF ( method .eq. 2 .or. method .eq. 5
     +              .or. method .eq. 6 ) icomp = iopcod (i)
C
C*		Do plot trace # and comp code arrangement settings
C*		and checks for box-whisker objects.
C
		CALL RDTD_OTN ( i, itrc, iotrc, ier )
		IF ( i .eq. 1 .and. ntrcs .gt. 1 ) THEN
		    ktrcnm (1) = iotrc
		    kopcod (1) = icomp
		    kntrcs = 1
		    knmucc = 1
		ELSE IF ( i .lt. ntrcs ) THEN
		    IF ( icomp .ne. kopcod (knmucc) ) THEN
			knmucc = knmucc + 1
			kopcod (knmucc) = icomp
		        IF ( i .eq. 2 ) THEN
			    nbxerr = nbxerr + 1
			    IF ( nbxerr .le. MAXERR ) THEN
			        ibxerr (nbxerr) = 1
			    END IF
			END IF
			IF ( nbrk .eq. 0 ) THEN
			    nbrk = i - lbrk
		        ELSE IF ( ( i - lbrk ) .ne. nbrk ) THEN
			    nbxerr = nbxerr + 1
			    IF ( nbxerr .le. MAXERR ) THEN
			    	ibxerr (nbxerr) = 2
			    END IF
			END IF
			lbrk = i
		    ELSE IF ( nbrk .eq. 0 ) THEN
			kntrcs = kntrcs + 1
			ktrcnm (kntrcs) = iotrc
		    ELSE
			jndx = MOD ( i, kntrcs )
			IF ( jndx .eq. 0 .or.
     +			     jndx .gt. MXTRCS ) THEN
			    jndx = kntrcs
			END IF
			IF ( ktrcnm (jndx) .ne. iotrc ) THEN
C
C*			    Set ibxclr to activate box-whisker error # 9.
C
			    ibxclr (i) = -1
			END IF
		    END IF
		ELSE IF ( i .eq. ntrcs ) THEN
		    IF ( knmucc .eq. 0 ) THEN
			nbxerr = nbxerr + 1
			IF ( nbxerr .le. MAXERR ) THEN
			    ibxerr (nbxerr) = 3
			END IF
C
C*			OTHERWISE . . .
C*		        Allow one trace left over with a different
C*		        comp code (e.g., event frequency):
C
		    ELSE IF ( icomp .ne. kopcod (knmucc) .and.
     +			 knmucc .eq. 1 ) THEN
C*			Do nothing.
		    ELSE IF ( icomp .ne. kopcod (knmucc) .and.
     +			      MOD (ntrcs,kntrcs) .eq. 1 ) THEN
C*			Do nothing.
		    ELSE IF ( icomp .ne. kopcod (knmucc) ) THEN
			nbxerr = nbxerr + 1
			IF ( nbxerr .le. MAXERR ) THEN
			        ibxerr (nbxerr) = 4
			END IF
		    ELSE IF ( nbrk .eq. 0 ) THEN
			kntrcs = kntrcs + 1
			ktrcnm (kntrcs) = iotrc
		    END IF
		    npairs = kntrcs - 1
		    IF ( npairs .le. 0 ) THEN
			nbxerr = nbxerr + 1
			IF ( nbxerr .le. MAXERR ) THEN
			    ibxerr (nbxerr) = 3
			END IF
		    END IF
		END IF
C*
		CALL RDTD_TRC ( itrc, icomp, lags(i), RMISSD, npts (i),
     +				xpts (1,i), dumtrc,
     +				xmin (i), xmax (i), ymin (i), ymax (i),
     +				clbl, rlbl, cltyp, iptyp,
     +				prmnam (i), prfct, ipcnt, cstat, iret )
		IF ( iptyp .eq. 14 ) THEN
		    iptype = 4
		    dorhd = .true.
		ELSE IF ( iptyp .eq. 24 ) THEN
		    iptype = 4
		    dodd2 = .true.
		END IF
		IF ( iret .ne. 0 ) THEN
		    WRITE (errmsg,1111) itrc
1111		    FORMAT ( 'TRACE #',I2.2,' error from RDTD_TRC:')
		    CALL RDTD_ERR ( iret, errmsg, ier )
		END IF
C*
		IF ( ( icomp .ne. 1360 .and. mdsply .eq. 6 ) .or.
     +               ( icomp .eq. 1360 .and. mdsply .ne. 6 ) ) THEN
		    iret = -31
		    CALL PLT_ERRO ( iret, ' ', ier )
		    RETURN
		END IF
		IF ( ( icomp .ne. 2307 .and. mdsply .eq. 7 ) .or.
     +               ( icomp .eq. 2307 .and. mdsply .ne. 7 ) ) THEN
		    iret = -47
		    CALL PLT_ERRO ( iret, ' ', ier )
		    RETURN
		END IF
		IF ( i .eq. 1 .and. icomp .eq. 1360 ) THEN
		    CALL ST_LSTR ( clbl (1), ln1, ier )
		    CALL ST_LSTR ( clbl (2), ln2, ier )
		    ctmsv = clbl (1) (1:ln1)
		    IF ( ln2 .gt. 0 ) THEN
			IF ( ln1 .gt. 10 ) ln1 = 10
			IF ( ln2 .gt. 10 ) ln2 = 10
			ctmsv = clbl (1)(1:ln1) // ' - ' //
     +				 clbl (2)(1:ln2)
		    END IF
		END IF
C*
		DO k = 1, npts (i)
		    trc (k,i) = dumtrc (k)
		END DO
C
C*		Apply running average smoothing.
C
		IF ( ismwnd .gt. 0 ) THEN
		    CALL PLT_SMTH ( trc (1,i), npts (i), ismwnd,
     +				    ismort, dumpts,
     +				    ymin (i), ymax (i), ier )
		    DO k = 1, npts (i)
			trc (k,i) = dumpts (k)
		    END DO
		END IF
C*
		IF ( iret .eq. 0 ) THEN
		    CALL PLT_XLBS ( MXPTS,
     +				    npts (i), xpts (1,i), clbl, rlbl,
     +				    nplbl, xplbl, cplbl, rplbl, ier )
		    IF ( ier .ne. 0 ) CALL PLT_ERRO ( ier, 'PLT_XLBS',
     +						      ierr )
		ELSE IF ( iret .lt. 0 ) THEN
		    iret = -6
		    CALL PLT_ERRO ( iret, ' ', ier )
		    RETURN
		END IF
C
C*		Get the data counts and compare.
C
		IF ( i .eq. 1 .and. itype .gt. 2 ) THEN
		    nxcnt = MXPTS
		    CALL RDTD_TRC ( itrc, 1, lags(i), RMISSD, nxcnt,
     +				    dumpts, dumtrc, xcmin, xcmax,
     +				    ycmin, ycmax, clbl, rlbl, dltyp,
     +				    iptyp, prmdum, qrfct, ipcnt,
     +				    cstat, iret )
		    IF ( iret .lt. 0 ) THEN
			CALL RDTD_ERR ( iret, 'RDTD_TRC', ier )
			iret = -6
			CALL PLT_ERRO ( iret, ' ', ier )
			RETURN
		    END IF
		    DO k = 1, nxcnt
			cnt (k,1) = dumtrc (k)
			cnt (k,2) = dumtrc (k)
		    END DO
		ELSE IF ( itype .gt. 2 ) THEN
		    nxx = MXPTS
		    CALL RDTD_TRC ( itrc, 1, lags(i), RMISSD, nxx,
     +				    dumpts, dumtrc, xcmin, xcmax,
     +				    ycmin, ycmax, clbl, rlbl, dltyp,
     +				    iptyp, prmdum, qrfct, ipcnt,
     +				    cstat,  iret )
		    IF ( iret .lt. 0 ) THEN
			CALL RDTD_ERR ( iret, 'RDTD_TRC', ier )
			iret = -6
			CALL PLT_ERRO ( iret, ' ', ier )
			RETURN
		    END IF
		    DO k = 1, nxx
			cnt (k,1) = dumtrc (k)
		    END DO
		    IF ( nxcnt .ne. nxx ) THEN
			iret = +2
			CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		    ELSE
			ifnd = 0
		        DO j = 1, nxx
			    IF ( cnt (j,1) .ne. cnt (j,2) ) THEN
				ifnd = ifnd + 1
			    END IF
			END DO
			IF ( ifnd .ne. 0 ) THEN
			    iret = +3
			    CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
			END IF
		    END IF
		END IF
C*		    
	    END DO
C*
	ELSE
	    iret = -4
	    CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	    RETURN
C*
	END IF
	IF ( mdsply .eq. 0 ) THEN
	    CALL PLT_INIT ( numtrc, libw, ier )
	    CALL PLT_MLBL ( numtrc, itrcs, prmnam, mdsply, method,
     +			    rfphg, cstat, iret )
	    CALL PLT_STAT ( MXPTS, MXTRC,
     +			    numtrc, trc, npts, iret )
	    RETURN
	END IF
	IF ( mdsply .eq. 6 ) THEN
C
C*	    All processing for the attributes diagram is in this block.
C
	    iptype = 7
C
C*	    Compute the 2*numtrc traces needed for the plot.
C*          The avgs are Brier scores.
C
	    CALL PLT_CATT ( MXPTS, MXTRC, numtrc, trc, xpts, npts,
     +                      dumtrc, dumpts, bscr, bssk, reli, reso,
     +			    uncr, sclm, ntrc, rplbl, xplbl, nplbl,
     +			    dxmin, iret )
	    IF ( iret .lt. 0 ) THEN
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
C*
	    itx = 0
	    CALL PLT_STRT ( lungc, cplbl, xplbl, nplbl, xmin, xmax,
     +			    ymin, ymax, ntrc, iptype, itx, iret )
	    IF ( iret .lt. 0 ) THEN
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
C*
	    DO i = 1, numtrc
		j = i + numtrc
		prmnam (j) = prmnam (i)
		itrcs (j) = i
	    END DO
	    ctmrng = ctmsv
	    CALL PLT_MLBL ( ntrc, itrcs, prmnam, iptype, method,
     +			    rfphg, cstat, iret )
	    IF ( iret .lt. 0 ) THEN
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
C*
	    IF ( luntxt .eq. 0 ) THEN
C
C*	        Display the labels.
C
	        CALL PLT_GLBL ( ntrc, avgs, bscr, bssk, reli, reso, uncr,
     +			        sclm, iptype, method, ipcnt, cstat, iret )
	        IF ( iret .ne. 0 ) THEN
	            CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	        END IF
C
C*	        Set the graph coordinates and draw axes.
C
	        CALL PLT_GAXS ( iptype, cltyp, cplbl, rplbl, xplbl, nplbl,
     +			        cnt, nxcnt, cstat, iret )
	        IF ( iret .ne. 0 ) THEN
	            CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	        END IF
C
C*	        Plot the traces.
C
	        barwth = dxmin / ( FLOAT ( ntrc / 2 ) + 1.0 )
	        CALL PLT_GTRC ( MXPTS, MXTRC,
     +			        ntrc, trc, xpts, npts, iret )
	        IF ( iret .ne. 0 ) THEN
	            CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	        END IF
C
C*	        Overlay the reference lines.
C
	        CALL PLT_ADRL ( sclm (1), iret )
	        IF ( iret .ne. 0 ) THEN
	            CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	        END IF
C*
	        CALL PLT_GFIN ( iret )
C*
	    ELSE
	        CALL PLT_TEXT ( MXPTS, MXTRC,
     +			        ntrc, trc, xpts, npts,
     +			        cltyp, cplbl, rplbl, xplbl, nplbl,
     +                          bscr, bssk, reli, reso, uncr,
     +			        sclm, iptype, ier )
	        IF ( ier .ne. 0 ) CALL PLT_ERRO ( ier, 'PLT_TEXT',
     +						  ierr )
	        CLOSE (UNIT=luntxt)
		CLOSE (UNIT=lunbxw, STATUS='DELETE')
	    END IF
	    RETURN
	END IF
C*
	IF ( mdsply .eq. 7 ) THEN
C
C*	    All processing for the CRPS Reli diagram is in this block.
C*          This is the quantile reliability diagram.
C
	    iptype = 8
C
C*	    Compute the numtrc traces needed for the plot.
C
C*          Output array key:
C*              bscr = CRPS = $RPS
C*              bssk = CRPS skill versus uncertaintly = $RSK
C*              reli = CRPS reliability = $REL
C*              reso = CRPS resolution = $RES
C*              uncr = CRPS uncertaintly estimate = $UNC
C*              sclm = Potential CRPS (CRPSpot) = $POT
C
	    CALL PLT_CRPR ( MXPTS, MXTRC, numtrc, trc, xpts, npts,
     +                      dumtrc, dumpts, bscr, bssk, reli, reso,
     +			    uncr, sclm, ntrc, rplbl, xplbl, nplbl,
     +			    dxmin, iret )
	    IF ( iret .lt. 0 ) THEN
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
C*
	    itx = 0
	    CALL PLT_STRT ( lungc, cplbl, xplbl, nplbl, xmin, xmax,
     +			    ymin, ymax, ntrc, iptype, itx, iret )
	    IF ( iret .lt. 0 ) THEN
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
C*
	    CALL PLT_MLBL ( ntrc, itrcs, prmnam, iptype, method,
     +			    rfphg, cstat, iret )
	    IF ( iret .lt. 0 ) THEN
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
C*
	    IF ( luntxt .eq. 0 ) THEN
C
C*	        Display the labels.
C
	        CALL PLT_GLBL ( ntrc, avgs, bscr, bssk, reli, reso, uncr,
     +			        sclm, iptype, method, ipcnt, cstat, iret )
	        IF ( iret .ne. 0 ) THEN
	            CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	        END IF
C
C*	        Set the graph coordinates and draw axes.
C
	        CALL PLT_GAXS ( iptype, cltyp, cplbl, rplbl, xplbl, nplbl,
     +			        cnt, nxcnt, cstat, iret )
	        IF ( iret .ne. 0 ) THEN
	            CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	        END IF
C
C*	        Plot the traces.
C
	        barwth = dxmin / ( FLOAT ( ntrc ) + 1.0 )
	        CALL PLT_GTRC ( MXPTS, MXTRC,
     +			        ntrc, trc, xpts, npts, iret )
	        IF ( iret .ne. 0 ) THEN
	            CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	        END IF
C
C*	        Plot user defined line segment.
C
	        IF ( iret .ge. 0 ) CALL PLT_GREF ( iret )
C*
	        CALL PLT_GFIN ( iret )
C*
	    ELSE
	        CALL PLT_TEXT ( MXPTS, MXTRC,
     +			        ntrc, trc, xpts, npts,
     +			        cltyp, cplbl, rplbl, xplbl, nplbl,
     +                          bscr, bssk, reli, reso, uncr,
     +			        sclm, iptype, ier )
	        IF ( ier .ne. 0 ) CALL PLT_ERRO ( ier, 'PLT_TEXT',
     +						  ierr )
	        CLOSE (UNIT=luntxt)
		CLOSE (UNIT=lunbxw, STATUS='DELETE')
	    END IF
	    RETURN
	END IF
C*
	IF ( method .eq. 6 ) THEN
C
C*          Display text page of statistical significance analysis.
C
	    itx = 1
	    CALL PLT_STRT ( lungc, cplbl, xplbl, nplbl, xmin, xmax,
     +			    ymin, ymax, numtrc, iptype, itx, iret )
	    CALL PLT_MLBL ( numtrc, itrcs, prmnam, mdsply, method,
     +			    rfphg, cstat, iret )
	    CALL PLT_ZSIG ( MXPTS, MXTRC,
     +			    numtrc, trc, npts, prmnam, 
     +                      clbl(1), clbl(npts(1)), iret )
	    IF ( iret .ne. 0 ) THEN
	        CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	    END IF
	    RETURN
	END IF
C
C*	Compute % difference.
C
	IF ( method .eq. 3 .or. method .eq. 4 .or.
     +       method .eq. 5 ) THEN
	    IF ( mdsply .eq. 2 .or. mdsply .eq. 5 .or.
     +		( mdsply .eq. 1 .and. itype .eq. 2 ) ) THEN
		iret = -20
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
	    IF ( method .eq. 3 ) THEN
		idtyp = 1
	    ELSE IF ( method .eq. 4 ) THEN
		idtyp = 2
	    ELSE IF ( method .eq. 5 ) THEN
		idtyp = 3
	    END IF
	    CALL PLT_CDIF ( idtyp, prfct, MXPTS, npts, trc,
     +			    ymin, ymax, iret )
	    IF ( iret .ne. 0 ) THEN
		CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
		RETURN
	    END IF
	    numtrc = 1
	    IF ( bxwflg ) THEN
		nbxerr = nbxerr + 1
		IF ( nbxerr .le. MAXERR ) THEN
		    ibxerr (nbxerr) = 8
		END IF
		bxwflg = .false.
	    END IF
	END IF
	IF ( method .eq. 2 .and. mdsply .eq. 3 .and. numtrc .gt. 1 )
     +	THEN
	    CALL PLT_CRPF ( MXPTS, MXTRC, numtrc, npts, trc,
     +			    iret )
	    IF ( iret .ne. 0 ) RETURN
	    stats = .false.
	    rfphg = .true.
	    ymin (1) = 0.
	    ymax (1) = FLOAT (numtrc) + 1.0
	    xmin (1) = 0.0
	    xmax (1) = 1.0
	    numtrc = 1
	END IF
C
C*	Reset display plot type using MDSPLY value.
C
	IF ( mdsply .eq. 2 ) THEN
	    iptype = 2
	ELSE IF ( mdsply .eq. 3 ) THEN
	    iptype = 5
	ELSE IF ( mdsply .eq. 4 ) THEN
	    iptype = 1
	    IF ( iptyp .ne. 2 ) THEN
		WRITE (6,*) ' WARNING -- plot is not a scatter plot.'
	    END IF
	ELSE IF ( mdsply .eq. 5 ) THEN
	    iptype = 6
	ELSE IF ( mdsply .le. 0 .or. mdsply .gt. 3 ) THEN
	    iret = -3
	    CALL PLT_ERRO ( iret, 'PLT_DRIV', ier )
	    RETURN
	END IF
C
C*	From the work above the following are defined now:
C*
C*	NUMTRC = number of traces to plot
C*	IPTYPE = type of plot (1=time series, 2=scatter, 3=skill
C*		 score vs threshold, 4=bins, and 5=histogram)
C*	CNT(1,1) = Data counts
C*	PRMNAM (*) = parameters names for each trace
C
C*	Load the plot control data structure, initialize graphics,
C*	and start the device driver.
C
	itx = 0
	CALL PLT_STRT ( lungc, cplbl, xplbl, nplbl, xmin, xmax,
     +			ymin, ymax, numtrc, iptype, itx, iret )
	IF ( iret .ne. 0 ) RETURN
	dornkh = dorhd
	dodd2t = dodd2
C
C*	Apply scaling if needed.
C
	IF ( sfctor .ne. 1.0 ) THEN
	    DO i = 1, numtrc
		IF ( .not. rhttrc (i) ) THEN
		    DO k = 1, npts (i)
		        IF ( .not. ERMISS ( trc (k,i) ) )
     +			  trc (k,i) = sfctor * trc (k,i)
		    END DO
		END IF
	    END DO
	END IF
	IF ( rfctor .ne. 1.0 ) THEN
	    DO i = 1, numtrc
		IF ( rhttrc (i) ) THEN
		    DO k = 1, npts (i)
		        IF ( .not. ERMISS ( trc (k,i) ) )
     +			  trc (k,i) = rfctor * trc (k,i)
		    END DO
		END IF
	    END DO
	END IF
C
C*	Make the labels first.
C
	CALL PLT_MLBL ( numtrc, itrcs, prmnam, iptype, method, rfphg,
     +			cstat, iret )
C*
        pltct = ( INDEX ( cstat, 'FHO' ) .gt. 0 )
	IF ( ( iptype .eq. 3 .or. iptype .eq. 4 ) .and. pltct ) THEN
C
C*	    Get the data counts from first trace.
C
	    IF ( iopcod (1) .eq. 1009 ) THEN
		ipos = -2
	    ELSE IF ( iopcod (1) .eq. 1010 ) THEN
		ipos = -3
	    ELSE IF ( iopcod (1) .eq. 1012 ) THEN
		ipos = -2
	    ELSE IF ( iopcod (1) .eq. 1013 ) THEN
		ipos = -3
	    ELSE
		ipos = ipcnt
	    END IF
	    nxcnt = MXPTS
	    CALL RDTD_TRC ( itrcs (1), ipos, lags(1), RMISSD, nxcnt,
     +			cnt, dumtrc,
     +			xcmin, xcmax, ycmin, ycmax,
     +			clbl, rlbl, dltyp, iptyp,
     +			prmdum, prfct, ipcnt, cstat, iret )
	    DO k = 1, nxcnt
		cnt (k,1) = dumtrc (k)
	    END DO
	END IF
C*
	IF ( luntxt .eq. 0 ) THEN
C
C*	    Plot the labels first.  PLT_GLBL sets the margins
C*	    for the graph.
C
C*	    First compute the trace count-weighted means (if needed).
C
	    DO i = 1, numtrc
		IF ( ltravg (i) ) THEN
		    nxcnt = MXPTS
		    CALL RDTD_TRC ( itrcs (i), 1, lags(i), RMISSD,
     +				    nxcnt, dumpts, dumtrc,
     +				    xcmin, xcmax, ycmin, ycmax,
     +				    clbl, rlbl, dltyp, iptyp,
     +				    prmdum, prfct, ipcnt,
     +				    cstat, iret )
		    avg = 0.0
		    cno = 0.0
		    DO k = 1, npts (i)
			ddd = dumtrc (k)
			IF ( .not. ERMISS ( trc (k,i) ) .and.
     +			     .not. ERMISS ( ddd ) ) THEN
			    avg = avg + dumtrc (k) * trc (k,i)
			    cno = cno + dumtrc (k)
			END IF
		    END DO
		    IF ( cno .gt. 0 ) THEN
			avgs (i) = avg / cno
		    ELSE
			avgs (i) = RMISSD
		    END IF
		END IF
	    END DO
	    CALL PLT_GLBL ( numtrc, avgs, bscr, bssk, reli, reso, uncr,
     +			    sclm, iptype, method, ipcnt, cstat, iret )
C
C*	    Draw the axes and border.  PLT_GAXS sets the
C*	    graph coordinates.
C
	    CALL PLT_GAXS ( iptype, cltyp, cplbl, rplbl, xplbl, nplbl,
     +			    cnt, nxcnt, cstat, iret )
C
C
C*	    Plot the data.
C
	    IF ( iptype .eq. 1 ) THEN
		CALL PLT_GTRC ( MXPTS, MXTRC,
     +				numtrc, trc, xpts, npts, iret )
	    ELSE IF ( iptype .eq. 2 ) THEN
		IF ( numtrc .ne. 2 ) THEN
		    iret = -5
		    CALL PLT_ERRO ( iret, ' ', ier )
		    RETURN
		END IF
		CALL PLT_GSCT ( MXPTS, MXTRC, trc, xpts, npts, iret )
	    ELSE IF ( iptype .eq. 3 ) THEN
		CALL PLT_GTRC ( MXPTS, MXTRC,
     +				numtrc, trc, xpts, npts, iret )
C
C*		Overlay box-whisker objects:
C
		CALL PLT_OBXW ( MXPTS, MXTRC,
     +				numtrc, trc, xpts, npts, iret )
C#		CALL PLT_ERRO ( iret, 'AFTER PLT_OBXW 3', ier )
		IF ( iret .eq. 0 ) THEN
		    CALL PLT_GBXA  ( iret )
		    IF ( iret .ne. 0 ) THEN
		        CALL PLT_ERRO ( iret, ' ', ier )
			iret = 0
		    END IF
		END IF
	    ELSE IF ( iptype .eq. 4 ) THEN
		CALL PLT_GTRC ( MXPTS, MXTRC,
     +				numtrc, trc, xpts, npts, iret )
C
C*		Overlay box-whisker objects:
C
		CALL PLT_OBXW ( MXPTS, MXTRC,
     +				numtrc, trc, xpts, npts, iret )
C#		CALL PLT_ERRO ( iret, 'AFTER PLT_OBXW 4', ier )
		IF ( iret .eq. 0 ) THEN
		    CALL PLT_GBXA  ( iret )
		    IF ( iret .ne. 0 ) THEN
		        CALL PLT_ERRO ( iret, ' ', ier )
			iret = 0
		    END IF
		END IF
	    ELSE IF ( iptype .eq. 5 ) THEN
		CALL PLT_GHIS ( trc, npts, stats, iret )
	    ELSE IF ( iptype .eq. 6 ) THEN
		CALL PLT_GTRC ( MXPTS, MXTRC,
     +				numtrc, trc, xpts, npts, iret )
	    ELSE
		iret = -7
		CALL PLT_ERRO ( iret, ' ', ier )
	    END IF
C
C*	    Plot user defined line segment.
C
	    IF ( iret .ge. 0 ) CALL PLT_GREF ( iret )
	    IF ( iret .ne. 0 ) THEN
		CALL PLT_ERRO ( iret, ' ', ierr )
		iret = ierr
	    END IF
C*
	    CALL PLT_GFIN ( iret )
	ELSE
	    CALL PLT_TEXT ( MXPTS, MXTRC,
     +			    numtrc, trc, xpts, npts,
     +			    cltyp, cplbl, rplbl, xplbl, nplbl,
     +                      bscr, bssk, reli, reso, uncr,
     +			    sclm, iptype, ier )
	    IF ( ier .ne. 0 ) CALL PLT_ERRO ( ier, 'PLT_TEXT',
     +						      ierr )
	    CLOSE (UNIT=luntxt)
	    ier = 0
	    IF ( bxwflg ) THEN
		CALL PLT_TBXW ( MXPTS, MXTRC, numtrc, trc, npts, ier )
	        CLOSE (UNIT=lunbxw)
	    ELSE
		CLOSE (UNIT=lunbxw, STATUS='DELETE')
	    END IF
	    IF ( ier .ne. 0 ) CALL PLT_ERRO ( ier, 'PLT_TBXW',
     +						      ierr )
	END IF
	CALL PLT_BXER ( ier )
C*	
	RETURN
	END
