        SUBROUTINE PLT_GAXS ( iptype, cltyp, cplbl, rplbl, xplbl, nplbl,
     +                        cnt, nxcnt, cstat, iret )
C************************************************************************
C* PLT_GAXS								*
C*									*
C* This subroutine draws the axes and border for a plot.		*
C*									*
C* PLT_GAXS  ( IPTYPE, CLTYP, CPLBL, PLBL, XPLBL, NPLBL, CNT,		*
C*             NXCNT, CSTAT, IRET )					*
C*									*
C* Input parameters:							*
C*	IPTYPE		INTEGER		Type of plot			*
C*					  0 - print trace statistics	*
C*					  1 - time series		*
C*					  2 - scatter plots		*
C*					  3 - skill score vs thresholds	*
C*					  4 - bins			*
C*					  5 - histogram			*
C*					  6 - ROC curve			*
C*					  7 - attributes diagram	*
C*                                        8 - CRPS RELI diagram         *
C*	CLTYP		CHAR*1		x axis label type		*
C*					  c = character			*
C*					  r = real			*
C*					  t = character time stamps	*
C*	CPLBL (NPLBL)	CHAR*		Character axis labels		*
C*	RPLBL (NPLBL)	REAL		Real axis labels		*
C*	XPLBL (NPLBL)	REAL		x positions of labels		*
C*	NPLBL		INTEGER		Number of labels		*
C*	CNT   (NXCNT)	REAL		Data counts			*
C*	NXCNT		INTEGER		Number of data counts		*
C*	CSTAT		CHAR*		Statistic type			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-17 = wrong # of data counts	*
C*					-18 = wrong lbl type for t ser  *
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98						*
C* K. Brill/EMC		 2/98	Make evenly spaced time axis labels	*
C* K. Brill/EMC		 4/98	Clean up / bug fixes			*
C* K. Brill/EMC		 5/98	User defined x axis labels		*
C* K. Brill/EMC		10/98	CALL PLT_MTAX				*
C* K. Brill/EMC		 1/99	Fix inifinite DO WHILE loops		*
C* K. Brill/EMC		 4/99	Changes for reversed AXES		*
C* K. Brill/HPC		01/00	Add HARDWR to PLT_GTXT call		*
C* K. Brill/HPC		 3/01	Changes for right-side yaxis; always	*
C*				allow user-supplied char x axis tic lbls*
C* K. Brill/HPC		 9/03	Changes for ROC curve IPTYPE = 6	*
C* K. Brill/HPC		12/03	If CNT is missing (< 0), set it to MSSNG*
C* K. Brill/HPC      20070124   Changes for attribute diagram		*
C* K. Brill/HPC	     20070618   Draw axis only if ichk > 0; plot obs	*
C*				counts as xxEnn if > 99,999 or 999,999	*
C* K. Brill/HPC      20090515   Plot data cnt values only if CSTAT	*
C*				contains FHO				*
C* K. Brill/IMSG     20150827   Plot obs counts for iptype = 4 also     *
C* K. Brill/IMSG     20160721   Check for IPTYPE = 8                    *
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	REAL		rplbl (*), xplbl (*), cnt (*)
	CHARACTER*(*)	cplbl (*), cltyp, cstat
C*
	LOGICAL		hardwr, pltct
	CHARACTER*24	cxlbl ( MAXVAL )
	CHARACTER	frmt*12, clft*4, crht*4
	REAL		xtics (MXDPTS), cxpos ( MAXVAL ), xb (5), yb (5)
C*------------------------------------------------------------------------
	iret = 0
	pltct = ( INDEX ( cstat, 'FHO' ) .gt. 0 )
C
C*	Check for # of counts same as # of x axis labels when IPTYPE = 3.
C
	IF ( ( iptype .eq. 3 .or. iptype .eq. 4 ) .and. pltct ) THEN
	    IF ( nplbl .ne. nxcnt ) THEN
		iret = -17
		RETURN
	    END IF
	END IF
C
C*	Set up graph coordinates.
C
	IF ( revers ) THEN
	    CALL GSGRAF ( iyaxis, 1, aspect, yaxbeg, xaxbeg,
     +		          yaxend, xaxend, ierrg )
	    ione = 2
	    itwo = 1
	    i3 = 4
	ELSE
	    CALL GSGRAF ( 1, iyaxis, aspect, xaxbeg, yaxbeg,
     +		          xaxend, yaxend, ierrg )
	    ione = 1
	    itwo = 2
	    i3 = 3
	END IF
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C
C*	Set axis label text.
C
	CALL PLT_GTXT ( tcslab, hardwr, ier )
C
C*	Set border color and line type.
C
	CALL PLT_GBDR  ( iclrsv, ier )
	ichk = iclrsv
C
C*	Process X axis information.
C
	IF ( iptype .eq. 1 ) THEN
	    IF ( cltyp .ne. 't' ) THEN
		iret = -18
		RETURN
	    ELSE
		nxlbl = MAXVAL
		ntics = MXDPTS
		CALL PLT_MTAX ( cplbl, xplbl, nplbl, nxlbl, ntics,
     +				cxlbl, cxpos, xtics, ier )
		IF ( ichk .gt. 0 )
     +		CALL GAAXIS ( ione, yaxbeg, .true., ilbfrx, itmfrx,
     +			      iglfrx, nxlbl, cxpos, cxlbl, ierrg )
		IF ( ntics .gt. 0 ) THEN
C
C*		    Draw tic marks.
C
		    IF ( ichk .gt. 0 )
     +		    CALL GAAXIS ( ione, yaxbeg, .true., 0, 1, 0,
     +				  ntics, xtics, cxlbl, ierrg )
		END IF
	    END IF
C*
	ELSE IF ( iptype .eq. 2 .or. iptype .eq. 5 .or.
     +		  iptype .eq. 6 .or. iptype .eq. 7 .or.
     +            iptype .eq. 8 ) THEN
	    IF ( ichk .gt. 0 )
     +	    CALL GDAXIS ( ione, yaxbeg, .true., ilbfrx, itmfrx,
     +			  iglfrx, -1, nxaxvl, xaxval, ierrg )
C*
	ELSE IF ( iptype .eq. 4 .and. naxudl .gt. 0 ) THEN
	    nax = MIN ( naxudl, nplbl )
	    IF ( ichk .gt. 0 )
     +	    CALL GAAXIS ( ione, yaxbeg, .true., ilbfrx, itmfrx,
     +			  iglfrx, nax, xplbl, xaxudl, ierrg )
	ELSE
C
C*	    Use labels from the trace data file.
C
	    IF ( cltyp .eq. 'r' ) THEN
C
C*		Build an array of label strings for GAAXIS.
C
		rmax = -1.E31
		rmin =  1.E31
		DO i = 1, nplbl
		    IF ( rplbl (i) .gt. rmax ) rmax = rplbl (i)
		    IF ( rplbl (i) .lt. rmin ) rmin = rplbl (i)
		END DO
		df = ( rmax - rmin ) / FLOAT ( nplbl )
		idec = 0
		DO WHILE ( df .lt. 1.0 .and. df .ne. 0. )
		    df = df * 10.
		    idec = idec + 1
		END DO
		IF ( idec .gt. 5 ) THEN
		    frmt = '(1PE11.4)'
		ELSE
		    ilft = 0
		    q = rmax
		    DO WHILE ( q .gt. 1.0 .and. q .ne. 0. )
			q = q / 10.
			ilft = ilft + 1
		    END DO
		    itot = ilft + idec + 2
		    CALL ST_INCH ( itot, clft, ier )
		    CALL ST_LSTR ( clft, ll, ier )
		    CALL ST_INCH ( idec, crht, ier )
		    CALL ST_LSTR ( crht, lr, ier )
		    frmt = '(F' // clft (1:ll) // '.' //
     +				   crht (1:lr) // ')'
		END IF
		i = 0
		DO WHILE ( i .lt. maxval .and. i .lt. nplbl )
		    i = i + 1
		    WRITE (cxlbl(i),frmt) rplbl (i)
		    CALL ST_RMBL ( cxlbl (i), cxlbl (i), lnx, ier )
		    cxpos (i) = xplbl (i)
		END DO
	        IF ( ichk .gt. 0 )
     +		CALL GAAXIS ( ione, yaxbeg, .true., ilbfrx, itmfrx,
     +			      iglfrx, i, cxpos, cxlbl, ierrg )
	    ELSE IF ( naxudl .eq. 0 ) THEN
		DO i = 1, nplbl
		    CALL ST_RMBL ( cplbl (i), cxlbl (i), lnx, ier )
		END DO
	        IF ( ichk .gt. 0 )
     +		CALL GAAXIS ( ione, yaxbeg, .true., ilbfrx, itmfrx,
     +			      iglfrx, nplbl, xplbl, cxlbl, ierrg )
	    ELSE
		nax = MIN ( naxudl, nplbl )
	        IF ( ichk .gt. 0 )
     +		CALL GAAXIS ( ione, yaxbeg, .true., ilbfrx, itmfrx,
     +			      iglfrx, nax, xplbl, xaxudl, ierrg )
	    END IF
	END IF
C
C*	Do the count axis for the skill score plot.
C
	IF ( ( iptype .eq. 3 .or. iptype .eq. 4 ) .and. ierrg .eq. 0
     +       .and. ichk .gt. 0 .and. pltct ) THEN
	    IF ( nxcnt .le. 8 ) THEN
		cov = 1.E06
	    ELSE
		cov = 1.E05
	    END IF
	    i = 0
	    DO WHILE ( i .lt. maxval .and. i .lt. nxcnt )
		i = i + 1
		IF ( cnt (i) .lt. cov ) THEN
		    icnt = NINT ( cnt (i) )
		    IF ( icnt .ge. 0 ) THEN
		        WRITE (cxlbl(i),'(I7)') icnt
		    ELSE
		        cxlbl(i) = 'MSSNG'
		    ENDIF
		ELSE
        	    ip = INT ( ALOG10 ( cnt(i) ) )
		    rman = cnt(i) / 10. ** ip
		    iman = NINT ( rman * 10 )
		    IF ( iman .ge. 100 ) THEN
	    	 	ip = ip + 1
	    	 	iman = iman / 10
		    END IF
		    rman = FLOAT (iman) / 10.
		    iman = NINT (rman * 10.)
		    ip = ip - 1
		    WRITE (cxlbl(i),'(I2.2,A1,I2.2)') iman, 'E', ip
		END IF
		CALL ST_RMBL ( cxlbl (i), cxlbl (i), lnx, ier )
		cxpos (i) = xplbl (i)
	    END DO
     	    CALL GAAXIS ( i3, yaxend, .false., ilbfrx, 0,
     +			  iglfrx, i, cxpos, cxlbl, ierrg )
     	    CALL GAAXIS ( ione, yaxend, .true., 0, itmfrx,
     +			  iglfrx, i, cxpos, cxlbl, ierrg )
	END IF
C
C*	Draw the y axses.
C
	IF ( ierrg .eq. 0 ) THEN
	    IF ( ichk .gt. 0 )
     +	    CALL GDAXIS ( itwo, xaxbeg, .true., ilbfry, itmfry,
     +			  iglfry, -1, nyaxvl, yaxval, ierrg )
	    IF ( rhtdrw ) THEN
		CALL GSGRAF ( 1, iyrxis, aspect, xaxbeg, yrxbeg,
     +			      xaxend, yrxend, ierrg )
	        IF ( ichk .gt. 0 )
     +		CALL GDAXIS ( 4, xaxend, .true., ilrfry, itrfry,
     +			      igrfry, -1, nyrxvl, yrxval, ierrg )
		CALL GSGRAF ( 1, iyaxis, aspect, xaxbeg, yaxbeg,
     +			      xaxend, yaxend, ierrg )
	    END IF
	END IF
C
C*	Complete the box around the plot.
C
	IF ( ichk .gt. 0 ) THEN
	  IF ( ierrg .eq. 0 .and. revers ) THEN
	    xb (1) = yaxbeg
	    yb (1) = xaxbeg
	    xb (2) = yaxend
	    yb (2) = xaxbeg
	    xb (3) = yaxend
	    yb (3) = xaxend
	    xb (4) = yaxbeg
	    yb (4) = xaxend
	    xb (5) = yaxbeg
	    yb (5) = xaxbeg
	    CALL GLINE ( 'M', 5, xb, yb, ierrg )
	  ELSE IF ( ierrg .eq. 0 ) THEN
	    xb (1) = xaxbeg
	    yb (1) = yaxbeg
	    xb (2) = xaxend
	    yb (2) = yaxbeg
	    xb (3) = xaxend
	    yb (3) = yaxend
	    xb (4) = xaxbeg
	    yb (4) = yaxend
	    xb (5) = xaxbeg
	    yb (5) = yaxbeg
	    CALL GLINE ( 'M', 5, xb, yb, ierrg )
	  END IF
	END IF
C*
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    IF ( iclrsv .gt. 0 ) CALL GSCOLR ( iclrsv, ier )
	    RETURN
	END IF

	IF ( iclrsv .gt. 0 ) CALL GSCOLR ( iclrsv, ier )
C*
	RETURN
	END
