	SUBROUTINE PLT_GBXA  ( iret )
C************************************************************************
C* PLT_GBXA								*
C*									*
C* This subroutine displays the box-whisker annotation text box.	*
C*									*
C* The relevant control file entry is formatted as follows:		*
C*									*
C*	B_TEXT = color/x;y/size;font;width;HWSW/flag			*
C*									*
C* PLT_GBXA  ( IRET )							*
C*									*
C* Output parameter:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-43 -> -45 = errors		*
C**									*
C* Log:									*
C* K. Brill/HPC		 6/12						*
C* K. Brill/HPC      20120622	Complete first version			*
C* K. Brill/HPC      20120626   Move default position up 2 char hghts	*
C* K. Brill/HPC      20120627   RETURN if .not. bxwflg			*
C* K. Brill/IMSG     20150512   Change confidence text                  *
C* K. Brill/IMSG     20151222   Keep "BOX CONF INT" if wskflg is true   *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1 )
C*
	REAL		xarr (2), yarr (2)
	CHARACTER*5	cbxci, cnsmp
	CHARACTER*42	cbxc

C*
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
C
C*	If color number is zero, do not do anything.
C
	IF ( itxclr .le. 0 ) RETURN
	IF ( .not. bxwflg ) RETURN
C
C*	Set border color.
C
	CALL GQCOLR ( iclrs, ier )
	CALL GSCOLR ( itxclr, ier )
C
C*	Set border line attributes.
C
	CALL GSLINE ( 1, 0, 1, 0, ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    CALL GSCOLR ( iclrs, ier )
	    RETURN
	END IF
C
C*	Set text attributes:
C
	CALL GQTEXT ( itf, ith, szt, itw, itb, itr, itj, ier )
	CALL IN_TEXT ( tcsbxw, ier )
	IF ( ier .ne. 0 ) THEN
	    iret = -43
	    CALL GSCOLR ( iclrs, ier )
	    CALL GSTEXT ( itf, ith, szt, itw, itb, itr, itj, ier )
	    RETURN
	END IF
C
C*	Query text size.
C
	CALL GQSYSZ ( xmk, ymk, xtx, ytx, xwb, ywb, ier )
C
C*	Determine position of lower corner of annotation box:
C
	IF ( ERMISS (xlltbx) .or. ERMISS (ylltbx) ) THEN
C
C*	    Using the default position.
C
	    CALL GQBND ( 'M', xarr(1), yarr(1), xarr(2), yarr(2), ier )
	    CALL GQBND ( 'V', xvl, yvb, xvr, yvt, iret )
	    CALL GTRANS ( 'M', 'V', 2, xarr, yarr, xarr, yarr, ier )
	    xllv = xarr (1) + .33 * ( xarr (2) - xarr (1) )
	    yllv = yarr (2) - 5.0 * ytx
C*
	ELSE IF ( lgctbx ) THEN
C
C*	    Using user supplied graph (M) coordinates:
C
	    CALL GTRANS ( 'M', 'V', 1, xlltbx, ylltbx,
     +			  xllv, yllv, ier )
	    IF ( ier .ne. 0 ) THEN
		iret = -44
	        CALL GSCOLR ( iclrs, ier )
	        CALL GSTEXT ( itf, ith, szt, itw, itb, itr, itj, ier )
		RETURN
	    END IF
C*
	ELSE
C
C*	    Using user supplied V coordinates:
C
	    xllv = xlltbx
	    yllv = ylltbx
C*
	END IF
C
C*	Check validity of coordinates:
C
	IF ( xllv .lt. 0 .or. xllv .gt. 1.0 .or.
     +	     yllv .lt. 0 .or. yllv .gt. 1.0 ) THEN
	    iret = -44
	    CALL GSCOLR ( iclrs, ier )
	    CALL GSTEXT ( itf, ith, szt, itw, itb, itr, itj, ier )
	    RETURN
	END IF
C
C*	Convert confidence interval and p level to text.
C
	WRITE ( cbxci, 10, IOSTAT=ier1 ) (1.0 - bxplvl)
10	FORMAT (F5.3)
	WRITE ( cnsmp, 20, IOSTAT=ier2 ) nsmpls
20	FORMAT (I5)
C
C*	Make the text string with an embedded return:
C
        IF ( wskflg ) THEN
            cbxc = 'BOX CONF INT = ' // cbxci
        ELSE
	    cbxc = 'CONFDNCE LVL = ' // cbxci
        END IF
	cbxc (21:21) = char (13)
	cbxc = cbxc (1:21) // '# OF SAMPLES = ' // cnsmp
	cbxc (42:42) = ' '
C
C*	Draw the annotation box:
C
	CALL GTEXT ( 'V', xllv, yllv, cbxc, 0., 1, 2, ier )
	IF ( ier .ne. 0 ) THEN
	    iret = -45
	    CALL GSCOLR ( iclrs, ier )
	    CALL GSTEXT ( itf, ith, szt, itw, itb, itr, itj, ier )
	    RETURN
	END IF
C
C*	Restore saved color and text attributes.
C
	CALL GSCOLR ( iclrs, ier )
	CALL GSTEXT ( itf, ith, szt, itw, itb, itr, itj, ier )
C*
	RETURN
	END
