	SUBROUTINE PLT_GBXW  ( sys, np, x, y, it, ibx, ipr, icc,
     +			       ysf, iret )
C************************************************************************
C* PLT_GBXW								*
C*									*
C* This subroutine displays the box-whisker objects for given pair	*
C* number and set of boxes associated with a particular computational	*
C* code.  The box-whisker object characteristics are obtained from the	*
C* common data structure.						*
C*									*
C* The relevant control file entry is formatted as follows:		*
C*									*
C*	BXWSKR = Line colors/widths/alpha/yes|no/yes|no			*
C*									*
C* PLT_GBXW  ( SYS, NP, X, Y, IT, IBX, IPR, ICC, YSF, IRET )		*
C*									*
C* Input parameters:							*
C*	SYS		CHAR*1		Coordinate system		*
C*					  'D' = device coordinates	*
C*					  'N' = normalized coordinates	*
C*					  'V' = view coordinates	*
C*					  'P' = plot coordinates	*
C*					  'M' = map coordinates		*
C*					  'G' = grid coordinates	*
C*	NP		INTEGER		Number of points		*
C*	X (NP)		REAL		x coordinates			*
C*	Y (NP)		REAL		y coordinates			*
C*	IT		INTEGER		Trace number			*
C*	IBX		INTEGER		Box-whisker object sequence #	*
C*					for box attributes and second	*
C*					index into SBXLEN, WSKRMX, and	*
C*					WSKRMN				*
C*	IPR		INTEGER		Pair number which determines	*
C*					placement of the objects	*
C*					relative to the benchmark trace *
C*					y value				*
C*	ICC		INTEGER		Comp code number		*
C*	YSF		REAL		Y-axis scale factor		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/04						*
C* K. Brill/HPC      20120330	Completed whisker elements		*
C* K. Brill/HPC      20120416   Add conditional box-whisker shift	*
C* K. Brill/HPC      20120420   Documentation				*
C* K. Brill/WPC      20140304	Pass in and use icc (comp code number)	*
C*				and it (trace number) to compute box	*
C*				whisker object positions for histograms *
C* K. Brill/WPC      20140919   Allow for skewness in the placement of  *
C*                              the box-whisker elements.               *
C* K. Brill/IMSG     20150512   If no whiskers, just draw error bars    *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C!			  Missing value fuzziness
C*
	CHARACTER*(*)	sys
	REAL		x (*), y (*)
C*
	REAL		xpoly (5), ypoly (5)
	REAL		xline (2), yline (2)
	LOGICAL		ERMISS, wok
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
C
C*	If color number is zero, do not do anything.
C
	IF ( ibxclr (ibx) .le. 0 ) RETURN
C
C*	Compute box location with respect to plot point.  The calculation
C*	is different for histograms, because the histogram clusters are
C*	centered on the abscissa point.
C
	nucc = knmucc
	itrc = 0
	isub = 1
	DO ii = 1, knmucc
C*	    Increment for the comparison trace.
	    itrc = itrc + 1
	    ichk = 0
	    DO jj = 1, npairs
C*		Increment for each trace paired with the comparison trace.
		itrc = itrc + 1
		IF ( itrc .le. MAXLIN ) THEN
		    ichk = ichk + ihstcl (itrc)
		END IF
	    END DO
	    IF ( ichk .eq. 0 ) THEN
		nucc = nucc - 1
		IF ( ii .lt. icc ) isub = isub + 1
	    END IF
	END DO
	IF ( ihstcl (it) .ne. 0 ) THEN
	    hinc = ( .5 * FLOAT ( (npairs+1) * nucc) -
     +		    FLOAT ( (icc-isub) * (npairs+1) ) - ipr + .5 )
     +		     * boxspc
	ELSE
	    hinc = ( .5 * FLOAT (npairs) - FLOAT (ipr) + 1. ) * boxspc
	END IF
C
C*	Query current color number, save it, and set new color.
C
	CALL GQCOLR ( iclrsv, ier )
	CALL GSCOLR ( ibxclr (ibx), ier )
	CALL GSLINE ( 1, 0, ibxlwd (ibx), 0, ierg )
C
C*	Draw the box-whisker objects where non-missing.
C
	ntot = 0
	DO WHILE ( ntot .lt. np )
	    ntot = ntot + 1
	    hfbx1 = sbxlen (ntot,ibx,1)
	    hfbx2 = sbxlen (ntot,ibx,2)
	    wkmx = wskrmx (ntot,ibx)
	    wkmn = wskrmn (ntot,ibx)
	    wok = .false.
	    IF ( .not. ERMISS ( x (ntot) ) .and.
     +		 .not. ERMISS ( y (ntot) ) .and.
     +		 .not. ERMISS ( hfbx1 ) .and.
     +		 .not. ERMISS ( hfbx2 ) ) THEN
		hfbx1 = hfbx1 * ysf
		hfbx2 = hfbx2 * ysf
		wok = .true.
C
C*		Draw the box.
C
		hstrt = x (ntot) - hinc
		xpoly (1) = hstrt + .25 * boxspc
	        ypoly (1) = y (ntot) - hfbx1
		ybot = ypoly (1)
		xpoly (2) = xpoly (1)
		ypoly (2) = y (ntot) + hfbx2
		ytop = ypoly (2)
		xpoly (3) = hstrt + .75 * boxspc
		ypoly (3) = ypoly (2)
		xpoly (4) = xpoly (3)
	        ypoly (4) = ypoly (1)
		xpoly (5) = xpoly (1)
		ypoly (5) = ypoly (1)
		IF ( bxshft ) THEN
		    DO ix = 1, 5
			xpoly (ix) = xpoly (ix) + .5 * boxspc
		    END DO
		END IF
C*
		xmid = hstrt + .5 * boxspc
		IF ( bxshft ) xmid = xmid + .5 * boxspc
C*
                IF ( wskflg ) THEN
		  IF ( revers .and. sys .eq. 'M' ) THEN
		    CALL GLINE ( sys, 5, ypoly, xpoly, ier )
		  ELSE
		    CALL GLINE ( sys, 5, xpoly, ypoly, ier )
		  END IF
                ELSE
C
C*                Draw error bar.
C
                  xline (1) = xpoly (1)
                  yline (1) = ypoly (1)
                  xline (2) = xpoly (4)
                  yline (2) = ypoly (4)
		  IF ( revers .and. sys .eq. 'M' ) THEN
		    CALL GLINE ( sys, 2, yline, xline, ier )
		  ELSE
		    CALL GLINE ( sys, 2, xline, yline, ier )
		  END IF
                  xline (1) = xmid
                  yline (1) = ypoly (1)
                  xline (2) = xmid
                  yline (2) = ypoly (2)
		  IF ( revers .and. sys .eq. 'M' ) THEN
		    CALL GLINE ( sys, 2, yline, xline, ier )
		  ELSE
		    CALL GLINE ( sys, 2, xline, yline, ier )
		  END IF
                  xline (1) = xpoly (2)
                  yline (1) = ypoly (2)
                  xline (2) = xpoly (3)
                  yline (2) = ypoly (3)
		  IF ( revers .and. sys .eq. 'M' ) THEN
		    CALL GLINE ( sys, 2, yline, xline, ier )
		  ELSE
		    CALL GLINE ( sys, 2, xline, yline, ier )
		  END IF
C*
                END IF
	    END IF
C*
	    IF ( wskflg .and. .not. ERMISS ( wkmx ) .and.
     +		 wok .and. .not. ERMISS ( wkmn ) ) THEN
		wkmx = wkmx * ysf
		wkmn = wkmn * ysf
C
C*		Draw the max whisker.
C
		xpoly (1) = xmid
		ypoly (1) = y (ntot) + hfbx2
		xpoly (2) = xpoly (1)
		ypoly (2) = ypoly (1) + wkmx
		IF ( revers .and. sys .eq. 'M' ) THEN
		    CALL GLINE ( sys, 2, ypoly, xpoly, ier )
		ELSE
		    CALL GLINE ( sys, 2, xpoly, ypoly, ier )
		END IF
C
C*		Draw the min whisker.
C
		ypoly (1) = y (ntot) - hfbx1
		ypoly (2) = ypoly (1) - wkmn
		IF ( revers .and. sys .eq. 'M' ) THEN
		    CALL GLINE ( sys, 2, ypoly, xpoly, ier )
		ELSE
		    CALL GLINE ( sys, 2, xpoly, ypoly, ier )
		END IF
	    END IF
	END DO
C
C*	Restore original color number.
C
	CALL GSCOLR ( iclrsv, ier )
C*
	RETURN
	END
