	SUBROUTINE PLT_GHGM  ( nt, sys, np, x, y, nhgm, iret )
C************************************************************************
C* PLT_GHGM								*
C*									*
C* This subroutine displays trace number NT as defined in the HSTGRM	*
C* common data structure.						*
C*									*
C* The relevant control file entry is formatted as follows:		*
C*									*
C*	HSTCLR = Line colors						*
C*									*
C* PLT_GHGM  ( NT, SYS, NP, X, Y, NHGM, IRET )				*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of the trace		*
C*	SYS		CHAR*1		Coordinate system		*
C*					  'D' = device coordinates	*
C*					  'N' = normalized coordinates	*
C*					  'V' = view coordinates	*
C*					  'P' = plot coordinates	*
C*					  'M' = map coordinates		*
C*					  'G' = grid coordinates	*
C*	NP		INTEGER		Number of points		*
C*	X (NP)		REAL		x coordinates			*
C*	Y (NP)		REAL		y coordinates			*
C*									*
C* Input and output parameter:						*
C*	NHGM		INTEGER		Input:  sequence number of last *
C*						histogram drawn		*
C*					Output: sequence number of this *
C*						histogram		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-14 = GEMPLT error		*
C*					-15 = NT out of range		*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/04						*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C!			  Missing value fuzziness
C*
	CHARACTER*(*)	sys
	REAL		x (*), y (*)
C*
	REAL		xpoly (4), ypoly (4)
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
	IF ( nt .gt. nlines ) THEN
	    iret = -15
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	If color number is zero, do not do anything.
C
	IF ( ihstcl (nt) .le. 0 ) RETURN
	IF ( rhttrc (nt) ) THEN
	    CALL GSGRAF ( 1, iyrxis, aspect, xaxbeg, yrxbeg,
     +			  xaxend, yrxend, ierrg )
	END IF
	nhgm = nhgm + 1
C
C*	Compute bar location with respect to plot point.
C
	hinc = ( .5 * FLOAT (nhstgm) - FLOAT (nhgm) + 1. ) * barwth
C
C*	Query current color number, save it, and set new color.
C
	CALL GQCOLR ( iclrsv, ier )
	CALL GSCOLR ( ihstcl (nt), ier )
C
C*	Draw the histogram bars where non-missing.
C
	ntot = 0
	DO WHILE ( ntot .lt. np )
	    ntot = ntot + 1
	    IF ( .not. ERMISS ( x (ntot) ) .and.
     +		 .not. ERMISS ( y (ntot) ) ) THEN
		hstrt = x (ntot) - hinc
		xpoly (1) = hstrt
	        ypoly (1) = 0.0
		xpoly (2) = hstrt
		ypoly (2) = y (ntot)
		xpoly (3) = hstrt + barwth
		ypoly (3) = y (ntot)
		xpoly (4) = xpoly (3)
	        ypoly (4) = 0.0
		IF ( revers .and. sys .eq. 'M' ) THEN
		    CALL GFILL ( sys, 4, ypoly, xpoly, ier )
		ELSE
		    CALL GFILL ( sys, 4, xpoly, ypoly, ier )
		END IF
		CALL PLT_GLIN  ( nt, sys, 4, xpoly, ypoly, iret )
	    END IF
	    hstrt = hstrt + hinc
	END DO
C
C*	Restore original color number.
C
	CALL GSCOLR ( iclrsv, ier )
C*
	RETURN
	END
