	SUBROUTINE PLT_GHIS ( trc, npts, stats, iret )
C************************************************************************
C* PLT_GHIS								*
C*									*
C* This subroutine draws a histogram plot.				*
C*									*
C* Relative frequencies in ranges centerd on the x values set in XAXVAL	*
C* in the XAXIS	common data structure are displayed in histogram form.	*
C*									*
C* The color numbers in ILCOLR are used to shade the histogram.  The	*
C* sequence of numbers is repeated if necessary to accomdate all of the	*
C* bars.  ILCOLR is stored in the LINE common data structure.		*
C*									*
C* PLT_GHIS  ( TRC, NPTS, STATS, IRET )					*
C*									*
C* Input parameters:							*
C*	TRC 		REAL		Trace data			*
C*	NPTS 		INTEGER		Number of trace points		*
C*	STATS		LOGICAL		Flag to display statistics	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		10/98						*
C* K. Brill/EMC		 4/99	Reverse coordinate changes		*
C* K. Brill/HPC		01/00	Add HARDWR to PLT_GTXT call		*
C* K. Brill/HPC		05/01	Add STATS flag; centered bars		*
C* K. Brill/HPC		12/01	Increment color for 0 frequency bins	*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999. )
	PARAMETER	( RDIFFD =  0.1    )
C*
	REAL		trc (*)
	LOGICAL		stats
C*
	CHARACTER	ctxt*18, crho*12
	REAL		xpoly (5), ypoly (5)
	LOGICAL		ERMISS, hardwr
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*-----------------------------------------------------------------------
	iret = 0
	IF ( revers ) THEN
	    WRITE (6,*) ' Reversed coordinate histogram is not allowed.'
	    RETURN
	END IF
C*
	CALL GQCOLR ( isvclr, ier )
	CALL GQLINE ( itypsv, ityphw, iwidsv, iwidhw, ier )
	CALL GSLINE ( 1, 0, 1, 0, ier )
C
C*	Draw the histogram.
C
	xleft = xaxval (1) - .5 * ( xaxval (2) - xaxval (1) )
	ypoly (1) = yaxbeg
	ypoly (2) = yaxbeg
	ic = 0
	DO i = 1, nxaxvl
	    IF ( i .eq. nxaxvl ) THEN
		xrht = xaxval (i) + .5 * ( xaxval (i) - xaxval (i-1) )
	    ELSE
		xrht = xaxval (i) + .5 * ( xaxval (i+1) - xaxval (i) )
	    END IF
	    IF ( xleft .ne. xrht ) THEN
C
C*		Find count for this interval.
C
		freq = 0.
		rn = 0.
		DO j = 1, npts
		    IF ( .not. ERMISS ( trc (j) ) ) THEN
			rn = rn + 1.
			IF ( ( trc (j) .ge. xleft .and.
     +			       trc (j) .lt. xrht ) .or.
     +			     ( trc (j) .eq. xrht .and.
     +			       i .eq. nxaxvl + 1 ) ) THEN
			    freq = freq + 1.
			END IF
		    END IF
		END DO
		IF ( rn .gt. 0. ) freq = freq / rn
		IF ( freq .gt. 0 ) THEN
		    ic = ic + 1
		    IF ( ic .gt. nlines ) ic = 1
		    icolr = ilcolr (ic)
		    CALL GSCOLR ( icolr, ier )
		    xpoly (1) = xleft
		    xpoly (2) = xrht
		    xpoly (3) = xrht
		    xpoly (4) = xleft
		    ypoly (3) = freq
		    ypoly (4) = freq
		    xpoly (5) = xpoly (1)
		    ypoly (5) = ypoly (1)
		    CALL GFILL ( 'M', 4, xpoly, ypoly, ier )
		    CALL GSCOLR ( ibcolr, ier )
		    CALL GLINE ( 'M', 5, xpoly, ypoly, ier )
		ELSE
		    ic = ic + 1
		    IF ( ic .gt. nlines ) ic = 1
		END IF
		xleft = xrht
	    END IF
	END DO
	CALL GEPLOT ( ier )
	CALL GSCOLR ( isvclr, ier )
	CALL GSLINE ( itypsv, ityphw, iwidsv, iwidhw, ier )
	CALL GEPLOT ( ier )
C*
	IF ( .not. stats ) RETURN
C
C*	Find mean and standard deviation.
C
	xmin = 1.1E31
	xmax = -1.1E31
	xsum = 0.
	x2sum = 0.
	rn = 0.
	DO i = 1, npts
	    IF ( .not. ERMISS ( trc (i) ) ) THEN
		rn = rn + 1.
		xsum = xsum + trc (i)
		x2sum = x2sum + trc (i) * trc (i)
		IF ( trc (i) .gt. xmax ) xmax = trc (i)
		IF ( trc (i) .lt. xmin ) xmin = trc (i)
	    END IF
	END DO
	rmu = xsum / rn
	rsig = SQRT ( x2sum / rn - rmu * rmu )
C
C*	Display the count, mean, and standard deviation.
C
	x1 = xaxbeg
	y2 = yaxend
	WRITE (crho,'(F10.0)') rn
	ctxt = 'COUNT = ' // crho
	CALL PLT_GTXT ( tcslab, hardwr, ier )
	CALL GTRANS ( 'M', 'V', 1, x1, y2, xv, yv, ier )
	CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 7, ierrg )
	WRITE (crho, '(1PE12.5)') rmu
	ctxt = 'AVG = ' // crho
	CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 4, ierrg )
	WRITE (crho, '(1PE12.5)') rsig
	ctxt = 'STD = ' // crho
	CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 1, ierrg )
	x1 = .5 * ( xaxbeg + xaxend )
	CALL GTRANS ( 'M', 'V', 1, x1, y2, xv, yv, ier )
	WRITE (crho, '(1PE12.5)') xmax
	ctxt = 'MAX = ' // crho
	CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 4, ierrg )
	WRITE (crho, '(1PE12.5)') xmin
	ctxt = 'MIN = ' // crho
	CALL GTEXT ( 'V', xv, yv, ctxt, 0., 2, 1, ierrg )
	IF ( ierrg .ne. 0 ) CALL PLT_PERR ( ierrg, iret )
C*
	RETURN
	END
