	SUBROUTINE PLT_GLBL ( numtrc, avgs, bscr, bssk, reli, reso,
     +			      uncr, cpot, iptype, method, ipcnt, cstat,
     +                        iret )
C************************************************************************
C* PLT_GLBL								*
C*									*
C* This subroutine places anotation labels on a plot.			*
C*									*
C* The label strings are generated by PLT_MLBL and reside in the 	*
C* LABELS common data structure.					*
C*									*
C* PLT_GLBL  ( NUMTRC, AVGS, BSCR, BSSK, RELI, RESO, UNCR, CPOT,	*
C*             IPTYPE, METHOD, CSTAT, IRET )				*
C*									*
C* Input parameters:							*
C*	NUMTRC		INTEGER		Number of traces		*
C*	AVGS (NUMTRC)	REAL		Average over each trace		*
C*	BSCR (NUMTRC)	REAL		Brier Score (BS) / CRPS         *
C*	BSSK (NUMTRC)	REAL		BS Skill / CRPS Skill vs UNC    *
C*	RELI (NUMTRC)	REAL		Reliability component of BS/CRPS*
C*	RESO (NUMTRC)	REAL		Resolution component of BS/CRPS *
C*	UNCR (NUMTRC)	REAL		Uncertainty component of BS/CRPS*
C*	CPOT (NUMTRC)	REAL		Potential CRPS                  *
C*	IPTYPE		INTEGER		Plot type			*
C*					  0 - print trace statistics	*
C*					  1 - time series		*
C*					  2 - scatter plot		*
C*					  3 - skill score vs threshold	*
C*					  4 - bins			*
C*					  5 - histogram			*
C*					  6 - ROC curve			*
C*					  7 - attribute diagram		*
C*                                        8 - CRPS RELI diagram         *
C*	METHOD		INTEGER		Display method:			*
C*					  1 - display plot as defined	*
C*					  2 - arbitrary traces & opcodes*
C*					      (an opcode for each trc)	*
C*					  3 - compute difference	*
C*					      between two traces for a	*
C*					      single opcode and display *
C*					  4 - compute % difference	*
C*					      between two traces for a	*
C*					      single opcode and display *
C*					  5 - compute skill score using *
C*					      2nd trace as reference	*
C*	IPCNT		INTEGER		Comp code of observation count  *
C*	CSTAT		CHAR*		Statistic type string		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98						*
C* K. Brill/EMC		 4/98	Plot count text string; use METHOD	*
C* K. Brill/EMC		 6/98	Leave room for means in scatter plot	*
C* K. Brill/EMC		10/98	Set margins and RETURN if LABLEV = 0 	*
C* K. Brill/EMC		10/98	Remove METHOD from CALL; leave room for	*
C*				histogram stats				*
C* K. Brill/EMC		11/98	Set y outside of IF			*
C* K. Brill/EMC		 1/99	METHOD = 3, use NXCHAR and NYCHAR	*
C* K. Brill/EMC		 4/99	Add means to trace labels; use REVERS	*
C* K. Brill/HPC		01/00	Standardize margins to tic-mark text	*
C* K. Brill/HPC		02/01	Rmv inf loop in title plot & split on -	*
C* K. Brill/HPC		03/01	Changes for right-side y axis		*
C* K. Brill/HPC		 2/03	Changes for method = 5			*
C* K. Brill/HPC		 5/03	Remove "MEAN = " if trace label is not	*
C*				default and trace mean is requested	*
C* K. Brill/HPC		 9/03	Changes for ROC curve (IPTYPE=6)	*
C* K. Brill/HPC		 1/04	Omit "...FIRST TRACE" from obs cnt lbl	*
C* K. Brill/HPC		 3/04	Plot filled box denoting histogram bar	*
C*				color in trace key; shorten line key	*
C* K. Brill/HPC		10/28	Allow \ new line forcing in title	*
C* K. Brill/HPC      20070125   Changes for attribute diagram		*
C* K. Brill/HPC      20080701   Pass in and use IPCNT			*
C* K. Brill/HPC      20090514   Add CSTAT as in input parameter		*
C* K. Brill/IMSG     20150827   Plot obs counts for iptype = 4 also     *
C* K. Brill/IMSG     20160720   Changes for CRPS RELI diagram           *
C* K. Brill/IMSG     20160727   Changes for 2-column trace labels       *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., RDIFFD = 0.1 )
C*
	REAL		avgs (*), bscr (*), bssk (*), reli (*),
     +			reso (*), uncr (*), cpot (*)
	CHARACTER*(*)   cstat
C*
	REAL		xp (2), yp (2)
	CHARACTER*128	cntstr, ostr
	CHARACTER*1	bs
C*
	LOGICAL		ERMISS, hardwr, oddt
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*------------------------------------------------------------------------
	iret = 0
C
C*	Query VIEW region bounds.
C
	CALL GQBND ( 'V', rlft, bot, rht, top, ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C
C*	Set axis tic-mark label text characteristics to serve as
C*	constant reference values for margins.
C
	CALL PLT_GTXT ( tcslab, hardwr, iret )
	IF ( iret .ne. 0 ) THEN
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Query text and marker sizes in normalized coordinates.
C
	CALL GQSYSZ ( wthmrk, hgtmrk, wthchr, hgtchr, rlwbx, rlwby,
     +		      ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C
C*	Initialize margins (in character size units).
C
	IF ( rmlbrt (1) .le. 0 ) THEN
	    eftmrg = 10.
	ELSE
	    eftmrg = rmlbrt (1)
	END IF
	IF ( rmlbrt (2) .le. 0 ) THEN
	    botmrg = 4.
	ELSE
	    botmrg = rmlbrt (2)
	END IF
	IF ( rmlbrt (3) .le. 0 ) THEN
	    rhtmrg = 4.
	    IF ( rhtdrw ) rhtmrg = 10.
	ELSE
	    rhtmrg = rmlbrt (3)
	END IF
	IF ( rmlbrt (4) .le. 0 ) THEN
	    topmrg = 1.
	ELSE
	    topmrg = rmlbrt (4)
	END IF
	xleft = eftmrg * wthchr
	xbot = botmrg * hgtchr
	xrght = rhtmrg * wthchr
	xtop = topmrg * hgtchr
	IF ( lablev .eq. 0 ) THEN
C
C*	    Set margins for plot and return.
C
	    CALL GSGMGN ( eftmrg, botmrg, rhtmrg, topmrg, ierrg )
	    IF ( ierrg .ne. 0 ) THEN
		CALL PLT_PERR ( ierrg, iret )
		RETURN
	    END IF
	    RETURN
	END IF
C
C*	Set title text characteristics.
C
	CALL PLT_GTXT ( tcsttl (1), hardwr, iret )
	IF ( iret .ne. 0 ) THEN
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Query text and marker sizes.
C
	CALL GQSYSZ ( wthmrk, hgtmrk, wthchr, hgtchr, rlwbx, rlwby,
     +		      ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C
C*	Compute space between lines of text, x and y centers.
C
	yspc = .6 * hgtchr
	xcnt = .5 * ( rlft + rht )
	ycnt = .5 * ( bot + top )
	dist = rht - rlft
C
C*	Plot title text centered, at the top.
C
	bs = CHAR ( 92 )
	CALL ST_LSTR ( ptitle, lng, ier )
	iq = INDEX ( ptitle, bs )
        IF ( iq .ne. 0 ) THEN
C
C*	  The user has provided line breaking back slashes.
C
	  y = top - xtop
	  iyoff = 0
	  nchr = iq - 1
	  ic1 = 1
	  ice = iq - 1
	  DO WHILE ( ice .le. lng )
	      ixoff = -nchr
	      CALL GTEXT ( 'V', xcnt, y, ptitle (ic1:ice),
     +			     0.0, ixoff, iyoff, ierrg )
	      IF ( ierrg .ne. 0 ) THEN
		CALL PLT_PERR ( ierrg, iret )
		RETURN
	      END IF
	      ic1 = ice + 2
	      IF ( ic1 .gt. lng ) THEN
		  ice = ic1
	      ELSE
	          iq = INDEX ( ptitle (ic1:), bs )
		  IF ( iq .eq. 0 ) THEN
		      ice = lng
		  ELSE
		      ice = ic1 + iq - 2
		  END IF
	      END IF
	      nchr = ice - ic1 + 1
	      iyoff = iyoff - 3
	      xtop = xtop + 1.5 * hgtchr
	  END DO
	ELSE
	  nchrx = INT ( dist / wthchr ) + 1
	  y = top - xtop
	  IF ( lng .le. nchrx ) THEN
	    ixoff = -lng
	    CALL GTEXT ( 'V', xcnt, y, ptitle, 0.0, ixoff, 0,
     +			 ierrg )
	    IF ( ierrg .ne. 0 ) THEN
		CALL PLT_PERR ( ierrg, iret )
		RETURN
	    END IF
	    xtop = xtop + 1.5 * hgtchr
	  ELSE
	    iyoff = 0
	    itend = 0
	    istrt = 1
	    nclft = lng
	    ncusd = 1
	    DO WHILE ( itend .lt. lng )
		isub = 1
		IF ( nclft .gt. nchrx ) THEN
		    ic = itend + nchrx
		    DO WHILE ( ic .gt. ncusd )
			ic = ic - 1
			IF ( ptitle (ic:ic) .eq. ' ' ) THEN
			    isplit = ic
			    ic = -9
			ELSE IF ( ptitle (ic:ic) .eq. '-' ) THEN
			    isplit = ic
			    ic = -9
			    isub = 0
			END IF
		    END DO
		    IF ( ic .eq. -9 ) THEN
			itend = isplit
		    ELSE
			itend = lng + 1
		    END IF
		ELSE
		    itend = lng + 1
		END IF
		nchrs = itend - istrt
		ncusd = itend + 1
		ixoff = -nchrs
		CALL GTEXT ( 'V', xcnt, y, ptitle (istrt:itend-isub),
     +			     0.0, ixoff, iyoff, ierrg )
		istrt = itend + 1
		nclft = lng - istrt + 1
		iyoff = iyoff - 3
		xtop = xtop + 1.5 * hgtchr
	    END DO
	  END IF
	END IF
C
C*	Leave room for correlation coefficient and means text.
C
	IF ( iptype .eq. 2 .or. iptype .eq. 6 ) THEN
	    xtop = xtop + 3.2 * hgtchr
	END IF
C
C*	Leave room for count, mean, and standard deviation.
C
	IF ( iptype .eq. 5 ) xtop = xtop + 3.2 * hgtchr
C
C*	Set trace label text characteristics.
C
	CALL PLT_GTXT ( tcsttl (2), hardwr, iret )
	IF ( iret .ne. 0 ) THEN
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Query text and marker sizes.
C
	CALL GQSYSZ ( wthmrk, hgtmrk, wthchr, hgtchr, rlwbx, rlwby,
     +		      ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
	yspc = .6 * hgtchr
	y = top - xtop - yspc
	IF ( ( numtrc .gt. 1 .and. iptype .ne. 2 .and.
     +	       iptype .ne. 5 ) .or.
     +       ( method .eq. 3 .or. method .eq. 4 .or.
     +	       method .eq. 5 ) .or.
     +	     ( numtrc .eq. 1 .and. ltravg (1) ) ) THEN
C
C*	    Plot the trace key.
C
            span = .5 * ABS ( rht - rlft ) - xleft
            nlns = 0
            np1 = 0
            yinc = 0
            nxt = 1
	    DO i = 1, numtrc
                oddt = ( MOD ( nxt, 2 ) .ne. 0 )
                IF ( .not. twocol .or. numtrc .eq. 1 ) THEN
	            xlft = rlft + xleft
	            stplin = xlft + .20 * ABS ( rht - rlft )
	            strtlb = stplin + wthchr
	            putmrk = xlft + .12 * ABS ( rht -rlft )
	            puthg = xlft + .12 * ABS ( rht -rlft )
	            xp (1) = xlft
	            xp (2) = stplin
	            dist = rht - stplin
                    nchrx = INT ( dist / wthchr )
                ELSE IF ( oddt ) THEN
	            xlft = rlft + xleft
	            stplin = xlft + .15 * span
	            strtlb = stplin + wthchr
	            putmrk = xlft + .09 * span
	            puthg = xlft + .09 * span
	            xp (1) = xlft
	            xp (2) = stplin
	            dist = rlft + xleft + span - stplin
                    nchrx = INT ( dist / wthchr )
                ELSE
	            xlft = rlft + xleft + span + wthchr
	            stplin = xlft + .15 * span
	            strtlb = stplin + wthchr
	            putmrk = xlft + .09 * span
	            puthg = xlft + .09 * span
	            xp (1) = xlft
	            xp (2) = stplin
	            dist = rht - strtlb
                    nchrx = INT ( dist / wthchr )
                END IF
C*
		IF ( ltravg (i) ) THEN
		    CALL ST_LSTR ( trclbl (i), ltl, ier )
		    IF ( ltl .eq. 0 ) THEN
			    cntstr (1:) = ' MEAN = '
			    ltl = ltl + 8
		    ELSE IF ( .not. usrlbl (i) ) THEN
			    cntstr (1:) = trclbl (i) (1:ltl) // ' MEAN = '
			    ltl = ltl + 8
		    ELSE
			cntstr (1:) = trclbl (i) (1:ltl) // ' = '
			ltl = ltl + 3
		    END IF
		    trclbl (i) (1: ) = cntstr (1:ltl)
		    IF ( .not. ERMISS (avgs (i) ) ) THEN
			    WRITE (cntstr, '(1PE12.5)') avgs (i)
			    trclbl (i) = trclbl (i) (1:ltl) // cntstr (1:12)
		    ELSE
			trclbl (i) = trclbl (i) (1:ltl) // 'MISSING'
		    END IF
		END IF
		IF ( iptype .eq. 7 ) THEN
C
C*		    Replace attribute diagram variables with numbers.
C
		    iq = INDEX ( trclbl (i), '$BSC' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( bscr (i) ) )
     +		    THEN
			CALL ST_RLCH ( bscr(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$BSC',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$BSK' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( bssk (i) ) )
     +		    THEN
			CALL ST_RLCH ( bssk(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$BSK',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$REL' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( reli (i) ) )
     +		    THEN
		  	CALL ST_RLCH ( reli(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$REL',
     +				       cntstr, ipos, ostr, ir )
		        trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$RES' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( reso (i) ) )
     +		    THEN
			CALL ST_RLCH ( reso(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$RES',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$UNC' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( uncr (i) ) )
     +		    THEN
			CALL ST_RLCH ( uncr(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$UNC',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		END IF
C*
		IF ( iptype .eq. 8 ) THEN
C
C*		    Replace CRPS RELI diagram variables with numbers.
C
		    iq = INDEX ( trclbl (i), '$RPS' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( bscr (i) ) )
     +		    THEN
			CALL ST_RLCH ( bscr(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$RPS',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$RSK' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( bssk (i) ) )
     +		    THEN
			CALL ST_RLCH ( bssk(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$RSK',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$REL' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( reli (i) ) )
     +		    THEN
		  	CALL ST_RLCH ( reli(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$REL',
     +				       cntstr, ipos, ostr, ir )
		        trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$RES' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( reso (i) ) )
     +		    THEN
			CALL ST_RLCH ( reso(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$RES',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$UNC' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( uncr (i) ) )
     +		    THEN
			CALL ST_RLCH ( uncr(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$UNC',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		    iq = INDEX ( trclbl (i), '$POT' )
		    IF ( iq .ne. 0 .and. .not. ERMISS ( cpot (i) ) )
     +		    THEN
			CALL ST_RLCH ( cpot(i), 4, cntstr, ir )
			CALL ST_RPST ( trclbl(i), '$POT',
     +				       cntstr, ipos, ostr, ir )
			trclbl (i) = ostr
		    END IF
		END IF
		IF ( trclbl (i) .ne. ' ' ) THEN
                    nxt = nxt + 1
		    yp (1) = y
		    yp (2) = y
                    ysav = y
		    IF ( ihstcl (i) .eq. 0 ) THEN
		    	CALL PLT_GLIN ( i, 'V', 2, xp, yp, ierrg )
		    	IF ( ierrg .ne. 0 ) THEN
			    CALL PLT_PERR ( ierrg, iret )
			    RETURN
		    	END IF
		    	CALL PLT_GMRK ( i, 'V', 1, putmrk, y, ierrg )
		    	IF ( ierrg .ne. 0 ) THEN
		 	    CALL PLT_PERR ( ierrg, iret )
			    RETURN
		    	END IF
		    ELSE
C
C*			Plot a filled box to indicate color of
C*			histogram bar.
C
			CALL GQCOLR ( iclrs, ier )
			CALL GSCOLR ( ihstcl (i), ier )
			CALL GSMRKR ( 19, 1, rmsize(i), imwdth(i),
     +				      ier )
			CALL GMARK ( 'V', 1, puthg, y, ierrg )
			CALL GSCOLR ( iclrs, ier )
		    END IF
		    CALL ST_LSTR ( trclbl (i), lng, ier )
		    IF ( lng .gt. 0 ) THEN
			x = strtlb
			IF ( lng .le. nchrx ) THEN
		            CALL GTEXT ( 'V', x, y, trclbl (i),
     +					 0.0, 0, 0, ierrg )
			ELSE
			    y = y + 2.25 * yspc
			    nc = 0
			    DO WHILE ( nc .lt. lng )
				nc = nc + 1
				nstrt = nc
				nstop = lng
				ldmp = lng - nc + 1
				ic = lng
				DO WHILE ( ic .gt. nc .and.
     +					   ldmp .gt. nchrx )
				    IF ( trclbl (i) (ic:ic) .eq. ' ' )
     +				    THEN
					nstop = ic - 1
					ldmp = nstop - nstrt + 1
				    END IF
				    ic = ic - 1
				END DO
				IF ( ldmp .gt. nchrx ) THEN
				    nstop = nstrt + nchrx - 1
			        END IF
				IF ( nstop .gt. nstrt ) THEN
				    y = y - 2.25 * yspc
				    CALL GTEXT ( 'V', x, y,
     +					     trclbl (i) (nstrt:nstop),
     +					     0.0, 0, 0, ierrg )
                                    IF ( .not. oddt .or.
     +                                   .not. twocol ) THEN
				        nlns = nlns + 1
                                    ELSE
                                        np1 = np1 + 1
                                        yinc = yinc + 2.25 * yspc
                                    END IF
				    IF ( ldmp .gt. nchrx ) THEN
					nc = nstop
				    ELSE
					nc = nstop + 1
				    END IF
				END IF
			    END DO
			END IF
			IF ( ierrg .ne. 0 ) THEN
			    CALL PLT_PERR ( ierrg, iret )
			    RETURN
			END IF
		    END IF
                    IF ( ( twocol .and. .not. oddt ) .or.
     +                     .not. twocol .or. numtrc .eq. 1 ) THEN
		        y = y - 2.25 * yspc - yinc
                        nlns = nlns + 1 + np1
                        np1 = 0
                        yinc = 0
                    ELSE
                        y = ysav
                    END IF
		END IF
	    END DO
C*          Note that nxt is 1 ahead of current trace count.
            IF ( twocol .and. MOD (nxt,2) .eq. 0 ) THEN
                y = ysav - 2.25 * yspc - yinc
                nlns = nlns + 1 + np1
            END IF
	    xtop = xtop + 1.4 * FLOAT ( nlns ) * hgtchr
	END IF
C
C*	Plot data counts label text.
C
	ifho = INDEX ( cstat, 'FHO' )
	IF ( ( iptype .eq. 3 .or. iptype .eq. 4 ) .and. ifho .ne. 0 )
     +      THEN
	    xlft = rlft + xleft
	    y = y - yspc
	    dist = rht - xlft
	    cntstr = 'OBSERVATION COUNTS:'
      	    IF ( .not. sngltr .and. ipcnt .eq. 1 ) THEN
      		cntstr = cntstr ( 1:18 ) // ' (FROM FIRST TRACE):'
      	    ELSE
      		cntstr = cntstr (1:18) // ':'
      	    END IF
	    CALL ST_LSTR ( cntstr, lng, ier )
	    nchrx = INT ( dist / wthchr ) + 1
	    IF ( lng .le. nchrx ) THEN
		CALL GTEXT ( 'V', xlft, y, cntstr, 0.0, 0, 0,
     +			     ierrg )
		IF ( ierrg .ne. 0 ) THEN
		    CALL PLT_PERR ( ierrg, iret )
		    RETURN
		END IF
		xtop = xtop + 1.5 * hgtchr
	    ELSE
		iyoff = 0
		itend = 0
		istrt = 1
		nclft = lng
		ncusd = 1
		DO WHILE ( itend .lt. lng )
		    IF ( nclft .gt. nchrx ) THEN
			ic = itend + nchrx
			DO WHILE ( ic .gt. ncusd )
			    ic = ic - 1
			    IF ( cntstr (ic:ic) .eq. ' ' ) THEN
				isplit = ic
				ic = -9
			    END IF
			END DO
			IF ( ic .eq. -9 ) THEN
			    itend = isplit
			ELSE
			    itend = lng + 1
			END IF
		    ELSE
			itend = lng + 1
		    END IF
		    ncusd = itend + 1
		    nchrs = itend - istrt
		    CALL GTEXT ( 'V', xlft, y, cntstr (istrt:itend-1),
     +			     0.0, 0, iyoff, ierrg )
		    IF ( ierrg .ne. 0 ) THEN
			CALL PLT_PERR ( ierrg, iret )
			RETURN
		    END IF
		    istrt = itend + 1
		    nclft = lng - istrt + 1
		    iyoff = iyoff - 3
		    xtop = xtop + 1.5 * hgtchr
		END DO
	    END IF
	    xtop = xtop + 2.0 * hgtchr
	END IF
C
C*	Plot axis labels.
C
C*	Set axis label text characteristics.
C
	CALL PLT_GTXT ( tcsttl (3), hardwr, iret )
	IF ( hardwr ) THEN
	    CALL PLT_ERRO ( 10, ' ', ier )
	END IF
	IF ( iret .ne. 0 ) THEN
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Query text and marker sizes.
C
	CALL GQSYSZ ( wthmrk, hgtmrk, wthchr, hgtchr, rlwbx, rlwby,
     +		      ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C
C*	Plot right-side label first.
C
	IF ( rhtdrw .and. yrxlbl .ne. ' ' ) THEN
	    CALL ST_LSTR ( yrxlbl, lng2, ier )
	    IF ( lng2 .gt. 0 ) THEN
		xrght = xrght + 1.5 * wthchr
		x = rht - hgtchr * 1.5
		y = ycnt + .5 * xbot -
     +			   .5 * xtop
		iyoff = -lng2
		CALL GTEXT ( 'V', x, y, yrxlbl, -90.0, iyoff,
     +			     (-2*nychrr), ierrg )
		IF ( ierrg .ne. 0 ) THEN
		    CALL PLT_PERR ( ierrg, iret )
		    RETURN
		END IF
	    END IF
	END IF
	yspc = .6 * hgtchr
	IF ( ( xaxlbl .ne. ' ' .or. yaxlbl .ne. ' ' ) .and.
     +	     .not. revers ) THEN 
	    CALL ST_LSTR ( xaxlbl, lng1, ier )
	    IF ( lng1 .gt. 0 ) xbot = xbot + 1.5 * hgtchr
	    CALL ST_LSTR ( yaxlbl, lng2, ier )
	    IF ( lng2 .gt. 0 ) xleft = xleft + 1.5 * wthchr
	    IF ( lng1 .gt. 0 ) THEN
		x = xcnt + .5 * xleft -
     +			   .5 * xrght
		y = bot
		ixoff = -lng1
		CALL GTEXT ( 'V', x, y, xaxlbl, 0.0, ixoff,
     +			     (2*nxchar), ierrg )
		IF ( ierrg .ne. 0 ) THEN
		    CALL PLT_PERR ( ierrg, iret )
		    RETURN
		END IF
	    END IF
	    IF ( lng2 .gt. 0 ) THEN
		x = rlft + hgtchr * 1.5
		y = ycnt + .5 * xbot -
     +			   .5 * xtop
		iyoff = -lng2
		CALL GTEXT ( 'V', x, y, yaxlbl, 90.0, iyoff,
     +			     (-2*nychar), ierrg )
		IF ( ierrg .ne. 0 ) THEN
		    CALL PLT_PERR ( ierrg, iret )
		    RETURN
		END IF
	    END IF
	ELSE IF ( ( xaxlbl .ne. ' ' .or. yaxlbl .ne. ' ' ) .and.
     +	          revers ) THEN
	    CALL ST_LSTR ( yaxlbl, lng1, ier )
	    IF ( lng1 .gt. 0 ) xbot = xbot + 1.5 * hgtchr
	    CALL ST_LSTR ( xaxlbl, lng2, ier )
	    IF ( lng2 .gt. 0 ) xleft = xleft + 1.5 * wthchr
	    IF ( lng1 .gt. 0 ) THEN
		x = xcnt + .5 * xleft -
     +			   .5 * xrght
		y = bot
		ixoff = -lng1
		CALL GTEXT ( 'V', x, y, yaxlbl, 0.0, ixoff,
     +			     (2*nychar), ierrg )
		IF ( ierrg .ne. 0 ) THEN
		    CALL PLT_PERR ( ierrg, iret )
		    RETURN
		END IF
	    END IF
	    IF ( lng2 .gt. 0 ) THEN
		x = rlft + hgtchr * 1.5
		y = ycnt + .5 * xbot -
     +			   .5 * xtop
		iyoff = -lng2
		CALL GTEXT ( 'V', x, y, xaxlbl, 90.0, iyoff,
     +			     (-2*nxchar), ierrg )
		IF ( ierrg .ne. 0 ) THEN
		    CALL PLT_PERR ( ierrg, iret )
		    RETURN
		END IF
	    END IF
	END IF
C
C*	Set margins for plot and return.
C
C*	Set size-reference text characteristics.
C
	CALL PLT_GTXT ( tcslab, hardwr, iret )
	IF ( iret .ne. 0 ) THEN
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Query text and marker sizes.
C
	CALL GQSYSZ ( wthmrk, hgtmrk, wthchr, hgtchr, rlwbx, rlwby,
     +		      ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C*
	topmrg = xtop / hgtchr
	eftmrg = xleft / wthchr
	botmrg = xbot / hgtchr
	rhtmrg = xrght / wthchr
	CALL GSGMGN ( eftmrg, botmrg, rhtmrg, topmrg, ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    RETURN
	END IF
C*
	RETURN
	END
