	SUBROUTINE PLT_GLIN  ( nline, sys, np, x, y, iret )
C************************************************************************
C* PLT_GLIN								*
C*									*
C* This subroutine draws line number NLINE as defined in the LINE	*
C* common data structure.						*
C*									*
C* The relevant control file entry is formatted as follows:		*
C*									*
C*	LINE   = Line colors/types/widths/labels			*
C*									*
C* PLT_GLIN  ( NLINE, SYS, NP, X, Y, IRET )				*
C*									*
C* Input parameters:							*
C*	NLINE		INTEGER		Number of the line		*
C*	SYS		CHAR*1		Coordinate system		*
C*					  'D' = device coordinates	*
C*					  'N' = normalized coordinates	*
C*					  'V' = view coordinates	*
C*					  'P' = plot coordinates	*
C*					  'M' = map coordinates		*
C*					  'G' = grid coordinates	*
C*	NP		INTEGER		Number of points		*
C*	X (NP)		REAL		x coordinates			*
C*	Y (NP)		REAL		y coordinates			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-14 = GEMPLT error		*
C*					-15 = NLINE out of range	*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98						*
C* K. Brill/EMC		 6/98	Check for missing points		*
C* K. Brill/EMC		 4/99	Reversed coordinate changes		*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C!			  Missing value fuzziness
C*
	CHARACTER*(*)	sys
	REAL		x (*), y (*)
C*
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
	IF ( nline .gt. nlines ) THEN
	    iret = -15
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	If color number is zero, do not do anything.
C
	IF ( ilcolr (nline) .le. 0 ) RETURN
C
C*	Query current color number, save it, and set new color.
C
	CALL GQCOLR ( iclrsv, ier )
	CALL GSCOLR ( ilcolr (nline), ier )
C
C*	Set line attributes.
C
	CALL GSLINE ( ildash (nline), 0, ilwdth (nline), 0,
     +		      ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    CALL GSCOLR ( iclrsv, ier )
	    RETURN
	END IF
C
C*	Draw the line in piece-wise non-missing segments.
C
	ierrg = 0
	ntot = 0
	istrt = 1
	DO WHILE ( ntot .lt. np .and. ierrg .eq. 0 )
	    ntot = ntot + 1
	    IF ( ERMISS ( x (ntot) ) .or. ERMISS ( y (ntot) ) ) THEN
		istop = ntot - 1
		npp = istop - istrt + 1
		IF ( npp .gt. 1 ) THEN
		    IF ( revers .and. sys .eq. 'M' ) THEN
			CALL GLINE ( sys, npp, y (istrt), x (istrt),
     +				     ierrg )
		    ELSE
			CALL GLINE ( sys, npp, x (istrt), y (istrt),
     +				     ierrg )
		    END IF
		END IF
		istrt = ntot + 1
	    END IF
	END DO
	npp = ntot - istrt + 1
	IF ( npp .gt. 1 ) THEN
	    IF ( revers .and. sys .eq. 'M' ) THEN
		CALL GLINE ( sys, npp, y (istrt), x (istrt), ierrg )
	    ELSE
		CALL GLINE ( sys, npp, x (istrt), y (istrt), ierrg )
	    END IF
	END IF
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    CALL GSCOLR ( iclrsv, ier )
	    RETURN
	END IF
C
C*	Restore original color number.
C
	CALL GSCOLR ( iclrsv, ier )
C*
	RETURN
	END
