	SUBROUTINE PLT_GMRK  ( nmark, sys, np, x, y, iret )
C************************************************************************
C* PLT_GMRK								*
C*									*
C* This subroutine draws marker number NMARK as defined in the MARKER	*
C* common data structure.						*
C*									*
C* The relevant control file entry is formatted as follows:		*
C*									*
C*	MARKER = Marker colors/types/sizes/widths			*
C*									*
C* PLT_GMRK  ( NMARK, SYS, NP, X, Y, IRET )				*
C*									*
C* Input parameters:							*
C*	NMARK		INTEGER		Number of the marker		*
C*	SYS		CHAR*1		Coordinate system		*
C*					  'D' = device coordinates	*
C*					  'N' = normalized coordinates	*
C*					  'V' = view coordinates	*
C*					  'P' = plot coordinates	*
C*					  'M' = map coordinates		*
C*					  'G' = grid coordinates	*
C*	NP		INTEGER		Number of points		*
C*									*
C*  Input and Output parameters:					*
C*	X (NP)		REAL		x coordinates			*
C*					If missing, reset off plot area *
C*	Y (NP)		REAL		y coordinates			*
C*					If X is missing, set to RMISSD  *
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-14 = GEMPLT error		*
C*					-16 = NMARK out of range	*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98						*
C* K. Brill/EMC		 4/99	Changes for reversed coordinates	*
C* K. Brill/HPC		12/01	Changes to avoid plotting missing data	*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1 )
C*
	CHARACTER*(*)	sys
	REAL		x (*), y (*)
C*
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
	IF ( nmark .gt. nmrkrs ) THEN
	    iret = -16
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	If color number is zero, do not do anything.
C
	IF ( imcolr (nmark) .le. 0 ) RETURN
C
C*	Query current color number, save it, and set new color.
C
	CALL GQCOLR ( iclrsv, ier )
	CALL GSCOLR ( imcolr (nmark), ier )
C
C*	Set marker attributes.
C
	CALL GSMRKR ( imtype (nmark), 1, rmsize (nmark), imwdth (nmark),
     +		      ierrg )
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    CALL GSCOLR ( iclrsv, ier )
	    RETURN
	END IF
C
C*	Scan for missing values.
C
	DO ip = 1, np
	    IF ( ERMISS ( y(ip) ) .or. ERMISS ( x(ip) ) ) THEN
		x (ip) = xaxbeg - .5 * ABS ( xaxend - xaxbeg )
		y (ip) = RMISSD
	    END IF
	END DO
C
C*	Draw the markers.
C
	IF ( revers .and. sys .eq. 'M' ) THEN
	    CALL GMARK ( sys, np, y, x, ierrg )
	ELSE
	    CALL GMARK ( sys, np, x, y, ierrg )
	END IF
	IF ( ierrg .ne. 0 ) THEN
	    CALL PLT_PERR ( ierrg, iret )
	    CALL GSCOLR ( iclrsv, ier )
	    RETURN
	END IF
C
C*	Restore original color number.
C
	CALL GSCOLR ( iclrsv, ier )
C*
	RETURN
	END
