	SUBROUTINE PLT_GSCR ( colors, iret )
C************************************************************************
C* PLT_GSCR								*
C*									*
C* This subroutine assigns colors to numbers by name or RGB values.	*
C*									*
C* The colors can be queried or set by name.  The color names		*
C* corresponding to the color numbers can be listed by ending the	*
C* color list with a ?.  Color numbers can be set to specific colors	*
C* by using the equal sign.  For example, 1=red;2=orange;3=blue;4;5?	*
C* sets color number 1 to red, 2 to orange, 3 to blue, and it lists	*
C* the current color names for all color numbers.  If =init follows	*
C* any number, the initial color assignment is restored, but any	*
C* accompanying color assignments by name are applied to alter the	*
C* initial colors.							*
C*									*
C* The color numbers can also be assigned RGB values following the	*
C* equal sign.  The values are separated by colons.  For example,	*
C* 3=51:76:204 assigns the color corresponding to RGB values 51, 76,	*
C* and 204 to color number 3.						*
C*									*
C* PLT_GSCR ( COLORS, IRET )						*
C*									*
C* Input parameters:							*
C*	COLORS		CHAR*		COLORS input			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/03	Modified copy of IN_COLR from GEMLIB	*
C************************************************************************
	PARAMETER	( MXCLNM=64, LLCLEV=64 )
C*
	CHARACTER*(*)	colors
C*
	LOGICAL		query
	INTEGER		irgb (3)
	CHARACTER	cname (LLCLEV)*24, carr (2)*16, name*16
	CHARACTER	colrin*128, xname*32
C------------------------------------------------------------------------
	iret = 0
	ncol = 0
	colrin = colors
C
C*	Check if ? is last character of colors list.
C
	CALL ST_LSTR  ( colrin, ilen, ier)
	IF  ( colrin ( ilen : ilen ) .eq. '?' )  THEN
	    query = .true.
	    colrin ( ilen:ilen ) = ' '
	  ELSE
	    query = .false.
	END IF
C
C*	Check for semicolons to separate colors.
C
	CALL ST_CLST  ( colrin, ';', ' ', LLCLEV, cname, kcol, ier )
	IF  ( kcol .eq. 0 )  kcol = 1
C
C*      Loop through each of the colors.
C
        DO  i = 1, kcol
C
C*	    Separate color number from the name or components to set.
C
	    CALL ST_CLST ( cname (i), '=', ' ', 2, carr, num, ier )
C
	    IF  ( ier .eq. 0 )  THEN
		ncol = ncol + 1
		IF  ( num .lt. 2 )  THEN
		    icolon = -1
		  ELSE
		    icolon = INDEX  ( carr (2), ':' )
		END IF
C
C*		Get the color number.
C
		CALL ST_NUMB  ( carr (1), jcolor, ier )
		IF  ( jcolor .le. 0 )  jcolor = 1
C
C*		Set the color by name.
C
	        IF  ( icolon .eq. 0 )  THEN
		    CALL ST_LCUC  ( carr (2), carr (2), ier )
		    IF  ( carr (2) .ne. 'INIT' )  THEN
			CALL GSCNAM  ( jcolor, carr (2), ier )
		      ELSE
			CALL GSCINT  ( ier )
		    END IF
C
C*		    Set the color by RGB components.
C
		  ELSE
		    CALL ST_ILST (carr (2), ':', -1, 3, irgb, num, ier)
		    IF  ( num .eq. 3 )  THEN
			CALL GSCRGB  ( jcolor, irgb (1), irgb (2),
     +				       irgb (3), ier )
		    END IF
                END IF
	    END IF
	END DO
C
C*	Write out color information if ? specified by user.
C
	IF  ( query ) THEN
C
C*	    Find out how many colors there are.  Only check MXCLNM
C*	    colors.
C
	    CALL GQNCOL ( nncolr, ier )
	    IF  ( nncolr .ge. MXCLNM )  nncolr = MXCLNM
C
C*	    Write title.
C
	    WRITE (6, 500)
500	    FORMAT ( 2X, 'COLOR', 2X, 'COLOR NAME', 8X, 'RED', 2X,
     +		     'GREEN', 2X, 'BLUE', 2X, 'X COLOR NAME' )
C
C*	    Loop through and get names and components of colors.
C
	    DO  i = 1, nncolr
		name = ' '
		CALL GQCOMP  (  i, name, ired, igreen, iblue, xname,
     +				ier )
		IF ( name  .eq. ' ' ) name  = 'redefined '
		IF ( xname .eq. ' ' ) xname = 'redefined '
		WRITE  ( 6, 510 ) i, name, ired, igreen, iblue, xname
510		FORMAT ( 4X, I3, 2X, A16, 1X, I4, 3X, I4, 2X, I4, 2X,
     +			 A32 )
	    END DO
	    WRITE  ( 6, * )
	END IF
C*
	RETURN
	END
