	SUBROUTINE PLT_ILIN  ( line, numtrc, iret )
C************************************************************************
C* PLT_ILIN								*
C*									*
C* This subroutine converts the input for the LINE variable into a	*
C* list of colors, line types, line widths and line label flags.	*
C* If the number of specifications is less than the number expected,	*
C* the input sequence will be repeated to fill the internal arrays.	*
C*									*
C* The LINE control file input must be of the form:			*
C*									*
C*      col1;col2;.../typ1;typ2.../wid1;wid2.../lab1;lab2...		*
C*									*
C* In general, lines are turned off by specifying color = 0.		*
C* 0 for line type or width will use a default value of 1.  0 for	*
C* line label will suppress labelling.					*
C*									*
C* If the label is set to a single number, say n, then every nth line	*
C* will be shown in the line type reference inset plot.			*
C*									*
C* PLT_ILIN  ( LINE, NUMTRC, IRET )					*
C*									*
C* Input parameters:							*
C*	LINE 		CHAR*		LINE input			*
C*	NUMTRC		INTEGER         Number expected			*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98	Created from IN_LINE			*
C* K. Brill/EMC		10/98	Set NLINES; use MAXLIN in ST_ILST	*
C* K. Brill/HPC		 2/03	Set NLINES to number expected		*
C* K. Brill/HPC		 3/03	Set NLINES to max # of any attribute	*
C* K. Brill/HPC          3/07   Fix illbls for repeated patterns	*
C************************************************************************
	INCLUDE		'plt.cmn'
C*
	CHARACTER*(*) 	line
C*
	CHARACTER	group (4)*60
C------------------------------------------------------------------------
	iret = 0
	nexp = numtrc
C
C*	Break list into four groups.
C
	CALL ST_CLST  ( line, '/', '1', 4, group, ng, ier )
C
C*      Decode color, type, width and label parts
C
	CALL ST_ILST ( group (1), ';', 0, MAXLIN, ilcolr, nclr, ier )
        CALL ST_ILST ( group (2), ';', 0, MAXLIN, ildash, ntyp, ier )
        CALL ST_ILST ( group (3), ';', 0, MAXLIN, ilwdth, nwid, ier )
        CALL ST_ILST ( group (4), ';', 0, MAXLIN, illbls, nlab, ier )
C
C*	Set defaults for no entry.
C
	nlines = MAX ( nclr, ntyp, nwid, nlab, nexp )
	IF  ( nclr .eq. 0 )  THEN
	    nclr       = 1
	    ilcolr  (1) = 1
	END IF
	IF  ( ntyp .eq. 0 )  THEN
	    ntyp       = 1
	    ildash  (1) = 1
	END IF
	IF  ( nwid .eq. 0 )  THEN
	    nwid       = 1
	    ilwdth (1) = 1
	END IF
	IF  ( nlab .eq. 0 )  THEN
	    nlab       = 1
	    illbls (1) = 1
	END IF
C
C*	Set labels to 0 and fill marker label array.
C
	DO  i = 1, nlab
            IF  ( illbls (i) .lt. 0 )  illbls (i) = 0
	END DO
C
C*	Set the repeated width patterns to fill buffer.
C
	IF  ( nwid .lt. nexp )  THEN
	    DO  i = nwid + 1, nexp
		j = MOD ( i-1, nwid ) + 1 
		ilwdth (i) = ilwdth ( j )
	    END DO
	END IF
C
C*      Repeat dash type pattern to fill buffer if necessary.
C
	IF  ( ntyp .lt. nexp )  THEN
	    DO  i = ntyp + 1, nexp
		ildash  (i) = ildash  ( MOD ( i-1, ntyp ) + 1 )
	    END DO
        END IF
C
C*      Repeat color pattern to fill buffer if necessary.
C
	IF  ( nclr .lt. nexp )  THEN
	    DO  i = nclr + 1, nexp
		ilcolr  (i) = ilcolr  ( MOD ( i-1, nclr ) + 1 )
	    END DO
        END IF
C
C*      If label is a single number n, then label every nth
C*      trace point with a marker;  otherwise repeat buffer
C*      to fill buffer if necessary.
C
	IF  ( nlab .eq. 1 )  THEN
	    j = illbls (1)
	    DO  i = 1, nexp
		illbls (i) = j
	    END DO
	ELSE
	    IF  ( nlab .lt. nexp )  THEN
	        DO  i = nlab + 1, nexp
		    j = MOD ( i-1, nlab ) + 1
		    illbls (i) = illbls ( j )
	        END DO
	    END IF
        END IF
C*
	RETURN
	END
