	SUBROUTINE PLT_ITAX ( axis, cplbl, xplbl, nplbl, axiso, iret )
C************************************************************************
C* PLT_ITAX								*
C*									*
C* This subroutine processes the time axis control input or just moves	*
C* AXIS into AXISO.							*
C*									*
C* The graphics control file entry for a time axis is formatted as	*
C* follows:								*
C*									*
C*     XAXIS = t_start:t_stop:increment/labfrq;glnfrq;ticfrq		*
C*									*
C* This case implies a time axis.  The strings t_start and t_stop must	*
C* be given in the form YYYYMMDDHH.  The output X axis string will be	*
C* in the form:								*
C*									*
C*	start/stop/increment/labfrq;glnfrq;ticfrq			*
C*									*
C* where start, stop, and increment will be floating point numbers in	*
C* units of days.							*
C*									*
C* If the AXIS input string is not of the form shown, then the output	*
C* string will be set to the input string and RETURN will execute.	*
C*									*
C* PLT_ITAX  ( AXIS, CPLBL, XPLBL, NPLBL, AXISO, IRET )			*
C*									*
C* Input parameters:							*
C*	AXIS		CHAR*		Input for axis			*
C*	CPLBL (NPLBL)	CHAR*		Character date labels		*
C*	XPLBL (NPLBL)	REAL		Label positions			*
C*	NPLBL		INTEGER		Number of labels		*
C*									*
C* Output parameters:							*
C*	AXISO		CHAR		Output axis control string	*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-19 = date-time entry invalid	*
C**									*
C* Log:									*
C* K. Brill/EMC		10/98						*
C************************************************************************
	CHARACTER*(*)	cplbl (*), axis, axiso
	REAL		xplbl (*)
C*
	CHARACTER*72    parts (2), substr (3)
	INTEGER		jdtm1 (5), jdtm2 (5)
	CHARACTER*2	lmo, lda, lhr, lmn
	CHARACTER*4	lyr
	CHARACTER*32	cstrt, cstop
C------------------------------------------------------------------------
	iret = 0
	axiso = axis
	iq = INDEX ( axis, ':' )
	IF ( iq .eq. 0 ) THEN
	    RETURN
	END IF
	cstrt = ' '
	cstop = ' '
	CALL ST_CLST ( axiso, '/', ' ', 2, parts, npt, ier )
	CALL ST_CLST ( parts (1), ':', ' ', 3, substr, nst, ier )
C
C*	Find closest start point and closest end point.
C
	IF ( substr (1) .ne. ' ' ) THEN
	    CALL ST_LSTR ( substr (1), lng, ier )
	    IF ( lng .ne. 10 ) THEN
		iret = -19
		RETURN
	    END IF
	    lyr = substr (1) (1:4)
	    CALL ST_NUMB ( lyr, jdtm1 (1), ier )
	    lmo = substr (1) (5:6)
	    CALL ST_NUMB ( lmo, jdtm1 (2), ier )
	    lda = substr (1) (7:8)
	    CALL ST_NUMB ( lda, jdtm1 (3), ier )
	    lhr = substr (1) (9:10)
	    CALL ST_NUMB ( lhr, jdtm1 (4), ier )
	    jdtm1 (5) = 0
	    ix = 0
	    ier = 1
	    DO WHILE ( ix .lt. nplbl .and. ier .ne. 0 )
		ix = ix + 1
		lyr = cplbl (ix) (1:4)
		CALL ST_NUMB ( lyr, jdtm2 (1), ier1 )
		lmo = cplbl (ix) (5:6)
		CALL ST_NUMB ( lmo, jdtm2 (2), ier )
		ier1 = ier1 + ier
		lda = cplbl (ix) (7:8)
		CALL ST_NUMB ( lda, jdtm2 (3), ier )
		ier1 = ier1 + ier
		lhr = cplbl (ix) (9:10)
		CALL ST_NUMB ( lhr, jdtm2 (4), ier )
		ier1 = ier1 + ier
		lmn = cplbl (ix) (11:12)
		CALL ST_NUMB ( lmn, jdtm2 (5), ier )
		ier1 = ier1 + ier
		IF ( ier1 .ne. 0 ) THEN
		    cstrt = ' '
		    ier = 99
		    ix = nplbl + 1
		END IF
		IF ( ier .eq. 0 )
     +		    CALL TI_MDIF  ( jdtm1, jdtm2, nmin, ier )
		IF ( ier .eq. 0 ) THEN
		    start = xplbl (ix) + FLOAT (nmin) / 1440. 
		    rdiff = ABS ( start - FLOAT ( NINT (start) ) )
		    IF ( rdiff .lt. .0001 )
     +			start = FLOAT ( NINT (start) )
		    CALL ST_RLCH ( start, 4, cstrt, ierr )
		END IF
	    END DO
	END IF
C*
	IF ( substr (2) .ne. ' ' ) THEN
	    CALL ST_LSTR ( substr (2), lng, ier )
	    IF ( lng .ne. 10 ) THEN
		iret = -19
		RETURN
	    END IF
	    lyr = substr (2) (1:4)
	    CALL ST_NUMB ( lyr, jdtm1 (1), ier )
	    lmo = substr (2) (5:6)
	    CALL ST_NUMB ( lmo, jdtm1 (2), ier )
	    lda = substr (2) (7:8)
	    CALL ST_NUMB ( lda, jdtm1 (3), ier )
	    lhr = substr (2) (9:10)
	    CALL ST_NUMB ( lhr, jdtm1 (4), ier )
	    jdtm1 (5) = 0
	    ix = nplbl + 1
	    ier = 1
	    DO WHILE ( ix .gt. 1 .and. ier .ne. 0 )
		ix = ix - 1
		lyr = cplbl (ix) (1:4)
		CALL ST_NUMB ( lyr, jdtm2 (1), ier1 )
		lmo = cplbl (ix) (5:6)
		CALL ST_NUMB ( lmo, jdtm2 (2), ier )
		ier1 = ier1 + ier
		lda = cplbl (ix) (7:8)
		CALL ST_NUMB ( lda, jdtm2 (3), ier )
		ier1 = ier1 + ier
		lhr = cplbl (ix) (9:10)
		CALL ST_NUMB ( lhr, jdtm2 (4), ier )
		ier1 = ier1 + ier
		lmn = cplbl (ix) (11:12)
		CALL ST_NUMB ( lmn, jdtm2 (5), ier )
		ier1 = ier1 + ier
		IF ( ier1 .ne. 0 ) THEN
		    cstop = ' '
		    ier = 99
C----		    ix = 0
		END IF
		IF ( ier .eq. 0 )
     +		    CALL TI_MDIF  ( jdtm1, jdtm2, nmin, ier )
		IF ( ier .eq. 0 ) THEN
		    stop = xplbl (ix) + FLOAT (nmin) / 1440. 
		    stop = xplbl (ix) + FLOAT (nmin) / 1440. 
		    rdiff = ABS ( stop - FLOAT ( NINT (stop) ) )
		    IF ( rdiff .lt. .0001 )
     +			stop = FLOAT ( NINT (stop) )
		    CALL ST_RLCH ( stop, 4, cstop, ierr )
		END IF
	    END DO
	END IF
	CALL ST_LSTR ( cstrt, lng, ier )
	IF ( lng .eq. 0 ) THEN
	    axiso = '/'
	    lno = 1
	ELSE
	    axiso = cstrt (1:lng) // '/'
	    lno = lng + 1
	END IF
	CALL ST_LSTR ( cstop, lng, ier )
	IF ( lng .eq. 0 ) THEN
	    axiso = axiso (1:lno) // '/'
	    lno = lno + 1
	ELSE
	    axiso = axiso (1:lno) // cstop (1:lng) // '/'
	    lno = lno + lng + 1
	END IF
	CALL ST_LSTR ( substr (3), lng, ier )
	IF ( lng .eq. 0 ) THEN
	    axiso = axiso (1:lno) // '/'
	    lno = lno + 1
	ELSE
	    axiso = axiso (1:lno) // substr (3) (1:lng) // '/'
	    lno = lno + lng + 1
	END IF
	IF ( parts (2) .eq. ' ' .and. lno .eq. 3 ) THEN
	    axiso = ' '
	ELSE IF ( parts (2) .ne. ' ' ) THEN
	    axiso = axiso (1:lno) // parts (2)
	END IF
C*
	RETURN
	END
