	SUBROUTINE PLT_IYAX ( axis, rmin, rmax, iptype, iret )
C************************************************************************
C* PLT_IYAX								*
C*									*
C* This subroutine processes the y axis control parameter.		*
C*									*
C* An array of axis label point coordinate values are stored.  The	*
C* frequencies with respect to the elements in the array of values	*
C* for the plotting of labels, grid lines and tick marks are also	*
C* stored.  If any of these frequency values is missing, the		*
C* corresponding stored value is set to default values.  Plotting	*
C* begins  with the first element.					*
C* 									*
C* The graphics control file entry is formatted as follows:		*
C*									*
C*  YAXIS = start/stop/increment/labfrq;glnfrq;ticfrq			*
C*									*
C*   or									*
C*									*
C*  YAXIS = start/stop/value1;value2;...;valueN/labfrq;glnfrq;ticfrq	*
C*									*
C* In the latter case, the increment specification has been replaced	*
C* with a list of values.  Failure to specify START and STOP will	*
C* result in default values determined on the basis of RMIN and RMAX.	*
C* A positive increment will generate values divisible by the 		*
C* increment.  A negative increment will generate values incremented	*
C* from START using the absolute value of the increment.		*
C*									*
C* The increment element may be entered as two values separated by a	*
C* colon (:).  The first value specifies a divisor of the actual	*
C* increment that will be computed.  The second value is the maximum	*
C* number of increments allowed in computing the actual increment.	*
C*									*
C* If IPTYPE = 3, the Y axis is extended by 5% to accomodate display	*
C* of OBS count numbers.						*
C*									*
C* PLT_IYAX  ( AXIS, RMIN, RMAX, IPTYPE, IRET )				*
C*									*
C* Input parameters:							*
C*	AXIS		CHAR*		Input for axis			*
C*	RMIN            REAL            Data minimum			*
C*	RMAX            REAL            Data maximum			*
C*	IPTYPE		INTEGER		TYPE of data display		*
C*					  0 - print trace statistics	*
C*					  1 - time series		*
C*					  2 - scatter plot		*
C*					  3 - skill score vs thrshlds	*
C*					  4 - bins			*
C*					  5 - histogram			*
C*					  6 - ROC curve			*
C*					  7 - attribute diagram		*
C*                                        8 - Quantile RELI diagram     *
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98   Created from IN_AXIS 			*
C* K. BRill/EMC		 4/98	Added IPTYPE				*
C* K. Brill/EMC		 4/98	Clean up / bug fixes			*
C* K. Brill/EMC		10/98	Set lower axis bound = 0 for histogram	*
C* K. Brill/HPC		 9/03	Document IPTYPE=6			*
C* K. Brill/HPC		 8/05	Halt DO WHILE if |IPWR| gets too big	*
C* K. Brill/HPC		 3/06	Add base value:max # increments input	*
C* K. Brill/HPC      20070125   Document iptype = 7			*
C* K. Brill/IMSG     20160718   Document iptype = 8			*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C*
	CHARACTER*(*)	axis
C*
	CHARACTER*72    substr (4)
	INTEGER         ihold (3)
	LOGICAL ERMISS
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
	rint = RMISSD
	dmin = rmin
	dmax = rmax
	ilfdef = 1
	igfdef = 0
	itfdef = 1
C
C*	Set DMIN and DMAX under appropriate circumstances.
C
	IF ( dmin .eq. dmax ) THEN
	  IF ( dmin .eq. 0. ) THEN
	    dmin = -.5
	    dmax =  .5
	  ELSE
	    test = abs ( dmin )
	    ipow = ALOG10 ( test ) - 1
	    add  = .5 * ( 10. ** ipow )
	    dmax = dmax + add
	    dmin = dmin - add
	  END IF
	END IF
C
C*      Break AXIS into four substrings.
C
	CALL ST_CLST ( axis, '/', ' ', 4, substr, nst, ier )
C
C*	Break the fourth substring into 3 frequency integers.  If the
C*      values are missing, set them to the input default values.
C
	CALL ST_ILST ( substr (4), ';', IMISSD, 3, ihold, nm, ier )
	DO i = 1, 3
	  IF ( ihold (i) .lt. 0 ) ihold (i) = IMISSD
	END DO
	IF  ( ihold (1) .ne. IMISSD )	THEN
            ilbfry = ihold (1)
	ELSE
	    ilbfry = ilfdef
        END IF
	IF  ( ihold (2) .ne. IMISSD )   THEN
            iglfry = ihold (2)
        ELSE
            iglfry = igfdef
	END IF
        IF  ( ihold (3) .ne. IMISSD )	THEN
            itmfry = ihold (3)
        ELSE
	    itmfry = itfdef
        END IF
C
C*      Decode START and STOP from first and second substrings.
C
	CALL ST_CRNM ( substr (1), start, ier )
	CALL ST_CRNM ( substr (2), stop,  ier )
C
C*      If START and STOP are still missing, establish defaults.
C
	IF ( ERMISS ( start ) ) THEN
	    start = dmin - .0375 * ABS ( dmax - dmin )
	END IF
	IF ( ERMISS ( stop ) ) THEN
	    stop = dmax + .0375 * ABS ( dmax - dmin )
	END IF
C
C*	At this point START and STOP are defined and not missing.
C
C*      Look at the third substring to see if it contains a list of
C*      values, a single number giving the increment, or specification
C*      of an increment divisor : maximum number of increments.
C
	icolon = INDEX ( substr (3), ':' )
	IF ( icolon .ne. 0 ) THEN
C
C*	    The "increment divisor : max increments" has been given.
C
	    CALL ST_RLST ( substr (3), ':', RMISSD, MAXVAL,
     +                     yaxval, nval, ier )
	    IF ( .not. ERMISS ( yaxval (1) ) ) rint = ABS (yaxval (1))
	    IF ( .not. ERMISS ( yaxval (2) ) ) THEN
		rmxdy = ABS ( FLOAT ( NINT ( yaxval (2) ) ) )
	    ELSE
	        rmxdy = 10.0
	    END IF
	ELSE
C
C*	    Either a list of values or an increment is specified.
C
	    CALL ST_RLST ( substr (3), ';', RMISSD, MAXVAL,
     +                     yaxval, nval, ier )
	    IF ( .not. ERMISS ( yaxval (1) ) ) rint = yaxval (1)
	    rmxdy = 10.0
	END IF
C
C*	Generate axis labels.
C
C*	If NVAL is not 1, do nothing; otherwise, generate the values
C*      using the start value, the increment and the stop value.
C
	IF ( nval .gt. 1 .and. icolon .eq. 0 ) THEN
C
C*          Do nothing.
C
	ELSE IF ( rint .eq. 0.0 ) THEN
	    nval = 2
	    yaxval (1) = start
	    yaxval (2) = stop
C*
	ELSE IF ( rint .gt. 0 .or. ERMISS ( yaxval (1) ) ) THEN
C
C*	    Set a convenient default interval.
C
	    IF ( ERMISS (rint) ) THEN
		delx = ABS ( stop - start )
		alpha = delx / rmxdy
		ipwr = 0
		DO WHILE ( ( alpha .lt. 1 .or. alpha .gt. rmxdy ) .and.
     +			     alpha .ne. 0.0 .and.
     +                       IABS (ipwr) .lt. 29 )
		    IF ( alpha .lt. 1. ) THEN
			ipwr = ipwr - 1
			alpha = alpha * rmxdy
		    ELSE IF ( alpha .gt. rmxdy ) THEN
			ipwr = ipwr + 1
			alpha = alpha / rmxdy
		    END IF
		END DO
		dy = FLOAT ( NINT ( alpha ) )
		rint = dy * rmxdy ** ipwr
	    ELSE IF ( icolon .ne. 0 ) THEN
C
C*		Solve (10**alpha * delx) / rint = rmxdy for alpha.
C*		The new value of rint is rint * 10 ** (-alpha).
C*		Adjust rint by an integer multiple if too big.
C
		delx = ABS ( stop - start )
		alpha = NINT ( ALOG10 ((rint * rmxdy) / delx) )
		rint = rint * 10 ** (-alpha)
		IF ( delx / rint .gt. rmxdy ) THEN
		    alpha = INT ( delx / (rmxdy * rint) ) + 1
		    IF ( alpha .lt. 1.0 ) alpha = 1.0
		    rint = alpha * rint
		END IF
	    END IF
C
C*	    Find multiplier to use for RINT to compute minimum value;
C*	    then, compute axis values divisible by the interval.
C
	    k   =  start / rint
	    xstrt = FLOAT (k) * rint
	    dq = rint
	    IF ( start .gt. stop .and. dq .gt. 0.0 ) dq = -dq
	    diff = ABS ( stop - start )
	    yaxval (1) = xstrt
	    nval = 1
	    chck = ABS ( yaxval (nval) + dq - start )
	    DO WHILE ( nval .lt. MAXVAL .and. chck .le. diff )
		nval = nval + 1
		yaxval ( nval ) = yaxval ( nval - 1 ) + dq 
		IF ( ABS ( yaxval (nval) - 0.0 ) .lt.
     +			.05 * ABS (dq) ) yaxval (nval) = 0.0
		chck = ABS ( yaxval (nval) + dq - start )
	    END DO

C*
	ELSE IF ( yaxval (1) .lt. 0 ) THEN
C
C*	    Set values by incrementing from START.
C
	    dq = -yaxval (1)
	    IF ( start .gt. stop .and. dq .gt. 0.0 ) dq = -dq
	    diff = ABS ( stop - start )
	    yaxval (1) = start
	    nval = 1
	    chck = ABS ( yaxval (nval) + dq - start )
	    DO WHILE ( nval .lt. MAXVAL .and. chck .le. diff )
		nval = nval + 1
		yaxval ( nval ) = yaxval ( nval - 1 ) + dq 
		IF ( ABS ( yaxval (nval) - 0.0 ) .lt.
     +			.05 * ABS (dq) ) yaxval (nval) = 0.0
		chck = ABS ( yaxval (nval) + dq - start )
	    END DO
	END IF
	yaxbeg = start
	yaxend = stop
	nyaxvl = nval
C*
	IF ( iptype .eq. 3 ) THEN
	    dy = ABS ( start - stop ) * .05
	    IF ( start .gt. stop ) dy = -dy
	    yaxend = yaxend + dy
	END IF
	IF ( iptype .eq. 5 ) THEN
	    yaxbeg = 0.0
	END IF
C*
	RETURN
	END
