	SUBROUTINE PLT_IYRX ( axis, rmin, rmax, iptype, iret )
C************************************************************************
C* PLT_IYRX								*
C*									*
C* This subroutine processes the right-side y axis control parameter.	*
C*									*
C* An array of axis label point coordinate values are stored.  The	*
C* frequencies with respect to the elements in the array of values	*
C* for the plotting of labels, grid lines and tick marks are also	*
C* stored.  If any of these frequency values is missing, the		*
C* corresponding stored value is set to default values.  Plotting	*
C* begins  with the first element.					*
C* 									*
C* The graphics control file entry is formatted as follows:		*
C*									*
C*  YAXIS = start/stop/increment/labfrq;glnfrq;ticfrq			*
C*									*
C*   or									*
C*									*
C*  YAXIS = start/stop/value1;value2;...;valueN/labfrq;glnfrq;ticfrq	*
C*									*
C* In the latter case, the increment specification has been replaced	*
C* with a list of values.  Failure to specify START and STOP will	*
C* result in default values determined on the basis of RMIN and RMAX.	*
C* A positive increment will generate values divisible by the 		*
C* increment.  A negative increment will generate values incremented	*
C* from START using the absolute value of the increment.		*
C*									*
C* If IPTYPE = 3, the Y axis is extended by 5% to accomodate display	*
C* of OBS count numbers.						*
C*									*
C* PLT_IYRX  ( AXIS, RMIN, RMAX, IPTYPE, IRET )				*
C*									*
C* Input parameters:							*
C*	AXIS		CHAR*		Input for axis			*
C*	RMIN            REAL            Data minimum			*
C*	RMAX            REAL            Data maximum			*
C*	IPTYPE		INTEGER		TYPE of data display		*
C*					  0 - print trace statistics	*
C*					  1 - time series		*
C*					  2 - scatter plot		*
C*					  3 - skill score vs thrshlds	*
C*					  4 - bins			*
C*					  5 - histogram			*
C*					  6 - ROC curve			*
C*					  7 - attributes diagram	*
C*                                        8 - Quantile RELI diagram     *
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/EMC		 3/01   Created from PLT_IYAX 			*
C* K. Brill/HPC		 9/03	Document IPTYPE=6			*
C* K. Brill/HPC      20070125	Document IPTYPE=7			*
C* K. Brill/IMSG     20160718	Document IPTYPE=8			*
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C*
	CHARACTER*(*)	axis
C*
	CHARACTER*72    substr (4)
	INTEGER         ihold (3)
	LOGICAL ERMISS
C*
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
	rint = RMISSD
	dmin = rmin
	dmax = rmax
	ilfdef = 1
	igfdef = 0
	itfdef = 1
C
C*	Set DMIN and DMAX under appropriate circumstances.
C
	IF ( dmin .eq. dmax ) THEN
	  IF ( dmin .eq. 0. ) THEN
	    dmin = -.5
	    dmax =  .5
	  ELSE
	    test = abs ( dmin )
	    ipow = ALOG10 ( test ) - 1
	    add  = .5 * ( 10. ** ipow )
	    dmax = dmax + add
	    dmin = dmin - add
	  END IF
	END IF
C
C*      Break AXIS into four substrings.
C
	CALL ST_CLST ( axis, '/', ' ', 4, substr, nst, ier )
C
C*	Break the fourth substring into 3 frequency integers.  If the
C*      values are missing, set them to the input default values.
C
	CALL ST_ILST ( substr (4), ';', IMISSD, 3, ihold, nm, ier )
	DO i = 1, 3
	  IF ( ihold (i) .lt. 0 ) ihold (i) = IMISSD
	END DO
	IF  ( ihold (1) .ne. IMISSD )	THEN
            ilrfry = ihold (1)
	ELSE
	    ilrfry = ilfdef
        END IF
	IF  ( ihold (2) .ne. IMISSD )   THEN
            igrfry = ihold (2)
        ELSE
            igrfry = igfdef
	END IF
        IF  ( ihold (3) .ne. IMISSD )	THEN
            itrfry = ihold (3)
        ELSE
	    itrfry = itfdef
        END IF
C
C*      Decode START and STOP from first and second substrings.
C
	CALL ST_CRNM ( substr (1), start, ier )
	CALL ST_CRNM ( substr (2), stop,  ier )
C
C*      If START and STOP are still missing, establish defaults.
C
	IF ( ERMISS ( start ) ) THEN
	    start = dmin - .0375 * ABS ( dmax - dmin )
	END IF
	IF ( ERMISS ( stop ) ) THEN
	    stop = dmax + .0375 * ABS ( dmax - dmin )
	END IF
C
C*	At this point START and STOP are defined and not missing.
C
C*      Look at the third substring to see if it contains a list of
C*      values, a single number giving the increment or a request for
C*      mandatory levels.
C
	CALL ST_RLST ( substr (3), ';', RMISSD, MAXVAL,
     +                 yrxval, nval, ier )
	IF ( .not. ERMISS ( yrxval (1) ) ) rint = yrxval (1)
C
C*	Generate axis labels.
C
C*	If NVAL is not 1, do nothing; otherwise, generate the values
C*      using the start value, the increment and the stop value.
C
	IF ( nval .gt. 1 ) THEN
C
C*          Do nothing.
C
	ELSE IF ( yrxval (1) .eq. 0.0 ) THEN
	    nval = 2
	    yrxval (1) = start
	    yrxval (2) = stop
C*
	ELSE IF ( yrxval (1) .gt. 0 .or. ERMISS ( yrxval (1) ) ) THEN
C
C*	    Set a convenient default interval.
C
	    IF ( ERMISS (rint) ) THEN
		delx = ABS ( stop - start )
		alpha = delx / 10.0
		ipwr = 0
		DO WHILE ( ( alpha .lt. 1 .or. alpha .gt. 10 ) .and.
     +			     alpha .ne. 0.0 )
		    IF ( alpha .lt. 1. ) THEN
			ipwr = ipwr - 1
			alpha = alpha * 10.
		    ELSE IF ( alpha .gt. 10 ) THEN
			ipwr = ipwr + 1
			alpha = alpha / 10.
		    END IF
		END DO
		dy = FLOAT ( NINT ( alpha ) )
		rint = dy * 10. ** ipwr
	    END IF
C
C*	    Find multiplier to use for RINT to compute minimum value;
C*	    then, compute axis values divisible by the interval.
C
	    k   =  start / rint
	    xstrt = FLOAT (k) * rint
	    dq = rint
	    IF ( start .gt. stop .and. dq .gt. 0.0 ) dq = -dq
	    diff = ABS ( stop - start )
	    yrxval (1) = xstrt
	    nval = 1
	    chck = ABS ( yrxval (nval) + dq - start )
	    DO WHILE ( nval .lt. MAXVAL .and. chck .le. diff )
		nval = nval + 1
		yrxval ( nval ) = yrxval ( nval - 1 ) + dq 
		IF ( ABS ( yrxval (nval) - 0.0 ) .lt.
     +			.05 * ABS (dq) ) yrxval (nval) = 0.0
		chck = ABS ( yrxval (nval) + dq - start )
	    END DO

C*
	ELSE IF ( yrxval (1) .lt. 0 ) THEN
C
C*	    Set values by incrementing from START.
C
	    dq = -yrxval (1)
	    IF ( start .gt. stop .and. dq .gt. 0.0 ) dq = -dq
	    diff = ABS ( stop - start )
	    yrxval (1) = start
	    nval = 1
	    chck = ABS ( yrxval (nval) + dq - start )
	    DO WHILE ( nval .lt. MAXVAL .and. chck .le. diff )
		nval = nval + 1
		yrxval ( nval ) = yrxval ( nval - 1 ) + dq 
		IF ( ABS ( yrxval (nval) - 0.0 ) .lt.
     +			.05 * ABS (dq) ) yrxval (nval) = 0.0
		chck = ABS ( yrxval (nval) + dq - start )
	    END DO
	END IF
	yrxbeg = start
	yrxend = stop
	nyrxvl = nval
C*
	IF ( iptype .eq. 3 ) THEN
	    dy = ABS ( start - stop ) * .05
	    IF ( start .gt. stop ) dy = -dy
	    yrxend = yrxend + dy
	END IF
	IF ( iptype .eq. 5 ) THEN
	    yrxbeg = 0.0
	END IF
C*
	RETURN
	END
