	SUBROUTINE PLT_MLBL ( numtrc, itrcs, prmnam, iptype, method,
     +			      rfphg, cstat, iret )
C************************************************************************
C* PLT_MLBL								*
C*									*
C* This subroutine makes the plot title, axis labels and trace key	*
C* labels.								*
C*									*
C* The label level parameter (LABLEV) is interpreted as follows:	*
C*									*
C*  LABLEV		Action						*
C*    0		No labels						*
C*    1         Mix of user-defined and default labels			*
C*    2		Plot ONLY user defined title and trace key labels	*
C*									*
C* LABLEV is in the plt.cmn data structure.				*
C*									*
C* PLT_MLBL  ( NUMTRC, ITRCS, PRMNAM, IPTYPE, METHOD, RFPHG, IRET )	*
C*									*
C* Input parameters:							*
C*	NUMTRC		INTEGER		Number of traces to plot	*
C*	ITRCS (NUMTRC)	INTEGER		Trace numbers			*
C*	PRMNAM (NUMTRC)	CHAR*		Parameter name from RDTD_TRC	*
C*	IPTYPE		INTEGER		Plot type			*
C*					  0 - print trace statistics	*
C*					  1 - time series		*
C*					  2 - scatter plot		*
C*					  3 - skill score vs threshold	*
C*					  4 - bins			*
C*					  5 - histogram			*
C*					  6 - ROC curve			*
C*					  7 - Attribute diagram		*
C*					  8 - Quantile RELI diagram     *
C*	METHOD		INTEGER		Display method:			*
C*					  1 - display plot as defined	*
C*					  2 - arbitrary traces & opcodes*
C*					      (an opcode for each trc)	*
C*					  3 - compute difference	*
C*					      between two traces for a	*
C*					      single opcode and display *
C*					  4 - compute % difference	*
C*					      between two traces for a	*
C*					      single opcode and display *
C*					  5 - compute skill score using *
C*					      2nd trace as reference	*
C*	RFPHG		LOGICAL		Flag for RFP histogram		*
C*	CSTAT		CHAR*		Statistic type string		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 +6 = invalid LABLEV value	*
C**									*
C* Log:									*
C* K. Brill/EMC		 1/98						*
C* K. Brill/EMC		 4/98	IF IPTYPE = 2, put PRMNAM in PTITLE	*
C* K. Brill/EMC		10/98	Changes for METHOD; allow mix of user-	*
C*				defined and default labels; IPTYPE = 0	*
C* K. Brill/EMC		 1/99	Changes METHOD = 3			*
C* K. Brill/HPC		 3/01	Changes for right-side yaxis		*
C* K. Brill/HPC		 5/01	Default labels for RPF histogram	*
C* K. Brill/HPC		 2/03	Changes for method = 5			*
C* K. Brill/HPC		 9/03	Changes for ROC curve (IPTYPE=6)	*
C* K. Brill/HPC		 3/04	Set default X axis lbl for talagd=.true.*
C* K. Brill/HPC		 5/04	Changed talagd to dornkh		*
C* K. Brill/HPC		 5/05	Set default X axis lbl for dodd2t=.true.*
C* K. Brill/HPC      20070125   Changes for attribute diagram		*
C* K. Brill/HPC      20090518   Pass in cstat and use to set appropriate*
C*				default xaxlbl for FSS stat type	*
C* K. Brill/HPC      20120320	Add box-whisker alpha value to title	*
C* K. Brill/IMSG     20160718   Handle IPTYPE == 8                      *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( MXLNS = MAXLIN )
C*
	INTEGER		itrcs (*)
	CHARACTER*(*)	prmnam (*), cstat
	LOGICAL		rfphg
C*
	CHARACTER*32	lbl (MXLNS), stat, parm
	CHARACTER*5	fld (MXLNS)
	CHARACTER*6	calfa
	INTEGER		nchrs (MXLNS), lngs (MXLNS)
	INTEGER		nfld (MXLNS)
	LOGICAL		mktlb (MXLNS), diffr, dfnum, ttlad, usdpr
C*
	INTEGER		iarchy (10)
	DATA		iarchy / 12, 10, 2, 3, 8, 9, 13, 14, 11, 6 /
	DATA		narchy / 10 /
	SAVE		narchy, iarchy
C*-----------------------------------------------------------------------
	iret = 0
	IF ( method .eq. 3 .or. method .eq. 4 .or. method .eq. 5 ) THEN
	    nmtr = 2
	ELSE
	    nmtr = numtrc
	END IF
	IF ( lablev .lt. 0 .or. lablev .gt. 2 ) THEN
	    iret = +6
	    CALL PLT_ERRO ( iret, ' ', ier )
	    RETURN
	END IF
C
C*	Make labels according to action specification.
C
	IF ( lablev .eq. 0 ) THEN
C
C*	    No labels.
C
	    RETURN
	END IF
C
C*	Check to see if labels are already set by user input.
C
	IF ( lablev .eq. 2 ) RETURN
C
C*	Construct default labels.
C
	IF ( dornkh .and. xaxlbl .eq. ' ' ) THEN
	    xaxlbl = 'ANALYSIS RANK W.R.T. ENSEMBLE'
	ELSE IF ( dodd2t .and. xaxlbl .eq. ' ' .and.
     +		  iptype .ne. 2 ) THEN
	    xaxlbl = 'DATA FIELD DEPTH POSITION'
	ELSE IF ( iptype .eq. 1 ) THEN
	    IF ( xaxlbl .eq. ' ' ) xaxlbl = 'TIME (YYMMDD/HHNN)'
	ELSE IF ( xaxlbl .eq. ' ' .and. iptype .eq. 3 .and.
     +		  INDEX ( cstat, 'FSS' ) .ne. 0 ) THEN
	    xaxlbl = 'SPATIAL SCALE (KM)'
	ELSE IF ( xaxlbl .eq. ' ' .and. iptype .ne. 2 .and.
     +		  iptype .ne. 5 .and. iptype .ne. 6 .and.
     +            iptype .ne. 7 .and. iptype .ne. 8 ) THEN
	    CALL RDTD_XLB ( xaxlbl, nchrs, ncdpt, ncnds, ier )
	ELSE IF ( xaxlbl .eq. ' ' .and. iptype .eq. 6 ) THEN
	    xaxlbl = 'FALSE ALARM RATE'
	ELSE IF ( xaxlbl .eq. ' ' .and. iptype .eq. 7 ) THEN
	    xaxlbl = 'FORECAST PROBABILITY'
	ELSE IF ( xaxlbl .eq. ' ' .and. iptype .eq. 8 ) THEN
	    xaxlbl = 'FORECAST QUANTILE'
	END IF
	IF ( ptitle .ne. ' ' ) THEN
	    ttlad = .false.
	ELSE
	    ttlad = .true.
	END IF
	usdpr = .false.
	
C
C*	See if the parameter names differ.  If they do, they can be
C*	used in the trace key instead of the trace labels.
C
	diffr = .false.
	dfnum = .false.
	IF ( nmtr .gt. 1 ) THEN
	    DO i = 1, nmtr
		DO j = i+1, nmtr
		    IF ( prmnam (i) .ne. prmnam (j) ) diffr = .true.
		    IF ( itrcs (i) .ne. itrcs (j) ) dfnum = .true.
		END DO
	    END DO
	END IF
	DO i = 1, nmtr
	   mktlb (i) = ( trclbl (i) .eq. ' ' )
	   lngs (i) = 0
	END DO
C
C*	General labels always go to title string.
C
	lng = 0
	CALL RDTD_GLB ( MXLNS, nlns, lbl, nchrs, fld, nfld,
     +			stat, ier )
	nhave = 0
	IF ( stat .ne. ' ' .and. stat .ne. 'NONE' .and.
     +	     ttlad ) THEN
	    CALL PLT_ADLB ( 'STAT', stat, ptitle,
     +			    lng, ier )
	    nhave = 10
	END IF
	IF ( nlns .gt. 0 .and. ttlad ) THEN
	    CALL PLT_MTTL ( fld, nfld, lbl, nlns, nhave, ptitle,
     +			    lng, ier )
	END IF
	IF ( iptype .eq. 0 ) THEN
	    DO i = 1, nmtr
		IF ( mktlb (i) ) THEN
		    CALL PLT_ADLB ( 'PARM', prmnam (i), trclbl (i),
     +				    lngs (i), ier )
		    it = itrcs (i)
		    CALL RDTD_TLB ( it, MXLNS, nlns, lbl, nchrs,
     +				    fld, nfld, stat, parm, ier )
		    CALL PLT_MTTL ( fld, nfld, lbl, nlns, nhave,
     +				    trclbl (i), lngs (i), ier )
		END IF
	    END DO
	    RETURN
	END IF
C*
	IF ( .not. dfnum ) THEN
	    sngltr = .true.
C
C*	    CASE 1:  single trace is source of all data.
C
	    DO i = 1, nmtr
		IF ( mktlb (i) )
     +		CALL PLT_ADLB ( 'PARM', prmnam (i), trclbl (i),
     +				lngs (i), ier )
	    END DO
	    usdpr = .true.
	    IF ( ttlad ) THEN
		it = itrcs (1)
		CALL RDTD_TLB ( it, MXLNS, nlns, lbl, nchrs, fld, nfld,
     +			        stat, parm, ier )
		CALL PLT_MTTL ( fld, nfld, lbl, nlns, nhave, ptitle,
     +				lng, ier )
	    END IF
	ELSE
	    sngltr = .false.
C
C*	    CASE 2:  multiple traces are source of data.
C
	    IF ( diffr ) THEN
		DO i = 1, nmtr
		    IF ( mktlb (i) ) THEN
			CALL PLT_ADLB ( 'PARM', prmnam (i), trclbl (i),
     +					lngs (i), ier )
			it = itrcs (i)
			CALL RDTD_TLB ( it, MXLNS, nlns, lbl, nchrs,
     +					fld, nfld, stat, parm, ier )
			CALL PLT_MTTL ( fld, nfld, lbl, nlns, nhave,
     +					trclbl (i), lngs (i), ier )
		    END IF
		    usdpr = .true.
		END DO
	    ELSE
		DO i = 1, nmtr
		    IF ( mktlb (i) ) THEN
			it = itrcs (i)
			CALL RDTD_TLB ( it, MXLNS, nlns, lbl, nchrs,
     +					fld, nfld, stat, parm, ier )
			CALL PLT_MTTL ( fld, nfld, lbl, nlns, nhave,
     +					trclbl (i), lngs (i), ier )
		    END IF
		END DO
	    END IF
	END IF
C*
	IF ( iptype .eq. 2 ) THEN
	    IF ( xaxlbl .eq. ' ' ) xaxlbl = trclbl (1)
	    IF ( yaxlbl .eq. ' ' ) yaxlbl = trclbl (2)
	    IF ( .not. usdpr ) THEN
		IF ( diffr ) THEN
		    CALL ST_LSTR ( xaxlbl, lngx, ier )
		    CALL PLT_ADLB ( 'PARM', prmnam (1), xaxlbl,
     +				    lngx, ier )
		    CALL ST_LSTR ( yaxlbl, lngx, ier )
		    CALL PLT_ADLB ( 'PARM', prmnam (2), yaxlbl,
     +				    lngx, ier )
		ELSE
		    CALL PLT_ADLB ( 'PARM', prmnam (1), ptitle,
     +				    lng, ier )
		END IF
		usdpr = .true.
	    END IF
	END IF
	IF ( iptype .eq. 6 ) THEN
	    IF ( xaxlbl .eq. ' ' ) xaxlbl = 'FALSE ALARM RATE'
	    IF ( yaxlbl .eq. ' ' ) yaxlbl = 'HIT RATE'
	    usdpr = .true.
	END IF
	IF ( iptype .eq. 7 ) THEN
	    IF ( xaxlbl .eq. ' ' ) xaxlbl = 'FORECAST PROBABILITY'
	    IF ( yaxlbl .eq. ' ' ) yaxlbl = 'OBSERVED FREQUENCY'
	    usdpr = .true.
	    IF ( ttlad ) THEN
		CALL PLT_ADLB ( ' ', ctmrng, ptitle, lng, ier )
	    END IF
	END IF
	IF ( iptype .eq. 8 ) THEN
	    IF ( xaxlbl .eq. ' ' ) xaxlbl = 'FORECAST QUANTILE'
	    IF ( yaxlbl .eq. ' ' ) yaxlbl = 'OBS CUMULTV FRQNCY'
	    usdpr = .true.
	END IF
	IF ( iptype .eq. 5 .and. .not. rfphg ) THEN
	    IF ( xaxlbl .eq. ' ' ) xaxlbl = trclbl (1)
	    IF ( yaxlbl .eq. ' ' ) yaxlbl = 'RELATIVE FREQUENCY'
	    IF ( .not. usdpr ) THEN
		CALL ST_LSTR ( xaxlbl, lngx, ier )
		CALL PLT_ADLB ( 'PARM', prmnam (1), xaxlbl,
     +				lngx, ier )
		usdpr = .true.
	    END IF
	END IF
	IF ( rfphg ) THEN
	    IF ( xaxlbl .eq. ' ' )
     +		xaxlbl = 'PLACEMENT FOR ' // trclbl (1)
	    IF ( yaxlbl .eq. ' ' )
     +		yaxlbl = 'RELATIVE PLACEMENT FREQUENCY'
	    IF ( .not. usdpr ) THEN
		CALL ST_LSTR ( xaxlbl, lngx, ier )
		CALL PLT_ADLB ( 'PLACEMENT FOR PARM', prmnam (1),
     +			        xaxlbl, lngx, ier )
		usdpr = .true.
	    END IF
	END IF
	IF ( yaxlbl .eq. ' ' ) THEN
	    IF ( .not. diffr .or. method .eq. 3
     +		 .or. method .eq. 4 .or.
     +		 method .eq. 5 ) THEN
		yaxlbl = prmnam (ifstls)
		usdpr = .true.
	    ELSE
		yaxlbl = prmnam (ifstls)
		DO i = 1, nmtr
		    IF ( .not. rhttrc (i) .and. i .ne. ifstls ) THEN
			CALL ST_LSTR ( yaxlbl, ly, ier )
			yaxlbl = yaxlbl (1:ly) // ' | ' // prmnam (i)
		    END IF
		END DO
		usdpr = .true.
	    END IF
	END IF
	IF ( iptype .eq. 7 ) THEN
	    IF ( yrxlbl .eq. ' ' .and. nhstgm .gt. 0 ) THEN
		yrxlbl = 'FREQUENCY OF FORECAST USE HISTOGRAM'
	    END IF
	END IF
	IF ( yrxlbl .eq. ' ' .and. rhtdrw ) THEN
	    IF ( .not. diffr .or. method .eq. 3
     +		 .or. method .eq. 4 .or.
     +		 method .eq. 5 ) THEN
		yrxlbl = prmnam (ifstrs)
		usdpr = .true.
	    ELSE
		yrxlbl = prmnam (ifstrs)
		DO i = 1, nmtr
		    IF (  rhttrc (i) .and. i .ne. ifstrs ) THEN
			CALL ST_LSTR ( yrxlbl, ly, ier )
			yrxlbl = yrxlbl (1:ly) // ' | ' // prmnam (i)
		    END IF
		END DO
		usdpr = .true.
	    END IF
	END IF
	IF ( .not. usdpr ) THEN
C
C*	    Add parm names to trace labels if not used.
C
	    DO i = 1, nmtr
		IF ( mktlb (i) )
     +		CALL PLT_ADLB ( 'PARM', prmnam (i), trclbl (i),
     +				lngs (i), ier )
	    END DO
	END IF
	IF ( mktlb (1) .and.
     +	     ( method .eq. 3 .or. method .eq. 4 .or.
     +         method .eq. 5 ) ) THEN
	    CALL ST_LSTR ( trclbl (1), ln, ier )
	    trclbl (1) = trclbl (1) (1:ln) // ' - ' //
     +			 trclbl (2)
	END IF
	IF ( method .eq. 3 ) THEN
	    CALL ST_LSTR ( yaxlbl, ln, ier )
	    yaxlbl = yaxlbl (1:ln) // ' DIFFERENCE '
	    IF ( rhtdrw ) THEN
		CALL ST_LSTR ( yrxlbl, ln, ier )
		yrxlbl = yrxlbl (1:ln) // ' DIFFERENCE '
	    END IF
	END IF
	IF ( method .eq. 4 ) THEN
	    CALL ST_LSTR ( yaxlbl, ln, ier )
	    yaxlbl = yaxlbl (1:ln) // ' % DIFFERENCE '
	    IF ( rhtdrw ) THEN
		CALL ST_LSTR ( yrxlbl, ln, ier )
		yrxlbl = yrxlbl (1:ln) // ' % DIFFERENCE '
	    END IF
	END IF
	IF ( method .eq. 5 ) THEN
	    CALL ST_LSTR ( yaxlbl, ln, ier )
	    yaxlbl = yaxlbl (1:ln) // ' SKILL SCORE '
	    IF ( rhtdrw ) THEN
		CALL ST_LSTR ( yrxlbl, ln, ier )
		yrxlbl = yrxlbl (1:ln) // ' SKILL SCORE '
	    END IF
	END IF
C
C*	If this is an attribute diagram and histogram colors are
C*      set for the frequency of use, then add the frequency of
C*      use trace labels.
C
	IF ( iptype .eq. 7 ) THEN
	    ixtr = nmtr/2
	    DO i = 1, nmtr/2
		ixtr = ixtr + 1
		IF ( nhstgm .gt. 0 ) THEN
		    IF ( .not. usrlbl (ixtr) ) THEN
	    	        CALL ST_LSTR ( trclbl (ixtr), ln, ier )
			trclbl(ixtr) = trclbl(ixtr)(1:ln) //
     +					' USE HISTOGRAM'
		    END IF
		ELSE
		    IF ( .not. usrlbl (ixtr) ) THEN
	    	        CALL ST_LSTR ( trclbl (ixtr), ln, ier )
			trclbl(ixtr) = trclbl(ixtr)(1:ln) //
     +					' FRCST USE FREQUENCY'
		    END IF
		END IF
	    END DO
C
C*	    Now add reliability trace qualifiers.
C
	    DO i = 1, nmtr/2
		IF ( .not. usrlbl (i) ) THEN
	   	    CALL ST_LSTR ( trclbl (i), ln, ier )
		    trclbl(i) = trclbl(i)(1:ln) // ' RELIABILITY'
		END IF
	    END DO
	END IF
C
C*	Add the box-whisker ALPHA value to the title.
C
	IF ( bxwflg .and. ttlad ) THEN
	    CALL ST_RLCH ( bxplvl, 3, calfa, ier )
	    CALL ST_LSTR ( ptitle, lngx, ier )
	    CALL PLT_ADLB ( 'CI ALPHA', calfa, ptitle, lngx, ier )
	END IF
C*
	RETURN
	END
