	SUBROUTINE PLT_OBXW ( mp, mt, ntrc, trc, xpts, npts, iret )
C************************************************************************
C* PLT_OBXW								*
C*									*
C* This subroutine overlays requested box-whisker objects on existing	*
C* graph.								*
C*									*
C* PLT_OBXW  ( MP, MT, NTRC, TRC, XPTS, NPTS, IRET )			*
C*									*
C* Input parameters:							*
C*	MP		INTEGER		Maximum points on a trace	*
C*	MT		INTEGER		Maximum number of traces	*
C*	NTRC		INTEGER		Number of traces to plot	*
C*	TRC (MP,MT)	REAL		Trace data			*
C*	XPTS (MP,MT)	REAL		x coordinates of trace points	*
C*	NPTS (MT)	INTEGER		Number of trace points		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-38 = X point counts differ	*
C*					-39 = resampling error		*
C*					-40 = wrong # of box objects	*
C**									*
C* Log:									*
C* K. Brill/HPC		 3/12						*
C* K. Brill/WPC          2/14		Pass icc to PLT_GBXW		*
C* K. Brill/WPC          8/14           Add smdn median differences     *
C* K. Brill/WPC          9/14           Add skew ratio for differences; *
C*                                      sbxls has below/above median box*
C*                                      lengths to reflect skewness     *
C* K. Brill/WPC      20141104           Check for missing skew ratio    *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., RDIFFD = 0.1 )
C*
	REAL		trc (mp,mt), xpts (mp,mt)
	INTEGER		npts (*)
C*
	REAL		sbxls (MXTRCS,2), smxs (MXTRCS), smns (MXTRCS)
        REAL            smdn (MXTRCS), skew (MXTRCS)
	LOGICAL		ERMISS
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C*-----------------------------------------------------------------------
	iret = 0
C*
	IF ( .not. bxwflg ) RETURN
C
C*	Check to see that all traces have the same number of X points.
C
	nchk = npts (1)
	DO it = 2, ntrc
	    IF ( npts (it) .ne. nchk ) THEN
		nbxerr = nbxerr + 1
		ibxerr (nbxerr) = 5
		iret = -38
	        RETURN
	    END IF
	END DO
C
C*	Do the resampling, X point by X point.
C
	nbxs = npairs * knmucc
	DO ip = 1, npts (1)
	    CALL RSMP_DRV ( ibxplt, ktrcnm, kntrcs,
     +			    kopcod, knmucc, ip, bxplvl, RMISSD, MXTRCS,
     +			    sbxls, smxs, smns, smdn, skew, nss, ier ) 
	    CALL RSMP_ERR ( ier, ' ', iret )
	    IF ( ier .ne. 0 ) THEN
		nbxerr = nbxerr + 1
		ibxerr (nbxerr) = 6
	        iret = -39
		RETURN
	    END IF
	    IF ( nss .ne. nbxs ) THEN
		nbxerr = nbxerr + 1
		ibxerr (nbxerr) = 7
		iret = -40
		RETURN
	    END IF
	    DO it = 1, nbxs
		sbxlen (ip,it,1) = sbxls (it,1)
		sbxlen (ip,it,2) = sbxls (it,2)
		wskrmx (ip,it) = smxs (it)
		wskrmn (ip,it) = smns (it)
                WRITE (6,*) it,
     +          ' - median of resampled differences = ', smdn (it)
                IF ( .not. ERMISS ( skew(it) ) ) THEN
                    WRITE (6,*) it,
     +              ' - skew ratio of resampled differences = ',
     +              skew (it)
                ELSE
                    WRITE (6,*) it,
     +              ' - skew ratio is undefined.'
                END IF
	    END DO
	END DO
C
	ipr = 1
	icc = 1
	DO ibx = 1, nbxs
	    IF ( ipr .gt. npairs ) THEN
		ipr = 1
		icc = icc + 1
	    END IF
	    it = ( icc - 1 ) * kntrcs + 1
C
C*	    Determine left or right coordinate system.
C
	    IF ( rhttrc (it) ) THEN
		CALL GSGRAF ( 1, iyrxis, aspect, xaxbeg, yrxbeg,
     +			      xaxend, yrxend, ierr )
		ysf = rfctor
	    ELSE
		ysf = sfctor
	    END IF
	    CALL PLT_GBXW ( 'M', npts (it), xpts (1,it), trc (1,it),
     +			    it, ibx, ipr, icc, ysf, ier )
C
C*	    Return coordinate to left side system.
C
	    IF ( rhttrc (it) ) THEN
		CALL GSGRAF ( 1, iyaxis, aspect, xaxbeg, yaxbeg,
     +			      xaxend, yaxend, ierr )
	    END IF
	    ipr = ipr + 1
	END DO
C*
C*
	RETURN
	END
