	SUBROUTINE PLT_WBXW  ( np, y, y2, ibx, ysf, iret )
C************************************************************************
C* PLT_WBXW								*
C*									*
C* This subroutine writes the box-whisker object data for given pair	*
C* number and set of boxes associated with a particular computational	*
C* code.  The box-whisker object data are obtained from the common	*
C* data structure.							*
C*									*
C* The relevant control file entry is formatted as follows:		*
C*									*
C*	BXWSKR = Line colors/widths/alpha/yes|no/yes|no			*
C*									*
C* PLT_WBXW  ( NP, Y, Y2, IBX, YSF, IRET )				*
C*									*
C* Input parameters:							*
C*	NP		INTEGER		Number of points		*
C*	Y (NP)		REAL		y values for bench mark trace	*
C*	Y2 (NP)		REAL		y values for paired trace	*
C*	IBX		INTEGER		Box-whisker object sequence #	*
C*					for box attributes and second	*
C*					index into SBXLEN, WSKRMX, and	*
C*					WSKRMN				*
C*	YSF		REAL		Y-axis scale factor		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC		 4/12						*
C* K. Brill/WPC          9/14   Use above/below median box lengths      *
C************************************************************************
	INCLUDE		'plt.cmn'
	PARAMETER	( RMISSD = -9999., IMISSD = -9999 )
	PARAMETER	( RDIFFD =  0.1    )
C!			  Missing value fuzziness
C*
	REAL		y (*), y2 (*)
C*
	REAL		yvals (6)
	LOGICAL		ERMISS, wok
	ERMISS (xxxx) = ( ABS ( xxxx - RMISSD ) .lt. RDIFFD )
C------------------------------------------------------------------------
	iret = 0
C
C*	If color number is zero, do not do anything.
C
	IF ( ibxclr (ibx) .le. 0 ) THEN
	    WRITE (lunbxw,1000) 'ZERO COLOR NUMBER = NO BXWSKR OBJECTS'
1000	    FORMAT (1X,'**',8X,A)
	    RETURN
	END IF
C
C*	Print the box-whisker values where non-missing.
C
	ntot = 0
	DO WHILE ( ntot .lt. np )
	    ntot = ntot + 1
	    hfbx1 = sbxlen (ntot,ibx,1)
	    hfbx2 = sbxlen (ntot,ibx,2)
	    wkmx = wskrmx (ntot,ibx)
	    wkmn = wskrmn (ntot,ibx)
	    wok = .false.
	    DO i = 1, 6
		yvals (i) = RMISSD
	    END DO
	    IF ( .not. ERMISS ( y (ntot) ) .and.
     +		 .not. ERMISS ( y2 (ntot) ) .and.
     +		 .not. ERMISS ( hfbx1 ) .and.
     +		 .not. ERMISS ( hfbx2 ) ) THEN
		hfbx1 = hfbx1 * ysf
		hfbx2 = hfbx2 * ysf
		wok = .true.
		yvals (1) = y (ntot)
		yvals (2) = y2 (ntot)
C
C*		Assign the Confidence interval.
C
		yvals (4) = y (ntot) - hfbx1
		yvals (5) = y (ntot) + hfbx2
		
	    END IF
C*
	    IF ( wskflg .and. .not. ERMISS ( wkmx ) .and.
     +		 wok .and. .not. ERMISS ( wkmn ) ) THEN
		wkmx = wkmx * ysf
		wkmn = wkmn * ysf
C
C*		Assign the whisker end points.
C
		yvals (6) = y (ntot) + hfbx2 + wkmx
C*
		yvals (3) = y (ntot) - hfbx1 - wkmn
	    END IF
C
C*	    Write out the values.
C
	    WRITE (lunbxw,2000) ntot, (yvals(ii), ii=1,6)
2000	    FORMAT (1X,I2,6(1X,1PE12.5))
	END DO
C*
	RETURN
	END
