        SUBROUTINE GD2SLL ( vdbfrcid, vdbfrchr, vdbanlid,
     +                      vdbfrcgd, vdbstatt, vdbprmnm,
     +                      vdblvlnm, ifhr, iymd, ihhm,
     +                      regins, output,
     +                      nobs, ogx, ogy, obs, for, scl, iret )
C************************************************************************
C* GD2SLL                                                               *
C*                                                                      *
C* This subroutine computes FHO values and writes out VSDB records.     *
C*									*
C* This subroutine assumes GSGPRJ has been called by DG_GRID for the    *
C* forecast grid.							*
C*                                                                      *
C* GD2SLL  ( VDBFRCID, VDBFRCHR, VDBANLID, VDBFRCGD, VDBSTATT,          *
C*           VDBPRMNM, VDBLVLNM, IFHR, IYMD, IHHM, REGINS, OUTPUT,      *
C*           NOBS, OGX, OGY, OBS, FOR, SCL, IRET )                      *
C*                                                                      *
C* Input parameters:                                                    *
C*      VDBFRCID        CHAR*           VSDB forecaster ID              *
C*      VDBFRCHR        CHAR*           VSDB foreast hour               *
C*      VDBANLID        CHAR*           VSDB analysis identification    *
C*      VDBFRCGD        CHAR*           VSDB forecast grid              *
C*      VDBSTATT        CHAR*           VSDB statistic type input       *
C*      VDBPRMNM        CHAR*           VSDB parameter name             *
C*      VDBLVLNM        CHAR*           VSDB level specification        *
C*      IFHR            INTEGER         Forecast hour                   *
C*      IYMD            INTEGER         Date:  YYYYMMDD                 *
C*      IHHM            INTEGER         TIME:  HHMM                     *
C*      REGINS          CHAR*           Regions table file name         *
C*      OUTPUT          CHAR*           Output specification            *
C*      NOBS            INTEGER         Number of observation points    *
C*      OGX (NOBS)      REAL            Obs X frcst grid rel coordinates*
C*      OGY (NOBS)      REAL            Obs Y frcst grid rel coordinates*
C*      OBS (NOBS)      REAL            Observation values              *
C*      FOR (NOBS)      REAL            Forecast values at obs points   *
C*      SCL (NOBS)      REAL            Frcst grd box scale at obs pts  *
C*                                                                      *
C* Output parameters:                                                   *
C*      IRET            INTEGER         Return code                     *
C*                                        0 = normal return             *
C**                                                                     *
C* Log:                                                                 *
C* K. Brill/HPC         10/05                                           *
C* K. Brill/IMSG        10/15   Use 4*LLMXGD                            *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXPOLY = 256 )
C*
        CHARACTER*(*)   vdbfrcid, vdbfrchr, vdbanlid,
     +                  vdbfrcgd, vdbstatt, vdbprmnm,
     +                  vdblvlnm, regins, output
        REAL            ogx (*), ogy (*), obs (*), for (*), scl (*)
C*
	REAL		rnx (4*LLMXGD), rny (4*LLMXGD)
	REAL		xpoly (MXPOLY), ypoly (MXPOLY), rval (2)
	INTEGER		inout (4*LLMXGD)
	INTEGER		luns (4)
	CHARACTER	region*32, sysin*2, devs(4)*1
	CHARACTER*80	record
	CHARACTER*32	entry (2)
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
	ihh = ihhm / 100
	sysin = 'N'
	CALL ST_NULL ( sysin, sysin, lnn, ier )
C
C*	Get length of data descriptors.
C
	CALL ST_LSTR ( vdbfrcgd, lgid, ier )
	CALL ST_LSTR ( vdbfrcid, lfr, ier )
	CALL ST_LSTR ( vdbanlid, las, ier )
	CALL ST_LSTR ( vdbprmnm, lpm, ier )
	CALL ST_LSTR ( vdbstatt, lst, ier )
C
C*      Get the output units.
C
        CALL IN_OUTT (output, 'GD2OBS', luns, nlun, devs, iret)
        IF ( iret .ne. 0 ) THEN
            CALL ER_WMSG ( 'IN', iret, ' ', ier )
            iret = -33
            RETURN
        END IF
C
C*	Get length of level specification string.
C
	CALL ST_LSTR ( vdblvlnm, lvc, ier )
C
C*	Generate data records for subregions and whole grid.
C
	CALL FL_SOPN ( regins, lunr, ios )
	IF ( ios .eq. 0 ) THEN
C
C*	    Prepare to call CGRINPOLY.
C
	    CALL GSMPRJ ( 'CED', 0., 0., 0., -90., 0., 90., 0.,
     +			  ier )
	    IF ( ier .ne. 0 ) THEN
		WRITE (6,*) ' Cannot set map projection.'
		ios = ier
	    END IF
	    IF ( ios .eq. 0 ) THEN
		CALL GTRANS ( 'G', 'N', nobs, ogx, ogy,
     +			      rnx, rny, ier )
		IF ( ier .ne. 0 ) THEN
		    WRITE (6,*) ' Cannot get normalized grid point',
     +				' coordinates.'
		    ios = ier
		END IF
	    END IF
	END IF
	DO WHILE ( ios .eq. 0 )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
		    region = vdbfrcgd(1:lgid) // '/' // entry(1)
		    CALL ST_LSTR ( region, lrgn, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
			    WRITE (6,*) ' Too many region vertices.'
			ELSE
			    ios = -1
			    WRITE (6,*) ' Invalid entry in ',
     +					regins
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points',
     +			' for region = ', region(1:lrgn)
			ios = ier
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, nobs, rnx, rny,
     +					  sysin, npoly, xpoly, ypoly,
     +					  inout, ier )
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
			ELSE
			    WRITE (record,1000) 'V01', vdbfrcid(1:lfr),
     +				  ifhr, iymd, ihh,
     +		                  vdbanlid(1:las), region(1:lrgn),
     +				  vdbstatt (1:lst), vdbprmnm(1:lpm),
     +				  vdblvlnm(1:lvc)
			    CALL ST_RXBL ( record, record, lln, ier )
			    CALL GDSNRM ( obs, for, nobs, inout,
     +					  nlun, luns, record, ier )
			END IF
		    END IF
		END IF
	    END IF
	END DO
	CALL FL_CLOS ( lunr, ier )
C
C*	Do entire grid.
C
	DO i = 1, nobs
	    inout (i) = 1
	END DO
C*
	WRITE (record,1000) 'V01', vdbfrcid(1:lfr), ifhr, iymd, ihh,
     +	      vdbanlid(1:las), vdbfrcgd(1:lgid), vdbstatt (1:lst),
     +	      vdbprmnm(1:lpm), vdblvlnm(1:lvc)
1000	FORMAT ( A, 1X, A, 1X, I3, 1X, I8, I2.2, 5 (1X, A), ' =' )
C*
	CALL ST_RXBL ( record, record, lln, ier )
	CALL GDSNRM ( obs, for, nobs, inout, nlun, luns, record,
     +		      ier )
C*
	RETURN
	END
