        SUBROUTINE SFLMFD ( kxy, agrd, fgrd, iret )
C************************************************************************
C* SFLMFD								*
C*									*
C* This subroutine modifies the forecast values so that the frequency	*
C* distribution of the forecast matches that of the observations.	*
C*									*
C*									*
C* SFLMFD ( KXY, AGRD, FGRD, IRET )					*
C*									*
C* Input parameters:							*
C*	KXY		INTEGER		Number of values in arrays	*
C*	AGRD (*)	REAL		Array of observation values	*
C*									*
C* Input and Output parameter:						*
C*	FGRD (*)	REAL		Array of forecast values	*
C*					Input:  original values		*
C*					Output:  adjusted values	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*									*
C* Reference:								*
C*									*
C* Clark, A. J., W. A. Gallus Jr., M. Xue, and F. Kong, 2009:  A	*
C*      comparison of precipitation forecast skill between the		*
C*      convection-allowing and large convection-parameterizing		*
C*      ensembles.  Wea. Forecasting, 24, 1121-1140.			*
C*									*
C**									*
C* Log:									*
C* K. Brill/IMSG     20150422   Created from gdlmfd.f                   *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	REAL 		agrd (*), fgrd (*)
C*
	REAL		aos (LLSTFL), fos (LLSTFL)
        INTEGER         irep (LLSTFL)
	LOGICAL		found
C*
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C
C*	Create order statistics of accumulations:
C
	noa = 0
	nof = 0
	amx = -1.1e31
	amn =  1.1e31
	fmx = -1.1e31
	fmn =  1.1e31
	DO ii = 1, kxy
	    IF ( .not. ERMISS ( agrd (ii) ) .and.
     +		 .not. ERMISS ( fgrd (ii) ) ) THEN
		noa = noa + 1
		aos (noa) = agrd (ii)
		IF ( aos(noa) .gt. amx ) amx = aos (noa)
		IF ( aos(noa) .lt. amn ) amn = aos (noa)
		nof = nof + 1
		fos (nof) = fgrd (ii)
                irep (nof) = 0
		IF ( fos(nof) .gt. fmx ) fmx = fos (nof)
		IF ( fos(nof) .lt. fmn ) fmn = fos (nof)
	    END IF
	END DO
	IF ( noa .eq. 0 .or. amx .eq. amn .or. fmx .eq. fmn ) RETURN
C
C*	Bubble sorting is applied:
C
	DO ii = 1, noa-1
	    DO jj = ii+1, noa
		IF ( aos (ii) .gt. aos (jj) ) THEN
		    save = aos (ii)
		    aos (ii) = aos (jj)
		    aos (jj) = save
		END IF
	    END DO
	END DO
C*
	DO ii = 1, nof-1
	    DO jj = ii+1, nof
		IF ( fos (ii) .gt. fos (jj) ) THEN
		    save = fos (ii)
		    fos (ii) = fos (jj)
		    fos (jj) = save
		END IF
	    END DO
	END DO
C
C*	Do the frequency matching:
C
	DO jj = 1, kxy
	    IF ( .not. ERMISS ( fgrd (jj) ) .and.
     +	         .not. ERMISS ( agrd (jj) ) ) THEN
		forval = fgrd (jj)
C
C*		Find the position of this amount in the
C*		forecast order statistics.
C
		found = .false.
		ii = 1
		DO WHILE ( .not. found .and. ii .lt. nof )
		    found = ( forval .ge. fos (ii) .and.
     +			      forval .lt. fos (ii+1) )
		    IF ( forval .eq. fos (ii) .and.
     +			 fos (ii) .eq. fos (ii+1) ) THEN
                        found = .true.
                        irep (ii) = irep (ii) + 1
                        ii = ii + irep (ii)
                        IF ( ii .gt. nof ) ii = nof
                    ELSE
                        ii = ii + 1
                    END IF
		END DO
C*
		ii = ii - 1
C
C*		Interpolate the quantile value position:
C
                swlo = FLOAT (ii)
		ddif = fos (ii+1) - fos (ii)
		IF ( ddif .gt. 1.0E-05 ) THEN
		    fswt = swlo + ( forval - fos(ii) ) / ddif
		ELSE
		    fswt = swlo
		END IF
		IF ( fswt .ge. FLOAT (ii+1) ) THEN
		    fswt = ii + 1
		END IF
C*
		ii = INT (fswt)
		IF ( ii .ge. noa ) THEN
		    qa = aos (noa)
		ELSE
C
C*		    Interpolate the observations between ii and ii+1.
C
		    awlo = FLOAT (ii)
		    qa = aos (ii) + ( aos (ii+1) - aos (ii) ) *
     +			     ( fswt - awlo )
		    IF ( qa .gt. aos (noa) ) qa = aos (noa)
		END IF
		fgrd (jj) = qa
	    END IF
	END DO
C*
	RETURN
	END
