	SUBROUTINE FOURIER ( data, n, rmean, var, acof, bcof, iret )
C************************************************************************
C* FOURIER								*
C*									*
C* This subroutine computes the mean, variance, and trigonometric	*
C* (Fourier) approximation coefficients for a series of an odd number	*
C* of data points.							*
C*									*
C* The value of N must be odd.  The trigonometric approximation is	*
C*									*
C*                  L							*
C*  y(x) = RMEAN + SUM { ACOF(k)*cos[(2*PI/N)*kx] +			*
C*                 k=1                 BCOF(k)*sin[(2*PI/N)*kx]		*
C*									*
C* where L = N/2, truncated.						*
C*									*
C* FOURIER  ( DATA, NPT, RMEAN, VAR, ACOF, BCOF, IRET )			*
C*									*
C* Input parameters:							*
C*	DATA (N)	REAL		Series of data values		*
C*	N		INTEGER		Number of data points (odd)	*
C*									*
C* Output parameters:							*
C*	RMEAN		REAL		Average of data values		*
C*	VAR		REAL		Variance of data values		*
C*	ACOF (N/2)	REAL*8		Cosine coefficients		*
C*	BCOF (N/2)	REAL*8		Sine coefficients		*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					 -5 = N is even			*
C*					 -6 = Missing data found	*
C**									*
C* Log:									*
C* K. Brill/HPC		 4/00						*
C* K. Brill/HPC		 7/00	Double precision arrays			*
C************************************************************************
	INCLUDE 	'GEMPRM.PRM'
C*
	REAL		data (*)
	DOUBLE
     +	PRECISION	acof (*), bcof (*)
C*
	DOUBLE
     +	PRECISION	darg, f, sum2, rmn, rn, rk, w, x
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C
C*	Check for N not odd.
C
	IF ( MOD (n,2) .eq. 0 ) THEN
	    iret = -5
	    RETURN
	END IF
	l = ( n - 1 ) / 2
	rn = DFLOAT (n)
	w = TWOPI / rn
	f = 2. / rn
	rmn = 0.
	sum2 = 0.
	DO k = 1, l
	    rk = DFLOAT (k)
	    acof (k) = 0.0
	    bcof (k) = 0.0
	    DO ix = 1, n
		x = ix - 1
		darg = w * rk * x
		acof (k) = acof (k) + data (ix) * DCOS ( darg )
		bcof (k) = bcof (k) + data (ix) * DSIN ( darg )
		IF ( k .eq. 1 ) THEN
		    IF ( ERMISS (data(ix)) ) THEN
			iret = -6
			RETURN
		    END IF
		    rmn = rmn + data (ix)
		    sum2 = sum2 + data (ix) * data (ix)
		END IF
	    END DO
	    acof (k) = f * acof (k)
	    bcof (k) = f * bcof (k)
	END DO
	rmn = rmn / rn
	var = sum2 / rn - rmn * rmn
	rmean = rmn
C*
	RETURN
	END
