	SUBROUTINE FHOVDB ( gridid, frcstr, anlsrc, parm, regins,
     +                      statyp, ifhr, iymd, ihhm, level, ivcord,
     +                      luns, nlun, agrd, fgrd, sgrd, kxf, kyf,
     +			    gnav, mfrq, useara, tmpg, tmpa, iret )
C************************************************************************
C* FHOVDB								*
C*									*
C* This subroutine computes FHO values and writes out VSDB records.	*
C*									*
C* FHOVDB  ( GRIDID, FRCSTR, ANLSRC, PARM, REGINS,			*
C*	     STATYP, IFHR, IYMD, IHHM, LEVEL, IVCORD, LUNS, NLUN,	*
C*	     AGRD, FGRD, SGRD, KXF, KYF, GNAV, MFRQ, USEARA,		*
C*	     TMPG, TMPA, IRET )						*
C*									*
C* Input parameters:							*
C*	GRIDID		CHAR*		Grid ID for FVS field 6		*
C*	FRCSTR		CHAR*		Forecaster ID for FVS field 2	*
C*	ANLSRC		CHAR*		Analysis description field	*
C*	PARM		CHAR*		Parameter name			*
C*	REGINS		CHAR*		Regions table file name		*
C*	STATYP		CHAR*		Statistic type for FVS field 7	*
C*	IFHR		INTEGER		Forecast hour			*
C*	IYMD		INTEGER		Date:  YYYYMMDD			*
C*	IHHM		INTEGER		TIME:  HHMM			*
C*	LEVEL (2)	INTEGER		Vertical level			*
C*	IVCORD		INTEGER		GEMPAK vertical coord number	*
C*	LUNS (NLUN)	INTEGER		List of output unit numbers	*
C*	NLUN		INTEGER		Number of output units		*
C*	AGRD (KXF,KYF)	REAL		Analysis grid			*
C*	FGRD (KXF,KYF)	REAL		Forecast probability grid	*
C*	SGRD (KXF,KYF)  REAL		Normalized box area grid	*
C*	KXF		INTEGER		Grid X dimension		*
C*	KYF		INTEGER		Grid Y dimension		*
C*	GNAV (*)	REAL		Grid navigation block		*
C*	MFRQ		LOGICAL		Flag to do frequency matching	*
C*	USEARA		LOGICAL		Flag to use box area sum	*
C*									*
C* Input and output parameter:						*
C*	TMPG (*)	REAL		Temporary grid array		*
C*	TMPA (*)	REAL		Temporary grid array		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC          3/03						*
C* K. Brill/HPC		 7/04	Add grid box normalized area grid	*
C* K. Brill/HPC         10/12   Changes for frequency matching		*
C* K. Brill/HPC          2/13   Pass USEARA flag along to FHONRM	*
C* K. Brill/WPC         10/14   Skip entire grid if REGIONS input is    *
C*                              followed by /X, where X is any string   *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXPOLY = 256, MXTH = 32 )
C*
	INTEGER		luns (*), level (2)
	CHARACTER*(*)	gridid, frcstr, anlsrc, parm, regins, statyp
	REAL		agrd (*), fgrd (*), sgrd (*), gnav (*)
	REAL		tmpg (*), tmpa (*)
	LOGICAL		mfrq, useara
C*
	REAL		rlat (LLMXGD), rlon (LLMXGD)
	REAL		xpoly (MXPOLY), ypoly (MXPOLY), rval (2)
	REAL		thlds (MXTH)
	CHARACTER*6	cthld (MXTH)
	INTEGER		inout (LLMXGD)
	CHARACTER*4	sttyp
	CHARACTER*256	sttps
	CHARACTER	vc*8, clev*8
	CHARACTER	region*32, sysin*2
	CHARACTER*80	record
	CHARACTER*128	entry (2)
        LOGICAL         dogrd
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
	ihh = ihhm / 100
	sysin = 'N'
	CALL ST_NULL ( sysin, sysin, lnn, ier )
C
C*	Get length of data descriptors.
C
	CALL ST_LSTR ( gridid, lgid, ier )
	CALL ST_LSTR ( frcstr, lfr, ier )
	CALL ST_LSTR ( anlsrc, las, ier )
	CALL ST_LSTR ( parm, lpm, ier )
C
C*	Parse the statistic type input.
C
	CALL ST_RMBL ( statyp, statyp, lns, ier )
	sttyp = statyp(1:4)
	CALL ST_LCUC ( sttyp, sttyp, ier )
	IF ( sttyp .ne. 'FHO>' .and. sttyp .ne. 'FHO<' ) THEN
	    iq = INDEX ( sttyp, 'FHO' )
	    IF ( iq .eq. 0 ) THEN
		iret = -28
		CALL ER_WMSG ( 'GDFHO', iret, ' ', ier )
	    ELSE
		iret = -27
		CALL ER_WMSG ( 'GDFHO', iret, ' ', ier )
	    END IF
	    iret = -18
	    CALL ER_WMSG ( 'GDFHO', iret, ' ', ier )
	    RETURN
	END IF
	sttps = statyp (5: )
	CALL ST_RLST ( sttps, ';', RMISSD, MXTH, thlds, nth, ier )
	IF ( ier .lt. 0 .or. nth .le. 0 ) THEN
	    iret = -18
	    CALL ER_WMSG ( 'GDFHO', iret, ' ', ier )
	    RETURN
	END IF
	IF ( ier .eq. 1 ) THEN
	    iret = -19
	    CALL ER_WMSG ( 'GDFHO', iret, ' ', ier )
	    RETURN
	END IF
	CALL ST_LSTR ( sttyp, lst, ier )
	CALL ST_CLST ( sttps, ';', ' ', MXTH, cthld, nth, ier )
C
C*	Translate vertical coordinate.
C
	CALL ST_INCH ( level (1), clev, ier )
	CALL ST_LSTR ( clev, lnl, ier )
	IF ( ivcord .eq. 0 ) THEN
	    vc = 'SFC'
	ELSE IF ( ivcord .eq. 1 ) THEN
	    vc = 'P' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 2 ) THEN
	    vc = 'T' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 3 ) THEN
	    vc = 'Z' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 4 ) THEN
	    vc = 'S' // clev (1:lnl)
	ELSE IF ( ivcord .eq. 5 ) THEN
	    vc = 'D' // clev (1:lnl)
	ELSE
	    vc = 'NONE'
	END IF
C*
	CALL ST_LSTR ( vc, lvc, ier )
C
C*	Generate data records for subregions and whole grid.
C
        CALL ST_CLST ( regins, '/', ' ', 2, entry, num, ier )
        IF ( entry (2) .ne. ' ' ) THEN
            dogrd=.false.
        ELSE
            dogrd=.true.
        ENDIF
        
	CALL FL_SOPN ( entry (1), lunr, ios )
	IF ( ios .eq. 0 ) THEN
C
C*	    Prepare to call CGRINPOLY.
C
	    CALL GSMPRJ ( 'CED', 0., 0., 0., -90., 0., 90., 0.,
     +			  ier )
	    IF ( ier .ne. 0 ) THEN
		WRITE (6,*) ' Cannot set map projection.'
		ios = ier
	    END IF
	    IF ( ios .eq. 0 ) THEN
C
C*		Create test points on grid.
C
		CALL GR_SNAV ( 16, gnav, ier )
		IF ( ier .ne. 0 ) THEN
		    WRITE (6,*) ' Cannot set grid navigation.'
		    ios = ier
		END IF
	    END IF
	    IF ( ios .eq. 0 ) THEN
		kxy = 0
		DO j = 1, kyf
		    DO i = 1, kxf
			kxy = kxy + 1
			rlat (kxy) = FLOAT (i)
			rlon (kxy) = FLOAT (j)
		    END DO
		END DO
		CALL GTRANS ( 'G', 'N', kxy, rlat, rlon,
     +			      rlat, rlon, ier )
		IF ( ier .ne. 0 ) THEN
		    WRITE (6,*) ' Cannot get normalized grid point',
     +				' coordinates.'
		    ios = ier
		END IF
	    END IF
	END IF
	DO WHILE ( ios .eq. 0 )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
		    region = gridid(1:lgid) // '/' // entry(1)
		    CALL ST_LSTR ( region, lrgn, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
			    WRITE (6,*) ' Too many region vertices.'
			ELSE
			    ios = -1
			    WRITE (6,*) ' Invalid entry in ',
     +					regins
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points',
     +			' for region = ', region(1:lrgn)
			ios = ier
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, kxy, rlat, rlon,
     +					  sysin, npoly, xpoly, ypoly,
     +					  inout, ier )
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
			ELSE
			    WRITE (record,1000) 'V01', frcstr(1:lfr),
     +				  ifhr, iymd, ihh,
     +		                  anlsrc(1:las), region(1:lrgn),
     +				  sttyp (1:lst), parm(1:lpm),
     +				  vc(1:lvc)
			    CALL ST_RXBL ( record, record, lln, ier )
			    CALL FHONRM ( sttyp, thlds, cthld, nth,
     +					  agrd, fgrd, sgrd, kxy,
     +					  inout, nlun, luns, mfrq,
     +					  useara, record, tmpg, tmpa,
     +					  ier )
			END IF
		    END IF
		END IF
	    END IF
	END DO
	CALL FL_CLOS ( lunr, ier )
C*
        IF ( .not. dogrd ) RETURN
C
C*	Do entire grid.
C
	kxy = kxf * kyf
	DO i = 1, kxy
	    IF ( .not. ERMISS (agrd(i)) .and.
     +		 .not. ERMISS (fgrd(i)) ) THEN
	        inout (i) = 1
	    ELSE
		inout (i) = 0
	    END IF
	END DO
C*
	WRITE (record,1000) 'V01', frcstr(1:lfr), ifhr, iymd, ihh,
     +	      anlsrc(1:las), gridid(1:lgid), sttyp (1:lst),
     +	      parm(1:lpm), vc(1:lvc)
1000	FORMAT ( A, 1X, A, 1X, I3, 1X, I8, I2.2, 5 (1X, A), ' =' )
C*
	CALL ST_RXBL ( record, record, lln, ier )
	CALL FHONRM ( sttyp, thlds, cthld, nth, agrd, fgrd, sgrd, kxy,
     +		      inout, nlun, luns, mfrq, useara, record, tmpg,
     +		      tmpa, ier )
C*
	RETURN
	END
