	SUBROUTINE GBSNRM ( sttyp, p1, p2, npr, agrd, pgrd, kxy, inout,
     +			    nlun, luns, chedr, iret )
C************************************************************************
C* GBSNRM								*
C*									*
C* This subroutine computes GBS record values and writes them out in	*
C* VSDB	format.								*
C*									*
C* INOUT is an array of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* GBSNRM ( STTYP, P1, P2, NPR, AGRD, PGRD, KXY, INOUT, NLUN, LUNS,	*
C*	    CHEDR, IRET )						*
C*									*
C* Input parameters:							*
C*	STTYP		CHAR*		Statistic type without range	*
C*	P1 (NPR)	REAL		Lower bound of prob ranges	*
C*	P2 (NPR)	REAL		Upper bound of prob ranges	*
C*	NPR		INTEGER		Number of probability ranges	*
C*	AGRD (KXY) 	REAL		Analysis grid values		*
C*	PGRD (KXY) 	REAL		Forecast probability values	*
C*	KXY		INTEGER		Number of grid points		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*									*
C* Input and output parameter:						*
C*	CHEDR		CHAR*		VSDB header record		*
C*					Output in all caps		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					-18 = STATTYP invalid		*
C*					-19 = > 2 categories in STATTYP	*
C*					-26 = invalid threshold		*
C*					-27 = invalid operator		*
C**									*
C* Log:									*
C* K. Brill/HPC		10/02						*
C* K. Brill/HPC		11/02	Restrict probabilities to 0 -> 1 range	*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=160 )
C*
	REAL 		agrd (*), pgrd (*), p1 (*), p2 (*)
	INTEGER		inout (*), luns (*)
	CHARACTER*(*)	sttyp, chedr
	
C*
	LOGICAL			chk, adrng
	CHARACTER		cl1l2*(MXC), cin*4
	CHARACTER*32		csave
	CHARACTER*16		pcats (3), crng
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C
C*	Parse the categories for the probability forecast.
C
	CALL ST_CLST ( sttyp, '|', ' ', 3, pcats, npct, ier )
	IF ( npct .lt. 2 ) THEN
	    iret = -18
	    CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
	    RETURN
	END IF
	IF ( npct .gt. 2 ) THEN
	    iret = -19
	    CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
	    RETURN
	END IF
C
C*	Set the comparison codes:  1 is >; 2 is >=; 3 is <; 4 is <=.
C
	kmpcd = 0
	IF ( pcats (2) (1:1) .eq. '>' ) THEN
	    IF ( pcats (2) (2:2) .eq. ':' ) THEN
		kmpcd = 2
		i1 = 3
	    ELSE
		kmpcd = 1
		i1 = 2
	    END IF
	ELSE IF ( pcats (2) (1:1) .eq. '<' ) THEN
	    IF ( pcats (2) (2:2) .eq. ':' ) THEN
		kmpcd = 4
		i1 = 3
	    ELSE
		kmpcd = 3
		i1 = 2
	    END IF
	END IF
	IF ( kmpcd .eq. 0 ) THEN
	    iret = -27
	    CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
	    RETURN
	END IF
	CALL ST_CRNM ( pcats (2) (i1:), thld, ier )
	IF ( ier .ne. 0 ) THEN
	    iret = -26
	    CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
	    RETURN
	END IF
	CALL ST_LCUC ( chedr, chedr, ier )
	CALL ST_LSTR ( chedr, lnch, ier )
C
C*	Loop over each probability range, checking the entire
C*	grid for each.
C
	IF ( npr .eq. 0 ) THEN
	    np = 1
	    adrng = .false.
	ELSE
	    np = npr
	    adrng = .true.
C
C*	    Find end of statistic type field in header and
C*	    save the trailing part in order to insert the
C*	    probability range.
C
	    ist = INDEX ( chedr, 'GBS' )
	    IF ( ist .eq. 0 ) THEN
		iret = -28
		CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
		RETURN
	    END IF
	    iq = INDEX ( chedr (ist: ), ' ' )
	    iadr = ist + iq
	    csave = chedr (iadr:lnch)
	    CALL ST_LSTR ( csave, lnsv, ier )
	    iadr = iadr - 2
	END IF
	DO ipr = 1, np
	    IF ( npr .eq. 0 ) THEN
		pr1 = 0.
		pr2 = 1.
	    ELSE
		pr1 = p1 (ipr)
		pr2 = p2 (ipr)
		kpr = NINT ( pr1 * 100. )
		CALL ST_INLN ( kpr, cin, lni, ier )
		IF ( lni .eq. 3 ) THEN
		    iret = -29
		    CALL ER_WMSG ( 'GDGBS', iret, ' ', ier )
		    RETURN
		END IF
		IF ( lni .eq. 2 .and. cin (2:2) .eq. '0' ) lni = 1
		crng = '/.' // cin(1:lni)
		lnr = lni + 2
		kpr = NINT ( pr2 * 100. )
		IF ( kpr .eq. 100 ) THEN
		    crng = crng (1:lnr) // '-1'
		    lnr = lnr + 2
		ELSE
		    CALL ST_INLN ( kpr, cin, lni, ier )
		    IF ( lni .eq. 2 .and. cin (2:2) .eq. '0' ) lni = 1
		    crng = crng (1:lnr) // '-' // '.' // cin (1:lni)
		    lnr = lnr + 2 + lni
		END IF
		chedr = chedr (1:iadr) // crng (1:lnr) // ' ' //
     +			csave (1:lnsv)
		CALL ST_LSTR ( chedr, lnch, ier )
	    END IF
	    n = 0
	    f1e1 = 0.
	    f12 = 0.0
	    n1 = 0.
	    f2e2 = 0.
	    f22 = 0.
	    DO i = 1, kxy
		IF ( .not. ERMISS ( agrd (i) ) .and.
     +		     .not. ERMISS ( pgrd (i) ) .and.
     +		     inout (i) .eq. 1 ) THEN
		    ip = NINT ( pgrd (i) * 1000. )
		    IF ( ip .lt. 0 ) ip = 0
		    IF ( ip .gt. 1000 ) ip = 1000
		    p = FLOAT (ip) / 1000.
		    pp = 1. - p
		    a = agrd (i)
		    IF ( pr1 .eq. 0. .and. p .ge. pr1 .and.
     +			p .le. pr2 ) THEN
			chk = .true.
		    ELSE IF ( p .gt. pr1 .and. p .le. pr2 ) THEN
			chk = .true.
		    ELSE
			chk = .false.
		    END IF
		    IF ( chk ) THEN
			IF ( kmpcd .eq. 1 ) THEN
			    IF ( a .gt. thld ) THEN
				e1 = 1.
				e2 = 0.
			    ELSE
				e1 = 0.
				e2 = 1.
			    END IF
			ELSE IF ( kmpcd .eq. 2 ) THEN
			    IF ( a .ge. thld ) THEN
				e1 = 1.
				e2 = 0.
			    ELSE
				e1 = 0.
				e2 = 1.
			    END IF
			ELSE IF ( kmpcd .eq. 3 ) THEN
			    IF ( a .lt. thld ) THEN
				e1 = 1.
				e2 = 0.
			    ELSE
				e1 = 0.
				e2 = 1.
			    END IF
			ELSE IF ( kmpcd .eq. 4 ) THEN
			    IF ( a .le. thld ) THEN
				e1 = 1.
				e2 = 0.
			    ELSE
				e1 = 0.
				e2 = 1.
			    END IF
			END IF
			n = n + 1
			f1e1 = f1e1 + p * e1
			f12 = f12 + p * p
			n1 = n1 + NINT ( e1 )
			f2e2 = f2e2 + pp * e2
			f22 = f22 + pp * pp
		    END IF
		END IF
	    END DO
C*
	    IF ( n .gt. 0 ) THEN
		rn = DFLOAT (n)
		f1e1 = f1e1 / rn
		f12 = f12 / rn
		rn1 = FLOAT (n1) / rn
		f2e2 = f2e2 / rn
		f22 = f22 / rn
		WRITE (cl1l2,1000) n, f1e1, f12, rn1, f2e2, f22
1000		FORMAT ( I8, 5(1X,1PE12.5) )
		CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
		DO i = 1, nlun
		    WRITE (luns(i), '(A,1X,A)') chedr (1:lnch),
     +				cl1l2 (1:lnch2)
		END DO
	    ELSE
		WRITE (6,*) chedr(1:lnch), ' --------:'
		WRITE (6,*) ' All points missing or not in region.'
	    END IF
	END DO
C*
	RETURN
	END
