	SUBROUTINE CMPAVG ( nrecs, nrgn, wgrd, gvar, ipoly, kxy, gout,
     +                      wsum, iret )
C************************************************************************
C*  CMPAVG								*
C*									*
C*  This program computes subregion area averages for the values in     *
C*  GVAR.  The subregions are integer coded using values 1 through      *
C*  NRGN on the grid IPOLY.  If NRECS > NRGN an NRGN+1 average over     *
C*  all non-missing points of IPOLY is also computed.  The averages are *
C*  returned in the array GOUT.                                         *
C*									*
C*  CMPAVG ( NRECS, NRGN, WGRD, GVAR, IPOLY, KXY, GOUT, WSUM, IRET )    * 
C*									*
C* Input parameters:							*
C*      NRECS           INTEGER         Number of averages expected     *
C*	NRGN            INTEGER		Number of regions coded in IPOLY*
C*      WGRD (KXY)      REAL            Grid box area weights           *
C*	GVAR (KXY)	REAL		Grid of values to average       *
C*	IPOLY (KXY)	INTEGER		Region code numbers             *
C*	KXY		INTEGER		Number of grid points           *
C*                                                                      *
C* Output parameter:							*
C*	GOUT (NRECS)	REAL		Array of averages returned      *
C*      WSUM (NRECS)    REAL            Sum of weights for each region  *
C*	IRET		INTEGER		Return code			*
C*									*
C* Log:									*
C* K. Brill/IMSG        06/16						*
C* K. Brill/IMSG        20170223        Use REAL*8 for accumlations     *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C************************************************************************
	INTEGER		ipoly (*)
	REAL		gvar (*), wgrd (*)
        REAL*8          gout (*), wsum (*)
C*
        REAL*8          wall, sall
C*
        INCLUDE         'ERMISS.FNC'
C*
C------------------------------------------------------------------------
	iret = 0
C*
        IF ( nrgn .eq. 0 ) THEN
            gout (1) = 0.0
            wsum (1) = 0.0
            DO ii = 1, kxy
                IF ( .not. ERMISS (gvar(ii)) .and.
     +               .not. ERMISS (wgrd(ii)) ) THEN
                    gout (1) = gout (1) + gvar (ii) * wgrd (ii)
                    wsum (1) = wsum (1) + wgrd (ii)
                END IF
            END DO
            IF ( wsum (1) .gt. 0 ) THEN
                gout (1) = gout (1) / wsum (1)
            ELSE
                wsum (1) = 0
            END IF
C*
            RETURN
C*
        END IF
C 
C*	Outer loop is over regions:
C
        wall = 0
        sall = 0
        DO irgn = 1 , nrgn
C
C*          Loop over points to average.
C
            gout (irgn) = 0.0
            wsum (irgn) = 0.0
            DO ii = 1, kxy
                IF ( ipoly (ii) .eq. irgn .and.
     +               .not. ERMISS (gvar(ii)) .and.
     +               .not. ERMISS (wgrd(ii)) ) THEN
                    gout (irgn) = gout (irgn) + gvar (ii) * wgrd (ii)
                    wsum (irgn) = wsum (irgn) + wgrd (ii)
                    sall = sall + gvar (ii) * wgrd (ii)
                    wall = wall + wgrd (ii)
                END IF
            END DO
            IF ( wsum (irgn) .gt. 0 ) THEN
                gout (irgn) = gout (irgn) / wsum (irgn)
            END IF
        END DO
        IF ( nrecs .gt. nrgn ) THEN
            irgn = nrgn + 1
            wsum (irgn) = wall
            gout (irgn) = 0.0
            IF ( wall .gt. 0 ) gout (irgn) = sall / wall
        END IF
C*
        RETURN
        END
