	SUBROUTINE GD2CRP ( parms, np, vhdrs, lhdrs, wgrd, anlyg,
     +                      ftime, fclvl, fcvcd,
     +                      mx, my, regions,
     +                      luns, nlun, ijskip, frcpv, iret )
C************************************************************************
C*  GD2CRP								*
C*									*
C*  This program computes VSDB CRPS statistic records given an analysis	*
C*  grid and grids of forecast percentile values.                       *
C*									*
C*  GD2CRP ( PARMS, NP, VHDRS, LHDRS, ANLYG, FTIME, FCLVL, FCVCD,       *
C*           MX, MY, REGIONS, LUNS, NLUN, FRCPV, IRET )			*
C*									*
C* Input parameters:							*
C*	PARMS (*)	CHAR*		List of boundaries of prb ranges*
C*      NP              INTEGER         Number of percentile parms      *
C*	VHDRS (9)	CHAR*		VSDB record headers		*
C*	LHDRS (9)	INTEGER		VSDB record header lengths	*
C*      WGRD (MX,MY)    REAL            Grid box area weights           *   
C*	ANLYG (MX,MY)	REAL		Analysis grid			*
C*	FRCPV (MX,MY)	REAL		Lowest percentile value grid--  *
C*                                        subsequent grids must be read *
C*      FTIME           CHAR*           Forecast date-time identifier   *
C*      FCLVL           CHAR*           Forecast level identifier       *
C*      FCVCD           CHAR*           Forecast vertical coordinate    *
C*	MX		INTEGER		Number of grid points along x	*
C*	MY		INTEGER		Number of grid points along y	*
C*	REGIONS		CHAR*		Name of file defining subregion *
C*					polygons			*
C*	LUNS (NLUN)	INTEGER		Output logical unit # array	*
C*	NLUN		INTEGER		Number of LUNS			*
C*      IJSKIP          INTEGER         Number of points to skip to     *
C*                                      speed up uncertainty calc       *
C*									*
C* Input and modified parameter:                                        *
C*	FRCPV (MX,MY)	REAL		Lowest percentile value grid--  *
C*                                        subsequent grids must be read *
C*                                                                      *
C* Output parameter:							*
C*	IRET		INTEGER		Return code			*
C*									*
C* Log:									*
C* K. Brill/IMSG	06/16						*
C* K. Brill/IMSG        07/16   Increase MXPOLY                         *
C* K. Brill/IMSG        02/17   Allow skipping entire grid to save time *
C* K. Brill/IMSG        03/17   Add IJSKIP *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER       ( MXPOLY = 2048, NRGNS = 20 )
C************************************************************************
	CHARACTER*(*)	parms(*), vhdrs (*), regions
	CHARACTER*(*)	ftime, fclvl, fcvcd
	INTEGER		lhdrs (*), luns (*)
	REAL		anlyg (*), frcpv (*)
	REAL		wgrd (*)
C*
	CHARACTER	gparm*48, cprj*4, sysin*2
	CHARACTER*128   record, entry (2)
	INTEGER		inout (LLMXGD), ipoly(LLMXGD)
	REAL		rnav (LLNNAV)
	REAL		rlat (LLMXGD), rlon (LLMXGD)
	REAL		xpoly (MXPOLY), ypoly (MXPOLY), rval (2)
C*
	CHARACTER	crgn*32, orec*128, orecs(NRGNS)*128
        LOGICAL         dogrd
C------------------------------------------------------------------------
	iret = 0
C 
C*	Set the region polygon array to missing everywhere.
C
        kxy = mx * my
	DO i = 1, mx * my
            ipoly(i)=IMISSD
	END DO
C
C*      Check region input for / followed by any character to indicate
C*      skipping the whole grid.
C
        CALL ST_CLST ( regions, '/', ' ', 2, entry, num, ier )
        IF ( entry (2) .ne. ' ' ) THEN
            dogrd=.false.
        ELSE
            dogrd=.true.
        ENDIF

C
C*	Generate the numeric identifier mask for the regions:
C
	lunr = 0
	CALL FL_SOPN ( entry (1), lunr, ios )
	IF ( ios .eq. 0 ) THEN
C
C*	    Get and set up the grid navigation.
C
	    CALL DG_QREF ( 0, LLNNAV, adum, rnav, mxg, ierr )
	    IF ( ierr .ne. 0 ) THEN
	        CALL ER_WMSG ( 'DG', ierr, ' ', ier )
	        iret = -17
	        RETURN
	    END IF
	    CALL GR_RNAV ( rnav, cprj, mx, my, ierr )
	    IF ( ierr .ne. 0 ) THEN
	        CALL ER_WMSG ( 'GR', ierr, ' ', ier )
	        iret = -18
	        RETURN
	    END IF
	    CALL GR_SNAV ( 20, rnav, ier )
	    IF ( ierr .ne. 0 ) THEN
	        CALL ER_WMSG ( 'GR', ierr, ' ', ier )
	        iret = -19
	        RETURN
	    END IF
C*
	    kk = 0
	    DO j = 1, my
	        DO i = 1, mx
		    kk = kk + 1
		    rlat (kk) = FLOAT (i)
		    rlon (kk) = FLOAT (j)
	        END DO
	    END DO
C*
	    CALL GSMPRJ ( cprj, rnav(11), rnav(12), rnav(13),
     +		          rnav(7), rnav(8), rnav(9), rnav(10), ier )
	    CALL GTRANS ( 'G', 'N', kxy, rlat, rlon,
     +		          rlat, rlon, ier )
	    IF ( ier .ne. 0 ) THEN
	        iret = -21
	        RETURN
	    END IF
	    sysin = 'N'
            CALL ST_NULL ( sysin, sysin, lx, ier )
	END IF
        nrgn = 0
	DO WHILE ( ios .eq. 0 .and. nrgn .lt. NRGNS )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
                    nrgn = nrgn + 1
		    crgn = entry(1)
		    CALL ST_LSTR ( crgn, lrgn, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
			    WRITE (6,*) ' Too many region vertices.'
			ELSE
			    ios = -1
			    WRITE (6,*) ' Invalid entry in ',
     +					regions
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points',
     +			' for region = ', crgn(1:lrgn)
			ios = ier
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, kxy, rlat, rlon,
     +					  sysin, npoly, xpoly, ypoly,
     +					  inout, ier )
			icnt = 0
			DO i = 1, kxy
			    icnt = icnt + inout (i)
                            IF ( inout (i) .ne. 0 ) THEN
                                ipoly (i) = nrgn
                            END IF
			END DO
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
                        ELSE IF ( icnt .le. 1 ) THEN
                            WRITE (6,*) ' A region has one or zero ',
     +                                  'points.'
			ELSE IF ( icnt .gt. 1 ) THEN
			    record = vhdrs(6)(1:lhdrs(6)) // '/' //
     +				     crgn(1:lrgn)
			    crgn = record
			    CALL ST_LSTR ( crgn, lrgn, ier )
			    record = vhdrs(1)
			    orec = vhdrs(1)
			    DO i = 2, 9
				CALL ST_LSTR ( record, l1, ier )
				CALL ST_LSTR ( orec, l2, ier )
				IF ( i .ne. 6 ) THEN
				    record = orec(1:l2) // ' ' //
     +					     vhdrs(i)(1:lhdrs(i))
				ELSE
				    record = orec(1:l2) // ' ' //
     +					     crgn(1:lrgn)
				END IF
				orec = record
			    END DO
                            CALL ST_LCUC ( orec, orec, ier )
                            CALL ST_RXBL ( orec, orec, l2, ier )
			    orecs(nrgn) = orec (1:l2)
			ELSE
			    WRITE (6,*) crgn(1:lrgn),
     +                            ' is not on the verification domain.'
			END IF
		    END IF
		END IF
	    END IF
	END DO
	CALL FL_CLOS ( lunr, ier )

        IF ( dogrd ) THEN
C
C*          Make the identifier record for the entire grid.
C
	    record = vhdrs(1)
	    orec = vhdrs(1)
	    DO i = 2, 9
	        CALL ST_LSTR ( record, l1, ier )
	        CALL ST_LSTR ( orec, l2, ier )
	        record = orec(1:l2) // ' ' //
     +	                 vhdrs(i)(1:lhdrs(i))
	        orec = record
	    END DO
            CALL ST_LCUC ( orec, orec, ier )
            CALL ST_RXBL ( orec, orec, l2, ier )
	    orecs(nrgn+1) = orec (1:l2)
            nrecs=nrgn + 1
            IF ( nrecs .eq. 1 ) THEN
	        DO i = 1, mx * my
                    ipoly(i)=1
	        END DO
            END IF
        ELSE
            nrecs = nrgn
        END IF
C*        
	CALL MKCRPS ( nrecs, nrgn, orecs, anlyg, parms, np,
     +                ftime, fclvl, fcvcd, ipoly, wgrd, kxy,
     +		      nlun, luns, ijskip, frcpv, iret )
C*
	RETURN
	END
