	PROGRAM  GDGCRPS
C************************************************************************
C* GDGCRPS								*
C*									*
C* This program compares forecast quantile (percentile) values against  *
C* a verifying analysis grid and computes CRPS VSDB fractions based on  *
C* the Hersbach (2000) decomposition for CRPS.                          *
C*									*
C**									*
C* Log:									*
C* K. Brill/IMSG      20160610						*
C* K. Brill/IMSG      20160725  Set MXPLVS to 11 rather than 9          *
C* K. Brill/IMSG      20160727  Use MXPLVS in ST_CLST call              *
C* K. Brill/IMSG      20170316  Add ciskip input for skipping           *
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C
C*      Define maximum number of percentile level grids allowed:
C
        PARAMETER       (MXPLVS = 11)
C*
	CHARACTER       vdbfrcid*(LLMXLN),
     +			vdbfrchr*(LLMXLN), atgdfile*(LLMXLN),
     +			anlygfnc*(LLMXLN),
     +			frctgfnc*(LLMXLN),
     +			vdbanlid*(LLMXLN), vdbanlgd*(LLMXLN),
     +			vdbstatt*(LLMXLN), vdbprmnm*(LLMXLN),
     +			vdblvlnm*(LLMXLN), regions*(LLMXLN),
     +			output*(LLMXLN), ciskip*(LLMXLN)
        LOGICAL         useara
C*
	REAL		anlyg (LLMXGD)
        REAL		frcpv (LLMXGD)
	REAL		alpha (LLMXGD), beta (LLMXGD), wgrd (LLMXGD)
	INTEGER		lhdrs (9), level (2), luns (4)
	CHARACTER	vlddtm*20, parm*12, ccc*2
        CHARACTER       devs(4)*1
	CHARACTER*16	gdatm, cstat
	CHARACTER*24	vhdrs (9)
        CHARACTER*48    parms(MXPLVS), gparm, gdfun
	CHARACTER*128	pfunc
	CHARACTER	time(2)*20, atime(2)*20, ftime*20
        CHARACTER       fclvl*8, fcvcd*4
	LOGICAL		respnd, done, proces, dopbs, nxtok
	LOGICAL		conth
C*
	INCLUDE		'ERMISS.FNC'
C-----------------------------------------------------------------------
C*	Initialize user interface and GEMPLT.
C
	CALL IP_INIT  ( respnd, iperr )
	IF  ( iperr .eq. 0 )  THEN
	    mode = 1
	    CALL GG_INIT  ( mode, iperr )
	    IF ( iperr .ne. 0 ) THEN
		ierr = -1
		CALL ER_WMSG ( 'GDGCRPS', ierr, ' ', ier )
	    END IF
	    CALL GG_SDEV ( 'GN', ierr )
	    IF ( ierr .ne. 0 ) THEN
		ierr = -2
		CALL ER_WMSG ( 'GDGCRPS', ierr, ' ', ier )
		iperr = ierr
	    END IF
	ELSE
	    ierr = -3
	    CALL ER_WMSG ( 'GDGCRPS', ierr, ' ', ier )
	END IF
	IF  ( iperr .eq. 0 )  THEN
	    done = .false.
	  ELSE
	    done = .true.
	END IF
	CALL IP_IDNT  ( 'GDGCRPS', ier )
	CALL GD_INIT ( ierr )
	CALL DG_INTL ( iret )
C
C*	Main loop to read in parameters and do verification.
C
	DO WHILE  ( .not. done )
C
C*	    Set flag to indicate processing will be done.
C
	    proces = .true.
            useara = .false.
C
C*	    Read in the variables from the user interface.
C
	    CALL GDBINP ( vdbfrcid, vdbfrchr, atgdfile,
     +			  anlygfnc, frctgfnc, vdbanlid,
     +			  vdbanlgd, vdbstatt, vdbprmnm,
     +			  vdblvlnm, regions, useara, ciskip,
     +                    output, iperr )
C
C*	    Check for errors or missing input.
C
	    IF ( vdbfrcid .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -4, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbfrchr .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -5, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbanlid .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -6, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbanlgd .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -7, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbstatt .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -8, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbprmnm .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -9, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdblvlnm .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -10, ' ', ier )
		proces = .false.
	    END IF
	    IF  ( iperr .ne. 0 )  THEN
		done = .true.
		proces = .false.
	    END IF
C
C*          Convert ciskip to an integer value.  Default is 0.
C
            CALL ST_RMBL ( ciskip, ciskip, lng, ierr )
            CALL ST_LCUC ( ciskip, ciskip, ierr )
            IF ( ciskip (1:lng) .eq. ' ' .or.
     +           ciskip (1:lng) .eq. 'NO' ) THEN
                ijskip = 0
            ELSE
                CALL ST_NUMB ( ciskip, ival, ierr )
                IF ( ierr .ne. 0 .or. ival .eq. IMISSD ) THEN
                    WRITE (6,*)  'CSKIP input is not valid.  Using 0.'
                    ijskip = 0
                ELSE
                    ijskip = ival
                ENDIF
            END IF
C*
	    IF ( proces ) THEN
C
C*		Get the output units.
C
		CALL IN_OUTT (output, 'GDGCRPS', luns, nlun,
     +			      devs, iret)
		IF ( iret .ne. 0 ) THEN
		    CALL ER_WMSG ( 'IN', iret, ' ', ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Check for a valid statistic type.
C
	    CALL ST_LCUC ( vdbstatt, cstat, ier )
	    dopbs = INDEX ( cstat, 'CRPS' ) .gt. 0
	    IF ( .not. dopbs ) THEN
		CALL ER_WMSG ( 'GDGCRPS', -11, ' ', ier )
		proces = .false.
	    END IF
C
C*	    Open the analysis grid and forecast files.
C
	    IF ( proces ) THEN
		CALL DG_NFIL ( atgdfile, ' ', ierr )
		IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, atgdfile, ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Set the internal date time stamp.
C
	    IF ( proces ) THEN
		gdatm = 'FIRST'
		CALL DG_NDTM ( gdatm, ierr )
		IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, ' ', ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Set the internal grid and retrieve the time stamp.
C
	    IF ( proces ) THEN
		CALL DG_NTIM ( .TRUE., .TRUE., time, nxtok, ierr )
		IF ( .not. nxtok ) THEN
		    CALL ER_WMSG ( 'GDGCRPS', -12, ' ', ier )
		    proces = .false.
		END IF
		IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, ' ', ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Read in the verifying analysis grid.
C
	    IF ( proces ) THEN
	        CALL DG_GRID ( time (1), '0', 'NONE', anlygfnc,
     +			       pfunc, anlyg, mx, my, atime, level,
     +			       ivcord, parm, ierr )
C*
	        IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, pfunc, ier )
		    proces = .false.
		    CALL ER_WMSG ( 'GDGCRPS', -14, ' ', ier )
	        ELSE
                    kxy = mx * my
C
C*		    Convert analysis time to the VSDB date-time stamp.
C
		    IF ( atime (2) .ne. ' ' ) THEN
		        CALL ER_WMSG ( 'GDGCRPS', +1, ' ', ier )
C**             Always use first time, NOT atime (1) = atime (2)
		    END IF
C*
		    CALL TG_VALD ( atime (1), vlddtm, ier )
		    iv = INDEX ( vlddtm, 'V' )
		    IF ( iv .ne. 0 ) THEN
		        atime(1) = vlddtm(1:iv-1)
		    ELSE
			atime(1) = vlddtm
		    END IF
		    CALL TI_CCNT ( atime (1), ccc, ierr )
		    IF ( ierr .ne. 0 ) THEN
			CALL ER_WMSG ( 'TI', ierr, atime(1), ier )
			CALL ER_WMSG ( 'GDGCRPS', -13, ' ', ier )
			proces = .false.
		    END IF
		    islash = INDEX ( atime (1), '/' )
C
C*		    Make a VSDB date-time stamp.
C
		    vlddtm = ccc // atime(1)(1:islash-1) //
     +			         atime(1)(islash+1:islash+2)
		    IF ( vlddtm .eq. ' ' ) THEN
		        CALL ER_WMSG ( 'GDGCRPS', -13, ' ', ier )
		        proces = .false.
		    END IF
	        END IF
	    END IF
C
C*          If the user requests area summation rather than count
C*          summation, then compute the reciprocal of the product
C*          of the map scale factors.   This product is the area
C*          normalized by the area of a grid box on the map
C*          projection plane.
C
            IF ( proces .and. useara ) THEN
                gdfun = 'QUO(1,MUL(msfx,msfy))'
	        CALL DG_GRID ( time (1), '0', 'NONE', gdfun,
     +			       pfunc, wgrd, mx, my, atime, level,
     +			       ivcord, parm, ierr )
C*
	        IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, pfunc, ier )
		    proces = .false.
		    CALL ER_WMSG ( 'GDGCRPS', -24, ' ', ier )
                END IF
            ELSE IF ( proces ) THEN
                DO ii = 1, kxy
                    wgrd (ii) = 1.0
                END DO
            END IF
C
C*	    Read in the first grid of forecast percentile values.
C
	    IF ( proces ) THEN
C
C*              Parse FRCTGFNC input to get the first parameter.
C
                CALL ST_CLST ( frctgfnc, ';', ' ', MXPLVS, parms,
     +                         np, iret )
                CALL ST_LSTR ( parms (1), lnc, ier )
                gparm = parms(1)(1:lnc) // "+2"
	        CALL DG_GRID ( time (1), '0', 'NONE', gparm,
     +			       pfunc, frcpv, mx, my, atime, level,
     +			       ivcord, parm, ierr )
C*
	        IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, pfunc, ier )
		    proces = .false.
		    CALL ER_WMSG ( 'GDGCRPS', -20, ' ', ier )
	        END IF
	    END IF
C
C*	    The first grid must have the identifiers in-line.
C
	    IF ( proces ) THEN
C
C*              Construct grid identifiers for the remaining percentile
C*              value grids that must be read.
C
                ftime = atime (1)
                CALL ST_INCH ( level (1), fclvl, ier1 )
                CALL LV_CCRD ( ivcord, fcvcd, ier2 )
                ierr = ier1 + ier2
	        IF ( ierr .ne. 0 ) THEN
		    proces = .false.
		    CALL ER_WMSG ( 'GDGCRPS', -15, ' ', ier )
	        END IF
	    END IF
C
C*	    Make the individual VSDB record header fields.
C
	    IF ( proces ) THEN
		CALL GDMHDR ( vdbfrcid, vdbfrchr, vlddtm, vdbanlid,
     +			      vdbanlgd, vdbstatt, vdbprmnm, vdblvlnm,
     +			      vhdrs, lhdrs, iperr )
		IF ( iperr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'GDGCRPS', iperr, ' ', ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Call the appropriate subroutine to generate VSDB records.
C
	    IF ( proces ) THEN
	        CALL GD2CRP ( parms, np, vhdrs, lhdrs, wgrd,
     +			      anlyg, ftime, fclvl, fcvcd,
     +			      mx, my, regions, luns, nlun,
     +                        ijskip, frcpv, iperr )
	        IF ( iperr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'GDGCRPS', iperr, ' ', ier )
		    proces = .false.
	        END IF
	    END IF
C
C*	    Prompt for next listing to be done.
C
	    CALL IP_DYNM  ( done, ier )
	END DO
C
C*	Print general error messages if necessary.
C
	IF  (iperr .ne. 0)  CALL ER_WMSG ( 'GDGCRPS', iperr, ' ', ier )
C
C*	Exit from GEMPLT and the TAE.
C
	CALL GENDP  ( 0, iret )
	CALL IP_EXIT  ( iret )
C*
	END
