	SUBROUTINE GDMHDR ( vdbfrcid, vdbfrchr, vlddtm, vdbanlid,
     +			    vdbanlgd, vdbstatt, vdbprmnm, vdblvlnm, 
     +			    thval, conth, vhdrs, lhdrs, iret )
C************************************************************************
C*  This program generates the VSDB record header fields.		*
C*  grid and a threshold grid.  The forecast areas are enclosed in	*
C*  polygons defined by lat/lon points given in a text file.		*
C*									*
C*  GDMHDR ( VDBFRCID, VDBFRCHR, VLDDTM, VDBANLID, VDBANLGD, VDBSTATT,	*
C*           VDBPRMNM, VDBLVLNM, THVAL, CONTH, VHDRS, LHDRS, IRET )	*
C*									*
C* Input parameters:							*
C*	VDBFRCID	CHAR*		VSDB forecaster ID		*
C*	VDBFRCHR	CHAR*		VSDB forecast hour		*
C*	VLDDTM		CHAR*		VSDB valid YYYYMMDDHH		*
C*	VDBANLID	CHAR*		VSDB analysis ID		*
C*	VDBANLGD	CHAR*		VSDB analysis grid/		*
C*	VDBSTATT	CHAR*		VSDB statistic type (PBS_xyz)	*
C*	VDBPRMNM	CHAR*		VSDB parameter name		*
C*	VDBLVLNM	CHAR*		VSDB level name			*
C*	THVAL		REAL		Threshod value if constant	*
C*	CONTH		LOGICAL		Flag for threshold = constant	*
C*									*
C* Output parameters:							*
C*	VHDRS (9)	CHAR*		VSDB record header fields	*
C*	LHDRS (9)	INTEGER		VSDB header field lengths	*
C*	IRET		INTEGER		Return code			*
C*									*
C* Log:									*
C* K. Brill/HPC		05/05						*
C* K. Brill/HPC	     20070215	Adapt from gdphdr.f for gdgpbs		*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
C*
	CHARACTER*(*)	vdbfrcid, vdbfrchr, vlddtm, vdbanlid,
     +			vdbanlgd, vdbstatt, vdbprmnm, vdblvlnm,
     +			vhdrs (*)
	INTEGER		lhdrs (*)
	LOGICAL		conth
C*
	CHARACTER*16	cthvl, ctemp
C------------------------------------------------------------------------
	iret = 0
C
C*	Create the VSDB header fields.
C
	vhdrs (1) = 'V01'
	lhdrs (1) = 3
C*
	CALL ST_LSTR ( vdbfrcid, ll, ier )
	vhdrs (2) = vdbfrcid (1:ll)
	lhdrs (2) = ll
C*
	CALL ST_LSTR ( vdbfrchr, ll, ier )
	vhdrs (3) = vdbfrchr (1:ll)
	lhdrs (3) = ll
C*
	CALL ST_LSTR ( vlddtm, ll, ier )
	IF ( ll .lt. 10 ) THEN
		iret = -16
		RETURN
	END IF
	vhdrs (4) = vlddtm (1:ll)
	lhdrs (4) = ll
C*
	CALL ST_LSTR ( vdbanlid, ll, ier )
	vhdrs (5) = vdbanlid (1:ll)
	lhdrs (5) = ll
C*
	CALL ST_LSTR ( vdbanlgd, ll, ier )
	vhdrs (6) = vdbanlgd (1:ll)
	lhdrs (6) = ll
C*
	CALL ST_LSTR ( vdbstatt, ll, ier )
	igrtr = INDEX ( vdbstatt, '/>' )
	IF ( igrtr .eq. 0 .and. conth ) THEN
	    rint = FLOAT ( NINT ( thval ) )
	    IF ( ABS ( rint - thval ) .lt. .0005 ) THEN
		ival = NINT ( thval )
		CALL ST_INCH ( ival, cthvl, ier )
	    ELSE IF ( thval .gt. 0.0 .and. thval .lt. 1.0 ) THEN
		CALL ST_RLCH ( thval, 2, ctemp, ier )
		iperd = INDEX ( ctemp, '.' )
		cthvl = ctemp ( iperd: )
	    ELSE
		CALL ST_RLCH ( thval, 2, cthvl, ier )
	    END IF
	    vhdrs (7) = vdbstatt (1:ll) // '/>' // cthvl
	    CALL ST_LSTR ( vhdrs(7), lhdrs(7), ier )
	ELSE
	    vhdrs (7) = vdbstatt (1:ll)
	    lhdrs (7) = ll
	END IF
C*
	CALL ST_LSTR ( vdbprmnm, ll, ier )
	vhdrs (8) = vdbprmnm (1:ll)
	lhdrs (8) = ll
C*
	CALL ST_LSTR ( vdblvlnm, ll, ier )
	vhdrs (9) = vdblvlnm (1:ll)
	lhdrs (9) = ll
C*
	RETURN
	END
