	SUBROUTINE GDLGET  ( gdfnam, gdatim, glevel, gvcord, gfunc,
     +			     grid, kx, ky, rnav, navsz, level, ivc,
     +			     time, iret )
C************************************************************************
C* GDLGET								*
C*									*
C* This subroutine opens a grid file and returns a grid and the grid	*
C* navigation.								*
C*									*
C* GDLGET  ( GDFNAM, GDATIM, GLEVEL, GVCORD, GFUNC, GRID, KX, KY, RNAV,	*
C*	     NAVSZ, LEVEL, IVC, TIME, IRET )				*
C*									*
C* Input parameters:							*
C*	GDFNAM		CHAR*		Grid file name user input	*
C*	GDATIM		CHAR*		Grid date time			*
C*	GLEVEL		CHAR*		Grid Level			*
C*	GVCORD		CHAR*		Grid vertical coordinate	*
C*	GFUNC		CHAR*		User input for grid function	*
C*									*
C* Output parameters:							*
C*	GRID (KX,KY)	REAL		Grid values			*
C*	KX		INTEGER		X grid dimension		*
C*	KY		INTEGER		Y grid dimension		*
C*	RNAV (*)	REAL		Navigation Block for grid	*
C*	NAVSZ		INTEGER		Length of navigation block	*
C*	LEVEL (2)	INTEGER		Vertical level			*
C*	IVC		INTEGER		Vertical coordinate		*
C*	TIME (2)	CHAR*20		Grid time			*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C*					 -1 = error			*
C**									*
C* Log:									*
C* K. BRILL/HPC		 3/01						*
C* K. Brill/HPC		 3/03	Also search for 'A' time if 'F' fails	*
C* K. Brill/HPC		12/04	Changes for new DG/GD			*
C* K. Brill/HPC		 1/05	Remove CALL FL_MFIL & filnam; CALL	*
C*				GD_CLOS					*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	CHARACTER*(*)	gdfnam, gdatim, glevel, gvcord, gfunc, time
	REAL		grid (*), rnav (*)
	INTEGER		level (2)
C*
	REAL		anl (LLNANL)
        CHARACTER       parm*12, pfunc*72, gdtm*20
	CHARACTER	garout*32, prjout*32
	LOGICAL		gottm
C------------------------------------------------------------------------
C-----------------------------------------------------------------------
	iret = 0
	CALL DG_INTL ( iret )
C
C*	Open the grid file to get the grid navigation.
C
	CALL GD_OPEN ( gdfnam, .false., LLNANL, LLNNAV, iacss, anl,
     +		       rnav, mxgrd, iret )
	IF  ( iret .ne. 0 )  THEN
	    CALL ER_WMSG ( 'DG', iret, ' ', ier )
	    iret = -1
	    RETURN
	END IF
	CALL GD_CLOS ( iacss, iret )
C
C*	Set the grid file and date-time stamp.
C
	CALL DG_NFIL ( gdfnam, ' ', iret )
	IF  ( iret .ne. 0 )  THEN
	    CALL ER_WMSG ( 'DG', iret, ' ', ier )
	    iret = -1
	    RETURN
	END IF
	CALL DG_NDTM ( gdatim, iret )
	IF  ( iret .ne. 0 )  THEN
	    CALL ER_WMSG ( 'DG', iret, ' ', ier )
	    iret = -1
	    RETURN
	END IF
	CALL DG_NTIM ( .false., .false., time, gottm, iret )
	IF  ( iret .ne. 0 )  THEN
	    CALL ER_WMSG ( 'DG', iret, ' ', ier )
	    iret = -1
	    RETURN
	END IF
C
C*	Set grid size for error checking.
C
	kx = NINT ( rnav (5) )
	ky = NINT ( rnav (6) )
C
C*	Compute requested grid for forecast.
C
	CALL DG_GRID  ( gdatim, glevel, gvcord, gfunc,
     +			pfunc, grid, kxf, kyf, time, 
     +			level, ivc, parm, iret )
	IF ( iret .ne. 0 ) THEN
C
C*	    Try getting the grid as an analysis 'A' grid.
C
	    gdtm = gdatim
	    iq = INDEX ( gdtm, 'F' )
	    IF ( iq .ne. 0 ) THEN
		gdtm (iq:iq) = 'A'
		CALL DG_GRID  ( gdtm, glevel, gvcord, gfunc,
     +				pfunc, grid, kxf, kyf, time, 
     +				level, ivc, parm, iret )
	    END IF
	END IF
	IF  ( iret .ne. 0 )  THEN
	    CALL ER_WMSG ( 'DG',  iret, pfunc, ier )
	    iret = -1
	END IF
	IF ( kxf .ne. kx .or. kyf .ne. ky ) THEN
	    iret = -32
	END IF
C*
	CALL DG_NEND ( ier )
C*
	RETURN
	END
