	SUBROUTINE GDBPBS ( catprobs, vhdrs, lhdrs, anlyg, frctg, thldg,
     +                      mx, my, regions, luns, nlun, iret )
C************************************************************************
C*  GDBPBS								*
C*									*
C*  This program computes VSDB PBS statistic records given an analysis	*
C*  grid, a grid of forecast probabilities, and a threshold grid along	*
C*  with the low, moderate, and high risk probability values.		*
C*									*
C*  GDBPBS ( CATPROBS, VHDRS, LHDRS, ANLYG, FRCTG, THLDG, MX, MY, 	*
C*           REGIONS, LUNS, NLUN, THVAL, CONTH, IRET )			*
C*									*
C* Input parameters:							*
C*	catprobs	CHAR*		Low, mdt, hgh risk cat probs	*
C*	VHDRS (9)	CHAR*		VSDB record headers		*
C*	LHDRS (9)	INTEGER		VSDB record header lengths	*
C*	ANLYG (MX,MY)	REAL		Analysis grid			*
C*	FRCTG (MX,MY	REAL		Forecast probability grid	*
C*	THLDG (MX,MY)	REAL		Threshold grid			*
C*	MX		INTEGER		Number of grid points along x	*
C*	MY		INTEGER		Number of grid points along y	*
C*	REGIONS		CHAR*		Name of file defining subregion *
C*					polygons			*
C*	LUNS (NLUN)	INTEGER		Output logical unit # array	*
C*	NLUN		INTEGER		Number of LUNS			*
C*									*
C* Output parameter:							*
C*	IRET		INTEGER		Return code			*
C*									*
C* Log:									*
C* K. Brill/HPC		06/05						*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER       ( MXPOLY = 1024 )
C************************************************************************
	CHARACTER*(*)	catprobs, vhdrs (*), regions
	INTEGER		lhdrs (*), luns (*)
	REAL		anlyg (*), frctg (*), thldg (*)
C*
	CHARACTER	cprj*4, sysin*2
	CHARACTER*80	record, entry (2)
	INTEGER		inout (LLMXGD)
	REAL		rnav (LLNNAV)
	REAL		rlat (LLMXGD), rlon (LLMXGD)
	REAL		xpoly (MXPOLY), ypoly (MXPOLY), rval (2)
C*
	CHARACTER	crgn*32, orec*128
	REAL		frsk (LLMXGD), sgrd (LLMXGD)
C------------------------------------------------------------------------
	iret = 0
C*
	CALL GDBC2G ( catprobs, frctg, mx, my, frsk, iret )
C
C*	Set the grid box area scaling grid to one everywhere.
C
	DO i = 1, mx * my
	    sgrd (i) = 1.0
	END DO
C*
	IF ( iret .ne. 0 ) RETURN
C
C*	Generate data records for subregions and whole grid.
C
	lunr = 0
	CALL FL_SOPN ( regions, lunr, ios )
	IF ( ios .eq. 0 ) THEN
C
C*	    Get and set up the grid navigation.
C
	    CALL DG_QREF ( 0, LLNNAV, adum, rnav, mxg, ierr )
	    IF ( ierr .ne. 0 ) THEN
	        CALL ER_WMSG ( 'DG', ierr, ' ', ier )
	        iret = -17
	        RETURN
	    END IF
	    CALL GR_RNAV ( rnav, cprj, mx, my, ierr )
	    IF ( ierr .ne. 0 ) THEN
	        CALL ER_WMSG ( 'GR', ierr, ' ', ier )
	        iret = -18
	        RETURN
	    END IF
	    CALL GR_SNAV ( 20, rnav, ier )
	    IF ( ierr .ne. 0 ) THEN
	        CALL ER_WMSG ( 'GR', ierr, ' ', ier )
	        iret = -19
	        RETURN
	    END IF
C*
	    kxy = 0
	    DO j = 1, my
	        DO i = 1, mx
		    kxy = kxy + 1
		    rlat (kxy) = FLOAT (i)
		    rlon (kxy) = FLOAT (j)
	        END DO
	    END DO
C*
	    CALL GSMPRJ ( cprj, rnav(11), rnav(12), rnav(13),
     +		          rnav(7), rnav(8), rnav(9), rnav(10), ier )
	    CALL GTRANS ( 'G', 'N', kxy, rlat, rlon,
     +		          rlat, rlon, ier )
	    IF ( ier .ne. 0 ) THEN
	        iret = -21
	        RETURN
	    END IF
	    sysin = 'N'
            CALL ST_NULL ( sysin, sysin, lx, ier )
	END IF
	DO WHILE ( ios .eq. 0 )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
		    crgn = entry(1)
		    CALL ST_LSTR ( crgn, lrgn, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
			    WRITE (6,*) ' Too many region vertices.'
			ELSE
			    ios = -1
			    WRITE (6,*) ' Invalid entry in ',
     +					regions
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points',
     +			' for region = ', crgn(1:lrgn)
			ios = ier
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, kxy, rlat, rlon,
     +					  sysin, npoly, xpoly, ypoly,
     +					  inout, ier )
			icnt = 0
			DO i = 1, kxy
			    icnt = icnt + inout (i)
			END DO
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
			ELSE IF ( icnt .gt. 0 ) THEN
			    record = vhdrs(6)(1:lhdrs(6)) // '/' //
     +				     crgn(1:lrgn)
			    crgn = record
			    CALL ST_LSTR ( crgn, lrgn, ier )
			    record = vhdrs(1)
			    orec = vhdrs(1)
			    DO i = 2, 9
				CALL ST_LSTR ( record, l1, ier )
				CALL ST_LSTR ( orec, l2, ier )
				IF ( i .ne. 6 ) THEN
				    record = orec(1:l2) // ' ' //
     +					     vhdrs(i)(1:lhdrs(i))
				ELSE
				    record = orec(1:l2) // ' ' //
     +					     crgn(1:lrgn)
				END IF
				orec = record
			    END DO
			    CALL MAKPBS ( anlyg, thldg, frsk, sgrd, kxy,
     +					  inout, nlun, luns, orec, iret )
			    IF ( iret .ne. 0 ) RETURN
			ELSE
			    WRITE (6,*) crgn(1:lrgn),
     +                            ' is not on the verification domain.'
			END IF
		    END IF
		END IF
	    END IF
	END DO
	CALL FL_CLOS ( lunr, ier )
C
C*	Do entire grid.
C
	kxy = mx * my
	DO i = 1, kxy
	    inout (i) = 1
	END DO
C*
	record = vhdrs(1)
	orec = vhdrs(1)
	DO i = 2, 9
	    CALL ST_LSTR ( record, l1, ier )
	    CALL ST_LSTR ( orec, l2, ier )
	    record = orec(1:l2) // ' ' //
     +	             vhdrs(i)(1:lhdrs(i))
	    orec = record
	END DO
	CALL MAKPBS ( anlyg, thldg, frsk, sgrd, kxy,
     +		      inout, nlun, luns, orec, iret )
C*
	RETURN
	END
