	SUBROUTINE MAKPBS ( anlyg, thldg, frsk, sgrd, kxy, inout,
     +			    nlun, luns, orec, iret )
C************************************************************************
C* MAKPBS								*
C*									*
C* This subroutine computes PBS_ record values and writes them out in	*
C* VSDB	format.								*
C*									*
C* INOUT is an array of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* MAKPBS ( ANLYG, THLDG, FRSK, SGRD, KXY, INOUT, NLUN, LUNS, OREC,	*
C*	    IRET )							*
C*									*
C* Input parameters:							*
C*	ANLYG (KXY)	REAL		Analysis grid			*
C*	THLDG (KXY)	REAL		Threshold grid			*
C*	FRSK  (KXY)	REAL		Forecast risk grid:		*
C*					0 = no risk			*
C*					1 = low risk			*
C*					2 = moderate risk		*
C*					3 = high risk			*
C*	SGRD  (KXY)	REAL		Normalized box area grid	*
C*	KXY		INTEGER		Number of grid points		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*									*
C* Input and output parameter:						*
C*	OREC		CHAR*		VSDB header record		*
C*					Output in all caps		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC		 5/05						*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=160 )
C*
	REAL 		anlyg (*), frsk (*), sgrd (*), thldg (*)
	INTEGER		inout (*), luns (*)
	CHARACTER*(*)	orec
	
C*
	REAL		foe (7)
C*		    foe (1) = fraction of events with low risk frcst
C*		    foe (2) = fraction of events with mdt risk frcst
C*		    foe (3) = fraction of events with hgh risk frcst
C*		    foe (4) = frctn of evnts >= thld with no risk frcst
C*		    foe (5) = frctn of evnts >= thld with low risk frcst
C*		    foe (6) = frctn of evnts >= thld with mdt risk frcst
C*		    foe (7) = frctn of evnts >= thld with hgh risk frcst
C*
	LOGICAL		obsd
	CHARACTER	cl1l2*(MXC)
	CHARACTER*32	csave
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	CALL ST_LCUC ( orec, orec, ier )
	CALL ST_RXBL ( orec, orec, lnch, ier )
C
C*	Initialize counters for the fractions.
C
	DO k = 1, 7
	    foe (k) = 0.0
	END DO
	rn = 0.0
	DO i = 1, kxy
	    IF ( .not. ERMISS ( anlyg (i) ) .and.
     +		 .not. ERMISS ( thldg (i) ) .and.
     +		 .not. ERMISS ( frsk (i) ) .and.
     +		 .not. ERMISS ( sgrd (i) ) .and.
     +		 inout (i) .eq. 1 ) THEN
		rn = rn + sgrd (i)
		IF ( anlyg (i) .gt. thldg (i) ) THEN
		    obsd = .true.
		ELSE
	    	    obsd = .false.
		END IF
		irisk = NINT ( frsk (i) )
		IF ( irisk .eq. 0 ) THEN
		    IF ( obsd ) foe (4) = foe (4) + sgrd (i)
		ELSE IF ( irisk .eq. 1 ) THEN
		    foe (1) = foe (1) + sgrd (i)
		    IF ( obsd ) foe (5) = foe (5) + sgrd (i)
		ELSE IF ( irisk .eq. 2 ) THEN
		    foe (2) = foe (2) + sgrd (i)
		    IF ( obsd ) foe (6) = foe (6) + sgrd (i)
		ELSE IF ( irisk .eq. 3 ) THEN
		    foe (3) = foe (3) + sgrd (i)
		    IF ( obsd ) foe (7) = foe (7) + sgrd (i)
		ELSE
		    iret = -23
		    RETURN
		END IF
	    END IF
	END DO
C*
	nrn = NINT ( rn )
	rn = FLOAT ( nrn )
	IF ( nrn .gt. 0 ) THEN
	    DO k = 1, 7
		foe (k) = foe (k) / rn
	    END DO
	    WRITE (cl1l2,1000) nrn, (foe(k),k=1,7)
1000	    FORMAT ( I7, 7(1X,F7.5) )
	    CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
	    DO i = 1, nlun
		WRITE (luns(i), '(A,A,A)') orec (1:lnch),
     +				' = ', cl1l2 (1:lnch2)
	    END DO
	ELSE
	    WRITE (6,*) orec(1:lnch), ' --------:'
	    WRITE (6,*)
     +		' All points zero, missing, or not in region.'
	END IF
C*
	RETURN
	END
