	PROGRAM  GDPBSFHO
C************************************************************************
C* GDPBSFHO								*
C*									*
C* This program compares forecast polygons extracted from VG files with *
C* a verifying analysis grid and computes either PBS_ or FHO fractions  *
C* relative to given thresholds.					*
C*									*
C**									*
C* Log:									*
C* K. Brill  		 5/05						*
C* K. Brill/HPC      20080304	CALL GD_INIT				*
C* K. Brill/HPC	     20080822   Call GDPFHX to allow threshold=forecast *
C* K. Brill          20131010   Use atime(1) from analysis DG_GRID	*
C************************************************************************
	INCLUDE		'gdpbsfho.cmn'
C*

	CHARACTER	fpolyfil*(LLMXLN), vdbfrcid*(LLMXLN),
     +			vdbfrchr*(LLMXLN), atgdfile*(LLMXLN),
     +			anlygfnc*(LLMXLN), thldgfnc*(LLMXLN),
     +			vdbanlid*(LLMXLN), vdbanlgd*(LLMXLN),
     +			vdbstatt*(LLMXLN), vdbprmnm*(LLMXLN),
     +			vdblvlnm*(LLMXLN), regions*(LLMXLN),
     +			output*(LLMXLN),   frctgfnc*(LLMXLN)
C*
	REAL		thldg (LLMXGD), anlyg (LLMXGD), fgrd (LLMXGD)
	INTEGER		lhdrs (9), level (2), luns (4)
	CHARACTER	vlddtm*20, parm*12, ccc*2
        CHARACTER       devs(4)*1
	CHARACTER*16	gdatm, cstat
	CHARACTER*24	vhdrs (9)
	CHARACTER*128	pfunc
	CHARACTER	time(2)*20, atime(2)*20
	LOGICAL		respnd, done, proces, dopbs, dofho, nxtok
	LOGICAL		conth, tinf
C*
	INCLUDE		'ERMISS.FNC'
C-----------------------------------------------------------------------
C*	Initialize user interface and GEMPLT.
C
	CALL IP_INIT  ( respnd, iperr )
	IF  ( iperr .eq. 0 )  THEN
	    mode = 1
	    CALL GG_INIT  ( mode, iperr )
	    IF ( iperr .ne. 0 ) THEN
		ierr = -1
		CALL ER_WMSG ( 'GDPBSFHO', ierr, ' ', ier )
	    END IF
	    CALL GG_SDEV ( 'GN', ierr )
	    IF ( ierr .ne. 0 ) THEN
		ierr = -2
		CALL ER_WMSG ( 'GDPBSFHO', ierr, ' ', ier )
		iperr = ierr
	    END IF
	ELSE
	    ierr = -3
	    CALL ER_WMSG ( 'GDPBSFHO', ierr, ' ', ier )
	END IF
	IF  ( iperr .eq. 0 )  THEN
	    done = .false.
	  ELSE
	    done = .true.
	END IF
	CALL IP_IDNT  ( 'GDPBSFHO', ier )
	CALL GD_INIT ( ierr )
	CALL DG_INTL ( iret )
C
C*	Main loop to read in parameters and do verification.
C
	DO WHILE  ( .not. done )
C
C*	    Set flag to indicate processing will be done.
C
	    proces = .true.
C
C*	    Read in the variables from the user interface.
C
	    CALL GDPINP ( fpolyfil, vdbfrcid, vdbfrchr, atgdfile,
     +			  anlygfnc, thldgfnc, vdbanlid,
     +			  vdbanlgd, vdbstatt, vdbprmnm,
     +			  vdblvlnm, regions, output, iperr )
C
C*	    Check for errors or missing input.
C
	    IF ( vdbfrcid .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -4, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbfrchr .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -5, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbanlid .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -6, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbanlgd .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -7, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbstatt .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -8, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdbprmnm .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -9, ' ', ier )
		proces = .false.
	    END IF
	    IF ( vdblvlnm .eq. ' ' ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -10, ' ', ier )
		proces = .false.
	    END IF
	    IF  ( iperr .ne. 0 )  THEN
		done = .true.
		proces = .false.
	    END IF
C*
	    IF ( proces ) THEN
C
C*		Get the output units.
C
		CALL IN_OUTT (output, 'GDPBSFHO', luns, nlun,
     +			      devs, iret)
		IF ( iret .ne. 0 ) THEN
		    CALL ER_WMSG ( 'IN', iret, ' ', ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Check for a valid statistic type.
C
	    CALL ST_LCUC ( vdbstatt, cstat, ier )
	    dopbs = INDEX ( cstat, 'PBS_' ) .gt. 0
	    dofho = INDEX ( cstat, 'FHO' ) .gt. 0
	    IF ( dopbs .and. dofho ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -11, ' ', ier )
		proces = .false.
	    ELSE IF ( .not. ( dopbs .or. dofho ) ) THEN
		CALL ER_WMSG ( 'GDPBSFHO', -11, ' ', ier )
		proces = .false.
	    END IF
	    IF ( dofho .and. cstat (5:5) .ne. ' ' ) THEN
C
C*		The FHO threshold is given; so FPOLYFIL must
C*              specify a GFUNC specification.
C
		CALL FL_INQR ( fpolyfil, tinf, pfunc, ier )
		IF ( tinf ) THEN
		    CALL ER_WMSG ( 'GDPBSFHO', -26, ' ', ier )
		    proces = .false.
		ELSE
		    tinf = .true.
		END IF
	    ELSE
		tinf = .false.
	    END IF
C
C*	    Open the analysis and threshold grid files.
C
	    IF ( proces ) THEN
		CALL DG_NFIL ( atgdfile, ' ', ierr )
		IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, atgdfile, ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Set the internal date time stamp.
C
	    IF ( proces ) THEN
		gdatm = 'FIRST'
		CALL DG_NDTM ( gdatm, ierr )
		IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, ' ', ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Set the internal grid and retrieve the time stamp.
C
	    IF ( proces ) THEN
		CALL DG_NTIM ( .TRUE., .TRUE., time, nxtok, ierr )
		IF ( .not. nxtok ) THEN
		    CALL ER_WMSG ( 'GDPBSFHO', -12, ' ', ier )
		    proces = .false.
		END IF
		IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, ' ', ier )
		    proces = .false.
		END IF
	    END IF
C
C*	    Read in the verifying analysis grid.
C
	    IF ( proces ) THEN
	        CALL DG_GRID ( time (1), '0', 'NONE', anlygfnc,
     +			       pfunc, anlyg, mx, my, atime, level,
     +			       ivcord, parm, ierr )
C*
	        IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, pfunc, ier )
		    proces = .false.
		    CALL ER_WMSG ( 'GDPBSFHO', -14, ' ', ier )
	        ELSE
C
C*		    Convert analysis time to the VSDB date-time stamp.
C
		    IF ( atime (2) .ne. ' ' ) THEN
		        CALL ER_WMSG ( 'GDPBSFHO', +1, ' ', ier )
C## Always use the first time, NOT atime (1) = atime (2)
		    END IF

		    CALL TG_VALD ( atime (1), vlddtm, ier )
		    iv = INDEX ( vlddtm, 'V' )
		    IF ( iv .ne. 0 ) THEN
		        atime(1) = vlddtm(1:iv-1)
		    ELSE
			atime(1) = vlddtm
		    END IF
		    CALL TI_CCNT ( atime (1), ccc, ierr )
		    IF ( ierr .ne. 0 ) THEN
			CALL ER_WMSG ( 'TI', ierr, atime(1), ier )
			CALL ER_WMSG ( 'GDPBSFHO', -13, ' ', ier )
			proces = .false.
		    END IF
		    islash = INDEX ( atime (1), '/' )
C
C*		    Make a VSDB date-time stamp.
C
		    vlddtm = ccc // atime(1)(1:islash-1) //
     +			         atime(1)(islash+1:islash+2)
		    IF ( vlddtm .eq. ' ' ) THEN
		        CALL ER_WMSG ( 'GDPBSFHO', -13, ' ', ier )
		        proces = .false.
		    END IF
	        END IF
	    END IF
C
C*	    Read in the grid of threshold values for PBS or FHO.
C
	    IF ( proces ) THEN
	        CALL DG_GRID ( time (1), '0', 'NONE', thldgfnc,
     +			       pfunc, thldg, mx, my, atime, level,
     +			       ivcord, parm, ierr )
C*
	        IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, 'pfunc', ier )
		    proces = .false.
		    CALL ER_WMSG ( 'GDPBSFHO', -15, ' ', ier )
	        END IF
		IF ( proces ) THEN
C
C*		    Check to see if the threshold is a constant value.
C
		    CALL ST_CRNM ( thldgfnc, thval, ier )
		    conth = .not. ( ERMISS ( thval ) .or. ier .ne. 0 )
		END IF
	    END IF
	    IF ( proces .and. dofho .and. .not. conth ) THEN
		WRITE (6,*) 'Using varying values as threshold for ',
     +                      ' FHO stats.'
		thval = RMISSD
	    END IF
C
C*	    Read forecast grid if required.
C
	    IF ( proces .and. tinf ) THEN
	        CALL DG_GRID ( time (1), '0', 'NONE', fpolyfil,
     +			       pfunc, fgrd, mx, my, atime, level,
     +			       ivcord, parm, ierr )
C*
	        IF ( ierr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'DG', ierr, 'pfunc', ier )
		    proces = .false.
		    CALL ER_WMSG ( 'GDPBSFHO', -28, ' ', ier )
	        END IF
		conth = .false.
	    END IF
C
C*	    Make the individual VSDB record header fields.
C
	    IF ( proces ) THEN
		CALL GDPHDR ( vdbfrcid, vdbfrchr, vlddtm, vdbanlid,
     +			      vdbanlgd, vdbstatt, vdbprmnm, vdblvlnm,
     +			      thval, conth, dofho, vhdrs, lhdrs, iperr )
		IF ( iperr .ne. 0 ) THEN
		    CALL ER_WMSG ( 'GDBPSFHO', iperr, ' ', ier )
		    proces = .false.
		END IF
	    END IF
		
C
C*	    Call the appropriate subroutine to generate VSDB records.
C
	    IF ( dopbs .and. proces ) THEN
		CALL GDPPBS ( fpolyfil, vhdrs, lhdrs, anlyg, thldg,
     +			      mx, my, regions, luns, nlun, iperr )
	    ELSE IF ( ( dofho .and. conth ) .and. proces )  THEN
		CALL GDPFHO ( fpolyfil, vhdrs, lhdrs, anlyg, mx, my,
     +			      thval, regions, luns, nlun, iperr )
	    ELSE IF ( ( dofho .and. tinf ) .and. proces ) THEN
		CALL GDPFHX ( thldg, mx, my, vhdrs, lhdrs, fgrd, anlyg,
     +			      regions, luns, nlun, iperr )
	    ELSE
C
C*		Avoid duplicate error messages.
C
		CALL ER_WMSG ( 'GDPBSFHO', -27, ' ', ier )
		iperr = 0
	    END IF
	    IF ( iperr .ne. 0 ) THEN
		CALL ER_WMSG ( 'GDBPSFHO', iperr, ' ', ier )
		proces = .false.
	    END IF
C
C*	    Prompt for next listing to be done.
C
	    CALL IP_DYNM  ( done, ier )
	END DO
C
C*	Print general error messages if necessary.
C
	IF  (iperr .ne. 0)  CALL ER_WMSG ( 'GDPBSFHO', iperr, ' ', ier )
C
C*	Exit from GEMPLT and the TAE.
C
	CALL GENDP  ( 0, iret )
	CALL IP_EXIT  ( iret )
C*
	END
