	SUBROUTINE GDPFHX ( thldg, mx, my, vhdrs, lhdrs, fgrd, anlyg,
     +                      regions, luns, nlun, iret )
C************************************************************************
C*  This program computes VSDB FHO statistic records given an analysis	*
C*  grid and a threshold=forecast grid.					*
C*									*
C*  GDPFHX ( THLDG, MX, MY, VHDRS, LHDRS, FGRD, ANLYG, REGIONS,		*
C*           LUNS, NLUN, THVAL, CONTH, IRET )				*
C*									*
C* Input parameters:							*
C*	THLDG (MX,MY)	REAL		Grid of forecast=threshold data *
C*	MX		INTEGER		Number of grid points along x	*
C*	MY		INTEGER		Number of grid points along y	*
C*	VHDRS (9)	CHAR*		VSDB record headers		*
C*	LHDRS (9)	INTEGER		VSDB record header lengths	*
C*      FGRD  (MX,MY)   REAL		Forecast grid			*
C*	ANLYG (MX,MY)	REAL		Analysis grid			*
C*	REGIONS		CHAR*		Name of file defining subregion *
C*					polygons			*
C*	LUNS (NLUN)	INTEGER		Output logical unit # array	*
C*	NLUN		INTEGER		Number of LUNS			*
C*									*
C* Output parameter:							*
C*	IRET		INTEGER		Return code			*
C*									*
C* Log:									*
C* K. Brill/HPC      20080822	Created from GDPFHO			*
C************************************************************************
	INCLUDE		'gdpbsfho.cmn'
C*
	CHARACTER*(*)	vhdrs (*), regions
	INTEGER		lhdrs (*), luns (*)
	REAL		thldg (*), fgrd (*), anlyg (*)
C*
	CHARACTER	crgn*32, orec*128
	REAL		fval (LLMXGD), sgrd (LLMXGD)
	LOGICAL		sgflg
C------------------------------------------------------------------------
	iret = 0
C
C*	Call GDPP2G just to set things in GPLT.  Ignore its IRET value.

	CALL GDPP2G ( ' ', 0, sgflg, fval, sgrd, kxf, kyf, irr )
C*
	sgflg = .false.
	kxy = kxf * kyf
	DO j = 1, kxy
	    fval (j) = fgrd (j)
	    sgrd (j) = 1.0
	END DO
C
C*	Generate data records for subregions and whole grid.
C
	lunr = 0
	CALL FL_SOPN ( regions, lunr, ios )
	DO WHILE ( ios .eq. 0 )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
		    crgn = entry(1)
		    CALL ST_LSTR ( crgn, lrgn, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
			    WRITE (6,*) ' Too many region vertices.'
			ELSE
			    ios = -1
			    WRITE (6,*) ' Invalid entry in ',
     +					regions
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points',
     +			' for region = ', crgn(1:lrgn)
			ios = ier
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, kxy, rlat, rlon,
     +					  sysin, npoly, xpoly, ypoly,
     +					  inout, ier )
			icnt = 0
			DO i = 1, kxy
			    icnt = icnt + inout (i)
			END DO
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
			ELSE IF ( icnt .gt. 0 ) THEN
			    record = vhdrs(6)(1:lhdrs(6)) // '/' //
     +				     crgn(1:lrgn)
			    crgn = record
			    CALL ST_LSTR ( crgn, lrgn, ier )
			    record = vhdrs(1)
			    orec = vhdrs(1)
			    DO i = 2, 9
				CALL ST_LSTR ( record, l1, ier )
				CALL ST_LSTR ( orec, l2, ier )
				IF ( i .ne. 6 ) THEN
				    record = orec(1:l2) // ' ' //
     +					     vhdrs(i)(1:lhdrs(i))
				ELSE
				    record = orec(1:l2) // ' ' //
     +					     crgn(1:lrgn)
				END IF
				orec = record
			    END DO
			    CALL MAKFHX ( anlyg, fval, sgrd, kxy, thldg,
     +					  inout, nlun, luns, orec, iret )
			    IF ( iret .ne. 0 ) RETURN
			ELSE
			    WRITE (6,*) crgn(1:lrgn),
     +                            ' is not on the verification domain.'
			END IF
		    END IF
		END IF
	    END IF
	END DO
	CALL FL_CLOS ( lunr, ier )
C
C*	Do entire grid.
C
	DO i = 1, kxy
	    inout (i) = 1
	END DO
C*
	record = vhdrs(1)
	orec = vhdrs(1)
	DO i = 2, 9
	    CALL ST_LSTR ( record, l1, ier )
	    CALL ST_LSTR ( orec, l2, ier )
	    record = orec(1:l2) // ' ' //
     +	             vhdrs(i)(1:lhdrs(i))
	    orec = record
	END DO
	CALL MAKFHX ( anlyg, fval, sgrd, kxy, thldg,
     +		      inout, nlun, luns, orec, iret )
C*
	RETURN
	END
