	SUBROUTINE GDPP2G ( fpolyfil, opval, rbsflg, fgrd, sgrd,
     +			    kxf, kyf, iret )
C************************************************************************
C* GDPP2G								*
C*									*
C* This subroutine creates a grid from the polygons given in the text	*
C* file containing polygon points.					*
C*									*
C* The value of largest magnitude is assigned to the output grid.	*
C* The grid navigation is optained by calling DG_QREF to retreive the	*
C* navigation of the reference grid.					*
C*									*
C* GDPP2G  ( FPOLYFIL, OPVAL, RBSFLG, FGRD, SGRD, KXF, KYF, IRET )	*
C*									*
C* Input parameters:							*
C*	FPOLYFIL	CHAR*		Name of polygon text file	*
C*	OPVAL		REAL		Outside-polygon value for FGRD	*
C*      RBSFLG		LOGICAL		Flag for future use of SGRD	*
C*									*
C* Output parameters:							*
C*	FGRD (KXF,KYF)	REAL		Forecast probability grid	*
C*	SGRD (KXF,KYF)	REAL		Relative grid box area size grid*
C*	KXF		INTEGER		Grid X dimension		*
C*	KYF		INTEGER		Grid Y dimension		*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC          5/05						*
C************************************************************************
	INCLUDE		'gdpbsfho.cmn'
C*
	CHARACTER*(*)	fpolyfil
	REAL		fgrd (*), sgrd (*)
	LOGICAL		rbsflg
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C
C*	Get and set up the grid navigation.
C
	CALL DG_QREF ( 0, LLNNAV, adum, rnav, mxg, ierr )
	IF ( ierr .ne. 0 ) THEN
	    CALL ER_WMSG ( 'DG', ierr, ' ', ier )
	    iret = -17
	    RETURN
	END IF
	CALL GR_RNAV ( rnav, cprj, kxf, kyf, ierr )
	IF ( ierr .ne. 0 ) THEN
	    CALL ER_WMSG ( 'GR', ierr, ' ', ier )
	    iret = -18
	    RETURN
	END IF
	CALL GR_SNAV ( 20, rnav, ier )
	IF ( ierr .ne. 0 ) THEN
	    CALL ER_WMSG ( 'GR', ierr, ' ', ier )
	    iret = -19
	    RETURN
	END IF
C
C*	Set the ouput forecast grid to missing.
C*	The output relative grid box area size is set to 1.0.
C*	It can be scaled at a later date if needed.
C
	kxy = 0
	DO j = 1, kyf
	    DO i = 1, kxf
		kxy = kxy + 1
		fgrd (kxy) = RMISSD
		sgrd (kxy) = 1.00
		rlat (kxy) = FLOAT (i)
		rlon (kxy) = FLOAT (j)
	    END DO
	END DO
C*
	CALL GSMPRJ ( cprj, rnav(11), rnav(12), rnav(13),
     +		      rnav(7), rnav(8), rnav(9), rnav(10), ier )
	CALL GTRANS ( 'G', 'N', kxy, rlat, rlon,
     +		      rlat, rlon, ier )
	IF ( ier .ne. 0 ) THEN
	    iret = -21
	    RETURN
	END IF
	sysin = 'N'
	CALL ST_NULL ( sysin, sysin, lx, ier )
C
C*	Return negative return code if no polygon file is given.
C
	IF ( fpolyfil .eq. ' ' ) THEN
	    iret = -24
	    RETURN
	END IF
C
C*	Open the polygon file.
C
	CALL FL_SOPN ( fpolyfil, lunr, ios )
	IF ( ios .ne. 0 ) THEN
	    CALL ER_WMSG ( 'FL', ios, ' ', ier )
	    iret = -20
	    RETURN
	END IF
	DO WHILE ( ios .eq. 0 )
	    READ ( lunr, '(A)', IOSTAT=ios ) record
	    IF ( ios .eq. 0 ) THEN
		CALL ST_CLST ( record, ' ', ' ', 2, entry, num, ier )
		IF ( num .eq. 2 .and. ier .ge. 0 ) THEN
		    CALL ST_CRNM ( entry (1), gvalu, ier )
		    CALL ST_NUMB ( entry (2), npoly, ier )
		    ip = 0
		    DO WHILE ( ip .lt. npoly .and. ios .eq. 0 )
			ip = ip + 1
			READ (lunr,'(A)',IOSTAT=ios) record
			CALL ST_RLST ( record, ' ', 0., 2, rval,
     +				       num, ier )
			IF ( num .eq. 2 .and. ier .ge. 0 .and.
     +			     ip .le. MXPOLY ) THEN
			    xpoly (ip) = rval (1)
			    ypoly (ip) = rval (2)
			ELSE IF ( ip .gt. MXPOLY ) THEN
			    ios = -1
		            iret = -22
			    WRITE (6,*) ' Too many FPOLY vertices.'
			ELSE
			    ios = -1
		            iret = -22
			    WRITE (6,*) ' Invalid entry in ',
     +					fpolyfil
			END IF
		    END DO
		    CALL GTRANS ( 'M', 'N', npoly, xpoly, ypoly,
     +				  xpoly, ypoly, ier )
		    IF ( ier .ne. 0 ) THEN
			WRITE (6,*)
     +			' Cannot get normalized polygon vertex points'
			ios = ier
		        iret = -22
		    END IF
		    IF ( ios .eq. 0 ) THEN
			CALL CGR_INPOLY ( sysin, kxy, rlat, rlon,
     +					  sysin, npoly, xpoly, ypoly,
     +					  inout, ier )
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) ' INPOLY check failed.'
			    ios = ier
			    iret = -22
			ELSE
			    inew = 0
			    iupd = 0
			    DO i = 1, kxy
				IF ( inout (i) .eq. 1 ) THEN
				    IF ( .not. ERMISS ( fgrd (i) ) )
     +				    THEN
				        cval = ABS ( gvalu )
					tval = ABS ( fgrd (i) )
					IF ( cval .gt. tval ) THEN
					    fgrd (i) = gvalu
					    iupd = iupd + 1
					END IF
				    ELSE
					fgrd (i) = gvalu
					inew = inew + 1
				    END IF
				END IF
			    END DO
			END IF
		    END IF
		END IF
	    END IF
	END DO
	IF ( iret .eq. 0 .and. .not. ERMISS ( opval ) ) THEN
C
C*	    Replace all values still missing.
C
	    DO i = 1, kxy
		IF ( ERMISS ( fgrd(i) ) ) THEN
		    fgrd (i) = opval
		END IF
	    END DO
	END IF
	CALL FL_CLOS ( lunr, ier )
C*
	RETURN
	END
