	SUBROUTINE MAKFHX ( anlyg, fval, sgrd, kxy, thval, inout,
     +			    nlun, luns, orec, iret )
C************************************************************************
C* MAKFHX								*
C*									*
C* This subroutine computes FHO record values and writes them out in	*
C* VSDB	format.  The threshold varies from grid point to grid point.	*
C*									*
C* INOUT is an array of flags denoting whether or not a grid point	*
C* is within the verification region.					*
C*									*
C*									*
C* MAKFHO ( ANLYG, FVAL, SGRD, KXY, THVAL, INOUT, NLUN, LUNS, OREC,	*
C*	    IRET )							*
C*									*
C* Input parameters:							*
C*	ANLYG (KXY)	REAL		Analysis grid			*
C*	FVAL  (KXY)	REAL		Forecast grid			*
C*	SGRD  (KXY)	REAL		Normalized box area grid	*
C*	KXY		INTEGER		Number of grid points		*
C*	THVAL (KXY)	REAL		Threshold values		*
C*	INOUT (KXY)	INTEGER		Flag to compare at grid point	*
C*					   1 = compare			*
C*					   0 = do not compare		*
C*	NLUN		INTEGER		Number of output units		*
C*	LUNS (NLUN)	INTEGER		Output unit numbers		*
C*									*
C* Input and output parameter:						*
C*	OREC		CHAR*		VSDB header record		*
C*					Output in all caps		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					  0 = normal return		*
C**									*
C* Log:									*
C* K. Brill/HPC      20080822	Created from makfho.f			*
C************************************************************************
	INCLUDE		'GEMPRM.PRM'
	PARAMETER	( MXC=160 )
C*
	REAL 		anlyg (*), sgrd (*), fval (*), thval (*)
	INTEGER		inout (*), luns (*)
	CHARACTER*(*)	orec
	
C*
	REAL		fho (3)
C*		    fho (1) = fraction of events forecast
C*		    fho (2) = fraction of events forecast and obsd (hits)
C*		    fho (3) = fraction of events observed
C*
	LOGICAL		frct, obsd, lgt
	CHARACTER	cl1l2*(MXC)
	CHARACTER*32	csave
C*
	INCLUDE		'ERMISS.FNC'
C------------------------------------------------------------------------
	iret = 0
C*
	CALL ST_LCUC ( orec, orec, ier )
	CALL ST_RXBL ( orec, orec, lnch, ier )
C
C*	Determine sense of comparison inequality.
C
	iqgt = INDEX ( orec, 'FHO>' )
	iqlt = INDEX ( orec, 'FHO<' )
	IF ( iqgt + iqlt .eq. 0 ) THEN
	    iret = -25
	    RETURN
	END IF
	lgt = iqgt .gt. 0
C
C*	Initialize counters for the fractions.
C
	DO k = 1, 3
	    fho (k) = 0.0
	END DO
	rn = 0.0
	DO i = 1, kxy
	    IF ( .not. ERMISS ( anlyg (i) ) .and.
     +		 .not. ERMISS ( fval (i) ) .and.
     +		 .not. ERMISS ( sgrd (i) ) .and.
     +		 inout (i) .eq. 1 ) THEN
		rn = rn + sgrd (i)
		IF ( anlyg (i) .ge. thval (i) .and. lgt ) THEN
		    obsd = .true.
		ELSE IF ( anlyg (i) .le. thval (i) .and. .not. lgt )
     +		THEN
		    obsd = .true.
		ELSE
	    	    obsd = .false.
		END IF
		IF ( fval (i) .ge. thval (i) .and. lgt ) THEN
		    frct = .true.
		ELSE IF ( fval (i) .le. thval (i) .and. .not. lgt )
     +		THEN
		    frct = .true.
		ELSE
	    	    frct = .false.
		END IF
		IF ( frct ) fho (1) = fho (1) + sgrd (i)
		IF ( frct .and. obsd ) fho (2) = fho (2) + sgrd (i)
		IF ( obsd ) fho (3) = fho (3) + sgrd (i)
	    END IF
	END DO
C*
	nrn = NINT ( rn )
	rn = FLOAT ( nrn )
	IF ( nrn .gt. 0 ) THEN
	    DO k = 1, 3
		fho (k) = fho (k) / rn
	    END DO
	    WRITE (cl1l2,1000) nrn, (fho(k),k=1,3)
1000	    FORMAT ( I7, 3(1X,F7.5) )
	    CALL ST_RXBL ( cl1l2, cl1l2, lnch2, ier )
	    DO i = 1, nlun
		WRITE (luns(i), '(A,A,A)') orec (1:lnch),
     +				' = ', cl1l2 (1:lnch2)
	    END DO
	ELSE
	    WRITE (6,*) orec(1:lnch), ' --------:'
	    WRITE (6,*)
     +		' All points zero, missing, or not in region.'
	END IF
C*
	RETURN
	END
