	PROGRAM MKPLOT
C************************************************************************
C*  This program plots trace data.					*
C*									*
C*  The following lines of input are read with no prompts:		*
C*									*
C*	1-  the name of a graphics control file				*
C*	2-  the name of the input trace data file			*
C*	3-  the plot number (IPLOT), the method number (METHOD), and	*
C*	    the display type (MDSPLY), lag for combining value (LAG)	*
C*	4-  if METHOD = 1, 0						*
C*	    if METHOD = 2, the trace number(s)				*
C*	    if METHOD = 3, exactly two trace numbers			*
C*	    if METHOD = 4, exactly two trace numbers			*
C*	    if METHOD = 5, exactly two trace numbers			*
C*	    if METHOD = 6, exactly two trace numbers			*
C*	5-  the operation code(s) (IOPCOD)				*
C*	    if METHOD = 2, one operation code (IOPCOD) per trace	*
C*	    if METHOD = 5, one operation code unless trace numbers are  *
C*	                   identical, then two operation codes		*
C*          if METHOD = 6, same condition as for 5			*
C*									*
C*	6-  the two trace smoothing control numbers			*
C*	    ISMWND = the running average window size in trace points	*
C*	    ISMORT = the running average window orientation flag	*
C*            if ISMORT < 0, window ends on each point			*
C*	      if ISMORT = 0, window centered on each point		*
C*	      if ISMORT > 0, window begins on each point		*
C*	    Set ISMWND = 0 for no smoothing.				*
C*									*
C*  If METHOD = 1, one computation code is applied to all the traces	*
C*  in the plot.  If METHOD = 2, the trace numbers and corresponding	*
C*  computational codes are entered on lines 4 and 5.  If METHOD = 3,   *
C*  4, or 5 two trace numbers and one operation code are entered.  If	*
C*  METHOD = 3, the simple difference between two traces is displayed	*
C*  as a single trace.  If METHOD = 4, the % difference between the	*
C*  two traces is displayed as a single trace.  The % difference is	*
C*  computed as follows at each	trace point after any smoothing:	*
C*									*
C*	              ( trace1 - trace2 )				*
C*       % diff = ------------------------------ * 100			*
C*			  | trace2 |					*
C*									*
C*  If METHOD = 5, the skill score or skill measure of the first	*
C*  trace relative to the second is computed according to:		*
C*									*
C*	                    ( trace1 - trace2 )				*
C*       skill score = ------------------------------			*
C*			( perfect score - trace2 )			*
C*									*
C*  The perfect score is a function of the statistic type and the	*
C*  parameter being computed from the statistics.			*
C*									*
C*  If METHOD = 6, the statistical significance of the differences of	*
C*  the paired values of two traces is assessed following sections	*
C*  5.2.3 and 5.2.4 of Wilks (2006).  The null hypothesis is that the	*
C*  two traces are the same.  The z value computed is the average	*
C*  of the differences divided by a standard deviation estimate that	*
C*  assumes serial dependence of the data along the trace.  This	*
C*  significance estimate should be applied to time series having	*
C*  enough points to apply the Central Limit Theorem.			*
C*									*
C*  If MDSPLY = 0, then statistics for all of the traces in the plot	*
C*  are computed and displayed as text on standard output.  No graphics	*
C*  are drawn.								*
C*									*
C*  If MDSPLY = 1 the plot is created and displayed as defined in the	*
C*  trace.dat file.  If MDSPLY = 2 and there are two traces defined,	*
C*  then a scatter plot is created.  If MDSPLY = 3 and exactly one	*
C*  trace is defined, then a histogram is drawn.  If MDSPLY = 4, force	*
C*  the display of trace data as line plots (usually used to look at	*
C*  data traces in a scatter plot).  MDSPLY = 5 creates a ROC curve	*
C*  with METHOD = 1 or 2 for a time series of data.  MDSPLY = 6 makes   *
C*  an attribute diagram with METHOD 1 or 2 given a time series of	*
C*  data and comp code = 1360.						*
C*									*
C*  If METHOD = 2 and MDSPLY = 3, then the relative placement frequency *
C*  histogram is constructed for the first trace among the remaining	*
C*  traces.  The series of numbers from which the histogram is made	*
C*  are computed by comparing the first trace value to all other trace	*
C*  values at each point.  If the first trace number is greatest, the	*
C*  assigned number is one.  If it is second greatest, it is given the	*
C*  value 2, and so on.  The resulting histogram gives the frequency at	*
C*  which the first trace falls into first place, second place, and so	*
C*  on.									*
C*									*
C*  The operation code here is an integer value that will be passed	*
C*  into RDTD_TRC as ICOMP.  See the documentation for RDTD_TRC for	*
C*  the meaning of the values of ICOMP.					*
C*									*
C*  If LAG > 0, then there is intra-trace data combination:  Each	*
C*  computed value at a trace point is computed after the preceding	*
C*  LAG-1 trace values have been combined with the values at the point.	*
C*  If LAG < 0, the intra-trace data combination resets and starts	*
C*  again every |LAG|+1 value along the trace.  The maximum number of	*
C*  values combined is |LAG|.						*
C*									*
C*  If LAG = -9999, then the lags for the individual traces may be	*
C*  entered on a seventh line following the smoothing control numbers.  *
C*  There must be a lag number for each trace.  These lag numbers may	*
C*  negative as described above.					*
C*									*
C** Log:								*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 8/98	METHOD = 6				*
C* K. Brill/EMC		10/98	Simplify METHOD and display type	*
C* K. Brill/EMC		 1/99	Add smoothing; diffs METHOD = 3/4; LAG	*
C* K. Brill/EMC		 2/99	Allow negative Op Codes at STOP 15	*
C* K. Brill/HPC		 3/00	Upped 16 to 20 for MXTRC		*
C* K. Brill/HPC		11/00	Upped 20 to 24 for MXTRC		*
C* K. Brill/HPC		 5/01	Document placement frequency histogram	*
C* K. Brill/HPC		 2/03	Changes for METHOD = 5			*
C* K. Brill/HPC		 5/04	Allow identical trace numbers and two	*
C*				operations codes for METHOD = 5		*
C* K. Brill/HPC	     20061117   Add METHOD = 6				*
C* K. Brill/HPC      20070126   Document MDSPLY = 5 and 6		*
C* K. Brill/HPC      20081105   Document ABS value in % diff; allow lag *
C*				to vary trace to trace; allow negative	*
C*				lag values				*
C* K. Brill/HPC      20100224   Increase ioline from 80 to 256		*
C* K. Brill/IMSG     20170928   Include version.f                       *
C************************************************************************
	PARAMETER	( MXTRC = 24 )
	CHARACTER*128	filnam
	CHARACTER	ioline*256
	INTEGER		itrcs (MXTRC), iopcod (MXTRC), lags (MXTRC)
C------------------------------------------------------------------------
        INCLUDE '../version.f'
C
C*	Open the graphics control file.
C
	lungc = 9
	READ (5,'(A)',IOSTAT=ios) filnam
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) ' Standard input for graphics control file',
     +			' name failed.'
	    STOP 1
	END IF
	OPEN ( UNIT=lungc, FILE=filnam, STATUS='OLD', IOSTAT=ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) ' Cannot open ', filnam
	    STOP 2
	END IF
C
C*	Open trace data file.
C
	luntd = 8
	READ (5,'(A)',IOSTAT=ios) filnam
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) ' Standard input for trace data file name',
     +			' failed.'
	    STOP 3
	END IF
	OPEN ( UNIT=luntd, FILE=filnam, STATUS='OLD', IOSTAT=ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) ' Cannot open ', filnam
	    STOP 4
	END IF
C
C*	Initialize trace reading software.
C
	CALL RDTD_INI ( luntd, nplts, iret )
	IF ( iret .ne. 0 ) THEN
	    CALL RDTD_ERR ( iret, 'RDTD_INI', ier )
	    STOP 5
	END IF
C
C*	Read the plot number and method number.
C
	READ (5,*,IOSTAT=ios) iplot, method, mdsply, lag
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) ' Standard input for plot, method,',
     +			' display, and lag numbers failed.'
	    STOP 6
	END IF
	IF ( iplot .le. 0 .or. iplot .gt. nplts ) THEN
	    WRITE (6,*) ' Plot number ', iplot, ' is invalid.'
	    STOP 7
	END IF
C
C*	Load all the information and data for this plot.
C
	CALL RDTD_FND ( luntd, iplot, .true., ntrcs, itype, iret )
	IF ( iret .ne. 0 ) THEN
	    CALL RDTD_ERR ( iret, 'RDTD_FND', ier )
	    STOP 8
	END IF
C
C*	Act according to the METHOD number.
C
	IF ( method .eq. 1 .and. lag .ne. -9999 ) THEN
C
C*	    Read dummy trace # (0), then read the operation code.
C
	    READ (5,*,IOSTAT=ios0) idum
	    nopcod = 1
	    READ (5,*,IOSTAT=ios) iopcod (1)
	    IF ( ios .ne. 0 ) THEN
		WRITE (6,*) ' Standard input for Op Code failed.'
		STOP 9
	    END IF
	    READ (5,*,IOSTAT=ios) ismwnd, ismort
	    IF ( ios .ne. 0 ) THEN
		WRITE (6,*)
     +		' Smoothing input failed -- no smoothing done.'
                ismwnd = 0
		ismort = 0
	    END IF
C
C*	    Build the list of trace numbers.
C
	    DO i = 1, ntrcs
		itrcs (i) = i
		lags (i) = lag
	    END DO
C
C*	    Do the plot.
C
	    CALL PLT_DRIV ( lungc, iplot, itrcs, ntrcs, method,
     +			    mdsply, iopcod, nopcod,
     +			    ismwnd, ismort, itype, lags, ier )
C*
	ELSE IF ( method .eq. 2 ) THEN
C
C*	    Read the trace numbers.
C
	    READ (5,'(A)',IOSTAT=ios) ioline
	    IF ( ios .ne. 0 ) THEN
		WRITE (6,*) ' Standard input for trace #s failed.'
		STOP 10
	    END IF
	    CALL ST_ILST ( ioline, ' ', -1, MXTRC, itrcs, ntrcs, ier )
	    IF ( ntrcs .le. 0 .or. itrcs (1) .le. 0 .or.
     +		 ier .lt. 0 ) THEN
		WRITE (6,*) 'Invalid trace numbers.'
		STOP 11
	    END IF
C
C*	    Read the operation codes.
C
	    READ (5,'(A)',IOSTAT=ios) ioline
	    IF ( ios .ne. 0 ) THEN
		WRITE (6,*) ' Standard input for Op Codes failed.'
		STOP 14
	    END IF
	    CALL ST_ILST ( ioline, ' ', -1, MXTRC, iopcod, nopcod, ier )
	    IF ( nopcod .le. 0 .or. ier .lt. 0 ) THEN
		WRITE (6,*) 'Invalid Op Codes.'
		STOP 15
	    END IF
	    IF ( nopcod .ne. ntrcs ) THEN
		WRITE (6,*) '# of Op codes must equal # of traces.'
		STOP 16
	    END IF
	    READ (5,*,IOSTAT=ios) ismwnd, ismort
	    IF ( ios .ne. 0 ) THEN
		WRITE (6,*)
     +		' Smoothing input failed -- no smoothing done.'
                ismwnd = 0
		ismort = 0
	    END IF
	    IF ( lag .eq. -9999 ) THEN
		READ(5,'(A)',IOSTAT=ios) ioline
		IF ( ios .ne. 0 ) THEN
                    WRITE (6,*) ' ',
     +		    'Standard input for individual lag numbers failed.'
                    STOP 17
		END IF
		CALL ST_ILST ( ioline, ' ', -1, MXTRC, lags, nlg, ier )
		IF ( nlg .ne. ntrcs ) THEN
		    WRITE (6,*) ' ',
     +              '# of lag numbers must equal # of traces.'
		    STOP 18
		END IF
	    ELSE
	        DO i = 1, ntrcs
		    lags (i) = lag
	        END DO
	    END IF
	    CALL PLT_DRIV ( lungc, iplot, itrcs, ntrcs, method,
     +			    mdsply, iopcod, nopcod,
     +			    ismwnd, ismort, itype, lags, ier )
C*
	ELSE IF ( ( method .eq. 3 .or. method .eq. 4 .or.
     +		  method .eq. 5 .or. method .eq. 6 ) .and.
     +		  lag .ne. -9999 ) THEN
C
C*	    Read two trace numbers, then read the operation code.
C
	    READ (5,*,IOSTAT=ios) itrcs (1), itrcs (2)
	    IF ( ios .ne. 0 ) THEN
		WRITE (6,*) ' Standard input for trace #s failed.'
		STOP 10
	    END IF
	    ntrcs = 2
	    IF ( itrcs (1) .ne. itrcs (2) .or. 
     +           ( method .ne. 5 .and. method .ne. 6 ) ) THEN
		nopcod = 1
		READ (5,*,IOSTAT=ios) iopcod (1)
		IF ( ios .ne. 0 ) THEN
		    WRITE (6,*) ' Standard input for Op Code failed.'
		    STOP 9
	        END IF
		IF ( method .eq. 5 .or. method .eq. 6 ) THEN
		    nopcod = 2
		    iopcod (2) = iopcod (1)
		END IF
	    ELSE
		nopcod = 2
		READ (5,*,IOSTAT=ios) iopcod (1), iopcod (2)
		IF ( ios .ne. 0 ) THEN
		    WRITE (6,*)
     +			' Same trace requires two different op codes.'
		    STOP 9
	        END IF
	    END IF
	    READ (5,*,IOSTAT=ios) ismwnd, ismort
	    IF ( ios .ne. 0 ) THEN
		WRITE (6,*)
     +		' Smoothing input failed -- no smoothing done.'
                ismwnd = 0
		ismort = 0
	    END IF
	    lags(1) = lag
	    lags(2) = lag
C
C*	    Do the plot.
C
	    CALL PLT_DRIV ( lungc, iplot, itrcs, ntrcs, method,
     +			    mdsply, iopcod, nopcod,
     +			    ismwnd, ismort, itype, lags, ier )
C*
	ELSE IF ( lag .eq. -9999 ) THEN
C*
	    WRITE (6,*) ' LAG = -9999 is not valid for ',
     +                  'METHOD = ', method, '.'
	ELSE
C
C*	    Invalid method.
C
	    WRITE (6,*) ' METHOD = ', method, ' is invalid.'
C*
	END IF
	CLOSE (luntd)
	STOP
	END
