	PROGRAM MKTRCS
C************************************************************************
C*  This program searches a set of files for the data traces defined	*
C*  in the input control file.						*
C*									*
C*  Without prompts, this program reads the following from standard	*
C*  input:								*
C*									*
C*  LINE			CONTENTS				*
C*   1	  name of the control file					*
C*   2	  name of a file containing the list of file names to search	*
C* [ 3    optional character C to trigger compression of output data]	*
C*									*
C*  If the optional third line of input is not present or begins with	*
C*  anything other than the character C, the output data is NOT		*
C*  compressed.								*
C*									*
C*  The output is in a file named trace.dat.				*
C*									*
C*  The control file contains records written by the script user_in.	*
C*  The control file contains blocks of records describing search	*
C*  conditions for the data.  Such a block begins with a header record	*
C*  having the following values separated by spaces:			*
C*									*
C*	ITRC	=	Trace number					*
C*	IDDFLD	=	Header/data field for condition			*
C*	IVRTYP	=	Variable type (independent vs dependent)	*
C*	ICMTYP	=	Data combination code				*
C*	NCN	=	Number records following this header		*
C*	IPLTNM	=	Number of this plot (used for data combination)	*
C*	IPLTYP	=	Type of plot (not used for searching)		*
C*	KMATCH  =	data loss tolerance percentage * 100 +		*
C*			  data combination consistency code		*
C*									*
C*  The remaining NCN records in the block contain the following:	*
C*									*
C*	ICNTYP	=	Type of search condition			*
C*	R1	=	Real search value or lower bound of range	*
C*	R2	=	Real upper bound of range			*
C*	C1	=	Character search string or lower bound of range	*
C*	C2	=	Character upper bound of range			*
C*									*
C*									*
C*  The maximum number of file names allowed in the input list is 1024.	*
C*  The maximum number of points in a trace is 1024.			*
C*									*
C*  The output file (trace.dat) is headed by a copy of the records	*
C*  from the input control file.  This is followed by a single record	*
C*  containing the string EOCF.  After EOCF is the trace data itself.	*
C*  A header line precedes each trace of data.  It contains the fol-	*
C*  lowing information separated by spaces:				*
C*									*
C*	ITRC	=	Number of trace					*
C*	NDPTS	=	Number of data values at each point of trace	*
C*	NTPTS	=	Number of points along the trace		*
C*	LBLTYP	=	Trace label data type (r=real, c=character)	*
C*	CMPRES  =	Flag for compressed data (T = compressed, F=not	*
C*			compressed---D20.12 formatted numerical data)	*
C*									*	
C*  The trace data itself follow the header, with one line for each	*
C*  point along the trace.  The space separated values are:		*
C*									*
C*	LABEL	=	Real or character label (24 bytes)		*
C*	COUNT	=	[Compressed] real value of data count value	*
C*	V1	=	[Compressed] real value of first data value	*
C*	V2	=	[Compressed] real value of second data value	*
C*	Vn	=	[Compressed] real value of nth data value	*
C*									*	
C*  If CMPRES is set to .true., the output data is compressed; other-	*
C*  wise it is written out as character data in D20.12 type format.	*
C*  The compression algorithm preserves 11 significant decimal digits	*
C*  of precision.  The value of n in Vn is NDPTS.			*
C*									*
C*  Log:								*
C*  K. F. Brill/EMC	10/97						*
C*  K. Brill/EMC	11/97	Pass plot id # and LMCH to SRCH_GET	*
C*  K. Brill/EMC	 2/98	Change LMCH to KMATCH			*
C*  K. Brill/EMC	 9/98	Update parameter values			*
C*  K. Brill/EMC	 1/99	New code for KMCH, KASE, KPDZ, KPLT	*
C*  K. Brill/HPC	 5/00	Increase MXDPH from 8 to 12		*
C*  K. Brill/HPC	12/01	Changes for number of records in output	*
C*  K. Brill/HPC	 3/04	Change MXDPH from 12 to 16.		*
C*  K. Brill/HPC	 8/05	Increase inrec to 512; MXDPH=24		*
C*  K. Brill/HPC     20061227   Use 25 in WRITE FORMAT statements	*
C*  K. Brill/HPC     20120309   Delete any trace.ucd file		*
C*  K. Brill/IMSG    20160728   Set MXDPH to 28                         *
C*  K. Brill/IMSG    20170620   Use 29 in WRITE FORMAT statements	*
C* K. Brill/IMSG     20170928   Include version.f                       *
C************************************************************************
	PARAMETER	( NFLS = 512, NCNMX = 64, NPTMX = 2048 )
	PARAMETER	( MXDPH = 28 )
	CHARACTER*256	filnam (NFLS)
	CHARACTER*24	charcn (2, NCNMX), clbls (NPTMX)
	CHARACTER*7	chrout (MXDPH)
	CHARACTER*1	srtyp, crtype
	INTEGER		icntyp (NCNMX), mknts (NPTMX), mkndx (MXDPH)
	INTEGER		msrti (NPTMX)
	REAL		realcn (2, NCNMX), rlbls (NPTMX)
	REAL*8		trace (NPTMX, MXDPH)
	REAL*8		trcout (MXDPH+1)
	CHARACTER	inrec*512
	CHARACTER*32	crec (5)
	INTEGER		ihdr (8)
	CHARACTER*12	chdr (8)
	REAL		rrec (3)
	LOGICAL		quiet, cmpres
	DATA		quiet /.true./
C------------------------------------------------------------------------
        INCLUDE '../version.f'
C*
	luno = 12
	luni = 11
	lunl = 10
C
C*	Remove any trace.ucd file.  Uncombined data files are used for
C*	resampling and must be regenerated each time.  If this file is
C*	required, it will be created by the SRCH library.
C
	OPEN ( UNIT=luno, FILE='trace.ucd', STATUS='UNKNOWN' )
	CLOSE ( UNIT=luno, STATUS='DELETE' )
C
C*	Open the output file.
C
	OPEN ( UNIT=luno, FILE='trace.dat', STATUS='unknown',
     +	       IOSTAT = ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) ' Cannot open the output file.'
	    STOP
	END IF
C
C*	Read control file name and open the file.
C
	READ (5,'(A)') inrec
	OPEN ( UNIT=luni, FILE=inrec, STATUS='old', IOSTAT=ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) 'Could not open control file ', inrec
	    STOP
	END IF
C
C*	Read the file name list file and open it.
C
	READ (5,'(A)') inrec
	OPEN ( UNIT=lunl, FILE=inrec, STATUS='old', IOSTAT=ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) 'Could not open list file ', inrec
	    STOP
	END IF
C
C*	Read in optional compression flag.
C
	inrec = ' '
	READ (5,'(A)',IOSTAT=ios) inrec
	IF ( ios .ne. 0 .or. inrec (1:1) .ne. 'C' ) THEN
	    cmpres = .false.
	ELSE
	    cmpres = .true.
	END IF
C
C*	Initialize search conditions.
C
	CALL SRCH_INI ( iret )
	IF ( iret .ne. 0 ) THEN
	    CALL SRCH_ERR ( iret, 'SRCH_INI', ier )
	    STOP
	END IF
C
C*	Now read through the control file and set conditions.
C
	ios = 0
	ntrc = 0
	DO WHILE ( ios .eq. 0 )
	    READ (luni,'(A)',IOSTAT=ios) inrec
	    IF ( ios .eq. 0 ) THEN
		CALL ST_LSTR ( inrec, lng, ier )
		WRITE (luno, '(A)') inrec (1:lng)
		CALL ST_CLST ( inrec, ' ', ' ', 8, chdr, num, ier )
		IF ( ier .ne. 0 .or. num .ne. 8 ) THEN
		    WRITE (6,*) ' Invalid control file header record.'
		    STOP
		END IF
		CALL ST_ILST ( inrec, ' ', -99, 7, ihdr, num, ier )
		IF ( ier .lt. 0 .or. num .ne. 7 ) THEN
		    WRITE (6,*) ' Invalid control file header record.'
		    STOP
		END IF
		itrc = ihdr (1)
		iddfld = ihdr (2)
		ivrtyp = ihdr (3)
		icmtyp = ihdr (4)
		ncn = ihdr (5)
		idplot = ihdr (6)
		islsh = INDEX ( chdr (8), '/' )
		IF ( islsh .eq. 0 ) THEN
C
C*		    Backward compatibility code.
C
		    CALL ST_NUMB ( chdr (8), kmatch, ier )
		    kmch = MOD ( kmatch, 100 )
		    kase = 0
		    kpdz = kmch / 10
		    kltp = kmatch / 100
		    kmch = MOD ( kmch, 10 )
C
C*		    If the loss tolerance percentage is missing, then
C*		    use the old default of 33%.
C
		    IF ( kltp .eq. 0 ) THEN
			CALL ST_LSTR ( chdr (8), iln, ier )
			IF ( iln .le. 2 ) THEN
			    kltp = 33
			END IF
		    END IF
		ELSE
		    CALL ST_ILST ( chdr (8), '/', 0, 4, ihdr, num, ier )
		    kmch = ihdr (1)
		    kase = ihdr (2)
		    kpdz = ihdr (3)
		    kltp = ihdr (4)
		END IF
		ntrc = MAX ( itrc, ntrc )
		DO i = 1, ncn
		    READ ( luni,'(A)',IOSTAT=ios) inrec
		    IF ( ios .ne. 0 ) THEN
			WRITE (6,*) ' Unexpected end of control file.'
			STOP
		    END IF
		    CALL ST_LSTR ( inrec, lng, ier )
		    WRITE (luno, '(A)') inrec (1:lng)
		    CALL ST_RLST ( inrec, ' ', 0, 3, rrec, num, ier )
		    IF ( ier .lt. 0 .or. num .ne. 3 ) THEN
			WRITE (6,*) ' Invalid control file condition ',
     +				    'record.'
			STOP
		    END IF
		    icntyp (i) = NINT ( rrec (1) )
		    realcn (1,i) = rrec (2)
		    realcn (2,i) = rrec (3)
C*
		    CALL ST_CLST ( inrec, ' ', ' ', 5, crec, num, ier )
		    IF ( ier .ne. 0 .or. num .ne. 5 ) THEN
			WRITE (6,*) ' Invalid control file condition ',
     +				    'record.'
			STOP
		    END IF
		    charcn (1,i) = crec (4)
		    charcn (2,i) = crec (5)
		END DO
		CALL SRCH_SET ( itrc, kmch, kase, kpdz, kltp,
     +				idplot, iddfld, icntyp, ivrtyp,
     +				icmtyp, charcn, realcn, ncn, iret )
		IF ( iret .ne. 0 ) THEN
		    CALL SRCH_ERR ( iret, 'SRCH_SET', ier )
		    STOP
		END IF
	    END IF
	END DO
	WRITE (luno,'(A)') 'EOCF'
	CLOSE (luni)
C
C*	Loop over sets of files.
C
	ios = 0
	DO WHILE ( ios .eq. 0 )
C
C*	    Read a list of file names.
C
	    nfile = 0
	    DO WHILE ( ios .eq. 0 .and. nfile .lt. NFLS )
		READ (lunl,'(A)',IOSTAT=ios) inrec
		IF ( ios .eq. 0 ) THEN
		    nfile = nfile + 1
		    filnam (nfile) = inrec
		END IF
	    END DO
	    IF ( nfile .gt. 0 )
     +		CALL SRCH_DRV ( filnam, nfile, luni, quiet, itrc,
     +			        iret )
	END DO
	CLOSE (lunl)
C*
	IF ( iret .ne. 0 ) THEN
	    CALL SRCH_ERR ( iret, 'SRCH_DRV', ier )
	    IF ( iret .lt. 0 ) STOP
	END IF
	mtrc = 0
	CALL SRCH_GET ( mtrc, mdpth, mxpts, msrti, mkndx,
     +			trace, mknts, clbls, rlbls, srtyp,
     +			iret )
C
C*
C* ------- Debug here:  	CALL SRCH_DMP ( ier )
C*
C
	IF ( mtrc .ne. ntrc ) THEN
	    WRITE (6,*)  ' Number of traces found does not match ',
     +			 'the number requested.'
	    STOP
	END IF
	DO it = 1, mtrc
	    mdpth = 0
	    mxpts = MXDPH
	    CALL SRCH_GET ( it, mdpth, mxpts, msrti, mkndx,
     +			    trace, mknts, clbls, rlbls, srtyp, ier )
	    IF ( ier .ne. 0 ) THEN
		CALL SRCH_ERR ( ier, 'SRCH_GET', ierr )
		IF ( ier .lt. 0 ) STOP
	    END IF
	    IF ( mdpth .gt. 0 ) THEN
		msrti (1) = 0
		mxpts = NPTMX
		DO id = 1, mdpth
		    CALL SRCH_GET ( it, id, mxpts, msrti, mkndx,
     +				    trace (1,id), mknts, clbls, rlbls,
     +				    srtyp, ier )
		    IF ( id .eq. 1 ) crtype = srtyp
		    IF ( ier .ne. 0 ) THEN
			CALL SRCH_ERR ( ier, 'SRCH_GET', ierr )
			IF ( ier .lt. 0 ) STOP
		    END IF
		END DO
C
C*		Write out this trace data.
C
		IF ( crtype .eq. ' ' .or. crtype .eq. 'n' ) THEN
		    IF ( clbls (1) .ne. ' ' ) THEN
			crtype = 'c'
		    ELSE IF ( rlbls (1) .gt. -1.E30 ) THEN
			crtype = 'r'
		    ELSE
			WRITE (6,*) ' Trace data has no label. '
			STOP
		    END IF
		END IF
		WRITE (luno,'(3(X,I9),X,A1,X,L1,X,A2)')
     +			it, mdpth, mxpts, crtype, cmpres, 'NR'
		DO i = 1, mxpts
		    DO j = 1, mdpth
			trcout (j) = trace (i,j)
		    END DO
		    mdpo = mdpth + 1
		    trcout (mdpo) = DFLOAT ( mknts (i) )
		    IF ( cmpres ) THEN
			CALL USR_ENCD ( trcout, mdpo, chrout, ier )
			IF ( crtype .eq. 'r' ) THEN
			    WRITE (luno, '(E24.7,29(X,A7))' ) rlbls (i),
     +				    ( chrout (iq), iq = 1, mdpo )
			ELSE
			    WRITE (luno, '(A24,29(X,A7))' ) clbls (i),
     +				    ( chrout (iq), iq = 1, mdpo )
			END IF
		    ELSE
			IF ( crtype .eq. 'r' ) THEN
			    WRITE (luno, '(E24.7,29(D20.12))' )
     +				    rlbls (i),
     +				    ( trcout (iq), iq = 1, mdpo )
			ELSE
			    WRITE (luno, '(A24,29(D20.12))' ) clbls (i),
     +				    ( trcout (iq), iq = 1, mdpo )
			END IF
		    END IF
		END DO
	    END IF
	END DO
	STOP
	END 
