	PROGRAM  PARSEVGF
C************************************************************************
C* PROGRAM PARSEVGF							*
C*									*
C* This program parses the output from vgftoascii.			*
C*									*
C* This program requires the name of an input file (the output from	*
C* vgftoascii),	a control file, and an output file.			*
C*									*
C* The control file contains lines having the following format:		*
C*									*
C* <ATTRIBUTE> [value] [label]						*
C*									*
C* Items enclosed in [] are optional.  An attribute is any string	*
C* enclosed by <> in the input file from vgftoascii.  The [value] and	*
C* [label] specifications are used to turn specific attribute value	*
C* strings into label strings in the output file.  If [label] is	*
C* omitted, the	label is the same as [value].  If both [value] and	*
C* [label] are omitted, then the label is the attribute value string.	*
C* Note that the attribute entry includes the <> delimiters.		*
C*									*
C* The output file has the following format:				*
C*									*
C* LABEL N								*
C* lat1 lon1								*
C* lat2 lon2								*
C*  .    .								*
C*  .    .								*
C*  .    .								*
C* latN lonN								*
C*									*
C* In this file LABEL is the label string and N is the number of points *
C* in the line.  Smoothed lines are expanded to account for smoothing.  *
C*									*
C**									*
C* Log:									*
C* K. Brill/HPC		 4/05						*
C************************************************************************
C------------------------------------------------------------------------
	PARAMETER	(MXPTS=1000, MXCFE=64)
C*
	CHARACTER	filnam*128
C*
	CHARACTER*16	atrbut(MXCFE), atrval(MXCFE), atrout(MXCFE)
	CHARACTER*16	carry(2), cvalu, cvout
	CHARACTER*256	cbufr
	REAL		rlat (MXPTS), rlon (MXPTS), rarr (2)
	REAL		xpts (MXPTS), ypts (MXPTS)
C*
	DATA		lunvgf, lunctr, lunout / 11, 12, 52 /
C------------------------------------------------------------------------
C
C*	Initialize GEMPAK and GEMPLT.
C
  	CALL IN_BDTA ( ier )
  	CALL GG_INIT ( 1, ier )
  	CALL GG_SDEV ( 'GN', ier )
C
C*	Open the input file.
C
	WRITE (6,*)
     +	'Enter name of input file holding vgftoascii results:'
	READ (5,'(A)') filnam
	OPEN ( UNIT=lunvgf, FILE=filnam, STATUS='OLD', IOSTAT=ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) 'Cannot open ', filnam
	    STOP
	END IF
	WRITE (6,*) 'Enter name of control file:'
	READ (5,'(A)') filnam
	OPEN ( UNIT=lunctr, FILE=filnam, STATUS='OLD', IOSTAT=ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) 'Cannot open ', filnam
	    STOP
	END IF
C
C*	Read the control file.
C
	irec = 0
	DO WHILE ( ios .eq. 0 )
	    READ (lunctr, '(A)', IOSTAT=ios) cbufr
	    IF ( ios .eq. 0 ) THEN
		iq = INDEX ( cbufr, '>' )
		IF ( iq .eq. 0 ) THEN
		    WRITE (6,*) 'Enclose attribute inside <>.'
		    WRITE (6,*) 'Error parsing control file.'
		    STOP
		END IF
		CALL ST_CLST ( cbufr(iq+1:), ' ', ' ', 2,
     +			       carry, nc, ier )
		IF ( ier .lt. 0 .or. nc .le. 0 ) THEN
		    carry (1) = ' '
		    carry (2) = ' '
		END IF
		irec = irec + 1
		IF ( irec .gt. MXCFE ) THEN
		    WRITE (6,*) 'Too many control file records.'
		    STOP
		END IF
		atrbut(irec) = cbufr (1:iq)
		atrval(irec) = carry (1)
		atrout(irec) = carry (2)
	    END IF
	END DO
	ncfe = irec
	CLOSE ( UNIT=lunctr )
C
C*	Open the output file.
C
	WRITE (6,*) 'Enter the name of the output file:'
	READ (5,'(A)') filnam
	OPEN ( UNIT=lunout, FILE=filnam, STATUS='UNKNOWN', IOSTAT=ios )
	IF ( ios .ne. 0 ) THEN
	    WRITE (6,*) 'Cannot open ', filnam
	    STOP
	END IF
C
C*	Parse the input file one line at a time.
C
	DO WHILE ( ios .eq. 0 )
	    READ (lunvgf, '(A)', IOSTAT=ios) cbufr
	    IF ( ios .eq. 0 ) THEN
	        iq = INDEX ( cbufr, '<SMOOTH>' )
		IF ( iq .ne. 0 ) THEN
	            is = INDEX ( cbufr(iq:), '>' ) + iq
	            ie = INDEX ( cbufr(iq+1:), '<' )
	            IF ( ie .eq. 0 ) THEN
		        CALL ST_LSTR ( cbufr, ie, ier )
	            ELSE
		        ie = ie + iq - 1
	            END IF
	            cvalu = cbufr ( is:ie )
	            IF ( cvalu .eq. '0' ) THEN
		        dnsty = 0
	            ELSE IF ( cvalu .eq. '1' ) THEN
		        dnsty = 1
	            ELSE IF ( cvalu .eq. '2' ) THEN
		        dnsty = 5
	            ELSE
		        WRITE (6,*) ' Invalid SMOOTH parameter.'
		        STOP
	            END IF
		END IF
C
C*	        Check for an attribute string in this line of input.
C
	        cvout = ' '
	        iq = 0
	        icfe = 0
	        DO WHILE ( iq .eq. 0 .and. icfe .lt. ncfe )
		    icfe = icfe + 1
		    CALL ST_LSTR ( atrbut(icfe), lng, ier )
		    iq = INDEX ( cbufr, atrbut(icfe)(1:lng) )
		    IF ( iq .ne. 0 ) THEN
		        is = INDEX ( cbufr(iq:), '>' ) + iq
		        ie = INDEX ( cbufr(iq+1:), '<' )
			IF ( ie .eq. 0 ) THEN
			    CALL ST_LSTR ( cbufr, ie, ier )
			ELSE
			    ie = ie + iq - 1
			END IF
		        cvalu = cbufr ( is:ie )
		        IF ( atrval (icfe) .eq. cvalu ) THEN
			    cvout = atrout (icfe)
			    IF ( cvout .eq. ' ' ) cvout = cvalu
		        ELSE IF ( atrval (icfe) .eq. ' ' ) THEN
			    cvout = cvalu
			    iq = 0
		        ELSE
			    iq = 0
		        END IF
		    END IF
	        END DO
C
C*	        Now find the number of points to read.
C
	        IF ( cvout .ne. ' ' ) THEN
		    iq = INDEX ( cbufr, '<NUMPTS>' )
		    DO WHILE ( iq .eq. 0 )
		        READ (lunvgf, '(A)', IOSTAT=ios ) cbufr
			IF ( ios .ne. 0 ) THEN
			    WRITE (6,*) 'Unexpected end of input file.'
			    STOP
			END IF
		        iq = INDEX ( cbufr, '<NUMPTS>' )
		    END DO
		    is = INDEX ( cbufr(iq:), '>' ) + iq
		    ie = INDEX ( cbufr(iq+1:), '<' )
		    IF ( ie .eq. 0 ) THEN
			CALL ST_LSTR ( cbufr, ie, ier )
		    ELSE
			ie = ie + iq - 1
		    END IF
		    cvalu = cbufr ( is:ie )
		    CALL ST_NUMB ( cvalu, npts, ier )
		    IF ( ier .eq. 0 .and. npts .gt. 0 ) THEN
			rmxlt = -1.1E31
			rmnlt =  1.1E31
			rmxln = -1.1E31
			rmnln =  1.1E31
			DO k = 1, npts
			    READ (lunvgf, '(A)', IOSTAT=ios ) cbufr
			    IF ( ios .ne. 0 ) THEN
				WRITE (6,*)
     +				'Unexpected file end while reading pts.'
				STOP
			    END IF
			    CALL ST_LSTR ( cbufr, lng, ier )
			    CALL ST_RLST ( cbufr(1:lng), ' ', -9999.,
     +					   2, rarr, nr, ier )
			    IF ( ier .ne. 0 .or. nr .ne. 2 ) THEN
				WRITE (6,*)
     +				'Invalid point coordinates read.'
				STOP
			    END IF
			    rlat (k) = rarr (1)
			    IF ( rlat(k) .lt. rmnlt ) rmnlt = rlat(k)
			    IF ( rlat(k) .gt. rmxlt ) rmxlt = rlat(k)
			    rlon (k) = rarr (2)
			    IF ( rlon(k) .lt. rmnln ) rmnln = rlon(k)
			    IF ( rlon(k) .gt. rmxln ) rmxln = rlon(k)
			END DO
C
C*			Execute steps to compute a smoothed curve.
C
			angl1 = .5 * ( rmxlt + rmnlt )
			angl2 = .5 * ( rmxln + rmnln )
			angl3 = 0.0
			CALL GSMPRJ ( 'CED', angl1, angl2, angl3,
     +				      rmnlt, rmnln, rmxlt, rmxln,
     +				      ier )
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*)
     +			    'Cannot create dummy CED projection.'
			    STOP
			END IF
C
C*			Transform lat/lon points to device coordinates.
C
			CALL GTRANS ( 'M', 'D', npts, rlat, rlon,
     +				      rlat, rlon, ier )
C
C*			Get device curve scaling factor.
C
			CALL GQCVSC ( dvscl, ier )
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) 'Device curve scale error.'
			    STOP
			END IF
			CALL CV_PRMT ( npts, rlat, rlon, dnsty,
     +				       MXPTS, dvscl, 0, 0, nout,
     +				       xpts, ypts, ier )
			IF ( ier .ne. 0 ) THEN
			    WRITE (6,*) 'Parametric curve fit failed.'
			    STOP
			END IF
			CALL GTRANS ( 'D', 'M', nout, xpts, ypts,
     +				      rlat, rlon, ier )
C
C*			Write out the header and the points.
C
			CALL ST_LSTR ( cvout, lng, ier )
		    	WRITE (lunout, '(A,1X,I5)') cvout (1:lng), nout
			DO k = 1, nout
			    WRITE (lunout,'(F7.2,1X,F7.2)')
     +				rlat(k), rlon(k)
			END DO
		    END IF
		END IF
	    END IF
	END DO
	CLOSE ( UNIT=lunvgf )
	CLOSE ( UNIT=lunout )
	STOP
C------------------------------------------------------------------------
	END
