	SUBROUTINE RDTD_AFW ( nrm, itrc, rmiss, ifld, npts, trcdat,
     +			      trcmin, trcmax, iret )
C************************************************************************
C* RDTD_AFW								*
C*									*
C* This subroutine applies weights to a trace.  These weights are	*
C* computed from data field # IFLD in the full data trace in RDTD.CMN.	*
C*									*
C* If the normalization flag is set, each trace element is divided by	*
C* the mean value of the weights after being multiplied by its weight.	*
C* If NRM=2, only normalization occurs with no mulitiplication.		*
C*									*
C* RDTD_AFW ( NRM, ITRC, RMISS, IFLD, NPTS, TRCDAT, TRCMIN, TRCMAX,	*
C*	      IRET )							*
C*									*
C* Input parameters:							*
C*	NRM		INTEGER		Flag for normalization:		*
C*					 0 -> multiply by weight only	*
C*					 1 -> multiply & normalize	*
C*					 2 -> normalize only, no mul.	*
C*	ITRC		INTEGER		Trace number			*
C*	RMISS		REAL		Missing value			*
C*	IFLD		INTEGER		Data field # to use for weights *
C*	NPTS		INTEGER		Number of points in trace	*
C*									*
C* Input and output parameters:						*
C*	TRCDAT (NPTS)	REAL*8		Trace values at the points	*
C*									*
C*									*
C* Output parameters:							*
C*	TRCMIN		REAL		Trace minimum			*
C*	TRCMAX		REAL		Trace maximum			*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-30 = invalid depth field	*
C*					-44 = counts do not match	*
C*					-45 = all weights are missing   *
C**									*
C* Log:									*
C* K. Brill/EMC		 7/00						*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	REAL*8		trcdat (*)
C*
	REAL*8		c, f
C*------------------------------------------------------------------------
	iret = 0
C
C*	Check trace point count match.
C
	IF ( npts .ne. ntrpts (itrc) ) THEN
	    iret = -44
	    RETURN
	END IF
	IF ( ifld .le. 0 .or. ifld .gt. ndepth (itrc) ) THEN
	    iret = -30
	    RETURN
	END IF
C
C*	Compute mean of weight field and multiply TRCDAT by the weight.
C
	sumw = 0.
	icnt = 0
	trcmin = 1.1E31
	trcmax = -1.1E31
	DO i = 1, npts
	    c = dtrace (itrc,1,i)
	    f = dtrace (itrc,ifld,i)
	    IF ( c .gt. -1.E30 .and.
     +		 f .gt. -1.E30 .and.
     +		 c .ne. 0. .and. trcdat (i) .ne. rmiss ) THEN
		wt = f / c
		sumw = sumw + wt
		icnt = icnt + 1
		IF ( nrm .ne. 2 ) THEN
		    trcdat (i) = trcdat (i) * wt
		    IF ( trcdat (i) .lt. trcmin ) trcmin = trcdat (i)
		    IF ( trcdat (i) .gt. trcmax ) trcmax = trcdat (i)
		END IF
	    ELSE
		trcdat (i) = rmiss
	    END IF
	END DO
	IF ( nrm .eq. 0 ) RETURN
C
C*	Divide each trace element by the mean weight.
C
	IF ( icnt .le. 0 ) THEN
	    iret = -45
	    RETURN
	END IF
	trcmin = 1.1E31
	trcmax = -1.1E31
	rn = FLOAT ( icnt )
	wbar = sumw / rn
	DO i = 1, npts
	    IF ( trcdat (i) .ne. rmiss ) THEN
		trcdat (i) = trcdat (i) / wbar
		IF ( trcdat (i) .lt. trcmin ) trcmin = trcdat (i)
		IF ( trcdat (i) .gt. trcmax ) trcmax = trcdat (i)
	    END IF
	END DO
C*
	RETURN
	END
