	SUBROUTINE RDTD_BAJ ( itrc, iba, banam, iret )
C************************************************************************
C* RDTD_BAJ								*
C*									*
C* This subroutine performs bias adjustment for FHO values.		*
C*									*
C* If the bias adjustment has changed, the trace data is re-initiaized.	*
C*									*
C* RDTD_BAJ ( ITRC, IBA, BANAM, IRET )					*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number			*
C*	IBA		INTEGER		Bias adjustment prefix #	*
C*					  0 = No bias adjustment	*
C*					101 = DH/DF based adjustment	*
C*					102 = Odds ratio based adjust.	*
C*					103 = DH/DM based adjustment	*
C*					104 = Frequency matching	*
C*									*
C* Output parameters:							*
C*	BANAM		CHAR*4		Bias adjustment name string	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 7/03						*
C* K. Brill/HPC      20070213	Added addition cases for odds ratio	*
C* K. Brill/HPC      20070215   Add prefix 103				*
C* K. Brill/WPC      20140502   Add prefix 104 (bias removed by		*
C*				frequency matching, FRQM)		*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	CHARACTER*(*)	banam
C*
	REAL*8		tn, f, h, o, td, dn
C*------------------------------------------------------------------------
	iret = 0
C*
	kchk = 4
	IF ( iba .eq. 101 ) THEN
	    banam = 'DHDF'
	ELSE IF ( iba .eq. 102 ) THEN
	    banam = 'ORBA'
	ELSE IF ( iba .eq. 103 ) THEN
	    banam = 'DHDA'
	ELSE IF ( iba .eq. 104 ) THEN
	    banam = 'FRQM'
	    kchk = 5
	ELSE
	    banam = ' '
	    RETURN
	END IF
C*
	np = ntrpts ( itrc )
	nd = ndepth ( itrc )
	IF ( nd .lt. kchk ) THEN
	    iret = -46
	    RETURN
	END IF
	DO ip = 1, np
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
            IF ( tn .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 .and.
     +		 tn .ne. 0.0 ) THEN
		IF ( iba .eq. 101 .and. o .gt. 0.0 .and. 
     +		     f .gt. 0.0 ) THEN
C
C*		    Fedor Mesinger's bias adjustment.
C
		    h = o * ( 1. - ( ( (o-h) / o ) ** (o/f) ) )
		    dtrace (itrc,2,ip) = o
		    dtrace (itrc,3,ip) = h
C*
	 	ELSE IF ( iba .eq. 102 ) THEN
C
C*		    The Odds Ratio bias adjustment.
C
		    IF ( ( f .eq. h .or. o .eq. h ) .and.
     +                     h .ne. 0 ) THEN
C
C*		        Perfect forecast, odds ratio is infinite.
C
		        dtrace (itrc,2,ip) = o
		        dtrace (itrc,3,ip) = o
C*
	 	    ELSE IF ( h .eq. 0 ) THEN
C
C*		        Degenerate case, odds ratio is zero.
C
		        dtrace (itrc,2,ip) = o
		        dtrace (itrc,3,ip) = 0.0
C*
		    ELSE IF ( o .gt. h .and.
     +			      f .gt. h .and. h .gt. 0 ) THEN
C
C*		        Odds ratio conservation bias adjustment.
C
		        td = h * ( tn - f - o + h )
		        dn = ( o - h ) * ( f - h )
		        td = td / dn
		        IF ( td .gt. 1.0 ) THEN
		            dn = o + .5 * ( tn / ( td - 1. ) )
		            h = dn - DSQRT ( dn * dn -
     +				   ( td * o * o ) / ( td - 1. ) )
		            dtrace (itrc,2,ip) = o
		            dtrace (itrc,3,ip) = h
		        ELSE IF ( td .eq. 1.0 ) THEN
C
C*			    Odds ratio is 1, forecast is random.
C
		            dtrace (itrc,2,ip) = o
		            dtrace (itrc,3,ip) = o * o
C*
		        ELSE
C
C*			    Odds ratio is less than 1.
C
		            dn = o - .5 * ( tn / ( 1. - td ) )
		            h = dn + DSQRT ( dn * dn +
     +				   ( td * o * o ) / ( 1. - td ) )
		            dtrace (itrc,2,ip) = o
		            dtrace (itrc,3,ip) = h
C*
		        END IF
		    END IF
	 	ELSE IF ( iba .eq. 103 ) THEN
C
C*		    Fedor Mesinger's dHdM method of bias adjustment:
C
		    CALL RDTD_HDM ( f, h, o, h, ier )
		    dtrace (itrc,2,ip) = o
		    dtrace (itrc,3,ip) = h
C*
	 	ELSE IF ( iba .eq. 104 ) THEN
C
C*		    Use frequency matched hit and forecast values:
C
		    IF ( nd .gt. 5 ) THEN
C 			Replace F value if present.
		        dtrace (itrc,2,ip) = dtrace (itrc,6,ip)
		    ELSE
C			Forecast value becomes same as obs value.
		        dtrace (itrc,2,ip) = dtrace (itrc,4,ip)
		    END IF
C		    Replace the hit rate.
		    dtrace (itrc,3,ip) = dtrace (itrc,5,ip)
C*
	 	END IF
	    END IF
	END DO
	reinit = .true.
C*
	RETURN
	END
