	SUBROUTINE RDTD_D2T ( mxt, mxd, npts, ndpth, itrc, dtrace,
     +			      rmiss, mpts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, iret )
C************************************************************************
C* RDTD_D2T								*
C*									*
C* This subroutine converts the values constituting the depth of a 	*
C* trace to a new trace composed of the means of the depth values.	*
C* The new trace consists of a single array of ndpth-1 values, each of	*
C* which is the mean of the depth value at the corresponding position	*
C* through all the points on the trace.					*
C*									*
C* RDTD_D2T ( MXT, MXD, NPTS, NDPTH, ITRC, DTRACE, RMISS, MPTS, XPTS,	*
C*	      TRCDAT, XMIN, XMAX, TRCMIN, TRCMAX, CLBL, RLBL, CLTYP,	*
C*	      IPTYP, IRET )						*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	NDPTH           INTEGER		Number of values per point	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C* Output parameters:							*
C*	MPTS		INTEGER		Number of output trace points	*
C*	XPTS   (MPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (MPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (MPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (MPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					 = 4 -> to force binned output	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 5/05						*
C* K. Brill/HPC      20070119	Documentation				*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL*4		xpts (*), rlbl (*)
	CHARACTER*(*)	clbl (*), cltyp
C*
	REAL*8		sn
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
C*
	iptyp = 24
	xmin = 1.
	xmax = FLOAT ( ndpth - 1 )
	trcmin = 1.E29
	trcmax = -1.E29
	cltyp = 'r'
C
C*	Initialize trace elements to 0.0.
C
	DO id = 1, ndpth-1
	    trcdat (id) = 0.0
	END DO
C
C*	Initialize total data count to 0.0.
C
	sn = 0.0
C
C*	Combine all of the trace points.
C
	DO ip = 1, npts
C
C*	    Check that all trace data is not missing.
C
	    ok = .true.
	    id = 0
	    DO WHILE ( ok .and. id .lt. ndpth )
		id = id + 1
		ok = ( dtrace (itrc,id,ip) .gt. -1.E30 )
	    END DO
	    IF ( ok ) THEN
C
C*	        Generate trace from data fields.
C
		sn = sn + dtrace (itrc,1,ip)
		DO id = 2, ndpth
		    trcdat (id-1) = trcdat (id-1) + dtrace (itrc,id,ip)
		END DO
	    END IF
	END DO
C
C*	Compute the mean for each value in the data field.
C
	IF ( sn .le. 0 )  THEN
	    DO id = 1, ndpth-1
		trcdat (id) = rmiss
	    END DO
	    mpts = 0
	    RETURN
	END IF
	DO id = 1, ndpth-1
	    trcdat (id) = trcdat (id) / sn
	    IF ( trcdat (id) .lt. trcmin ) trcmin = trcdat (id)
	    IF ( trcdat (id) .gt. trcmax ) trcmax = trcdat (id)
	    xpts (id) = FLOAT (id)
	    clbl (id) = ' '
	    rlbl (id) = xpts (id)
	END DO
	mpts = ndpth-1
C*
	RETURN
	END
