	SUBROUTINE RDTD_EST ( itrc, rmiss, ifld, npts, trcdat,
     +			      trcmin, trcmax, iret )
C************************************************************************
C* RDTD_EST								*
C*									*
C* This subroutine extracts the values of a single trace corresponding	*
C* to data field # IFLD in the full data trace in RDTD.CMN.		*
C*									*
C* If IFLD < 0 or IFLD = 1, the values are not divided by the count.	*
C* If IFLD < 0, the |IFLD| is the field number.				*
C*									*
C* RDTD_EST ( ITRC, RMISS, IFLD, NPTS, TRCDAT, TRCMIN, TRCMAX, IRET )	*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number			*
C*	RMISS		REAL		Missing value			*
C*	IFLD		INTEGER		Data field # to extract		*
C*									*
C* Output parameters:							*
C*	NPTS		INTEGER		Number of points in trace	*
C*	TRCDAT (NPTS)	REAL*8		Trace values at the points	*
C*	TRCMIN		REAL		Trace minimum			*
C*	TRCMAX		REAL		Trace maximum			*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-30 = field not valid		*
C**									*
C* Log:									*
C* K. Brill/EMC		 8/00						*
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	REAL*8		trcdat (*)
C*
	REAL*8		c, f
C*------------------------------------------------------------------------
	iret = 0
C*
	indx = ABS (ifld)
	IF ( indx .eq. 0 .or. indx .gt. ndepth (itrc) ) THEN
	    iret = -30
	    RETURN
	END IF
C
C*	Assign trace point count.
C
	npts = ntrpts (itrc)
C*
	trcmin = 1.1E31
	trcmax = -1.1E31
	IF ( ifld .lt. 0 .or. ifld .eq. 1 ) THEN
            DO i = 1, npts
                c = dtrace (itrc,indx,i)
                IF ( c .lt. -1.E30 ) THEN
                    trcdat (i) = rmiss
                ELSE
                    IF ( c .lt. trcmin ) trcmin = c
                    IF ( c .gt. trcmax ) trcmax = c
                    trcdat (i) = c
                END IF
            END DO
	    RETURN
	END IF
C
C*	Extract the trace point data and divide by count.
C
	DO i = 1, npts
	    c = dtrace (itrc,1,i)
	    f = dtrace (itrc,indx,i)
	    IF ( c .gt. -1.E30 .and.
     +		 f .gt. -1.E30 .and.
     +		 c .ne. 0. ) THEN
		trcdat (i) = f / c
		IF ( trcdat (i) .lt. trcmin ) trcmin = trcdat (i)
		IF ( trcdat (i) .gt. trcmax ) trcmax = trcdat (i)
	    ELSE
		trcdat (i) = rmiss
	    END IF
	END DO
C*
	RETURN
	END
