	SUBROUTINE RDTD_FND ( luntd, iplot, loadd, ntrcs, itype, iret )
C************************************************************************
C* RDTD_FND								*
C*									*
C* This subroutine finds all the data for a given plot number.		*
C*									*
C* RDTD_INI should be called before calling RDTD_FND.			*
C*									*
C* LUNTD is the unit number to which the trace data file is connected.	*
C*									*
C* This subroutine searchs the trace data file header block which	*
C* contains the search control information for the traces associated	*
C* with a particular plot.  The information pertaining to plot number	*
C* IPLOT is retrieved and stored internally for later access.		*
C*									*
C* If LOADD is true, then the remainder of the trace data file is	*
C* searched for the trace data for this	plot.				*
C*									*
C* RDTD_FND ( LUNTD, IPLOT, LOADD, NTRCS, ITYPE, IRET )			*
C*									*
C* Input parameters:							*
C*	LUNTD		INTEGER		Unit number of trace data file	*
C*	IPLOT		INTEGER		Plot number to find		*
C*	LOADD		LOGICAL		Flag to load trace data		*
C*									*
C* Output parameters:							*
C*	NTRCS		INTEGER		# of traces in this plot	*
C*	ITYPE		INTEGER		Type of plot			*
C*					  1 = time series		*
C*					  2 = scatter plot		*
C*					  3 = skill score vs thrshld	*
C*					  4 = bins			*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					 -1 = invalid header record	*
C*					 -2 = too few condition records *
C*					 -4 = no EOCF record in file	*
C*					 -5 = too many traces		*
C*					 -6 = plot type is inconsistent	*
C**									*
C* Log:									*
C* K. Brill/EMC		11/97						*
C* K. Brill/EMC		12/97	Added LOADD				*
C* K. Brill/EMC		 6/98	Changes for multiple temp conditions	*
C* K. Brill/EMC		 1/99	Set KPLTID				*
C* K. Brill/HPC		 9/00	Initialize probabilities if flag to	*
C*				load traces is set			*
C* K. Brill/HPC		 3/05	CALL RDTD_SIC for all traces		*
C* K. Brill/HPC		 5/05	CALL RDTD_IPB for any PBS type		*
C* K. Brill/HPC		10/05	Pass trace # & data depth to RDTD_IPB	*
C* K. Brill/HPC		11/05	CALL RDTD_IPB for each trace		*
C* K. Brill/IMSG        07/16   CALL RDTD_IRP for each trace            *
C************************************************************************
	INCLUDE		'rdtd.cmn'
C*
	LOGICAL		loadd
C*
	CHARACTER*80	recrd
	CHARACTER*16	cptyp
	INTEGER		ihdr (7)
	LOGICAL		found
C*------------------------------------------------------------------------
	iret = 0
	ntrcs = 0
	itype = 0
	ios = 0
	recrd = ' '
	DO WHILE ( ios .eq. 0 .and. recrd (1:4) .ne. ENDHDR )
	    READ ( luntd, '(A)', IOSTAT=ios ) recrd
	    IF ( ios .eq. 0 .and. recrd (1:4) .ne. ENDHDR ) THEN
		CALL ST_ILST ( recrd, ' ', -99, 7, ihdr, num, ier )
		IF ( num .ne. 7 ) THEN
		    iret = -1
		    RETURN
		END IF
		IF ( ihdr (6) .eq. iplot ) THEN
		    ivrtyp = ihdr (3)
		    jtype = ihdr (7)
C
C*		    See if trace number is already in list.
C
		    found = .false.
		    nt = 0
		    DO WHILE ( .not. found .and. nt .lt. ntrcs )
			nt = nt + 1
			IF ( ntrlst (nt) .eq. ihdr (1) ) THEN
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found ) THEN
			nt = nt + 1
			IF ( nt .gt. MXTRCS ) THEN
			    iret = -5
			    RETURN
			END IF
			ntrlst (nt) = ihdr (1)
			icombo (nt) = ihdr (4)
			ntrcs = nt
		    END IF
		    IF ( nt .eq. 1 .and. .not. found ) THEN
			itype = jtype
		    ELSE IF ( jtype .ne. itype ) THEN
			iret = -6
			RETURN
		    END IF
C*
		    IF ( ivrtyp .eq. 1 ) THEN
C
C*			Store independent variable condition if
C*			first trace; otherwise, RDTD_SIC stores
C*			potential trace label info.
C
			CALL RDTD_SIC ( luntd, nt, ihdr, iret )
			IF ( iret .ne. 0 ) RETURN
		    ELSE
C
C*			Handle dependent variable condition.
C
			CALL RDTD_DVC ( luntd, nt, ihdr, iret )
			IF ( iret .ne. 0 ) RETURN
C*
		    END IF
		ELSE
		    CALL RDTD_SKP ( luntd, ihdr (5), iret )
		    IF ( iret .ne. 0 ) RETURN
		END IF
	    END IF
	END DO
	ntrace = ntrcs
	IF ( ios .ne. 0 ) THEN
	    iret = -4
	    RETURN
	END IF
	IF ( ntmpcn .gt. 0 ) CALL RDTD_SDV ( iret )
	IF ( iret .ne. 0 ) RETURN
C
C*	Check to see if label information from independent variable
C*	conditions is needed.
C
	DO i = 1, ntrace
	    IF ( ntrcnd (i) .eq. 0 ) THEN
		ntrcnd (i) = 1
		ktctyp (i,1) = kivtyp (1,1)
		ktcfld (i,1) = kivfld (1)
		ctcnd1 (i,1,1) = civctl (i)
		ntrcls (1,1) = 1
	    END IF
	END DO
C
C*	Now fill the trace data common structure.
C*	Also initialize probabilities for PBS stat types.
C*	Also initialize probabilities for CRPS stat types.
C
	IF ( loadd ) THEN
C*
	    CALL RDTD_LTD ( luntd, itype, iret )
C*
	    IF ( iret .eq. 0 ) THEN
		i = 0
		DO WHILE ( i .lt. ntrace )
		    i = i + 1
		    ipbs  = INDEX ( statnm (i), 'PBS_' )
		    IF ( ipbs .ne. 0 ) THEN
		        CALL ST_LSTR ( statnm (i), lng, ier )
		        islsh = INDEX ( statnm (i), '/' ) - 1
		        iparn = INDEX ( statnm (i), '(' ) - 1
		        IF ( iparn .gt. 0 .and. iparn .lt. islsh )
     +			    islsh = iparn
		        IF ( islsh .eq. -1 ) islsh = iparn
		        IF ( islsh .eq. -1 ) islsh = lng
			cptyp = statnm (i) (ipbs+4:islsh)
			ndd = ndepth ( i )
		        CALL ST_UCLC ( cptyp, cptyp, ier )
		        CALL RDTD_IPB ( cptyp, i, ndd, iret )
		    END IF
		    ipbs  = INDEX ( statnm (i), 'CRPS' )
		    IF ( ipbs .ne. 0 ) THEN
			ndd = ndepth ( i )
                        CALL RDTD_IRP ( i, ndd, iret )
		    END IF
		END DO
	    END IF
C*
	END IF
C*
	kpltid = iplot
C*
	RETURN
	END
