	SUBROUTINE RDTD_PRC  ( mxt, mxd, ndpth, npts,
     +			       itrc, dtrace, rmiss,
     +                         prbs, npbs,
     +			       mpts, xpts, trcdat,
     +			       xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			       cltyp, iptyp, prmnam, prfct, iret )
C************************************************************************
C* RDTD_PRC								*
C*									*
C* This subroutine computes the parametric ROC curve implied by the	*
C* odds ratio for data in an entire PBS time series trace.  The		*
C* assigned forecast probabilities are used to compute the sums for	*
C* counts in 2 X 2 contingency tables for each foreast probability	*
C* category.  These tables are summed to yield a single 2 X 2 		*
C* contingency table for each trace point.				*
C*									*
C* RDTD_PRC  ( MXT, MXD, NDPTH, NPTS, ITRC, DTRACE, RMISS, PRBS, NPBS,	*
C*             MPTS, XPTS, TRCDAT, XMIN, XMAX, TRCMIN, TRCMAX, CLBL,	*
C*	       RLBL, CLTYP, IPTYP, PRMNAM, PRFCT, IRET )		*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NDPTH		INTEGER		Number of values/point		*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*	PRBS (NPBS) 	REAL		Forecast probabilities		*
C*	NPBS		INTEGER		Number of frcst probabilities	*
C*									*
C* Input and Output parameter:						*
C*	MPTS		INTEGER		Input:  maximum number of output*
C*						point allowed.		*
C*					Output:  actual number of output*
C*						 points.		*
C* Output parameters:							*
C*	XPTS   (MPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (MPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (MPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (MPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					 = 4 -> to force binned output	*
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 5/08						*
C* K. Brill/HPC      20090828	Created from prior rdtd_prc		*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL*4		prbs (*)
	REAL*4		xpts (*), rlbl (*)
	CHARACTER*(*)	clbl (*), prmnam, cltyp
C*
	REAL*8		sumnz, res, tn, aa, bb, cc, dd, bx, cx, xn
	REAL*8		sn, sf, sh, so, f, h, o, td, dn, oyes, fyes
	LOGICAL		done
C*-----------------------------------------------------------------------
	iret = 0
	prfct = rmiss
	iptyp = 4
	xmin = 0.
	xmax = 1.0
	trcmin = 0.
	trcmax = 1.0
	cltyp = 'r'
	prmnam = 'HIT RATE'
	sn = 0.0
	sf = 0.0
	sh = 0.0
	so = 0.0
C
C*      Compute the number of probability bins.
C
	npb = ndpth / 2
	IF ( npb * 2 .ne. ndpth .or. npb .ne. npbs ) then
	    iret = -61
	    RETURN
	END IF
C
C*	Compute index of data field having number of events
C*      observed with zero probability forecast.
C
	ioapz = npb + 1
C
C*      Execute outer loop over PBS trace points.
C
	DO ip = 1, npts
C
C*	    Compute number of non-zero probability forecasts
C* 	    and the residual (number of events with zero
C* 	    forecast probability).
C
	    tn = dtrace (itrc,1,ip)
	    IF ( tn .gt. 0.0 ) then
	        sumnz = 0.0
	        DO inz = 2, npb
		    sumnz = sumnz + dtrace (itrc,inz,ip)
	        END DO
	        res = tn - sumnz
C
C*		Construct a contingency table for each category.
C*		Sum all contingency tables together.
C
		xn = res
		aa = 0.0
		bb = 0.0
		cc = 0.0
		dd = 0.0
		DO inz = 1, npb
		    IF ( inz .gt. 1 ) THEN
			xn = dtrace (itrc,inz,ip)
		    END IF
		    ioap = inz + npb
		    fyes = prbs(inz) * xn
		    oyes = dtrace (itrc,ioap,ip)
		    IF ( oyes .gt. fyes ) THEN
			bx = 0.0
			cx = oyes - fyes
		    ELSE
			bx = fyes - oyes
			cx = 0.0
		    END IF
		    aa = aa + ( oyes - cx )
		    bb = bb + bx
		    cc = cc + cx
		    dd = dd + ( xn - ( oyes + bx ) )
		END DO
		f = aa + bb
		h = aa
		o = aa + cc
		sn = sn + tn
		sf = sf + f
		sh = sh + h
		so = so + o
	    END IF
	END DO
C*
	WRITE (6,*) ' F H O n = ', sf, sh, so, sn
	td = sh * ( sn - sf - so + sh )
	dn = ( so - sh ) * ( sf - sh )
	IF ( dn .ne. 0.0 ) THEN
	    td = td / dn
	    xtrn = ( DSQRT ( td ) - 1. ) / td
	    IF ( xtrn .lt. .00005 ) xtrn = .45
	    xtrn = xtrn + .05
	    x = 0
	    xinc = xtrn / 15.
	    xpts (1) = 0.0
	    trcdat (1) = 0.0
	    DO iop = 2, 16
		x = x + xinc
		trcdat (iop) = ( td * x ) / ( 1. + ( td - 1. ) * x )
		xpts (iop) = x
	    END DO
	    iop = 16
	    xincl = xinc
	    xinc = ( 1. - xtrn ) / 15.
	    IF ( (xinc - xincl) .lt. 0.0 ) xincl = 0.0
	    DO WHILE ( x .lt. 1. )
		x = x + xinc - xincl
		IF ( x .lt. 1 ) THEN
		    iop = iop + 1
		    trcdat (iop) = ( td * x ) / ( 1. + ( td - 1. ) * x )
		    xpts (iop) = x
		END IF
		xincl = xincl - .5 * xincl
	    END DO
	    mpts = iop + 1
	    xpts (mpts) = 1.0
	    trcdat (mpts) = 1.0
	ELSE
	    iret = -63
	    RETURN
	END IF
C*
	RETURN
	END
