	SUBROUTINE RDTD_ROC ( mxt, mxd, npts,
     +			      itrc, dtrace, rmiss,
     +			      mpts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, prmnam, prfct, iret )
C************************************************************************
C* RDTD_ROC								*
C*									*
C* This subroutine computes the points on the ROC curve implied by the	*
C* odds ratio for an entire time series trace.				*
C*									*
C* RDTD_ROC ( INDX, MXT, MXD, NPTS, ITRC, DTRACE, RMISS, MPTS, XPTS,	*
C*	      TRCDAT, XMIN, XMAX, TRCMIN, TRCMAX, CLBL, RLBL, CLTYP,	*
C*	      IPTYP, PRMNAM, PRFCT, IRET )				*
C*									*
C* Input parameters:							*
C*	MXT		INTEGER		Max # of traces in DTRACE	*
C*	MXD		INTEGER		Max # of values/point in DTRACE	*
C*	NPTS		INTEGER		Number of points in the trace	*
C*	ITRC		INTEGER		Trace #				*
C*	DTRACE (MXT,MXD,						*
C*		NPTS)	REAL*8		Trace values			*
C*	RMISS		REAL		Missing value for output	*
C*									*
C* Output parameters:							*
C*	MPTS		INTEGER		Number of output trace points	*
C*	XPTS   (MPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (MPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (MPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (MPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					 = 4 -> to force binned output	*
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/HPC		 9/03						*
C************************************************************************
	REAL*8		dtrace (mxt,mxd,*), trcdat (*)
	REAL*4		xpts (*), rlbl (*)
	CHARACTER*(*)	clbl (*), prmnam, cltyp
C*
	REAL*8		tn, f, h, o, td, dn
	REAL*8		sn, sf, sh, so
C*-----------------------------------------------------------------------
	iret = 0
	prfct = rmiss
	iptyp = 4
	xmin = 0.
	xmax = 1.0
	trcmin = 0.
	trcmax = 1.0
	cltyp = 'r'
	prmnam = 'HIT RATE'
	sn = 0.0
	sf = 0.0
	sh = 0.0
	so = 0.0
C
C*	Sum over all trace series points.
C
	DO ip = 1, npts
	    tn = dtrace (itrc,1,ip)
	    f  = dtrace (itrc,2,ip)
	    h  = dtrace (itrc,3,ip)
	    o  = dtrace (itrc,4,ip)
	    IF ( tn .gt. -1.E30 .and.
     +		 f  .gt. -1.E30 .and.
     +		 h  .gt. -1.E30 .and.
     +		 o  .gt. -1.E30 .and.
     +           tn .ne. 0.0 ) THEN
		sn = sn + tn
		sf = sf + f
		sh = sh + h
		so = so + o
	    END IF
	END DO
	td = sh * ( sn - sf - so + sh )
	dn = ( so - sh ) * ( sf - sh )
	IF ( dn .ne. 0.0 ) THEN
	    td = td / dn
	    xtrn = ( DSQRT ( td ) - 1. ) / td
	    IF ( xtrn .lt. .00005 ) xtrn = .45
	    xtrn = xtrn + .05
	    x = 0
	    xinc = xtrn / 15.
	    xpts (1) = 0.0
	    trcdat (1) = 0.0
	    DO iop = 2, 16
		x = x + xinc
		trcdat (iop) = ( td * x ) / ( 1. + ( td - 1. ) * x )
		xpts (iop) = x
	    END DO
	    iop = 16
	    xincl = xinc
	    xinc = ( 1. - xtrn ) / 15.
	    IF ( (xinc - xincl) .lt. 0.0 ) xincl = 0.0
	    DO WHILE ( x .lt. 1. )
		x = x + xinc - xincl
		IF ( x .lt. 1 ) THEN
		    iop = iop + 1
		    trcdat (iop) = ( td * x ) / ( 1. + ( td - 1. ) * x )
		    xpts (iop) = x
		END IF
		xincl = xincl - .5 * xincl
	    END DO
	    mpts = iop + 1
	    xpts (mpts) = 1.0
	    trcdat (mpts) = 1.0
	ELSE
	    iret = -47
	    RETURN
	END IF
C*
	RETURN
	END
