	SUBROUTINE RDTD_TRC ( itrc, icomp, lag,
     +			      rmiss, npts, xpts, trcdat,
     +			      xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			      cltyp, iptyp, prmnam, prfct, ipcnt, 
     +			      statyp, iret )
C************************************************************************
C* RDTD_TRC								*
C*									*
C* This subroutine returns a specific trace of data.			*
C*									*
C* The traces are numbered in the order in which they are found in the	*
C* trace data file.							*
C*									*
C* ICOMP tells what value to pick off from the data field, or what	*
C* value to compute from the data field numbers:			*
C*									*
C*	ICOMP			Action					*
C*									*
C*	 -n		Return raw data for field n (undivided sum)	*
C*	 -1		Record count at all trace points		*
C*	  0		Return only CLTYP and IPTYP			*
C*	  1		Return data from field 1 = the data count	*
C*	  2		Return data from field 2 divided by count	*
C*	  3		Return data from field 3 divided by count	*
C*	n < 1000	Return data from field n divided by count	*
C*	1001		Compute BIAS from FHO values			*
C*	1002		Compute Equitable Threat Score (ETS)		*
C*	1003		Compute Critical Success Index (=TS)		*
C*	1004		Compute False Alarm Ratio (FAR)			*
C*	1005		Compute Postagreement (PA)			*
C*	1006		Compute Prefigurance (=POD)			*
C*	1007		Compute Probability of Detection (POD)		*
C*	1008		Compute Threat Score (TS)			*
C*	1009		Cumulative Forecast Prcp Vol % vs Thrshld	*
C*	1010		Cumulative Correctly Frcst Prcp Vol % vs Thrshld*
C*	1011		Cumulative Observed Prcp Vol % vs Thrshld	*
C*	1012		Forecast Prcp Vol % of Ttl vs Thrshld		*
C*	1013		Correctly Forecast Prcp Vol % of Ttl vs Thrshld	*
C*	1014		Observed Prcp Vol % of Ttl vs Thrshld           *
C*	1015		Forecast Prcp # % of Ttl # vs Thrshld           *
C*	1016		Correctly Forecast Prcp # % of Ttl # vs Thrshld *     
C*	1017		Observed Prcp # % of Ttl # vs Thrshld		*
C*	1018		Forecast # % of Ttl <= Thrshld vs Thrshld	*
C*	1019		Correctly Frcst # % of Ttl <= Thrshld vs Thrshld*
C*	1020		Observed # % of Ttl <= Thrshld # vs Thrshld	*
C*	1021		False Alarm Rate (f-h)/(N-o) (POFD)		*
C*	1022		Conditional Miss Rate (o-h)/(N-f) (CMR)		*
C*	1023		Heidke Skill Score (HSS)			*
C*	1024		Peirce-Hanssen-Kuipers True Skill Score (TSS)	*
C*	1025		Compute ODDS RATIO				*
C*	1026		Compute log of ODDS RATIO			*
C*	1027		Compute standard error of log of ODDS RATIO	*
C*	1028		ODDS RATIO Skill Score (ORSS)			*
C*	1029		Compute ODDS RATIO Skill Score Cubed		*
C*	1030		Compute log (ODDS RATIO) / STD ERROR of same	*
C*	1031		Area between ODDS RATIO ROC & chance ROC curves	*
C*      1032		ROC curve parametric in OR for time series	*
C*	1033		Odds ratio Parameterized ROC area (OPRA) score	*
C*	1034	        Frcst accuracy rate = proportion correct (PC)	*
C*      1035            Extreme Dependency Score (EDS)			*
C*      1036            Clayton Skill Score (CSS)			*
C*	1037		Explicit dH/dF Threat Score (TSDHDF) 		*
C*	1038		Explicit dH/dF Equitable Threat Score (ETSDHDF) *
C*	1039		Explicit dH/dA Threat Score (TSDHDA)		*
C*	1040		Explicit dH/dA Equitable Threat Score (ETSDHDA) *
C*      1041		Symmetric Extreme Dependency Score (SEDS)	*
C*      1042		Extremal Dependence Index (EDI)			*
C*      1043		Symmetric Extremal Dependence Index (SEDI)	*
C*      1044            Two-Alternative Forced Choice test (2AFC)       *
C*									*
C*	1051		Critical Performance Ratio (CPR) for POD	*
C*	1052		CPR for EDS					*
C*	1053		CPR for TSS					*
C*	1054		CPR for PC					*
C*	1055		CPR for POFD					*
C*	1056		CPR for FAR					*
C*	1057		CPR for TS					*
C*	1058		CPR for ETS					*
C*	1059		CPR for HSS					*
C*	1060		CPR for CSS					*
C*	1061		CPR for ORSS					*
C*	1062		CPR for CMR					*
C*	1063		CPR for PA					*
C*	1064		CPR for TSDHDF					*
C*	1065		CPR for ETSDHDF					*
C*	1066		CPR for TSDHDA					*
C*	1067		CPR for ETSDHDA					*
C*      1068		CPR reference midway between CPR benchmarks	*
C*									*
C*  Any of the preceding 10xx series may be computed from bias adjusted	*
C*  FHO values.  To do this, precede the 10xx code number with one of	*
C*  the following bias adjustment specification prefixes:		*
C*									*
C*	101		Fedor Mesinger's dH/dF bias adjustment		*
C*	102		Conservation of Odds Ratio bias adjustment	*
C*	103             Fedor Mesinger's dH/dA bias adjustment		*
C*	104             Bias removed by frequency matching (requires	*
C*			extended FHO record -- FHOh[f], where h is the  *
C*			bias removed hit fraction, and f is the bias	*
C*			removed forecast fraction, which is replaced by *
C*			O=observed fraction if absent)			*
C*									*
C*  Any of the preceding 10xx series that are N dependent may be	*
C*  computed using F+O-H from the Mth preceding threshold.  The first M	*
C*  thresholds use the original value of N, the total number.  Thres-   *
C*  hold must be the independent variable.  To do this, precede the	*
C*  10xx code with the following prefix:				*
C*									*
C*      20M   The F+O-H value from i-M threshold is used, M>0 and M<10	*
C*									*
C*  The critical performance ratio (CPR) is described in Brill (2009)	*
C*  published in W & F.							*
C*									*
C*	-------		-------						*
C*	1101		Compute BIAS (SAL1L2, SL1L2, ML1L2)		*
C*	1102		Compute RMS error (SAL1L2, SL1L2, ML1L2)	*
C*	1103		Compute Correlation (SAL1L2, SL1L2, ML1L2)	*
C*	1104		Compute Covariance (SAL1L2,SL1L2, ML1L2)	*
C*	1105		Compute Forecast Variance (SAL1L2, SL1L2, ML1L2)*
C*	1106		Compute Obs Variance (SAL1L2, SL1L2, ML1L2)	*
C*	1107		Compute Forecast Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1108		Compute Obs Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1109		Compute Error Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1110		Compute BIAS+Err Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1111		Compute BIAS-Err Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1112		Compute BIAS**2					*
C*	1113		Compute -2*Covariance				*
C*	1114		Compute Error Variance				*
C*	1115		Compute Mean Squared Error			*
C*	1116		Scalar ensemble statistical consistency index   *
C*									*
C*  See RDTD_TRK for documentation of prefixes 10, 11, 12, and 13 to	*
C*  1101--1115 above.							*
C*									*
C*	1201		Compute speed BIAS (VAL1L2, VL1L2)		*
C*	1202		Compute vector RMS error (VAL1L2, VL1L2)	*
C*	1203		Compute vector Correlation (VAL1L2, VL1L2)	*
C*	1204		Compute vector Covariance (VAL1L2,VL1L2)	*
C*	1205		Compute vector Forecast Variance (VAL1L2, VL1L2)*
C*	1206		Compute vector Obs Variance (VAL1L2, VL1L2)	*
C*	1207		Compute vector Forecast Std Dev (VAL1L2, VL1L2)	*
C*	1208		Compute vector Obs Std Dev (VAL1L2, VL1L2)	*
C*	1209		Compute U comp BIAS (VAL1L2, VL1L2)		*
C*	1210		Compute V comp BIAS (VAL1L2, VL1L2)		*
C*	1211		Compute vector BIAS magnitude (VAL1L2, VL1L2)	*
C*	1212		Compute vector Error Std Dev (VAL1L2, VL1L2)	*
C*	1213		Compute vector BIAS**2				*
C*	1214		Compute -2 * (vector Covariance)		*
C*	1215		Compute vector Error Variance			*
C*	1216		Compute vector Mean Squared Error		*
C*	1217		Vector ensemble statistical consistency index   *
C*									*
C*	1301		Compute Panofsky-Brier Score for PBS_WWX stat	*
C*	1302		Compute frequency of observation exceeding	*
C*			  threshold for	the no risk category		*
C*	1303		Compute frequency of observation exceeding	*
C*			  threshold for	the low risk category		*
C*	1304		Compute frequency of observation exceeding	*
C*			  threshold for	the moderate risk category	*
C*	1305		Compute frequency of observation exceeding	*
C*			  threshold for	the high risk category		*
C*	1306		Compute target Brier Score for PBS_WWX stat	*
C*            For low + moderate + high risk categories:		*
C*	1307		Compute BIAS Score from PBS values		*
C*	1308		Compute Equitable Threat Score from PBS values	*
C*	1309		Compute Critical Success Index from PBS values	*
C*	1310		Compute False Alarm Ratio from PBS values	*
C*	1311		Compute Postagreement from PBS values		*
C*	1312		Compute Prefigurance from PBS values		*
C*	1313		Compute Probability of Detection from PBS values*
C*	1314		Compute Threat Score from PBS values		*
C*            For moderate + high risk categories:			*
C*	1315		Compute BIAS Score from PBS values		*
C*	1316		Compute Equitable Threat Score from PBS values	*
C*	1317		Compute Critical Success Index from PBS values	*
C*	1318		Compute False Alarm Ratio from PBS values	*
C*	1319		Compute Postagreement from PBS values		*
C*	1320		Compute Prefigurance from PBS values		*
C*	1321		Compute Probability of Detection from PBS values*
C*	1322		Compute Threat Score from PBS values		*
C*            For high risk category:					*
C*	1323		Compute BIAS Score from PBS values		*
C*	1324		Compute Equitable Threat Score from PBS values	*
C*	1325		Compute Critical Success Index from PBS values	*
C*	1326		Compute False Alarm Ratio from PBS values	*
C*	1327		Compute Postagreement from PBS values		*
C*	1328		Compute Prefigurance from PBS values		*
C*	1329		Compute Probability of Detection from PBS values*
C*	1330		Compute Threat Score from PBS values		*
C*            Overall sums:						*
C*	1331		Total number in forecast risk areas (2+3+4)*N 	*
C*	1332		Total number > threshold (5+6+7+8)*N		*
C*            For low + moderate + high risk categories:		*
C*	1333		Compute Heidke Skill Score from PBS values		*
C*	1334		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1335		Compute ODDS RATIO				*
C*	1336		Compute log of ODDS RATIO			*
C*	1337		Compute Standard Error of log of ODDS RATIO	*
C*	1338		Compute ODDS RATIO Skill Score			*
C*	1339		Compute ODDS RATIO Skill Score Cubed		*
C*            For moderate + high risk categories:			*
C*	1340		Compute Heidke Skill Score from PBS values	*
C*	1341		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1342		Compute ODDS RATIO				*
C*	1343		Compute log of ODDS RATIO			*
C*	1344		Compute Standard Error of log of ODDS RATIO	*
C*	1345		Compute ODDS RATIO Skill Score			*
C*	1346		Compute ODDS RATIO Skill Score Cubed		*
C*            For high risk category:					*
C*	1347		Compute Heidke Skill Score from PBS values	*
C*	1348		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1349		Compute ODDS RATIO				*
C*	1350		Compute log of ODDS RATIO			*
C*	1351		Compute Standard Error of log of ODDS RATIO	*
C*	1352		Compute ODDS RATIO Skill Score			*
C*	1353		Compute ODDS RATIO Skill Score Cubed		*
C*            For all PBS categories:					*
C*	1354		Compute sample climatological BS (uncertainty)  *
C*	1355		Compute Reliability term of BS decomposition	*
C*	1356		Compute Resolution term of BS decomposition	*
C*	1357		Compute Uncertainty term of BS decomposition	*
C*	1358		Compute Brier Skill Score against sample climo	*
C*      1359            Compute the sample climatological frequency     *
C*      1360		Attribute Diagram for time series of PBS data   *
C*      1361            Compute Extreme Dependency Score (EDS)		*
C*	1362		ROC Curve for time series of PBS data		*
C*	1363		Odds ratio parametric ROC curve for PBS data	*
C*									*
C*      1401            Forecast variance weighted PE			*
C*      1402		Analysis variance weighted PE			*
C*      1403		Forecast variance fraction weighted PE		*
C*      1404		Analysis variance fraction weighted PE		*
C*      1405            Forecast variance fraction			*
C*	1406		Analysis variance fraction			*
C*	1407		Forecast amplitude				*
C*									*
C*	1500		Brier score from BS records			*
C*	150x		Compute average forecast probability for	*
C*			events occurring in category x			*
C*	155x		Compute observed frequency for category x	*
C*      1590            Brier score for sample climatology for BS recs  *
C*									*
C*      1600            Display RHET/RHNT stats as Ranked Histogram     *
C*      1601            Probability analysis lower than ensemble range  *
C*      1602            Probability analysis is within ensemble range   *
C*      1603            Probability analysis is higher than ens range   *
C*      1604            Probability analysis is outside ensemble range  *
C*	1605		Display 1601--1604 as 4-point trace		*
C*	1606		Missing rate error (MRE)			*
C*									*
C*      1700            No-skill fraction based on Ranked Prob Score    *
C*									*
C*      1801		Average directional error for TRK stats		*
C*									*
C*      1901            X direction S1 score from extended SL1L2 norms  *
C*      1902            Y direction S1 score from extended SL1L2 norms  *
C*      1903            Total S1 score from extended SL1L2 norms 	*
C*									*
C*                      Computational codes for ST_MODE records:	*
C*      2001            Intensity bias					*
C*      2002		Area bias					*
C*      2003            Observation to forecast compass direction	*
C*      2004            Probability of detection			*
C*      2005            Threat score					*
C*									*
C*			Computational code for FSS records:		*
C*	2101		Compute the Fractions Skill Score (FSS)		*
C*									*
C*			Computational code for PFR records:		*
C*      2201            Compute P ( F > O | O >= threshold )		*
C*      2202            Compute P ( F > O | F >= threshold )		*
C*      2203            Compute Bias = P ( F > Th ) / P ( O > Th )	*
C*      2204            Compute P ( F > O | F & O >= threshold )	*
C*									*
C*      2301            Compute mean CRPS (Hersbach, 2000)              *
C*      2302            Compute potential CRPS                          *
C*      2303            Compute reliability component of CRPS           *
C*      2304            Resolution component residual for CRPS          *
C*      2305            Uncertainty component estimate for CRPS         *
C*      2306            CRPS skill versus uncertainty                   *
C*      2307            Reliability diagram for percentile levels       *
C*									*
C*	9001		Compute count as fraction of total along trace	*
C*      9002		Trace of data field values avgd ovr all pts	*
C*									*
C* XPTS is an array of real valued relative plotting positions for	*
C* the points on this trace.  If IPTYP = 1 or 2, XPTS is the time in	*
C* days from the earliest time in the entire plot.  Otherwise,	XPTS	*
C* gives the relative position of the data values as positive integer	*
C* values.								*
C*									*
C* CLTYP determines whether the labels are character or real type.	*
C* If CLTYP = r, the labels are real; if CLTYP = c, the labels are 	*
C* character.  If CLTYP = t, the labels are character time stamps.	*
C*									*
C* If LAG > 0, then the value at a data point on a trace becomes the	*
C* combination of that trace point's values with those of the preceding	*
C* LAG-1 trace points.							*
C*									*
C* The missing value flag is RMISS on return.				*
C*									*
C* Note that TRCDAT is a REAL*8 array.					*
C*									*
C* RDTD_TRC ( ITRC, ICOMP, LAG, RMISS, NPTS, XPTS, TRCDAT, XMIN, XMAX,	*
C*	      TRCMIN, TRCMAX, CLBL, RLBL, CLTYP, IPTYP, PRMNAM,		*
C*	      PRFCT, STATYP, IRET )					*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number			*
C*	ICOMP		INTEGER		Computational code number	*
C*	LAG		INTEGER		Intra-trace data combo lag	*
C*	RMISS		REAL		Missing value			*
C*									*
C* Input and output parameter:						*
C*	NPTS		INTEGER		Input: maximum # of trace points*
C*					Output: actual number		*
C*									*
C* Output parameters:							*
C*	XPTS   (NPTS)	REAL		x coordinate of data points	*
C*	TRCDAT (NPTS)	REAL*8		Trace data			*
C*	XMIN		REAL		Minmum value in XPTS		*
C*	XMAX		REAL		Maximum value in XPTS		*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	CLBL   (NPTS)	CHAR*		Character trace point labels	*
C*	RLBL   (NPTS)	REAL		Real trace point labels		*	
C*	CLTYP		CHAR*1		Label type			*
C*					   c = character		*
C*					   r = real			*
C*					   t = character time stamps	*
C*	IPTYP		INTEGER		Plot type			*
C*					   1 = time series		*
C*					   2 = scatter plot		*
C*					   3 = skill score vs thrshld	*
C*					   4 = categorically binned	*
C*					  14 = Analysis rank wrt ens	*
C*	PRMNAM		CHAR*		Computed parameter name		*
C*	PRFCT		REAL		Perfect forecast value		*
C*      IPCNT		INTEGER		Comp code for obs count		*
C*	STATYP		CHAR*24		Statistic Type string		*
C*	IRET		INTEGER		Return code			*
C*					+02 = all trc pnts missing	*
C*				 	  0 = normal return 		*
C*					-29 = cannot compute stats	*
C*					-30 = data field not present	*
C*					-31 = NPTS too small for trace	*
C*					-32 = invalid ICOMP code	*
C*					-36 = data depth too small	*
C**									*
C* Log:									*
C* K. Brill/EMC		12/97						*
C* K. Brill/EMC		 1/98	Added PRMNAM				*
C* K. Brill/EMC		 4/98	Return computed parm name only		*
C* K. Brill/EMC		 4/98	Check LTAXIS				*
C* K. Brill/EMC		 6/98	Assign TRCDAT in order of sorted labels *
C* K. Brill/EMC		 6/98	Fill t series gaps with missing values	*
C* K. Brill/EMC		 1/99	Add intra-trace data combination (LAG)	*
C* K. Brill/HPC		 2/00	+2 return for all trace points missing	*
C* K. Brill/HPC		 8/00	Changes for PBS_WWX, PHSE stats, % prcp	*
C*				volume vs threshold			*
C* K. Brill/HPC		 9/00	Added target Brier score, code 1306	*
C* K. Brill/HPC		12/00	Compute skill scores from PBS #s	*
C* K. Brill/HPC		 3/01	Add codes 1015--1020			*
C* K. Brill/HPC		 7/01	Add codes 1331 and 1332			*
C* K. Brill/HPC		12/01	Added codes 1109--1115, 1211--1216	*
C* K. Brill/HPC		12/01	Change to read # of contrib records	*
C* K. Brill/HPC		 6/02	Add CALL CPB_GSCR for code 1500; add	*
C*				call to CPB_GAFP for 1501+; add call to	*
C*				CPB_GOBP for 1551+			*
C* K. Brill/HPC		10/02	Added codes 1021-29; 1333-1353		*
C* K. Brill/HPC		12/02	Added code 9001				*
C* K. Brill/HPC		 2/03	Set the perfect forecast value; read	*
C*				PRMNAM from a .lst file			*
C* K. Brill/HPC		 3/03	Added code 1030				*
C* K. Brill/HPC		 5/03	Get stat name from ind var if blank	*
C* K. Brill/HPC		 6/03	Add BIAS adjustment capability		*
C* K. Brill/HPC		 8/03	Added code 1031				*
C* K. Brill/HPC		 9/03	Added code 1032				*
C* K. Brill/HPC		10/03	Added code 1033				*
C* K. Brill/HPC		11/03	Added 20M codes for using previous N	*
C* K. Brill/HPC		11/03	Check ALPTMS to handle missing traces	*
C* K. Brill/HPC		 3/04	Added codes 1600--1605 & 1700; added	*
C*				default labels for TLGEA, TLGNA, RPS	*
C* K. Brill/HPC		 4/04	Added code 1606, 1116, 1217		*
C* K. Brill/HPC		 5/04	Change TLG.A stats to RH.T stats	*
C* K. Brill/HPC		 5/04	Set prfct=0.0 for RPS			*
C* K. Brill/HPC		12/04	Added code 1034				*
C* K. Brill/HPC		 5/05	Added code 1354, 1590, 9002		*
C* K. Brill/HPC		 8/05	Added codes 1355--1358			*
C* K. Brill/HPC		11/05	Make prbwwx a function of trace #	*
C* K. Brill/HPC      20061227   Add TRK error stats computations	*
C* K. Brill/HPC      20061228   Add code 1035 (EDS)			*
C* K. Brill/HPC      20070116   Added code 1359				*
C* K. Brill/HPC      20070119   Changes for code 1360 (attribute diag.) *
C* K. Brill/HPC      20070209   Add code 1361 (EDS for PBS stats)	*
C* K. Brill/HPC      20070215   Add prefix 103 for Mesinger's dH/dA adj *
C* K. Brill/HPC      20070618   Support ML1L2 stat type			*
C* K. Brill/HPC      20071204   Support SL1L2 extension for S1 scores   *
C* K. Brill/HPC      20080131   Cleanup default names for ESL1L2 and	*
C*				EVL1L2; add def names for SL1L2 S1 ext 	*
C* K. Brill/HPC      20080309	Add CSS					*
C* K. Brill/HPC      20080310   Add TSDHDF, ETSDHDF, TSDHDA, ETSDHDA;	*
C*				Add CPR calculations			*
C* K. Brill/HPC      20080509   Add code 1362 (ROC curve for PBS stats) *
C* K. Brill/HPC      20080520   Add code 1363 (parametric ROC for PBS)	*
C* K. Brill/HPC      20080620   Add codes 2001--2005 for ST_MODE	*
C* K. Brill/HPC      20080630   Return IPCNT in calling sequence	*
C* K. Brill/HPC      20090514   Add Fractions Skill Score; pass back	*
C*				stat type as returned argument		*
C* K. Brill/HPC      20090902   Fix for erroneous codes 1362 & 1363	*
C* K. Brill/HPC      20100223	Add code 1068 (CPR benchmark reference) *
C* K. Brill/HPC      20100915   Add code 2201 for PFR stats		*
C* K. Brill/HPC      20100930   Add code 2202 & 2203 for PFR stats	*
C* K. Brill/HPC      20101001	Add code for 2204 for PFR stats		*
C* K. Brill/HPC      20110310   Write warning message if user specifies *
C*				prefix 101 (Mesinger's dH/dF method)	*
C* K. Brill/HPC      20110805   Add codes 1041, 1042, and 1043		*
C* K. Brill/HPC      20120327   Set nembrs and cstatc in common		*
C* K. Brill/HPC      20120328	Fix to use trcdat in CALL for code 1361	*
C* K. Brill/WPC      20140506   Changes for 104 bias removed prefix	*
C* K. Brill/IMSG     20160706   Add codes 2301-> 2305 for CRPS & decomp *
C* K. Brill/IMSG     20160720   Add code 2306 for CRPS skill vs UNC;    *
C*                              2307 for CRPS reliability diagram       *
C* K. Brill/IMSG     20170823   Added code 1044 for 2AFC score          *
C************************************************************************
	INCLUDE		'rdtd.cmn'
	PARAMETER	( TOLRNC = .00005 )
C*
	REAL*8		trcdat (*)
	REAL		rlbl (*), xpts (*)
	CHARACTER*(*)	clbl (*), cltyp, prmnam, statyp
C*
	CHARACTER*24	qclbl, cstat, parts (4)
	CHARACTER*32	stfil
	CHARACTER*5	cpren
	CHARACTER*4	banam, thlag
	CHARACTER*1	ccat
	REAL*8		trcdum (MXDPTS)
	REAL		trcsav (MXDPTS)
	REAL*8		td
	LOGICAL		fhoflg, found, exist
C*------------------------------------------------------------------------
	iret = 0
C*      Set the Computational Code for FHO observation counts:
	ipcnt = -4
	prfct = rmiss
	iptyp = iptype
	cltyp = lbltyp
	IF ( icomp .eq. 0 ) RETURN
	IF ( ntrpts (itrc) .gt. npts ) THEN
	    iret = -31
	    RETURN
	ELSE
	    mxpts = npts
	    npts = ntrpts (itrc)
	END IF
	IF ( icombo (itrc) .lt. 0 ) THEN
	    iret = -32
	    RETURN
	END IF
	DO i = 1, MXDPTS
	    trcdat (i) = rmiss
	END DO
C
C*	Re-initialize trace data if necessary.
C
	CALL RDTD_REI ( ier )
C
C*	Do intra-trace data combination.
C
	CALL RDTD_LAG ( lag, itrc, ier )
C*
	IF ( statnm (itrc) .ne. ' ' ) THEN
	    cstat = statnm (itrc)
	ELSE
	    cstat = stativ
	END IF
	statyp = cstat
	imode = INDEX ( cstat, 'ST_MODE' )
	IF ( imode .ne. 0 ) THEN
	    ipcnt = 1
	END IF
C
C*	Check for BIAS adjustment.
C
	fhoflg = ( INDEX ( cstat, 'FHO' ) .gt. 0 )
	IF ( fhoflg .and. ( icomp .gt.  1000000 .or.
     +			    icomp .lt. -1000000 ) .and.
     +       ABS (icomp) .lt. 1050000 ) THEN
	    IF ( icomp .lt. 0 ) THEN
		isgn = -1
		icomp = -icomp
	    ELSE
		isgn = 1
	    END IF
C
C*	    Detect bias adjustment specification prefix.
C
	    iba = INT ( icomp / 10000 )
	    icmp = icomp - iba * 10000
	    icmp = isgn * icmp
	    ibk = 0
	ELSE IF ( fhoflg .and. kivfld (1) .eq. 11 .and.
     +            ABS (icomp) .gt. 2000000 ) THEN
	    IF ( icomp .lt. 0 ) THEN
		isgn = -1
		icomp = -icomp
	    ELSE
		isgn = 1
	    END IF
C
C*	    Detect backward look for N specification prefix.
C
	    ibk = MOD ( INT ( icomp / 10000 ), 100 )
	    icmp = icomp - (200 + ibk) * 10000
	    icmp = isgn * icmp
	    iba = 0
	ELSE
	    icmp = icomp
	    iba = 0
	    ibk = 0
	END IF
C*
	IF ( iba .eq. 101 ) THEN
	    WRITE (6,*)
	    WRITE (6,*) ' WARNING:  dH/dF bias adjustment is not',
     +                  ' recommended.'
	    WRITE (6,*)
	END IF
	CALL RDTD_BAJ ( itrc, iba, banam, iret )
	CALL RDTD_TLG ( itrc, ibk, thlag, iret2 )
C
C*	Check for ensemble mean L1L2 norms.
C
	iqe = INDEX ( cstat, 'L1L2' )
	IF ( iqe .ne. 0 ) THEN
	    iqe = INDEX ( cstat, 'E' )
	    IF ( iqe .eq. 1 ) THEN
		islsh = INDEX ( cstat, '/' ) + 1
		CALL ST_NUMB ( cstat (islsh:), nmem, ier )
		IF ( ier .ne. 0 ) THEN
		    iret = 5
		    nmem = 1000
		END IF
	    END IF
	END IF
	cstatc = cstat
	nembrs = nmem
C*
	IF ( iret .ne. 0 .or. iret2 .ne. 0 ) RETURN
	prmnam = parmnm (itrc)
	indx = 0
	trcmax = -1.E30
	trcmin = 1.E30
	ncats = ndepth (itrc) / 3
	max15 = 1500 + ncats
	mx155 = 1550 + ncats
	IF ( icmp .gt. 1000 .and. icmp .le. 1068 ) THEN
	    IF ( .not. fhoflg .or. ndepth (itrc) .lt. 4 ) THEN
		iret = -29
		RETURN
	    END IF
	    IF ( icmp .eq. 1001 ) THEN
		CALL CS_BSSK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BIAS_SCORE'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1002 ) THEN
		CALL CS_ETSK ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'EQ_THT_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1003 .or. icmp .eq. 1008 ) THEN
		CALL CS_TSSK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'CSI=THRTSC'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1004 ) THEN
		CALL CS_FASK ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FLS_ALRM_RATIO'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1005 ) THEN
		CALL CS_PASK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'POSTAGREMT'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1006 .or. icmp .eq. 1007 ) THEN
		CALL CS_PDSK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'PREFIG=POD'
		prfct = 1.
		IF ( icmp .eq. 1007 ) prmnam = 'PROB_OF_DET'
	    ELSE IF ( icmp .eq. 1009 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_CMLTV_%TOTVL'
	    ELSE IF ( icmp .eq. 1010 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_CMLTV_%TOTVL'
	    ELSE IF ( icmp .eq. 1011 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_CMLTV_%TOTVL'
	    ELSE IF ( icmp .eq. 1012 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_%TOTAL_VOL'
	    ELSE IF ( icmp .eq. 1013 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_%TOTAL_VOL'
	    ELSE IF ( icmp .eq. 1014 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_%TOTAL_VOL'
	    ELSE IF ( icmp .eq. 1015 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_%TOTAL_CNT'
	    ELSE IF ( icmp .eq. 1016 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_%TOTAL_CNT'
	    ELSE IF ( icmp .eq. 1017 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_%TOTAL_CNT'
	    ELSE IF ( icmp .eq. 1018 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
		prmnam = 'FOR_%TTL#<THLD'
	    ELSE IF ( icmp .eq. 1019 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
		prmnam = 'VRF_%TTL#<THLD'
	    ELSE IF ( icmp .eq. 1020 ) THEN
		DO ip = 1, ntrpts (itrc)
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
		prmnam = 'OBS_%TTL#<THLD'
	    ELSE IF ( icmp .eq. 1021 ) THEN
		CALL CS_FASK ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FLS_ALRM_RATE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1022 ) THEN
		CALL CS_FASK ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'COND_MSS_RATE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1023 ) THEN
		CALL CS_ETSK ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'HEIDKE_SKL_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1024 ) THEN
		CALL CS_ETSK ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'P-H-K_SKL_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1025 ) THEN
		CALL CS_ORSK ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ODDS_RATIO'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1026 ) THEN
		CALL CS_ORSK ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'LOG_ODDS_RATIO'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1027 ) THEN
		CALL CS_ORSK ( 3, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'STDERR_LOG(OR)'
	    ELSE IF ( icmp .eq. 1028 ) THEN
		CALL CS_ORSK ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ODDS_RTO_SKL_SCR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1029 ) THEN
		CALL CS_ORSK ( 4, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ODDS_RTO_SKSC**3'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1030 ) THEN
		CALL CS_ORSK ( 5, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'LN_OR/STDV_LN_OR'
		prfct = rmiss
	    ELSE IF ( icmp .eq. 1031 ) THEN
		CALL CS_ORSK ( 6, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ROC_AREA-CHANCE'
		prfct = .5
	    ELSE IF ( icmp .eq. 1032 ) THEN
		CALL RDTD_ROC ( MXTRCS, MXDPTH, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     +			        npts, xpts, trcdat,
     +			        xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			        cltyp, iptyp, prmnam, prfct, iret )
		RETURN
	    ELSE IF ( icmp .eq. 1033 ) THEN
		CALL CS_ORSK ( 7, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'OPRA SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1034 ) THEN
		CALL CS_CFRK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ACCURACY_RATE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1035 ) THEN
		CALL CS_EDSK ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'EXTRM_DEPNDNCY_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1036 ) THEN
		CALL CS_CSSK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'CLAYTON_SKILL_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1037 ) THEN
		CALL CS_TSBA ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'DHDF_THREAT_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1038 ) THEN
		CALL CS_TSBA ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'DHDF_EQ_THREAT_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1039 ) THEN
		CALL CS_TSBA ( 3, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'DHDA_THREAT_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1040 ) THEN
		CALL CS_TSBA ( 4, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'DHDA_EQ_THREAT_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1041 ) THEN
		CALL CS_EDSK ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SYM_EXTRM_DEP_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1042 ) THEN
		CALL CS_EDSK ( 3, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'EXTRML_DEPNDNC_INDEX'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1043 ) THEN
		CALL CS_EDSK ( 4, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SYM_EXTRML_DEP_INDEX'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1044 ) THEN
		CALL CS_2AFC ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = '2AFC_TEST_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .ge. 1051 .and. icmp .le. 1067 ) THEN
C
C*		Compute a CPR value.
C
		icpr = icmp - 1050
		CALL CS_CCPR ( icpr, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, prmnam,
     +			       trcdum, trcmin, trcmax, iret )
		prfct = rmiss
	    ELSE IF ( icmp .eq. 1068 ) THEN
		CALL CS_BMRK ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'CPR_BNCHMRK_REFERNCE'
		prfct = -9999
	    END IF
	ELSE IF ( icmp .gt. 1100 .and. icmp .le. 1116 ) THEN
	    IF ( ndepth (itrc) .lt. 6 ) THEN
		iret = -36
		RETURN
	    END IF
	    IF ( icmp .eq. 1101 ) THEN
		CALL CS_BIAS ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCALR_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1102 ) THEN
		CALL CS_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCALR_RMSE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1103 ) THEN
		CALL CS_CORR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCALR_CORR'
		prfct = 1.
	    ELSE IF ( icmp .eq. 1104 ) THEN
		CALL CS_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_COVAR'
	    ELSE IF ( icmp .eq. 1105 ) THEN
		CALL CS_FVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_FRVAR'
	    ELSE IF ( icmp .eq. 1106 ) THEN
		CALL CS_OVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_OBVAR'
	    ELSE IF ( icmp .eq. 1107 ) THEN
		CALL CS_FSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_FRSDV'
	    ELSE IF ( icmp .eq. 1108 ) THEN
		CALL CS_OSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_OBSDV'
	    ELSE IF ( icmp .eq. 1109 ) THEN
		CALL CS_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCLR_ERROR_SIG'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1110 .or.
     +		      icmp .eq. 1111 ) THEN
		IF ( icmp .eq. 1110 ) THEN
		    sign = 1.0
		    prmnam = 'SCLR_BIAS+ERRSIG'
		ELSE
		    sign = -1.0
		    prmnam = 'SCLR_BIAS-ERRSIG'
		END IF
		CALL CS_BIAS ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		DO ip = 1, ntrpts (itrc)
		    trcsav (ip) = trcdum (ip)
		END DO
		CALL CS_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		trcmax = -1.E30
		trcmin = 1.E30
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss .and.
     +			 trcsav (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcsav (ip) + sign * trcdum (ip)
			IF ( trcdum (ip) .gt. trcmax )
     +			    trcmax = trcdum (ip)
			IF ( trcdum (ip) .lt. trcmin )
     +			    trcmin = trcdum (ip)
			icnt = icnt + 1
		    ELSE
			trcdum (ip) = rmiss
		    END IF
		END DO
		IF ( icnt .eq. 0 ) THEN
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
	    ELSE IF ( icmp .eq. 1112 ) THEN
		CALL CS_BIAS ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		trcmax = -1.E30
		trcmin = 1.E30
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			IF ( trcdum (ip) .gt. trcmax )
     +			    trcmax = trcdum (ip)
			IF ( trcdum (ip) .lt. trcmin )
     +			    trcmin = trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .eq. 0 ) THEN
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = 'SCALR_BIAS**2'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1113 ) THEN
		CALL CS_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = -2.0 * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    qmax = trcmax
		    trcmax = -2.0 * trcmin
		    trcmin = -2.0 * qmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = '-2*SCLR_COVAR'
	    ELSE IF ( icmp .eq. 1114 ) THEN
		CALL CS_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = 'SCLR_ERROR_VAR'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1115 ) THEN
		CALL CS_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
		prmnam = 'SCALR_MSE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1116 ) THEN
		CALL CS_ESCI ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, nmem,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'SCALAR_ESCI'
		prfct = 1.0
	    END IF
	ELSE IF ( icmp .gt. 1200 .and. icmp .le. 1217 ) THEN
	    IF ( ndepth (itrc) .lt. 8 ) THEN
		iret = -36
		RETURN
	    END IF
	    IF ( icmp .eq. 1201 ) THEN
		CALL CV_BIAS ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_SPD_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1202 ) THEN
		CALL CV_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_RMSE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1203 ) THEN
		CALL CV_CORR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_CORR'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1204 ) THEN
		CALL CV_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_COVAR'
	    ELSE IF ( icmp .eq. 1205 ) THEN
		CALL CV_FVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_FRVAR'
	    ELSE IF ( icmp .eq. 1206 ) THEN
		CALL CV_OVAR ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_OBVAR'
	    ELSE IF ( icmp .eq. 1207 ) THEN
		CALL CV_FSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_FRSDV'
	    ELSE IF ( icmp .eq. 1208 ) THEN
		CALL CV_OSTD ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_OBSDV'
	    ELSE IF ( icmp .eq. 1209 ) THEN
		CALL CS_BIAS ( 1, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'U-CMP_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1210 ) THEN
		CALL CS_BIAS ( 2, MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'V-CMP_BIAS'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1211 ) THEN
		CALL CV_VBIS ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTR_BIAS_MAG'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1212 ) THEN
		CALL CV_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VCTR_ERROR_SIG'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1213 ) THEN
		CALL CV_VBIS ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'VECTR_BIAS**2'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1214 ) THEN
		CALL CV_COVA ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = -2.0 * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    qmax = trcmax
		    trcmax = -2.0 * trcmin
		    trcmin = -2.0 * qmax
		END IF
		prmnam = '-2*VCTR_COVAR'
	    ELSE IF ( icmp .eq. 1215 ) THEN
		CALL CV_ESIG ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'VCTR_ERROR_VAR'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1216 ) THEN
		CALL CV_RMSE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, iret )
		icnt = 0
		DO ip = 1, ntrpts (itrc)
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
		prmnam = 'VECTR_MSE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1217 ) THEN
		CALL CV_ESCI ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, nmem,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'VECTOR_ESCI'
		prfct = 1.0
	    END IF
	ELSE IF ( icmp .gt. 1300 .and. icmp .le. 1306 ) THEN
	    IF ( icmp .eq. 1301 ) THEN
		CALL CPB_SCR ( 0, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BRIER_SCORE'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1306 ) THEN
		CALL CPB_SCR ( 1, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'TARGET_BRIER_SCR'
	    ELSE
C
C*		Compute codes 1302--1305.
C
		nrisk = icmp - 1301
		CALL CPB_FRQ ( MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss, nrisk,
     +			       trcdum, trcmin, trcmax, iret )
		IF ( nrisk .eq. 1 ) THEN
		    prmnam = 'NO_RISK_PRB'
		ELSE IF ( nrisk .eq. 2 ) THEN
		    prmnam = 'LOW_RISK_PRB'
		ELSE IF ( nrisk .eq. 3 ) THEN
		    prmnam = 'MOD_RISK_PRB'
		ELSE IF ( nrisk .eq. 4 ) THEN
		    prmnam = 'HI_RISK_PRB'
		END IF
	    END IF
	    IF ( iret .ne. 0 ) THEN
		iret = iret - 41
		RETURN
	    END IF
	ELSE IF ( icmp .ge. 1307 .and. icmp .le. 1363 ) THEN
C
C*	    Compute skill scores using the PBS numbers.
C
	    IF ( icmp .lt. 1315 .or. ( icmp .ge. 1333 .and.
     +		 icmp .le. 1339 ) ) THEN
		icat = 1
		cpren = 'LOW+_'
	    ELSE IF ( icmp .lt. 1323 .or. ( icmp .ge. 1340 .and.
     +		      icmp .le. 1346 ) ) THEN
		icat = 2
		cpren = 'MOD+_'
	    ELSE IF ( icmp .lt. 1331 .or. ( icmp .ge. 1347 .and.
     +		      icmp .le. 1353 ) ) THEN
		icat = 3
		cpren = 'HIGH_'
	    END IF
	    ndp = ndepth (itrc)
	    IF ( icmp .eq. 1307 .or. icmp .eq. 1315 .or.
     +		 icmp .eq. 1323 ) THEN
		CALL CPB_BSSK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'BIAS_SCORE'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1308 .or. icmp .eq. 1316 .or.
     +		      icmp .eq. 1324 ) THEN
		CALL CPB_ETSK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'EQ_THT_SCR'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1309 .or. icmp .eq. 1317 .or.
     +		      icmp .eq. 1325 ) THEN
		CALL CPB_FASK ( 1, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'FLS_ALR_RAT'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1310 .or. icmp .eq. 1318 .or.
     +		      icmp .eq. 1326 ) THEN
		CALL CPB_FASK ( 0, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'FLS_ALR_RTO'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1311 .or. icmp .eq. 1319 .or.
     +		      icmp .eq. 1327 ) THEN
		CALL CPB_PASK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'POSTAGREMT'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1312 .or. icmp .eq. 1313 .or.
     +		      icmp .eq. 1320 .or. icmp .eq. 1321 .or.
     +		      icmp .eq. 1328 .or. icmp .eq. 1329 ) THEN
		CALL CPB_PDSK ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'POD=PREFIG'
		prfct = 1.0
		IF ( icmp .eq. 1313 .or. icmp .eq. 1321 .or.
     +		     icmp .eq. 1329 ) prmnam = cpren // 'PROB_OF_DET'
	    ELSE IF ( icmp .eq. 1314 .or. icmp .eq. 1322 .or.
     +		      icmp .eq. 1330 ) THEN
		CALL CPB_TSSK ( 0, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'CSI=THRTSC'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1331 ) THEN
		CALL CPB_SUMS ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, 1,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'SUM_IN_RISK_AREA'
	    ELSE IF ( icmp .eq. 1332 ) THEN
		CALL CPB_SUMS ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, 2,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'SUM > THRESHOLD'
	    ELSE IF ( icmp .eq. 1333 .or. icmp .eq. 1340 .or.
     +		      icmp .eq. 1347 ) THEN
		CALL CPB_TSSK ( 1, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'HEIDKE_SKSC'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1334 .or. icmp .eq. 1341 .or.
     +		      icmp .eq. 1348 ) THEN
		CALL CPB_TSSK ( 2, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'P-H-K_SKSCR'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1335 .or. icmp .eq. 1342 .or.
     +		      icmp .eq. 1349 ) THEN
		CALL CPB_TSSK ( 4, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'ODDS_RATIO'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1336 .or. icmp .eq. 1343 .or.
     +		      icmp .eq. 1350 ) THEN
		CALL CPB_TSSK ( 6, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'LN(ODS_RTO)'
		prfct = 1.E29
	    ELSE IF ( icmp .eq. 1337 .or. icmp .eq. 1344 .or.
     +		      icmp .eq. 1351 ) THEN
		CALL CPB_TSSK ( 3, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'STDERR_LNOR'
	    ELSE IF ( icmp .eq. 1338 .or. icmp .eq. 1345 .or.
     +		      icmp .eq. 1352 ) THEN
		CALL CPB_TSSK ( 5, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'ODSRTO_SKSC'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1339 .or. icmp .eq. 1346 .or.
     +		      icmp .eq. 1353 ) THEN
		CALL CPB_TSSK ( 7, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = cpren // 'ODDS_RSS**3'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1354 ) THEN
		CALL CPB_UREF ( 0, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +			        itrc, dtrace, rmiss, trcdum, trcmin,
     +				trcmax, iret )
		prmnam = 'SMPL_CLIMO_BSCR'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1355 ) THEN
		CALL CPB_DSCR ( 1, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BS_RELIABILITY'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1356 ) THEN
		CALL CPB_DSCR ( 2, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BS_RESOLUTION'
		prfct = rmiss
	    ELSE IF ( icmp .eq. 1357 ) THEN
		CALL CPB_DSCR ( 3, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BS_UNCERTAINTY'
		prfct = rmiss
	    ELSE IF ( icmp .eq. 1358 ) THEN
		CALL CPB_DSCR ( 4, MXTRCS, MXDPTH, ndepth (itrc),
     +			       ntrpts (itrc),
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'BS_SKLL_VS_CLIMO'
		prfct = 1.0
	    ELSE IF ( icmp .eq. 1359 ) THEN
		CALL CPB_UREF ( 1, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +			        itrc, dtrace, rmiss, trcdum, trcmin,
     +				trcmax, iret )
		prmnam = 'SMPL_CLIMO_FREQ'
		prfct = rmiss
	    ELSE IF ( icmp .eq. 1360 ) THEN
	        ipbsn  = INDEX ( cstat, 'PBS' )
		IF ( ipbsn .eq. 0 ) THEN
		    iret = -60
		    RETURN
		END IF
	        CALL RDTD_D2P ( 1, MXTRCS, MXDPTH,
     +			    ntrpts (itrc), ndepth (itrc),
     +			    itrc, dtrace, rmiss,
     +			    npts, xpts, trcdat,
     +			    xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			    cltyp, iptyp, iret )
		xmin=1000
		xmax=-1000
		DO ip = 1, npbwwx (itrc)
		    xpts (ip) = prbwwx (ip,itrc)
		    xpts (ip+npbwwx(itrc)) = 2.0 + xpts (ip)
		    IF ( xpts (ip) .gt. xmax ) xmax = xpts (ip)
		    IF ( xpts (ip) .lt. xmin ) xmin = xpts (ip)
		END DO
	    	prmnam = 'ATTRIBUTE_DIAGRAM'
		prfct = rmiss
		clbl (1) = xclbls (itrc,1)
		clbl (2) = xclbls (itrc,ntrpts(itrc))
		RETURN
C*
	    ELSE IF ( icmp .eq. 1361 ) THEN
		CALL CPB_TSSK ( 8, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss, 1,
     +				trcdat, trcmin, trcmax, iret )
		prmnam = 'FRCST_PROB_>_0_EDS'
		prfct = 1.0
		RETURN
	    ELSE IF ( icmp .eq. 1362 ) THEN
		npts = mxpts
		CALL RDTD_RCC ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     +			        prbwwx (1,itrc), npbwwx (itrc),
     +			        npts, xpts, trcdat,
     +			        xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			        cltyp, iptyp, prmnam, prfct, iret )
		RETURN
	    ELSE IF ( icmp .eq. 1363 ) THEN
		npts = mxpts
		CALL RDTD_PRC ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     + 			        prbwwx (1,itrc), npbwwx (itrc),
     +			        npts, xpts, trcdat,
     +			        xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			        cltyp, iptyp, prmnam, prfct, iret )
		RETURN
	    END IF
C*
	ELSE IF ( icmp .gt. 1400 .and. icmp .le. 1407 ) THEN
	    IF ( icmp .eq. 1401 .and. lbltyp .ne. 't' ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 4, 5,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'AC_FORVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1401 ) THEN
C
C*		For time series, divide each weighted element
C*		by the mean of the weights.
C
		CALL RDTD_EST ( itrc, rmiss, 4, kpts, trcdum,
     +				trcmin, trcmax, iret )
		IF ( iret .lt. 0 ) RETURN
		CALL RDTD_AFW ( 2, itrc, rmiss, 5, ntrpts (itrc),
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'TS_FORVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1402 .and. lbltyp .ne. 't' ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 6, 7,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'AC_ANLVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1402 ) THEN
C
C*		For time series, divide each weighted element
C*		by the mean of the weights.
C
		CALL RDTD_EST ( itrc, rmiss, 6, kpts, trcdum,
     +				trcmin, trcmax, iret )
		IF ( iret .lt. 0 ) RETURN
		CALL RDTD_AFW ( 2, itrc, rmiss, 7, ntrpts (itrc),
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'TS_ANLVAR_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1403 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 4, 10,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FORVARFRC_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1404 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 6, 11,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ANLVARFRC_WTD_PE'
		prfct = 0.
	    ELSE IF ( icmp .eq. 1405 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 5, 10,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FOR_VARIANCE_FRC'
	    ELSE IF ( icmp .eq. 1406 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 4, 7, 11,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'ANL_VARIANCE_FRC'
	    ELSE IF ( icmp .eq. 1407 ) THEN
		CALL CS_BNOP ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			       itrc, dtrace, rmiss, 1, 3, 9,
     +			       trcdum, trcmin, trcmax, iret )
		prmnam = 'FORCST_AMPLITUDE'
	    END IF
	ELSE IF ( icmp .ge. 1500 .and. icmp .le. max15 ) THEN
	    IF ( icmp .eq. 1500 ) THEN
		CALL CPB_GSCR ( MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		prmnam = 'BRIER_SCORE'
		prfct = 0.
	    END IF
	    IF ( icmp .gt. 1500 ) THEN
		ncat = icmp - 1500
		CALL CPB_GAFP ( ncat, MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		WRITE (ccat,'(I1)') ncat
		prmnam = 'AVG_FR_PRB|OB_C' // ccat
	    END IF
	ELSE IF ( icmp .gt. max15 .and. icmp .le. mx155 ) THEN
	    ncat = icmp - 1550
	    CALL CPB_GOBP ( ncat, MXTRCS, MXDPTH, ndepth (itrc),
     +			    ntrpts (itrc),
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, iret )
	    WRITE (ccat,'(I1)') ncat
	    prmnam = 'OBSVD_FREQ_CAT_' // ccat
	ELSE IF ( icmp .eq. 1590 ) THEN
	    CALL CPB_GUNC ( MXTRCS, MXDPTH, ndepth (itrc),
     +			    ntrpts (itrc),
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, iret )
	    prmnam = 'SMPL_CLIMO_BSCR'
	    prfct = 0.
	ELSE IF ( icmp .ge. 1600 .and. icmp .le. 1606 ) THEN
	    IF ( icmp .eq. 1600 ) THEN
		CALL RDTD_TGD ( MXTRCS, MXDPTH, cstat,
     +				ntrpts (itrc), ndepth (itrc),
     +				itrc, dtrace, rmiss,
     +			        npts, xpts, trcdat,
     +			        xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			        cltyp, iptyp, prmnam, prfct, iret )
		RETURN
	    ELSE IF ( icmp .eq. 1601 ) THEN
		ndp = ndepth (itrc)
		CALL CPB_PANL ( 1, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'PROB_ANLY_LOWER'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1602 ) THEN
		ndp = ndepth (itrc)
		CALL CPB_PANL ( 2, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'PROB_ANLY_WITHIN'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1603 ) THEN
		ndp = ndepth (itrc)
		CALL CPB_PANL ( 3, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'PROB_ANLY_HIGHER'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1604 ) THEN
		ndp = ndepth (itrc)
		CALL CPB_PANL ( 4, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'PROB_ANLY_OUTSID'
		prfct = 0.0
	    ELSE IF ( icmp .eq. 1605 ) THEN
		CALL RDTD_PAE ( MXTRCS, MXDPTH,
     +				ntrpts (itrc), ndepth (itrc),
     +				itrc, dtrace, rmiss,
     +			        npts, xpts, trcdat,
     +			        xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			        cltyp, iptyp, prmnam, prfct, iret )
		RETURN
	    ELSE IF ( icmp .eq. 1606 ) THEN
		ndp = ndepth (itrc)
		CALL CPB_PANL ( 5, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, iret )
		prmnam = 'MSSNG_RATE_ERROR'
		prfct = 0.0
	    END IF
	ELSE IF ( icmp .eq. 1700 ) THEN
	    ndp = ndepth (itrc)
	    CALL CPB_NRPS ( MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, iret )
	    prmnam = 'NO_SKILL_FRCTN'
	ELSE IF ( icmp .eq. 1801 ) THEN
	    CALL CS_DIRE ( MXTRCS, MXDPTH, ntrpts (itrc),
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, iret )
		prmnam = 'DIR_OBS_TO_FRCST'
		prfct = 0.0
	ELSE IF ( icmp .eq. 1901 ) THEN
	    ndp = ndepth (itrc)
	    CALL CS_CS1S ( 1, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, iret )
		prmnam = 'X-DIR_S1_SCORE'
		prfct = 0.0
	ELSE IF ( icmp .eq. 1902 ) THEN
	    ndp = ndepth (itrc)
	    CALL CS_CS1S ( 2, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, iret )
		prmnam = 'Y-DIR_S1_SCORE'
		prfct = 0.0
	ELSE IF ( icmp .eq. 1903 ) THEN
	    ndp = ndepth (itrc)
	    CALL CS_CS1S ( 3, MXTRCS, MXDPTH, ndp, ntrpts (itrc),
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, iret )
		prmnam = 'S1_SCORE'
		prfct = 0.0
        ELSE IF ( icmp .gt. 2000 .and. icmp .le. 2005 ) THEN
	    IF ( icmp .eq. 2001 ) THEN
	        CALL STX_MODE ( 1, MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		prmnam = 'MODE_INT_BIAS'
	        prfct = 0.0
	    ELSE IF ( icmp .eq. 2002 ) THEN
	        CALL STX_MODE ( 2, MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		prmnam = 'MODE_AREA_BIAS'
	        prfct = 1.0
	    ELSE IF ( icmp .eq. 2003 ) THEN
	        CALL STX_MODE ( 3, MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		prmnam = 'MODE_OBS->FOR_DRCTN'
	        prfct = rmiss
	    ELSE IF ( icmp .eq. 2004 ) THEN
	        CALL STX_MODE ( 4, MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		prmnam = 'MODE_POD'
	        prfct = 1.0
	    ELSE IF ( icmp .eq. 2005 ) THEN
	        CALL STX_MODE ( 5, MXTRCS, MXDPTH, ndepth (itrc),
     +			        ntrpts (itrc),
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, iret )
		prmnam = 'MODE_THRT_SCORE'
	        prfct = 1.0
	    END IF
        ELSE IF ( icmp .eq. 2101 ) THEN
	    CALL STX_FRSS ( MXTRCS, MXDPTH, ndepth (itrc),
     +			    ntrpts (itrc),
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, iret )
	    prmnam = 'FRCTNS_SKLL_SCR'
	    prfct = 1.0
        ELSE IF ( icmp .eq. 2201 .or. icmp .eq. 2202 .or.
     +		  icmp .eq. 2203 .or. icmp .eq. 2204 ) THEN
	    kmp = icmp - 2200
	    CALL CS_CPFR ( kmp, MXTRCS, MXDPTH, ntrpts (itrc),
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, iret )
	    IF ( kmp .eq. 1 ) THEN
	        prmnam = 'PROB(F>O|O>=THRSHLD)'
	        prfct = rmiss
	    ELSE IF ( kmp .eq. 2 ) THEN
	        prmnam = 'PROB(F>O|F>=THRSHLD)'
	        prfct = rmiss
	    ELSE IF ( kmp .eq. 3 ) THEN
	        prmnam = 'PROB(F>T)/PROB(O>T)'
	        prfct = 1
	    ELSE
	        prmnam = 'PROB(F>O|F&O>=THRSH)'
	        prfct = rmiss
	    END IF
        ELSE IF ( icmp .eq. 2301 .or. icmp .eq. 2302 .or.
     +		  icmp .eq. 2303 .or. icmp .eq. 2304 .or.
     +            icmp .eq. 2305 .or. icmp .eq. 2306 ) THEN
	    kmp = icmp - 2300
	    CALL CPB_CRPS ( kmp, MXTRCS, MXDPTH, ndepth (itrc),
     +                      ntrpts (itrc), itrc, dtrace, rmiss,
     +			    crpspl (1,itrc), ncrpsp (itrc),
     +			    trcdum, trcmin, trcmax, iret )
	    IF ( kmp .eq. 1 ) THEN
	        prmnam = 'MEAN_CRPS'
	        prfct = 0.0
	    ELSE IF ( kmp .eq. 2 ) THEN
	        prmnam = 'POTENTIAL_CRPS'
	        prfct = 0.0
	    ELSE IF ( kmp .eq. 3 ) THEN
	        prmnam = 'CRPS_RELIABILITY'
	        prfct = 0.0
	    ELSE IF ( kmp .eq. 4 ) THEN
	        prmnam = 'CRPS_RESOLUTION'
	        prfct = rmiss
	    ELSE IF ( kmp .eq. 5 ) THEN
	        prmnam = 'CRPS_UNCERTAINTY'
	        prfct = rmiss
	    ELSE
	        prmnam = 'CRPS_SKLL_VS_UNCRTNT'
	        prfct = 1.0
	    END IF
	ELSE IF ( icmp .eq. 2307 ) THEN
C
C*              CRPS quantile reliability diagram from time series.
C
	        ipbsn  = INDEX ( cstat, 'CRPS' )
		IF ( ipbsn .eq. 0 ) THEN
		    iret = -67
		    RETURN
		END IF
	        CALL RDTD_D2P ( 2, MXTRCS, MXDPTH,
     +			    ntrpts (itrc), ndepth (itrc),
     +			    itrc, dtrace, rmiss,
     +			    npts, xpts, trcdat,
     +			    xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			    cltyp, iptyp, iret )
		xmin=1000
		xmax=-1000
                xpts (1) = 0.0
                ii = 1
		DO ip = 1, ncrpsp (itrc)
                    ii = ii + 1
		    xpts (ii) = crpspl (ip,itrc)
		    IF ( xpts (ii) .gt. xmax ) xmax = xpts (ip)
		    IF ( xpts (ii) .lt. xmin ) xmin = xpts (ip)
		END DO
                DO ip = ( ncrpsp (itrc) + 1 ), ndepth (itrc)
                    ii = ii + 1
		    xpts (ii) = rmiss
                END DO
	    	prmnam = 'CRPS_RELI_DIAGRAM'
		prfct = rmiss
		clbl (1) = xclbls (itrc,1)
		clbl (2) = xclbls (itrc,ntrpts(itrc))
		RETURN
C*
	ELSE IF ( icmp .eq. 9001 ) THEN
	    CALL RDTD_CFT ( 0, MXTRCS, MXDPTH, ntrpts (itrc),
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, iret )
	    prmnam = 'CNT_FRAC_TRC_TTL'
	ELSE IF ( icmp .eq. 9002 ) THEN
	    CALL RDTD_D2T ( MXTRCS, MXDPTH,
     +			    ntrpts (itrc), ndepth (itrc),
     +			    itrc, dtrace, rmiss,
     +			    npts, xpts, trcdat,
     +			    xmin, xmax, trcmin, trcmax, clbl, rlbl,
     +			    cltyp, iptyp, iret )
	    prmnam = cstat
	    prfct = rmiss
	    RETURN
	ELSE IF ( ( icmp .ge. 101101 .and. icmp .le. 101115 ) .or.
     +            ( icmp .ge. 111101 .and. icmp .le. 111115 ) .or.
     +            ( icmp .ge. 121101 .and. icmp .le. 121115 ) .or.
     +            ( icmp .ge. 131101 .and. icmp .le. 131115 ) ) THEN
	     CALL RDTD_TRK ( icmp, itrc, rmiss,
     +			     trcsav, trcdat, trcmin, trcmax,
     +			     prmnam, prfct, iret )
	     IF ( iret .lt. 0 ) RETURN
	     DO ip = 1, ntrpts (itrc)
		trcdum (ip) = trcdat (ip)
	     END DO
	ELSE IF ( icmp .gt. 1000 ) THEN
	    iret = -32
	    RETURN
	ELSE IF ( icmp .eq. -1 ) THEN
	    DO ip = 1, ntrpts (itrc)
		IF ( drecnm (itrc,ip) .ge. 0 ) THEN
		    trcdum (ip) = drecnm (itrc,ip)
		    IF ( trcdum (ip) .gt. trcmax )
     +			trcmax = trcdum (ip)
		    IF ( trcdum (ip) .lt. trcmin )
     +			trcmin = trcdum (ip)
		ELSE
		    trcdum (ip) = rmiss
		END IF
	    END DO
	ELSE IF ( icmp .lt. -1 .or. icmp .eq. 1 ) THEN
	    CALL RDTD_EST ( itrc, rmiss, icmp, kpts, trcdum,
     +			    trcmin, trcmax, iret )
	    IF ( iret .lt. 0 ) RETURN
	    indx = ABS (icmp)
	ELSE
	    CALL RDTD_EST ( itrc, rmiss, icmp, kpts, trcdum,
     +			    trcmin, trcmax, iret )
	    IF ( iret .lt. 0 ) RETURN
	    indx = ABS (icmp)
	END IF
C
C*	Set default trace labels.  Check for file with list
C*      of labels.
C
	CALL ST_CLST ( cstat, '_', 'x', 4, parts, npr, ier )
	IF ( npr .gt. 0 ) THEN
	    CALL ST_RNAN ( parts (npr), qclbl, lls, iret )
	    ispc = INDEX ( qclbl, ' ' ) - 1
	    qclbl = qclbl (1:ispc) // '.lst'
	    IF ( npr .gt. 1 ) THEN
		DO ipr = 1, npr-1
		    IF ( ipr .eq. 1 ) THEN
			stfil = parts (ipr)
		    ELSE
			CALL ST_LSTR ( stfil, lls, ier )
			lls = lls + 1
			stfil (lls:) = parts (ipr)
		    END IF
		END DO
		CALL ST_LSTR ( stfil, lls, ier )
		lls = lls + 1
		stfil (lls:) = qclbl
	    ELSE
		stfil = qclbl
	    END IF
	    INQUIRE ( FILE = stfil, EXIST = exist )
	    IF ( exist ) THEN
	        OPEN ( FILE = stfil, UNIT=99, IOSTAT=ios )
	        exist = ( ios .eq. 0 )
	    END IF
	ELSE
	    exist = .false.
	END IF
	IF ( indx .eq. 1 ) THEN
	    prmnam = 'DATA_COUNT'
	ELSE IF ( indx .gt. 1 .and. exist ) THEN
	    ii = 0
	    im1 = indx - 1
	    DO WHILE ( ii .lt. im1 .and. ios .eq. 0 )
		ii = ii + 1
		READ ( 99, '(A)', IOSTAT=ios ) stfil
		IF ( ii .eq. im1 ) THEN
		    CALL ST_CLST ( stfil, ' ', ' ', 2, parts, npr, ier )
		    prmnam = parts (1)
		    IF ( npr .gt. 1 ) THEN
			CALL ST_CRNM ( parts (2), prfct, ier )
		    ELSE
			prfct = rmiss
		    END IF
		END IF
	    END DO
	    IF ( ios .ne. 0 ) THEN
		prmnam = 'UNDEFINED_PARM'
	    END IF
	    CLOSE ( UNIT=99 )
	ELSE IF ( indx .gt. 1 ) THEN
	    iml1l2 = INDEX ( cstat, 'ML1L2' )
	    isl1l2 = INDEX ( cstat, 'SAL1L2' ) +
     +		     INDEX ( cstat, 'SL1L2' )  +
     +		     INDEX ( cstat, 'SSAL1L2' )
	    ivl1l2 = INDEX ( cstat, 'VAL1L2' ) +
     +		     INDEX ( cstat, 'VL1L2' )  +
     +		     INDEX ( cstat, 'VSAL1L2' )
	    ifho   = INDEX ( cstat, 'FHO' )
	    ipbsn  = INDEX ( cstat, 'PBS_WWX' )
	    iphse  = INDEX ( cstat, 'PHSE' )
	    ivlck  = INDEX ( cstat, 'VLCEK' )
	    igbs   = INDEX ( cstat, 'GBS' )
	    irhe   = INDEX ( cstat, 'RHET' )
	    irhn   = INDEX ( cstat, 'RHNT' )
	    irps   = INDEX ( cstat, 'RPS' )
	    itrk   = INDEX ( cstat, 'TRK' )
	    iesl1  = INDEX ( cstat, 'ESL1L2' )
	    ievl1  = INDEX ( cstat, 'EVL1L2' )
	    ifss   = INDEX ( cstat, 'FSS' )
	    ipfr   = INDEX ( cstat, 'PFR' )
	    IF ( iml1l2 .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'F_MEAN'
		IF ( indx .eq. 3 ) prmnam = 'O_MEAN'
		IF ( indx .eq. 4 ) prmnam = 'FO_MEAN'
		IF ( indx .eq. 5 ) prmnam = 'F2_MEAN'
		IF ( indx .eq. 6 ) prmnam = 'O2_MEAN'
		IF ( indx .eq. 7 ) THEN
		    prmnam = 'MAE'
		    prfct = 0.0
		END IF
	    ELSE IF ( isl1l2 .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'F_MEAN'
		IF ( indx .eq. 3 ) prmnam = 'O_MEAN'
		IF ( indx .eq. 4 ) prmnam = 'FO_MEAN'
		IF ( indx .eq. 5 ) prmnam = 'F2_MEAN'
		IF ( indx .eq. 6 ) prmnam = 'O2_MEAN'
		IF ( indx .eq. 7 ) prmnam = 'MEAN_ABS_ERR'
		IF ( indx .eq. 8 ) prmnam = 'X_|DF-DA|_MEAN'
		IF ( indx .eq. 9 ) prmnam = 'X_MX(|DF|,|DA|)_MEAN'
		IF ( indx .eq. 10 ) prmnam = 'Y_|DF-DA|_MEAN'
		IF ( indx .eq. 11 ) prmnam = 'Y_MX(|DF|,|DA|)_MEAN'
	    ELSE IF ( iesl1 .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'F_MEAN'
		IF ( indx .eq. 3 ) prmnam = 'O_MEAN'
		IF ( indx .eq. 4 ) prmnam = 'FO_MEAN'
		IF ( indx .eq. 5 ) prmnam = 'F2_MEAN'
		IF ( indx .eq. 6 ) prmnam = 'O2_MEAN'
		IF ( indx .eq. 7 ) prmnam = 'S_VAR_WRT_ENS_MN'
		IF ( indx .eq. 8 ) THEN
		    prmnam = 'S_VER_OUTLR_FRCT'
		    prfct = 0.0
		END IF
	    ELSE IF ( ivl1l2 .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'UF_MEAN'
		IF ( indx .eq. 3 ) prmnam = 'VF_MEAN'
		IF ( indx .eq. 4 ) prmnam = 'UO_MEAN'
		IF ( indx .eq. 5 ) prmnam = 'VO_MEAN'
		IF ( indx .eq. 6 ) prmnam = 'F.O_MEAN'
		IF ( indx .eq. 7 ) prmnam = 'F.F_MEAN'
		IF ( indx .eq. 8 ) prmnam = 'O.O_MEAN'
	    ELSE IF ( ievl1 .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'UF_MEAN'
		IF ( indx .eq. 3 ) prmnam = 'VF_MEAN'
		IF ( indx .eq. 4 ) prmnam = 'UO_MEAN'
		IF ( indx .eq. 5 ) prmnam = 'VO_MEAN'
		IF ( indx .eq. 6 ) prmnam = 'F.O_MEAN'
		IF ( indx .eq. 7 ) prmnam = 'F.F_MEAN'
		IF ( indx .eq. 8 ) prmnam = 'O.O_MEAN'
		IF ( indx .eq. 9 ) prmnam = 'V_VAR_WRT_ENS_MN'
		IF ( indx .eq. 10 ) THEN
		    prmnam = 'V_VER_OUTLR_FRCT'
		    prfct = 0.0
		END IF
	    ELSE IF ( ifho .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'FRCST'
		IF ( indx .eq. 3 ) prmnam = 'HITS'
		IF ( indx .eq. 4 ) prmnam = 'OBSRVD'
		IF ( indx .eq. 5 ) prmnam = 'BIAS_RMVD_HITS'
		IF ( indx .eq. 6 ) prmnam = 'BIAS_RMVD_FRCST'
	    ELSE IF ( ivlck .ne. 0 ) THEN
		IF ( indx .ge. 2 .and.
     +		     indx .le. 5 ) prfct = 0.
		IF ( indx .eq. 2 ) prmnam = 'S1'
		IF ( indx .eq. 3 ) prmnam = 'BIAS'
		IF ( indx .eq. 4 ) prmnam = 'ERROR_SD'
		IF ( indx .eq. 5 ) prmnam = 'RMS_ERROR'
		IF ( indx .eq. 6 ) prmnam = 'OBS_AVG'
		IF ( indx .eq. 7 ) prmnam = 'OBS_SD'
	    ELSE IF ( ipbsn .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'EVNT_FRC_LO_RISK'
		IF ( indx .eq. 3 ) prmnam = 'EVNT_FRC_MD_RISK'
		IF ( indx .eq. 4 ) prmnam = 'EVNT_FRC_HI_RISK'
		IF ( indx .eq. 5 ) prmnam = 'EVNTFRC>TH_NORSK'
		IF ( indx .eq. 6 ) prmnam = 'EVNTFRC>TH_LORSK'
		IF ( indx .eq. 7 ) prmnam = 'EVNTFRC>TH_MDRSK'
		IF ( indx .eq. 8 ) prmnam = 'EVNTFRC>TH_HIRSK'
	    ELSE IF ( iphse .ne. 0 ) THEN
		IF ( ( indx .ge. 2 .and. indx .le. 4 )
     +            .or. indx .eq. 6 ) prfct = 0.
		IF ( indx .eq. 2 ) prmnam = 'PHASE_ERROR'
		IF ( indx .eq. 3 ) prmnam = 'AMPLITUDE_ERROR'
		IF ( indx .eq. 4 ) prmnam = 'FORVAR*PHS_ERROR'
		IF ( indx .eq. 5 ) prmnam = 'FORVAR_CONTRIB'
		IF ( indx .eq. 6 ) prmnam = 'ANLVAR*PHS_ERROR'
		IF ( indx .eq. 7 ) prmnam = 'ANLVAR_CONTRIB'
		IF ( indx .eq. 8 ) prmnam = 'ANALY_PHSANG'
		IF ( indx .eq. 9 ) prmnam = 'ANALY_AMPLTD'
		IF ( indx .eq. 10 ) prmnam = 'TTLFOR_VARIANCE'
		IF ( indx .eq. 11 ) prmnam = 'TTLANL_VARIANCE'
	    ELSE IF ( igbs .ne. 0 ) THEN
		ncat = ( indx - 1 ) / 3 + 1
		IF ( MOD ( (indx-1), 3 ) .eq. 0 ) ncat = ncat - 1
		WRITE (ccat,'(I1)') ncat
		IF ( MOD ( indx, 3 ) .eq. 2 )
     +		    prmnam = 'MN_FR_PRB*OBS_C' // ccat
		IF ( MOD ( indx, 3 ) .eq. 0 )
     +		    prmnam = 'MN(FR_PRB**2)_C' // ccat
		IF ( MOD ( indx, 3 ) .eq. 1 )
     +		    prmnam = 'FRACTION_OBSD_C' // ccat
	    ELSE IF ( irhe .ne. 0 .or. irhn .ne. 0 ) THEN
		WRITE (prmnam,1111) indx-1
1111		FORMAT ('BIN_#_',I2.2,'_PROB')
	    ELSE IF ( irps .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'RANKED_PROB_SCR'
		IF ( indx .eq. 3 ) prmnam = 'FRCTN_WITH_SKILL'
		IF ( indx .eq. 4 ) prmnam = 'CLIM_RNKD_PRB_SC'
		prfct=0.0
	    ELSE IF ( itrk .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'OBSERVED_LATITUDE'
		IF ( indx .eq. 3 ) prmnam = 'OBSERVED_LONGITUDE'
		IF ( indx .eq. 4 ) prmnam = 'SEARCH_ONLY_ANGLE'
		IF ( indx .eq. 5 ) prmnam = 'DISTANCE_ERROR'
		IF ( indx .eq. 6 ) prmnam = 'DISTANCE_ERROR**2'
		IF ( indx .eq. 7 ) prmnam = 'X_COMP_VEC_POS_ERROR'
		IF ( indx .eq. 8 ) prmnam = 'Y_COMP_VEC_POS_ERROR'
		IF ( indx .eq. 9 ) prmnam = 'CEN_PMSL_F_MEAN'
		IF ( indx .eq. 10 ) prmnam = 'CEN_PMSL_O_MEAN'
		IF ( indx .eq. 11 ) prmnam = 'CEN_PMSL_F*O_MEAN'
		IF ( indx .eq. 12 ) prmnam = 'CEN_PMSL_F*F_MEAN'
		IF ( indx .eq. 13 ) prmnam = 'CEN_PMSL_O*O_MEAN'
		IF ( indx .eq. 14 ) prmnam = 'MAX_WIND_F_MEAN'
		IF ( indx .eq. 15 ) prmnam = 'MAX_WIND_O_MEAN'
		IF ( indx .eq. 16 ) prmnam = 'MAX_WIND_F*O_MEAN'
		IF ( indx .eq. 17 ) prmnam = 'MAX_WIND_F*F_MEAN'
		IF ( indx .eq. 18 ) prmnam = 'MAX_WIND_O*O_MEAN'
		IF ( indx .eq. 19 ) prmnam = '850_VORT_F_MEAN'
		IF ( indx .eq. 20 ) prmnam = '850_VORT_O_MEAN'
		IF ( indx .eq. 21 ) prmnam = '850_VORT_F*O_MEAN'
		IF ( indx .eq. 22 ) prmnam = '850_VORT_F*F_MEAN'
		IF ( indx .eq. 23 ) prmnam = '850_VORT_O*O_MEAN'
	    ELSE IF ( imode .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'OBS_OBJ_CNTRD_LAT'
		IF ( indx .eq. 3 ) prmnam = 'OBS_OBJ_CNTRD_LON'
		IF ( indx .eq. 4 ) prmnam = 'FRCST_OBJ_CNTRD_LAT'
		IF ( indx .eq. 5 ) prmnam = 'FRCST_OBJ_CNTRD_LON'
		IF ( indx .eq. 6 ) prmnam = 'OBS->FRCST_CMPSS_ANG'
		IF ( indx .eq. 7 ) prmnam = 'OBS->FRCST_DISTANCE'
		IF ( indx .eq. 8 ) prmnam = 'U-COMP_OBS->FRCST'
		IF ( indx .eq. 9 ) prmnam = 'V_COMP_OBS->FRCST'
		IF ( indx .eq. 10 ) prmnam = 'FRCST_OBJ_MDN_INT'
		IF ( indx .eq. 11 ) prmnam = 'OBS_OBJ_MDN_INT'
		IF ( indx .eq. 12 ) prmnam = 'FRCST_OBJ_AREA'
		IF ( indx .eq. 13 ) prmnam = 'OBS_OBJ_AREA'
		IF ( indx .eq. 14 ) prmnam = 'FOR-OBS_ORNT_ANG_DIF'
		IF ( indx .eq. 15 ) prmnam = 'FOR-OBS_INTRSCTN_ARA'
		IF ( indx .eq. 16 ) prmnam = 'FOR-OBS_UNION_AREA'
		IF ( indx .eq. 17 ) prmnam = 'INTRSCTN/UNION_AREA'
	    ELSE IF ( ifss .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'FRCTNS_BRIER_SCR'
		IF ( indx .eq. 3 ) prmnam = 'MN_SQRD_FRCST_FRCNTS'
		IF ( indx .eq. 4 ) prmnam = 'MN_SQRD_OBSVD_FRCTNS'
	    ELSE IF ( ipfr .ne. 0 ) THEN
		IF ( indx .eq. 2 ) prmnam = 'FRCTN_FRCSTS_>_OBS'
		IF ( indx .eq. 3 ) prmnam = 'FRCTN_F>O_AND_O>=TH'
		IF ( indx .eq. 4 ) prmnam = 'FRCTN_O_>=_THRESHOLD'
		IF ( indx .eq. 5 ) prmnam = 'FRCTN_F>O_AND_F>=TH'
		IF ( indx .eq. 6 ) prmnam = 'FRCTN_F_>=_THRESHOLD'
		IF ( indx .eq. 7 ) prmnam = 'FRCTN_F>O&F>TH&O>TH'
		IF ( indx .eq. 8 ) prmnam = 'FRCTN_F&O_>=_THRSHLD'
	    ELSE
		prmnam = 'UNDEFINED_PARM'
	    END IF
	END IF
C
C*	Place bias adjustment string before name, truncating
C*      string at left end.
C
	IF ( banam .ne. ' ' ) THEN
	    prmnam = banam // '_' // prmnam
	END IF
C
C*	Place threshold lag string before name, truncating
C*      string at left end.
C
	IF ( thlag .ne. ' ' ) THEN
	    prmnam = thlag // '_' // prmnam
	END IF
C
C*	Scan for all missing values.
C
	icnt = 0
	DO ip = 1, npts
	    IF ( trcdum (ip) .eq. rmiss ) icnt = icnt + 1
	END DO
	IF ( icnt .eq. npts ) THEN
	    iret = +2
	END IF
C
C*	Do x-axis values.
C
	xmax = -1.E30
	xmin = 1.E30
	IF ( iptyp .eq. 1 .or. iptyp .eq. 2 ) THEN
	    DO ip = 1, npts
		td = FLOAT ( kmnuts (itrc,ip) ) / 1440.D00
		IF ( td .gt. xmax ) xmax = td
		IF ( td .lt. xmin ) xmin = td
		xpts (ip) = td
		trcdat (ip) = trcdum (ip)
	    END DO
	    IF ( iptyp .eq. 1 ) THEN
		CALL RDTD_MVL ( itrc, rmiss, mxpts, xpts, trcdat, npts,
     +				rlbl, clbl, ier )
		IF ( ier .ne. 0 ) iret = ier
		RETURN
	    END IF
	ELSE
	    npts = npntrs
	    DO ip = 1, npts
		xpts (ip)= ip
	    END DO
	    it = itrc
	    IF ( lbltyp .eq. 'r' ) THEN
		DO ip = 1, ntrpts (it)
		    qlbl = xrlbls (it,ip)
		    i = 0
		    found = .false.
		    DO WHILE ( i .lt. npntrs .and. .not. found )
			i = i + 1
			IF ( ABS ( xrlbls (1,kpntrs(i)) - qlbl )
     +				.lt. TOLRNC ) THEN
			    td = FLOAT ( i )
			    IF ( td .gt. xmax ) xmax = td
			    IF ( td .lt. xmin ) xmin = td
			    xpts (i) = td
			    trcdat (i) = trcdum (ip)
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found .and. .not. alptms (it) ) THEN
			iret = -26
			RETURN
		    END IF
		END DO
	    ELSE
		DO ip = 1, ntrpts (it)
		    qclbl = xclbls (it,ip)
		    i = 0
		    found = .false.
		    DO WHILE ( i .lt. npntrs .and. .not. found )
			i = i + 1
			IF ( xclbls (1,kpntrs(i)) .eq. qclbl ) THEN
			    td = FLOAT ( i )
			    IF ( td .gt. xmax ) xmax = td
			    IF ( td .lt. xmin ) xmin = td
			    xpts (i) = td
			    trcdat (i) = trcdum (ip)
			    found = .true.
			END IF
		    END DO
		    IF ( .not. found .and. .not. alptms (it) ) THEN
			iret = -26
			RETURN
		    END IF
		END DO
	    END IF
	END IF
C*	
	IF ( cltyp .eq. 'r' .and. ltaxis ) THEN
	    DO ip = 1, npts
		rlbl (ip) = xrlbls (itrc,ip)
		clbl (ip) = ' '
	    END DO
	ELSE IF ( ltaxis ) THEN
	    DO ip = 1, npts
		rlbl (ip) = rmiss
		clbl (ip) = xclbls (itrc,ip)
	    END DO
	ELSE IF ( cltyp .eq. 'r' .and. .not. ltaxis ) THEN
	    DO ip = 1, npntrs
		rlbl (ip) = xrlbls (1,kpntrs(ip))
		clbl (ip) = ' '
	    END DO
	ELSE IF ( .not. ltaxis ) THEN
	    DO ip = 1, npntrs
		rlbl (ip) = rmiss
		clbl (ip) = xclbls (1,kpntrs(ip))
	    END DO
	END IF
C
C*	Compute % or accumulated % for ICOMP = 1009--1017.
C
	IF ( icmp .ge. 1009 .and. icmp .le. 1011 ) THEN
	    CALL CS_ACCM ( 1, trcdum, npts, rmiss, clbl, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
	IF ( icmp .ge. 1012 .and. icmp .le. 1014 ) THEN
	    CALL CS_ACCM ( 0, trcdum, npts, rmiss, clbl, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
	IF ( icmp .ge. 1015 .and. icmp .le. 1017 ) THEN
	    CALL CS_PCBC ( trcdum, npts, rmiss, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
	IF ( icmp .ge. 1018 .and. icmp .le. 1020 ) THEN
	    CALL CS_RPBT ( trcdum, npts, rmiss, trcdat,
     +			   trcmin, trcmax, ier )
	END IF
C*
	RETURN
	END
