	SUBROUTINE GET_DOM  ( lun, tblfil, names, n, kgrdnm,
     +			      isubll, jsubll, isubur, jsubur, iret )
C************************************************************************
C* GET_DOM								*
C*									*
C* This subroutine reads in a grid region information lookup table file	*
C* and parses it for GRIB grid number and subset information.		*
C*									*
C* The structure of the table is according to the following example:	*
C*									*
C* ! NAME   REF_# ISUBLL JSUBLL ISUBUR JSUBUR |   DESCRIPTION		*
C*  G211     211     1       1     93     65  | Full GRID 211		*
C*  G211A    211     1      33     47     65  | NW Quadrant of GRID 211 *
C*									*
C* Not that ! in column one denotes a comment in the table.		*
C*									*
C* Each table file entry has two parts.  The first part gives the	*
C* region name, the GRIB grid number, and the subset grid coordinates.	*
C* The second part is a short text description of the grid.  A |	*
C* separates these two parts.						*
C*									*
C* If a requested subset name is not found in the table, the values	*
C* of the grid number and the subset coordinates will be set to -9999.	*
C* If IRET > 0, its value gives the number of subset region names not	*
C* found.								*
C*									*
C* The unit number LUN is arbitrary, but must be a valid FORTRAN unit	*
C* number.  It will be connected to the file named in TBLFIL for the	*
C* duration of this subroutine and then closed.				*
C*									*
C* GET_DOM  ( LUN, TBLFIL, NAMES, N, KGRDNM,				*
C*	      ISUBLL, JSUBLL, ISUBRR, JSUBRR, IRET )			*
C*									*
C* Input parameters:							*
C*	LUN		INTEGER		Unit number for table file	*
C*	TBLFIL		CHAR*		Grid region table file name	*
C*	NAMES (N)	CHAR*8		Grid region names to find	*
C*	N		INTEGER		Number of grid regions to find	*
C*									*
C* Output parameters:							*
C*	KGRDNM (N)	INTEGER		GRIB grid number		*
C*	ISUBLL (N)	INTEGER		Lower-left x subset index	*
C*	JSUBLL (N)	INTEGER		Lower-left y subset index	*
C*	ISUBUR (N)	INTEGER		Upper-right x subset index	*
C*	JSUBUR (N)	INTEGER		Upper-right y subset index	*
C*	IRET		INTEGER		Return code			*
C*					 +n = n grids not found in tbl	*
C*					  0 = normal return		*
C*					 -1 = invalid region tbl entry	*
C*					 -2 = invalid unit number	*
C*					 -3 = could not open table file *
C*									*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C************************************************************************
	CHARACTER*(*)	tblfil
	CHARACTER*8	names (*)
	INTEGER		kgrdnm (*), isubll (*), jsubll (*),
     +			isubur (*), jsubur (*)
C*
	CHARACTER*80	buffr
	CHARACTER*12	field (6)
	LOGICAL		found
C------------------------------------------------------------------------
	iret  = 0
	IF ( lun .le. 0 ) THEN
	    iret = -2
	    RETURN
	END IF
	CALL VSDB_OPN ( lun, tblfil, 'r', ier )
	IF ( ier .ne. 0 ) THEN
	    WRITE (6,*) ' Error return from VSDB_OPN = ', ier
	    iret = -3
	    CLOSE ( lun )
	    RETURN
	END IF
C
C*	Initialize the grid bounds arrays to a missing value flag.
C*	Set the projection type flags to false.
C
	DO ig = 1, n
	    kgrdnm (ig) = -9999
	    isubll (ig) = -9999
	    jsubll (ig) = -9999
	    isubur (ig) = -9999
	    jsubur (ig) = -9999
	END DO
C*
	REWIND lun
	ipart = 1
	iostat = 0
	DO WHILE ( iostat .eq. 0 )
	    READ ( lun, 1000, IOSTAT=iostat ) buffr
1000	    FORMAT (A)
	    ibang = INDEX ( buffr(1:1), '!' )
	    IF ( iostat .eq. 0 .and. ibang .eq. 0 ) THEN
		    CALL ST_CLST ( buffr, ' ', ' ', 6, field,
     +				   num, ier )
		    IF ( ier .lt. 0 ) THEN
			iret = -1
			CLOSE ( lun )
			RETURN
		    END IF
		    found = .false.
		    ig = 0
		    DO WHILE ( .not. found .and. ig .lt. n )
			ig = ig + 1
			IF ( names (ig) .eq. field (1) ) THEN
			    CALL ST_NUMB ( field (2), kgrdnm (ig), ier )
			    CALL ST_NUMB ( field (3), isubll (ig), ier )
			    CALL ST_NUMB ( field (4), jsubll (ig), ier )
			    CALL ST_NUMB ( field (5), isubur (ig), ier )
			    CALL ST_NUMB ( field (6), jsubur (ig), ier )
			    found = .true.
			END IF
		    END DO
	    END IF
	END DO
C
C*	Check for unassigned grid name.
C
	DO i = 1, n
	    IF ( kgrdnm (i) .eq. -9999 ) THEN
		iret = iret + 1
	    END IF
	END DO
C*
	CLOSE ( lun )
	RETURN
	END
