	SUBROUTINE RSMP_CAL ( itrc, icomp, rmiss, npts, ndpth,
     +			      trcdat, trcmin, trcmax, iret )
C************************************************************************
C* RSMP_CAL								*
C*									*
C* This subroutine returns a specific trace of data for one of a pair	*
C* of traces for resampled VSDB data.					*
C*									*
C* ICOMP tells what value to pick off from the data field, or what	*
C* value to compute from the data field numbers (table is from RDTD_TRC *
C* and not all codes apply in the box-whisker context):			*
C*									*
C*	ICOMP			Action					*
C*									*
C*	 -n		Return raw data for field n (undivided sum)	*
C*	 -1		Record count at all trace points		*
C*	  0		Return only CLTYP and IPTYP			*
C*	  1		Return data from field 1 = the data count	*
C*	  2		Return data from field 2 divided by count	*
C*	  3		Return data from field 3 divided by count	*
C*	n < 1000	Return data from field n divided by count	*
C*	1001		Compute BIAS from FHO values			*
C*	1002		Compute Equitable Threat Score (ETS)		*
C*	1003		Compute Critical Success Index (=TS)		*
C*	1004		Compute False Alarm Ratio (FAR)			*
C*	1005		Compute Postagreement (PA)			*
C*	1006		Compute Prefigurance (=POD)			*
C*	1007		Compute Probability of Detection (POD)		*
C*	1008		Compute Threat Score (TS)			*
C*	1009		Cumulative Forecast Prcp Vol % vs Thrshld	*
C*	1010		Cumulative Correctly Frcst Prcp Vol % vs Thrshld*
C*	1011		Cumulative Observed Prcp Vol % vs Thrshld	*
C*	1012		Forecast Prcp Vol % of Ttl vs Thrshld		*
C*	1013		Correctly Forecast Prcp Vol % of Ttl vs Thrshld	*
C*	1014		Observed Prcp Vol % of Ttl vs Thrshld           *
C*	1015		Forecast Prcp # % of Ttl # vs Thrshld           *
C*	1016		Correctly Forecast Prcp # % of Ttl # vs Thrshld *     
C*	1017		Observed Prcp # % of Ttl # vs Thrshld		*
C*	1018		Forecast # % of Ttl <= Thrshld vs Thrshld	*
C*	1019		Correctly Frcst # % of Ttl <= Thrshld vs Thrshld*
C*	1020		Observed # % of Ttl <= Thrshld # vs Thrshld	*
C*	1021		False Alarm Rate (f-h)/(N-o) (POFD)		*
C*	1022		Conditional Miss Rate (o-h)/(N-f) (CMR)		*
C*	1023		Heidke Skill Score (HSS)			*
C*	1024		Peirce-Hanssen-Kuipers True Skill Score (TSS)	*
C*	1025		Compute ODDS RATIO				*
C*	1026		Compute log of ODDS RATIO			*
C*	1027		Compute standard error of log of ODDS RATIO	*
C*	1028		ODDS RATIO Skill Score (ORSS)			*
C*	1029		Compute ODDS RATIO Skill Score Cubed		*
C*	1030		Compute log (ODDS RATIO) / STD ERROR of same	*
C*	1031		Area between ODDS RATIO ROC & chance ROC curves	*
C*      1032		ROC curve parametric in OR for time series	*
C*	1033		Odds ratio Parameterized ROC area (OPRA) score	*
C*	1034	        Frcst accuracy rate = proportion correct (PC)	*
C*      1035            Extreme Dependency Score (EDS)			*
C*      1036            Clayton Skill Score (CSS)			*
C*	1037		Explicit dH/dF Threat Score (TSDHDF) 		*
C*	1038		Explicit dH/dF Equitable Threat Score (ETSDHDF) *
C*	1039		Explicit dH/dA Threat Score (TSDHDA)		*
C*	1040		Explicit dH/dA Equitable Threat Score (ETSDHDA) *
C*      1041		Symmetric Extreme Dependency Score (SEDS)	*
C*      1042		Extremal Dependence Index (EDI)			*
C*      1043		Symmetric Extremal Dependence Index (SEDI)	*
C*      1044            Two-Alternative Forced Choice test (2AFC)       *
C*									*
C*	1051		Critical Performance Ratio (CPR) for POD	*
C*	1052		CPR for EDS					*
C*	1053		CPR for TSS					*
C*	1054		CPR for PC					*
C*	1055		CPR for POFD					*
C*	1056		CPR for FAR					*
C*	1057		CPR for TS					*
C*	1058		CPR for ETS					*
C*	1059		CPR for HSS					*
C*	1060		CPR for CSS					*
C*	1061		CPR for ORSS					*
C*	1062		CPR for CMR					*
C*	1063		CPR for PA					*
C*	1064		CPR for TSDHDF					*
C*	1065		CPR for ETSDHDF					*
C*	1066		CPR for TSDHDA					*
C*	1067		CPR for ETSDHDA					*
C*      1068		CPR reference midway between CPR benchmarks	*
C*									*
C*  Any of the preceding 10xx series may be computed from bias adjusted	*
C*  FHO values.  To do this, precede the 10xx code number with one of	*
C*  the following bias adjustment specification prefixes:		*
C*									*
C*	101		Fedor Mesinger's dH/dF bias adjustment		*
C*	102		Conservation of Odds Ratio bias adjustment	*
C*	103             Fedor Mesinger's dH/dA bias adjustment		*
C*      104             Frequency matching bias removed FHOh[f]	data	*
C*									*
C*  Any of the preceding 10xx series that are N dependent may be	*
C*  computed using F+O-H from the Mth preceding threshold.  The first M	*
C*  thresholds use the original value of N, the total number.  Thres-   *
C*  hold must be the independent variable.  To do this, precede the	*
C*  10xx code with the following prefix:				*
C*									*
C*      20M   The F+O-H value from i-M threshold is used, M>0 and M<10	*
C*									*
C*  The critical performance ratio (CPR) is described in Brill (2009)	*
C*  published in W & F.							*
C*									*
C*	-------		-------						*
C*	1101		Compute BIAS (SAL1L2, SL1L2, ML1L2)		*
C*	1102		Compute RMS error (SAL1L2, SL1L2, ML1L2)	*
C*	1103		Compute Correlation (SAL1L2, SL1L2, ML1L2)	*
C*	1104		Compute Covariance (SAL1L2,SL1L2, ML1L2)	*
C*	1105		Compute Forecast Variance (SAL1L2, SL1L2, ML1L2)*
C*	1106		Compute Obs Variance (SAL1L2, SL1L2, ML1L2)	*
C*	1107		Compute Forecast Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1108		Compute Obs Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1109		Compute Error Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1110		Compute BIAS+Err Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1111		Compute BIAS-Err Std Dev (SAL1L2, SL1L2, ML1L2)	*
C*	1112		Compute BIAS**2					*
C*	1113		Compute -2*Covariance				*
C*	1114		Compute Error Variance				*
C*	1115		Compute Mean Squared Error			*
C*	1116		Scalar ensemble statistical consistency index   *
C*									*
C*  See RSMP_CAL for documentation of prefixes 10, 11, 12, and 13 to	*
C*  1101--1115 above.							*
C*									*
C*	1201		Compute speed BIAS (VAL1L2, VL1L2)		*
C*	1202		Compute vector RMS error (VAL1L2, VL1L2)	*
C*	1203		Compute vector Correlation (VAL1L2, VL1L2)	*
C*	1204		Compute vector Covariance (VAL1L2,VL1L2)	*
C*	1205		Compute vector Forecast Variance (VAL1L2, VL1L2)*
C*	1206		Compute vector Obs Variance (VAL1L2, VL1L2)	*
C*	1207		Compute vector Forecast Std Dev (VAL1L2, VL1L2)	*
C*	1208		Compute vector Obs Std Dev (VAL1L2, VL1L2)	*
C*	1209		Compute U comp BIAS (VAL1L2, VL1L2)		*
C*	1210		Compute V comp BIAS (VAL1L2, VL1L2)		*
C*	1211		Compute vector BIAS magnitude (VAL1L2, VL1L2)	*
C*	1212		Compute vector Error Std Dev (VAL1L2, VL1L2)	*
C*	1213		Compute vector BIAS**2				*
C*	1214		Compute -2 * (vector Covariance)		*
C*	1215		Compute vector Error Variance			*
C*	1216		Compute vector Mean Squared Error		*
C*	1217		Vector ensemble statistical consistency index   *
C*									*
C*	1301		Compute Panofsky-Brier Score for PBS_WWX stat	*
C*	1302		Compute frequency of observation exceeding	*
C*			  threshold for	the no risk category		*
C*	1303		Compute frequency of observation exceeding	*
C*			  threshold for	the low risk category		*
C*	1304		Compute frequency of observation exceeding	*
C*			  threshold for	the moderate risk category	*
C*	1305		Compute frequency of observation exceeding	*
C*			  threshold for	the high risk category		*
C*	1306		Compute target Brier Score for PBS_WWX stat	*
C*            For low + moderate + high risk categories:		*
C*	1307		Compute BIAS Score from PBS values		*
C*	1308		Compute Equitable Threat Score from PBS values	*
C*	1309		Compute Critical Success Index from PBS values	*
C*	1310		Compute False Alarm Ratio from PBS values	*
C*	1311		Compute Postagreement from PBS values		*
C*	1312		Compute Prefigurance from PBS values		*
C*	1313		Compute Probability of Detection from PBS values*
C*	1314		Compute Threat Score from PBS values		*
C*            For moderate + high risk categories:			*
C*	1315		Compute BIAS Score from PBS values		*
C*	1316		Compute Equitable Threat Score from PBS values	*
C*	1317		Compute Critical Success Index from PBS values	*
C*	1318		Compute False Alarm Ratio from PBS values	*
C*	1319		Compute Postagreement from PBS values		*
C*	1320		Compute Prefigurance from PBS values		*
C*	1321		Compute Probability of Detection from PBS values*
C*	1322		Compute Threat Score from PBS values		*
C*            For high risk category:					*
C*	1323		Compute BIAS Score from PBS values		*
C*	1324		Compute Equitable Threat Score from PBS values	*
C*	1325		Compute Critical Success Index from PBS values	*
C*	1326		Compute False Alarm Ratio from PBS values	*
C*	1327		Compute Postagreement from PBS values		*
C*	1328		Compute Prefigurance from PBS values		*
C*	1329		Compute Probability of Detection from PBS values*
C*	1330		Compute Threat Score from PBS values		*
C*            Overall sums:						*
C*	1331		Total number in forecast risk areas (2+3+4)*N 	*
C*	1332		Total number > threshold (5+6+7+8)*N		*
C*            For low + moderate + high risk categories:		*
C*	1333		Compute Heidke Skill Score from PBS values	*
C*	1334		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1335		Compute ODDS RATIO				*
C*	1336		Compute log of ODDS RATIO			*
C*	1337		Compute Standard Error of log of ODDS RATIO	*
C*	1338		Compute ODDS RATIO Skill Score			*
C*	1339		Compute ODDS RATIO Skill Score Cubed		*
C*            For moderate + high risk categories:			*
C*	1340		Compute Heidke Skill Score from PBS values	*
C*	1341		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1342		Compute ODDS RATIO				*
C*	1343		Compute log of ODDS RATIO			*
C*	1344		Compute Standard Error of log of ODDS RATIO	*
C*	1345		Compute ODDS RATIO Skill Score			*
C*	1346		Compute ODDS RATIO Skill Score Cubed		*
C*            For high risk category:					*
C*	1347		Compute Heidke Skill Score from PBS values	*
C*	1348		Compute Peirce-Hanssen-Kuipers Skill Score	*
C*	1349		Compute ODDS RATIO				*
C*	1350		Compute log of ODDS RATIO			*
C*	1351		Compute Standard Error of log of ODDS RATIO	*
C*	1352		Compute ODDS RATIO Skill Score			*
C*	1353		Compute ODDS RATIO Skill Score Cubed		*
C*            For all PBS categories:					*
C*	1354		Compute sample climatological BS (uncertainty)  *
C*	1355		Compute Reliability term of BS decomposition	*
C*	1356		Compute Resolution term of BS decomposition	*
C*	1357		Compute Uncertainty term of BS decomposition	*
C*	1358		Compute Brier Skill Score against sample climo	*
C*      1359            Compute the sample climatological frequency     *
C*      1360		Attribute Diagram for time series of PBS data   *
C*      1361            Compute Extreme Dependency Score (EDS)		*
C*	1362		ROC Curve for time series of PBS data		*
C*	1363		Odds ratio parametric ROC curve for PBS data	*
C*									*
C*      1401            Forecast variance weighted PE			*
C*      1402		Analysis variance weighted PE			*
C*      1403		Forecast variance fraction weighted PE		*
C*      1404		Analysis variance fraction weighted PE		*
C*      1405            Forecast variance fraction			*
C*	1406		Analysis variance fraction			*
C*	1407		Forecast amplitude				*
C*									*
C*	1500		Brier score from BS records			*
C*	150x		Compute average forecast probability for	*
C*			events occurring in category x			*
C*	155x		Compute observed frequency for category x	*
C*      1590            Brier score for sample climatology for BS recs  *
C*									*
C*      1600            Display RHET/RHNT stats as Ranked Histogram     *
C*      1601            Probability analysis lower than ensemble range  *
C*      1602            Probability analysis is within ensemble range   *
C*      1603            Probability analysis is higher than ens range   *
C*      1604            Probability analysis is outside ensemble range  *
C*	1605		Display 1601--1604 as 4-point trace		*
C*	1606		Missing rate error (MRE)			*
C*									*
C*      1700            No-skill fraction based on Ranked Prob Score    *
C*									*
C*      1801		Average directional error for TRK stats		*
C*									*
C*      1901            X direction S1 score from extended SL1L2 norms  *
C*      1902            Y direction S1 score from extended SL1L2 norms  *
C*      1903            Total S1 score from extended SL1L2 norms 	*
C*									*
C*                      Computational codes for ST_MODE records:	*
C*      2001            Intensity bias					*
C*      2002		Area bias					*
C*      2003            Observation to forecast compass direction	*
C*      2004            Probability of detection			*
C*      2005            Threat score					*
C*									*
C*			Computational code for FSS records:		*
C*	2101		Compute the Fractions Skill Score (FSS)		*
C*									*
C*			Computational code for PFR records:		*
C*      2201            Compute P ( F > O | O >= threshold )		*
C*      2202            Compute P ( F > O | F >= threshold )		*
C*      2203            Compute Bias = P ( F > Th ) / P ( O > Th )	*
C*      2204            Compute P ( F > O | F & O >= threshold )	*
C*									*
C*      2301            Compute mean CRPS (Hersbach, 2000)              *
C*      2302            Compute potential CRPS                          *
C*      2303            Compute reliability component of CRPS           *
C*      2304            Resolution component residual for CRPS          *
C*      2305            Uncertainty component estimate for CRPS         *
C*      2306            CRPS skill versus uncertainty                   *
C*      2307            Reliability diagram for percentile levels       *
C*									*
C*	9001		Compute count as fraction of total along trace	*
C*      9002		Trace of data field values avgd ovr all pts	*
C*----------------------------------------------------------------------*
C*									*
C* The missing value flag is RMISS on return.				*
C*									*
C* Note that TRCDAT is a REAL*8 array.					*
C*									*
C* RSMP_CAL ( ITRC, ICOMP, RMISS, NPTS, NDPTH, TRCDAT, TRCMIN, TRCMAX,	*
C*	      IRET )							*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace pair number (1 or 2)	*
C*	ICOMP		INTEGER		Computational code number	*
C*	RMISS		REAL		Missing value			*
C*	NPTS		INTEGER		Number of samples		*
C*	NDPTH		INTEGER		Data depth			*
C*									*
C* Output parameters:							*
C*	TRCDAT (NPTS)	REAL*8		Trace data			*
C*	TRCMIN		REAL		Minimum value in TRCDAT		*
C*	TRCMAX		REAL		Maximum	value in TRCDAT		*
C*	IRET		INTEGER		Return code			*
C*					+02 = all trc pnts missing	*
C*				 	  0 = normal return 		*
C*					 -6 = contextually invalid code *
C*					 -7 = comp code is invalid	*
C*					 -8 = sample is too large	*
C*					 -9 = computation failed	*
C*					-12 = data depth too small	*
C**									*
C* Log:									*
C* K. Brill/HPC      20120327	Adapted from RDTD_TRC			*
C* K. Brill/HPC      20120413   Cleanup return codes			*
C* K. Brill/HPC      20120705   Pass npts (not kpts) to RSMP_EST	*
C* K. Brill/HPC      20120912   Improve error processing		*
C* K. Brill/WPC      20140306	Documentation correction		*
C* K. Brill/WPC      20140506   Change for prefix 104 (bias removed FHO)*
C* K. Brill/IMSG     20160707   Add calls to RDTD_VL2 and CPB_CRPS      *
C* K. Brill/IMSG     20160712   Add comp code 2306                      *
C* K. Brill/IMSG     20170823   Add comp code 1044                      *
C************************************************************************
	INCLUDE		'rsmp.cmn'
C*
	REAL*8		trcdat (*)
C*
	CHARACTER*1	lbltyp
	CHARACTER*64	prmnam
	CHARACTER*24	clbl, cstat
	REAL*8		trcdum (MXRSMP)
	REAL		trcsav (MXRSMP)
	LOGICAL		fhoflg
C*------------------------------------------------------------------------
	iret = 0
	ier0 = 0
	ircs = 0
	ircv = 0
	ircpb = 0
	irstx = 0
C*
	IF ( icomp .eq. 0 ) THEN
	    iret = -7
	    RETURN
	END IF
	IF ( npts .gt. MXRSMP ) THEN
	    iret = -8
	    RETURN
	END IF
	DO i = 1, MXRSMP
	    trcdat (i) = rmiss
	END DO
C
C*	Recall # of members for ensemble metrics and the statistic
C*	type saved by the RDTD library.
C
C*      IMPORTANT NOTE:  All traces are assumed to have the same
C*                       calibration.  If this assumption changes,
C*                       the actual trace numbers to load need to
C*                       be passed back to the RDTD library to get
C*                       the correct calibrations.
C
	CALL RDTD_VAL ( nmem, cstat, lbltyp, prbwwx, npbwwx, ier0 )
	CALL RDTD_VL2 ( crpspl, ncrpsp, ier0 )
C
C*	Check for BIAS adjustment.
C
	fhoflg = ( INDEX ( cstat, 'FHO' ) .gt. 0 )
	IF ( fhoflg .and. ( icomp .gt.  1000000 .or.
     +			    icomp .lt. -1000000 ) .and.
     +       ABS (icomp) .lt. 1050000 ) THEN
	    IF ( icomp .lt. 0 ) THEN
		isgn = -1
		icomp = -icomp
	    ELSE
		isgn = 1
	    END IF
C
C*	    Detect bias adjustment specification prefix.
C
	    iba = INT ( icomp / 10000 )
	    icmp = icomp - iba * 10000
	    icmp = isgn * icmp
	    ibk = 0
	ELSE IF ( fhoflg .and.
     +            ABS (icomp) .gt. 2000000 ) THEN
	    IF ( icomp .lt. 0 ) THEN
		isgn = -1
		icomp = -icomp
	    ELSE
		isgn = 1
	    END IF
C
C*	    Detect backward look for N specification prefix.
C
	    ibk = MOD ( INT ( icomp / 10000 ), 100 )
	    icmp = icomp - (200 + ibk) * 10000
	    icmp = isgn * icmp
	    iba = 0
	ELSE
	    icmp = icomp
	    iba = 0
	    ibk = 0
	END IF
C*
	IF ( iba .eq. 101 ) THEN
	    WRITE (6,*)
	    WRITE (6,*) ' WARNING:  dH/dF bias adjustment is not',
     +                  ' recommended.'
	    WRITE (6,*)
	END IF
	CALL RSMP_BAJ ( itrc, iba, npts, ndpth, iret )
	IF ( iret .ne. 0 ) RETURN
C*
	indx = 0
	trcmax = -1.E30
	trcmin = 1.E30
	ncats = ndpth / 3
	max15 = 1500 + ncats
	mx155 = 1550 + ncats
	IF ( icmp .gt. 1000 .and. icmp .le. 1068 ) THEN
	    IF ( .not. fhoflg .or. ndpth .lt. 4 ) THEN
		iret = -7
		RETURN
	    END IF
	    IF ( icmp .eq. 1001 ) THEN
		CALL CS_BSSK ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1002 ) THEN
		CALL CS_ETSK ( 0, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1003 .or. icmp .eq. 1008 ) THEN
		CALL CS_TSSK ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1004 ) THEN
		CALL CS_FASK ( 0, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1005 ) THEN
		CALL CS_PASK ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1006 .or. icmp .eq. 1007 ) THEN
		CALL CS_PDSK ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1009 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
	    ELSE IF ( icmp .eq. 1010 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
	    ELSE IF ( icmp .eq. 1011 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
	    ELSE IF ( icmp .eq. 1012 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
	    ELSE IF ( icmp .eq. 1013 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
	    ELSE IF ( icmp .eq. 1014 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
	    ELSE IF ( icmp .eq. 1015 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
	    ELSE IF ( icmp .eq. 1016 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
	    ELSE IF ( icmp .eq. 1017 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
	    ELSE IF ( icmp .eq. 1018 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,2,ip)
		END DO
	    ELSE IF ( icmp .eq. 1019 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,3,ip)
		END DO
	    ELSE IF ( icmp .eq. 1020 ) THEN
		DO ip = 1, npts
		    trcdum (ip) = dtrace (itrc,4,ip)
		END DO
	    ELSE IF ( icmp .eq. 1021 ) THEN
		CALL CS_FASK ( 1, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1022 ) THEN
		CALL CS_FASK ( 2, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1023 ) THEN
		CALL CS_ETSK ( 1, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1024 ) THEN
		CALL CS_ETSK ( 2, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1025 ) THEN
		CALL CS_ORSK ( 0, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1026 ) THEN
		CALL CS_ORSK ( 2, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1027 ) THEN
		CALL CS_ORSK ( 3, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1028 ) THEN
		CALL CS_ORSK ( 1, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1029 ) THEN
		CALL CS_ORSK ( 4, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1030 ) THEN
		CALL CS_ORSK ( 5, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1031 ) THEN
		CALL CS_ORSK ( 6, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1032 ) THEN
		WRITE (6,*) ' Box-whisker objects are not ',
     +			    'supported for time series parametric ',
     +			    'ROC curves.'
		iret = -6
		RETURN
	    ELSE IF ( icmp .eq. 1033 ) THEN
		CALL CS_ORSK ( 7, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1034 ) THEN
		CALL CS_CFRK ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1035 ) THEN
		CALL CS_EDSK ( 1, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1036 ) THEN
		CALL CS_CSSK ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1037 ) THEN
		CALL CS_TSBA ( 1, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1038 ) THEN
		CALL CS_TSBA ( 2, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1039 ) THEN
		CALL CS_TSBA ( 3, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1040 ) THEN
		CALL CS_TSBA ( 4, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1041 ) THEN
		CALL CS_EDSK ( 2, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1042 ) THEN
		CALL CS_EDSK ( 3, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1043 ) THEN
		CALL CS_EDSK ( 4, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1044 ) THEN
		CALL CS_2AFC ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .ge. 1051 .and. icmp .le. 1067 ) THEN
C
C*		Compute a CPR value.
C
		icpr = icmp - 1050
		CALL CS_CCPR ( icpr, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, prmnam,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1068 ) THEN
		CALL CS_BMRK ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    END IF
	ELSE IF ( icmp .gt. 1100 .and. icmp .le. 1116 ) THEN
	    IF ( ndpth .lt. 6 ) THEN
		iret = -12
		RETURN
	    END IF
	    IF ( icmp .eq. 1101 ) THEN
		CALL CS_BIAS ( 0, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1102 ) THEN
		CALL CS_RMSE ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1103 ) THEN
		CALL CS_CORR ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1104 ) THEN
		CALL CS_COVA ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1105 ) THEN
		CALL CS_FVAR ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1106 ) THEN
		CALL CS_OVAR ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1107 ) THEN
		CALL CS_FSTD ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1108 ) THEN
		CALL CS_OSTD ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1109 ) THEN
		CALL CS_ESIG ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1110 .or.
     +		      icmp .eq. 1111 ) THEN
		IF ( icmp .eq. 1110 ) THEN
		    sign = 1.0
		ELSE
		    sign = -1.0
		END IF
		CALL CS_BIAS ( 0, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
		DO ip = 1, npts
		    trcsav (ip) = trcdum (ip)
		END DO
		CALL CS_ESIG ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
		icnt = 0
		trcmax = -1.E30
		trcmin = 1.E30
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss .and.
     +			 trcsav (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcsav (ip) + sign * trcdum (ip)
			IF ( trcdum (ip) .gt. trcmax )
     +			    trcmax = trcdum (ip)
			IF ( trcdum (ip) .lt. trcmin )
     +			    trcmin = trcdum (ip)
			icnt = icnt + 1
		    ELSE
			trcdum (ip) = rmiss
		    END IF
		END DO
		IF ( icnt .eq. 0 ) THEN
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
	    ELSE IF ( icmp .eq. 1112 ) THEN
		CALL CS_BIAS ( 0, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
		icnt = 0
		trcmax = -1.E30
		trcmin = 1.E30
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			IF ( trcdum (ip) .gt. trcmax )
     +			    trcmax = trcdum (ip)
			IF ( trcdum (ip) .lt. trcmin )
     +			    trcmin = trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .eq. 0 ) THEN
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
	    ELSE IF ( icmp .eq. 1113 ) THEN
		CALL CS_COVA ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = -2.0 * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    qmax = trcmax
		    trcmax = -2.0 * trcmin
		    trcmin = -2.0 * qmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
	    ELSE IF ( icmp .eq. 1114 ) THEN
		CALL CS_ESIG ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
	    ELSE IF ( icmp .eq. 1115 ) THEN
		CALL CS_RMSE ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		ELSE
		    trcmin = rmiss
		    trcmax = rmiss
		END IF
	    ELSE IF ( icmp .eq. 1116 ) THEN
		CALL CS_ESCI ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, nmem,
     +			       trcdum, trcmin, trcmax, ircs )
	    END IF
	ELSE IF ( icmp .gt. 1200 .and. icmp .le. 1217 ) THEN
	    IF ( ndpth .lt. 8 ) THEN
		iret = -12
		RETURN
	    END IF
	    IF ( icmp .eq. 1201 ) THEN
		CALL CV_BIAS ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1202 ) THEN
		CALL CV_RMSE ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1203 ) THEN
		CALL CV_CORR ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1204 ) THEN
		CALL CV_COVA ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1205 ) THEN
		CALL CV_FVAR ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1206 ) THEN
		CALL CV_OVAR ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1207 ) THEN
		CALL CV_FSTD ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1208 ) THEN
		CALL CV_OSTD ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1209 ) THEN
		CALL CS_BIAS ( 1, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1210 ) THEN
		CALL CS_BIAS ( 2, 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1211 ) THEN
		CALL CV_VBIS ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1212 ) THEN
		CALL CV_ESIG ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
	    ELSE IF ( icmp .eq. 1213 ) THEN
		CALL CV_VBIS ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
	    ELSE IF ( icmp .eq. 1214 ) THEN
		CALL CV_COVA ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = -2.0 * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    qmax = trcmax
		    trcmax = -2.0 * trcmin
		    trcmin = -2.0 * qmax
		END IF
	    ELSE IF ( icmp .eq. 1215 ) THEN
		CALL CV_ESIG ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
	    ELSE IF ( icmp .eq. 1216 ) THEN
		CALL CV_RMSE ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss,
     +			       trcdum, trcmin, trcmax, ircv )
		icnt = 0
		DO ip = 1, npts
		    IF ( trcdum (ip) .ne. rmiss ) THEN
			trcdum (ip) = trcdum (ip) * trcdum (ip)
			icnt = icnt + 1
		    END IF
		END DO
		IF ( icnt .ne. 0 ) THEN
		    trcmin = trcmin * trcmin
		    trcmax = trcmax * trcmax
		END IF
	    ELSE IF ( icmp .eq. 1217 ) THEN
		CALL CV_ESCI ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, nmem,
     +			       trcdum, trcmin, trcmax, ircv )
	    END IF
	ELSE IF ( icmp .gt. 1300 .and. icmp .le. 1306 ) THEN
	    IF ( icmp .eq. 1301 ) THEN
		CALL CPB_SCR ( 0, 2, MXDPTH, ndpth, npts,
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1306 ) THEN
		CALL CPB_SCR ( 1, 2, MXDPTH, ndpth, npts,
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, ircpb )
	    ELSE
C
C*		Compute codes 1302--1305.
C
		nrisk = icmp - 1301
		CALL CPB_FRQ ( 2, MXDPTH, ndpth, npts,
     +			       itrc, dtrace, rmiss, nrisk,
     +			       trcdum, trcmin, trcmax, ircpb )
	    END IF
	    IF ( iret .ne. 0 ) THEN
		iret = -9
		RETURN
	    END IF
	ELSE IF ( icmp .ge. 1307 .and. icmp .le. 1363 ) THEN
C
C*	    Compute skill scores using the PBS numbers.
C
	    IF ( icmp .lt. 1315 .or. ( icmp .ge. 1333 .and.
     +		 icmp .le. 1339 ) ) THEN
		icat = 1
	    ELSE IF ( icmp .lt. 1323 .or. ( icmp .ge. 1340 .and.
     +		      icmp .le. 1346 ) ) THEN
		icat = 2
	    ELSE IF ( icmp .lt. 1331 .or. ( icmp .ge. 1347 .and.
     +		      icmp .le. 1353 ) ) THEN
		icat = 3
	    END IF
	    ndp = ndpth
	    IF ( icmp .eq. 1307 .or. icmp .eq. 1315 .or.
     +		 icmp .eq. 1323 ) THEN
		CALL CPB_BSSK ( 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1308 .or. icmp .eq. 1316 .or.
     +		      icmp .eq. 1324 ) THEN
		CALL CPB_ETSK ( 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1309 .or. icmp .eq. 1317 .or.
     +		      icmp .eq. 1325 ) THEN
		CALL CPB_FASK ( 1, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1310 .or. icmp .eq. 1318 .or.
     +		      icmp .eq. 1326 ) THEN
		CALL CPB_FASK ( 0, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1311 .or. icmp .eq. 1319 .or.
     +		      icmp .eq. 1327 ) THEN
		CALL CPB_PASK ( 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1312 .or. icmp .eq. 1313 .or.
     +		      icmp .eq. 1320 .or. icmp .eq. 1321 .or.
     +		      icmp .eq. 1328 .or. icmp .eq. 1329 ) THEN
		CALL CPB_PDSK ( 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1314 .or. icmp .eq. 1322 .or.
     +		      icmp .eq. 1330 ) THEN
		CALL CPB_TSSK ( 0, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1331 ) THEN
		CALL CPB_SUMS ( 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, 1,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1332 ) THEN
		CALL CPB_SUMS ( 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, 2,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1333 .or. icmp .eq. 1340 .or.
     +		      icmp .eq. 1347 ) THEN
		CALL CPB_TSSK ( 1, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1334 .or. icmp .eq. 1341 .or.
     +		      icmp .eq. 1348 ) THEN
		CALL CPB_TSSK ( 2, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1335 .or. icmp .eq. 1342 .or.
     +		      icmp .eq. 1349 ) THEN
		CALL CPB_TSSK ( 4, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1336 .or. icmp .eq. 1343 .or.
     +		      icmp .eq. 1350 ) THEN
		CALL CPB_TSSK ( 6, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1337 .or. icmp .eq. 1344 .or.
     +		      icmp .eq. 1351 ) THEN
		CALL CPB_TSSK ( 3, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1338 .or. icmp .eq. 1345 .or.
     +		      icmp .eq. 1352 ) THEN
		CALL CPB_TSSK ( 5, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1339 .or. icmp .eq. 1346 .or.
     +		      icmp .eq. 1353 ) THEN
		CALL CPB_TSSK ( 7, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, icat,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1354 ) THEN
		CALL CPB_UREF ( 0, 2, MXDPTH, ndp, npts,
     +			        itrc, dtrace, rmiss, trcdum, trcmin,
     +				trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1355 ) THEN
		CALL CPB_DSCR ( 1, 2, MXDPTH, ndpth, npts,
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1356 ) THEN
		CALL CPB_DSCR ( 2, 2, MXDPTH, ndpth, npts,
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1357 ) THEN
		CALL CPB_DSCR ( 3, 2, MXDPTH, ndpth, npts,
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1358 ) THEN
		CALL CPB_DSCR ( 4, 2, MXDPTH, ndpth, npts,
     +			       itrc, dtrace, rmiss,
     +			       prbwwx (1,itrc), npbwwx (itrc),
     +			       trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1359 ) THEN
		CALL CPB_UREF ( 1, 2, MXDPTH, ndp, npts,
     +			        itrc, dtrace, rmiss, trcdum, trcmin,
     +				trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1360 ) THEN
		WRITE (6,*) ' Box-whisker objects are not yet ',
     +			    'supported for attribute diagrams.'
		iret = -6
		RETURN
C*
	    ELSE IF ( icmp .eq. 1361 ) THEN
		CALL CPB_TSSK ( 8, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss, 1,
     +				trcdat, trcmin, trcmax, ircpb )
		RETURN
	    ELSE IF ( icmp .eq. 1362 ) THEN
		WRITE (6,*) ' Box-whisker objects are not yet ',
     +			    'supported for ROC curves.'
		iret = -6
		RETURN
	    ELSE IF ( icmp .eq. 1363 ) THEN
		WRITE (6,*) ' Box-whisker objects are not yet ',
     +			    'supported for parametric ROC curves.'
		iret = -6
		RETURN
	    END IF
C*
	ELSE IF ( icmp .gt. 1400 .and. icmp .le. 1407 ) THEN
	    IF ( icmp .eq. 1401 .and. lbltyp .ne. 't' ) THEN
		CALL CS_BNOP ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, 4, 4, 5,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1401 ) THEN
		WRITE (6,*) ' Box-whisker objects are not supported ',
     +			    'in this context.'
		iret = -6
		RETURN
	    ELSE IF ( icmp .eq. 1402 .and. lbltyp .ne. 't' ) THEN
		CALL CS_BNOP ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, 4, 6, 7,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1402 ) THEN
		WRITE (6,*) ' Box-whisker objects are not supported ',
     +			    'in this context.'
		iret = -6
		RETURN
	    ELSE IF ( icmp .eq. 1403 ) THEN
		CALL CS_BNOP ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, 4, 4, 10,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1404 ) THEN
		CALL CS_BNOP ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, 4, 6, 11,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1405 ) THEN
		CALL CS_BNOP ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, 4, 5, 10,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1406 ) THEN
		CALL CS_BNOP ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, 4, 7, 11,
     +			       trcdum, trcmin, trcmax, ircs )
	    ELSE IF ( icmp .eq. 1407 ) THEN
		CALL CS_BNOP ( 2, MXDPTH, npts,
     +			       itrc, dtrace, rmiss, 1, 3, 9,
     +			       trcdum, trcmin, trcmax, ircs )
	    END IF
	ELSE IF ( icmp .ge. 1500 .and. icmp .le. max15 ) THEN
	    IF ( icmp .eq. 1500 ) THEN
		CALL CPB_GSCR ( 2, MXDPTH, ndpth, npts,
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, ircpb )
	    END IF
	    IF ( icmp .gt. 1500 ) THEN
		ncat = icmp - 1500
		CALL CPB_GAFP ( ncat, 2, MXDPTH, ndpth, npts,
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, ircpb )
	    END IF
	ELSE IF ( icmp .gt. max15 .and. icmp .le. mx155 ) THEN
	    ncat = icmp - 1550
	    CALL CPB_GOBP ( ncat, 2, MXDPTH, ndpth, npts,
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, ircpb )
	ELSE IF ( icmp .eq. 1590 ) THEN
	    CALL CPB_GUNC ( 2, MXDPTH, ndpth, npts,
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, ircpb )
	ELSE IF ( icmp .ge. 1600 .and. icmp .le. 1606 ) THEN
	    IF ( icmp .eq. 1600 ) THEN
		WRITE (6,*) ' Box-whisker objects are not supported ',
     +			    'in this context (comp code 1600).'
		iret = -6
		RETURN
	    ELSE IF ( icmp .eq. 1601 ) THEN
		ndp = ndpth
		CALL CPB_PANL ( 1, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1602 ) THEN
		ndp = ndpth
		CALL CPB_PANL ( 2, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1603 ) THEN
		ndp = ndpth
		CALL CPB_PANL ( 3, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1604 ) THEN
		ndp = ndpth
		CALL CPB_PANL ( 4, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, ircpb )
	    ELSE IF ( icmp .eq. 1605 ) THEN
		WRITE (6,*) ' Box-whisker objects are not supported ',
     +			    'in this context (comp code 1605).'
		iret = -6
		RETURN
	    ELSE IF ( icmp .eq. 1606 ) THEN
		ndp = ndpth
		CALL CPB_PANL ( 5, 2, MXDPTH, ndp, npts,
     +				itrc, dtrace, rmiss,
     +				trcdum, trcmin, trcmax, ircpb )
	    END IF
	ELSE IF ( icmp .eq. 1700 ) THEN
	    ndp = ndpth
	    CALL CPB_NRPS ( 2, MXDPTH, ndp, npts,
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, ircpb )
	ELSE IF ( icmp .eq. 1801 ) THEN
	    CALL CS_DIRE ( 2, MXDPTH, npts,
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, ircs )
	ELSE IF ( icmp .eq. 1901 ) THEN
	    ndp = ndpth
	    CALL CS_CS1S ( 1, 2, MXDPTH, ndp, npts,
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, ircs )
	ELSE IF ( icmp .eq. 1902 ) THEN
	    ndp = ndpth
	    CALL CS_CS1S ( 2, 2, MXDPTH, ndp, npts,
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, ircs )
	ELSE IF ( icmp .eq. 1903 ) THEN
	    ndp = ndpth
	    CALL CS_CS1S ( 3, 2, MXDPTH, ndp, npts,
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, ircs )
        ELSE IF ( icmp .gt. 2000 .and. icmp .le. 2005 ) THEN
	    IF ( icmp .eq. 2001 ) THEN
	        CALL STX_MODE ( 1, 2, MXDPTH, ndpth, npts,
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, irstx )
	    ELSE IF ( icmp .eq. 2002 ) THEN
	        CALL STX_MODE ( 2, 2, MXDPTH, ndpth, npts,
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, irstx )
	    ELSE IF ( icmp .eq. 2003 ) THEN
	        CALL STX_MODE ( 3, 2, MXDPTH, ndpth, npts,
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, irstx )
	    ELSE IF ( icmp .eq. 2004 ) THEN
	        CALL STX_MODE ( 4, 2, MXDPTH, ndpth, npts,
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, irstx )
	    ELSE IF ( icmp .eq. 2005 ) THEN
	        CALL STX_MODE ( 5, 2, MXDPTH, ndpth, npts,
     +			        itrc, dtrace, rmiss,
     +			        trcdum, trcmin, trcmax, irstx )
	    END IF
        ELSE IF ( icmp .eq. 2101 ) THEN
	    CALL STX_FRSS ( 2, MXDPTH, ndpth, npts,
     +			    itrc, dtrace, rmiss,
     +			    trcdum, trcmin, trcmax, irstx )
        ELSE IF ( icmp .eq. 2201 .or. icmp .eq. 2202 .or.
     +		  icmp .eq. 2203 .or. icmp .eq. 2204 ) THEN
	    kmp = icmp - 2200
	    CALL CS_CPFR ( kmp, 2, MXDPTH, npts,
     +			   itrc, dtrace, rmiss,
     +			   trcdum, trcmin, trcmax, ircs )
        ELSE IF ( icmp .eq. 2301 .or. icmp .eq. 2302 .or.
     +		  icmp .eq. 2303 .or. icmp .eq. 2304 .or.
     +            icmp .eq. 2305 .or. icmp .eq. 2306 ) THEN
	    kmp = icmp - 2300
	    CALL CPB_CRPS ( kmp, 2, MXDPTH, ndpth, npts,
     +                      itrc, dtrace, rmiss,
     +			    crpspl (1,itrc), ncrpsp (itrc),
     +			    trcdum, trcmin, trcmax, ircpb )
        ELSE IF ( icmp .eq. 2307 ) THEN
	    WRITE (6,*) ' Box-whisker objects are not supported ',
     +			'for CRPS reliability diagrams.'
	    iret = -6
	    RETURN
	ELSE IF ( icmp .eq. 9001 ) THEN
	    WRITE (6,*) ' Box-whisker objects are not supported ',
     +			'for the count fraction.'
	    iret = -6
	    RETURN
	ELSE IF ( icmp .eq. 9002 ) THEN
	    WRITE (6,*) ' Box-whisker objects are not supported ',
     +			'for Comp Code 9002.'
	    iret = -6
	    RETURN
	ELSE IF ( ( icmp .ge. 101101 .and. icmp .le. 101115 ) .or.
     +            ( icmp .ge. 111101 .and. icmp .le. 111115 ) .or.
     +            ( icmp .ge. 121101 .and. icmp .le. 121115 ) .or.
     +            ( icmp .ge. 131101 .and. icmp .le. 131115 ) ) THEN
	     CALL RSMP_TRK ( icmp, itrc, rmiss, trcsav, npts, ndpth,
     +			     trcdat, trcmin, trcmax, iret )
	     IF ( iret .lt. 0 ) RETURN
	     DO ip = 1, npts
		trcdum (ip) = trcdat (ip)
	     END DO
	ELSE IF ( icmp .gt. 1000 ) THEN
	    WRITE (6,*) ' No box-whisker objects are possible. '
	    iret = -6
	    RETURN
	ELSE IF ( icmp .eq. -1 ) THEN
	    WRITE (6,*) ' Box-whisker objects are not supported ',
     +			'for Comp Code -1.'
	    iret = -6
	    RETURN
	ELSE IF ( icmp .lt. -1 .or. icmp .eq. 1 ) THEN
	    CALL RSMP_EST ( itrc, rmiss, icmp, npts, ndpth, trcdum,
     +			    trcmin, trcmax, iret )
	    IF ( iret .lt. 0 ) RETURN
	    indx = ABS (icmp)
	ELSE
	    CALL RSMP_EST ( itrc, rmiss, icmp, npts, ndpth, trcdum,
     +			    trcmin, trcmax, iret )
	    IF ( iret .lt. 0 ) RETURN
	    indx = ABS (icmp)
	END IF
C
C*	Scan for all missing values.
C
	icnt = 0
	DO ip = 1, npts
	    trcdat (ip) = trcdum (ip)
	    IF ( trcdum (ip) .eq. rmiss ) icnt = icnt + 1
	END DO
	IF ( icnt .eq. npts ) THEN
	    iret = +2
	END IF
C
C*	Compute % or accumulated % for ICOMP = 1009--1017.
C
	IF ( icmp .ge. 1009 .and. icmp .le. 1011 ) THEN
	    CALL CS_ACCM ( 1, trcdum, npts, rmiss, clbl, trcdat,
     +			   trcmin, trcmax, ircs )
	END IF
	IF ( icmp .ge. 1012 .and. icmp .le. 1014 ) THEN
	    CALL CS_ACCM ( 0, trcdum, npts, rmiss, clbl, trcdat,
     +			   trcmin, trcmax, ircs )
	END IF
	IF ( icmp .ge. 1015 .and. icmp .le. 1017 ) THEN
	    CALL CS_PCBC ( trcdum, npts, rmiss, trcdat,
     +			   trcmin, trcmax, ircs )
	END IF
	IF ( icmp .ge. 1018 .and. icmp .le. 1020 ) THEN
	    CALL CS_RPBT ( trcdum, npts, rmiss, trcdat,
     +			   trcmin, trcmax, ircs )
	END IF
C
C*	Error processing:
C
	IF ( ircs .ne. 0 ) THEN
	    WRITE (6,*) ' Error code from CS library = ', ircs
	    iret = -14
	ELSE IF ( ircpb .ne. 0 ) THEN
	    WRITE (6,*) ' Error code from CPB library = ', ircpb
	    iret = -14
	ELSE IF ( irstx .ne. 0 ) THEN
	    WRITE (6,*) ' Error code from STX library = ', irstx
	    iret = -14
	ELSE IF ( ier0 .ne. 0 ) THEN
	    WRITE (6,*) ' Unexpected non-zero error code.'
	    iret = -14
	END IF
C*
	RETURN
	END
