	SUBROUTINE SRCH_ADD ( quiet, iret )
C************************************************************************
C* SRCH_ADD								*
C*									*
C* This subroutine applies a set of search conditions to a particular	*
C* record.  If the search conditions are met, data is added to the	*
C* appropriate element of the internal trace array (DTRACE).		*
C*									*
C* The record data is in the COMMON array called RECORD.		*
C*									*
C* If QUIET is set to .true., error message printing is suppressed.	*
C*									*
C* SRCH_ADD ( QUIET, IRET )						*
C*									*
C* Input parameters:							*
C*	QUIET		LOGICAL		Flag to suppress error mesgs	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-16 = parsing error		*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		10/97	Pass KIVNPT (itrc) value to SRCH_CHK	*
C* K. Brill/EMC		 8/98	Added a debug print out feature		*
C* K. Brill/EMC		 3/99   If ICHKPT = -1, dump data at all points *
C* K. Brill/EMC		01/00	FORMAT X to 1X for LINUX; add CATBIN chk*
C* K. Brill/HPC		 3/03	Allow acceptance of a record if one or	*
C*                              more successive dep var srch conditions *
C*				for the same field is satisfied.	*
C* K. Brill/HPC		 3/03	Allow search acceptance of stat type	*
C*				with threshold				*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	LOGICAL		quiet
C*
	CHARACTER	cvrsn*8, cmdl*24, canl*24, crgn*24, cstat*24,
     +			cprm*24, clvl*24, cstth*24
	CHARACTER*24	clist ( MXDVLS )
	CHARACTER*24	clbl ( MXIVCN )
	REAL		rlbl ( MXIVCN )
	REAL		rlist ( MXDVLS )
	REAL		rlvl (2)
	LOGICAL		skip, found, ok, ok2
C*------------------------------------------------------------------------
	iret = 0
	CALL SRCH_RUF ( skip, iret )
	IF ( skip .or. iret .ne. 0 ) RETURN
C
C*	Do detailed parsing of the fields already read.
C
	numrel = MXRDAT
	CALL VSDB_FST ( 'NULL', hfield, numfld, ivrson, crdata, numrel,
     +			cvrsn, cmdl, fh, rfw, cymdhn, rymdhw, rymdhi,
     +			canl, crgn, cstat, cstth, rthrsh, lthflg, cprm,
     +			clvl, rlvl, nlev, reldat, ier )
	IF ( ier .ne. 0 ) THEN
	    IF ( .not. quiet ) CALL VSDB_ERR ( ier, ' ', iii )
	    iret = -16
	    RETURN
	END IF
C
C*	Begin checking.
C
	DO itrc = 1, ntrace
C
C*	    Check dependent variable conditions first.
C
	    ifldl=0
	    ok2 = .false.
	    ok = .true.
	    icnd = 0
	    icmb = kdvcmb (itrc)
	    DO WHILE ( ok .and. icnd .lt. kdvncn (itrc) )
		icnd = icnd + 1
		icode = kdvcod (itrc, icnd)
		ifeld = kdvfld (itrc, icnd)
		nlist = kdvnls (itrc, icnd)
		DO i = 1, nlist
		    clist (i) = cdvcnd (itrc, icnd, i)
		    rlist (i) = rdvcnd (itrc, icnd, i)
		END DO
		CALL SRCH_CHK (
     +				cvrsn, cmdl, fh, rfw, cymdhn, rymdhw,
     +				rymdhi, canl, crgn, cstat, cstth,
     +				rthrsh,
     +				lthflg, cprm, clvl, rlvl, nlev, icmb,
     +				icode, 0, ifeld, clist, rlist, nlist,
     +				.false., ok, clbl, rlbl, ier )
C
C*		If two or more search conditions are for the same
C*		field, allow any one (or more) of them to match.
C
		IF ( icnd .lt. kdvncn (itrc) ) THEN
		    ifdnx = kdvfld (itrc, icnd+1)
		ELSE
		    ifdnx = 0
		END IF
		IF ( ifeld .eq. ifdnx ) THEN
		    IF ( .not. ok2 ) ok2 = ok
		    ok = .true.
		    ifldl = ifeld
		ELSE IF ( ifeld .eq. ifldl ) THEN
		    IF ( .not. ok2 ) ok2 = ok
		    ok = ok2
		    ok2 = .false.
		    ifldl = 0
		ELSE
		    ok2 = .false.
		    ifldl = 0
		END IF
		IF ( .not. quiet ) CALL VSDB_ERR ( ier , ' ', iii )
	    END DO
	    IF ( ok ) THEN
C
C*		Check independent variable conditions.
C
		ipt = 0
		found = .false.
		DO WHILE ( .not. found .and. ipt .lt. kivnpt (itrc) )
		    ipt = ipt + 1
		    icnd = 0
		    ok2 = .true.
		    DO WHILE ( ok2 .and. icnd .lt. kivncn (itrc) )
			icnd = icnd + 1
			icode = kivcod (itrc, icnd, ipt)
			ifeld = kivfld (itrc, icnd)
			DO i = 1, 2
			    clist (i) = civcnd (itrc, icnd, ipt, i)
			    rlist (i) = rivcnd (itrc, icnd, ipt, i)
			END DO
			nlist = 1
			ncdip = kivnpt (itrc)
			CALL SRCH_CHK (
     +				cvrsn, cmdl, fh, rfw, cymdhn, rymdhw,
     +				rymdhi, canl, crgn, cstat, cstth,
     +				rthrsh,
     +				lthflg, cprm, clvl, rlvl, nlev,
     +				icmb, icode, ncdip, ifeld,
     +				clist, rlist, nlist,
     +				.true., ok2, clbl (icnd), rlbl (icnd),
     +				ier )
			IF ( .not. quiet )
     +			        CALL VSDB_ERR ( ier , ' ', iii )
		    END DO
		    found = ok2
		    IF ( found ) THEN
			IF ( ( ldebug .and. ipt .eq. ichkpt ) .or.
     +			     ( ldebug .and. ichkpt .eq. -1 ) ) THEN
			    ieq = INDEX ( record, '=' ) - 2
			    icnt = NINT ( reldat (1) )
			    IF ( MOD ( kntdmp, 50 ) .eq. 0 ) THEN
				WRITE (lundbo, 1000)
1000				FORMAT ( ' TRC #  POINT #  DATA COUNT',
     +					 '    RECORD HEADER ----' )
			    END IF
			    WRITE (lundbo,1001) itrc, ipt, icnt,
     +						record (1:ieq)
1001			    FORMAT (1X,I4,2X,I7,3X,I10,1X,A)
			    kntdmp = kntdmp + 1
			END IF
C
C*			Load the data into internal storage.
C
			CALL SRCH_LOD ( itrc, ipt, clbl, rlbl, iret )
			IF ( lunout .gt. 0 ) THEN
			    CALL ST_LSTR ( record, lng, ier )
			    WRITE ( lunout, '(A)' ) record (1:lng)
			END IF
C
C*			Allow data point to fall into more than one
C*			bin.
C
			found = ( .not. catbin (itrc) )
		    END IF
		END DO
	    END IF
	END DO
C*
	RETURN
	END
