	SUBROUTINE SRCH_CBN ( iret )
C************************************************************************
C* SRCH_CBN								*
C*									*
C* This subroutine combines trace data at trace point locations.	*
C*									*
C* SRCH_CBN ( IRET )							*
C*									*
C* Input parameters:							*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +2 = some trace has 0 points	*
C*				 	  0 = normal return 		*
C*					-36 = no data combination	*
C*					-48 = kinds of traces differ	*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		10/97	Changes for DTRACE initially missing	*
C* K. Brill/EMC		11/97	Re-do for post-search combination	*
C* K. Brill/EMC		 2/98	Changes for KMATCH			*
C* K. Brill/EMC		 3/98	Check for 0 length trace		*
C* K. Brill/EMC		 4/98	Add call to SRCH_TM2			*
C* K. Brill/EMC		 8/98	CALL SRCH_NCC for all traces in DCP 15	*
C* K. Brill/EMC		10/98	Use KPRCNT to get loss tolerance %	*
C* K. Brill/EMC		 1/99	Allow data combination case be input	*
C* K. Brill/EMC		 4/99	Print out search diagnostic counts	*
C* K. Brill/EMC		 1/99	CALL SRCH_LMS to find missing traces	*
C* K. Brill/HPC		12/01	CALL new routine SRCH_STT for DCP # 03	*
C* K. Brill/HPC		 5/02	CALL new routine SRCH_STT for DCP # 11	*
C* K. Brill/HPC		 5/03	Use high variable data path (SRCH_NCC)	*
C*				for MFQEQ0 only if NO != 0		*
C* K. Brill/HPC		 5/03	Allow padding for any bin condition	*
C* K. Brill/HPC		12/03	Remove MFQEQ0 check for DCP # 08 & 11	*
C* K. Brill/HPC         05/11	Homogenize trace point labels for	*
C*				traces with conditionally determined	*
C*				independent variable bins		*
C* K. Brill/HPC         02/12   Changes for uncombined data output	*
C* K. Brill/HPC	        03/12	Eliminate check for ucd.ctl file	*
C* K. Brill/HPC         03/13   Call SRCH_DSC not SRCH_CSC for DCP # 06	*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		iothr (MXTRCS),
C*			    list of trace #s associated with current one
     +			imstr (MXTRCS),
C*			    number of master trace for each trace
     +			kind (MXTRCS),
C*			    kind of trace (1=time series, 0=other)
     +			mstfrq (MXTRCS),
C*			    the most frequent data count value
     +			mstart (MXTRCS)
C*			    the first trace point with MSTFRQ count
	REAL		ratio (MXTRCS)
C*			    # with MSTFRQ / NDATAP
	CHARACTER	errstr*32, ctrc*4, cyes*3
	LOGICAL		ok, mfqeq0, dopad, hmgnz, rsam, csam, lucd
C*------------------------------------------------------------------------
	iret = 0
C
C*	Set trace tracking arrays to zero.
C
	DO i = 1, MXTRCS
	    iothr (i) = 0
	    imstr (i) = 0
	    kind (i) = 0
	    mstfrq (i) = 0
	    mstart (i) = 0
	    ratio (i) = 0
	END DO
	mfqeq0 = .false.
	hmgnz = .false.
	n1 = 0
C
C*	Check for the uncombined data output control file:  ucd.ctl
C##	NOTE:  This check was removed during testing 3/23/12.
C
C#	INQUIRE  ( FILE = 'ucd.ctl', EXIST = okwucd, IOSTAT = ier )
C
C# REMOVED--	Open the control file, read, and check for "yes":
C
	lucd = .true.
	okwucd = .true.
C
C#	IF ( okwucd ) THEN
C#	    OPEN ( UNIT = lunucd, FILE = 'ucd.ctl',  STATUS = 'OLD',
C#     +         	   ACCESS = 'SEQUENTIAL',  IOSTAT = iostat )
C#            IF ( iostat .eq. 0 ) THEN
C#	        cyes = ' '
C#	        READ ( lunucd, '(A3)', IOSTAT = iostat ) cyes
C#		CALL ST_LCUC ( cyes, cyes, ier )
C#	        okwucd = ( cyes .eq. 'YES' .and. iostat .eq. 0 )
C#	    ELSE
C#	        okwucd = .false.
C#	    END IF
C#	    CLOSE ( UNIT = lunucd )
C#	ELSE
C#	    lucd = .false.
C#	END IF
C#	IF ( .not. okwucd .and. lucd ) THEN
C#	    WRITE (6,*) 'ucd.ctl file was found but is NOT valid.'
C#	    WRITE (6,*) ' NO uncombined data for significance tests',
C#     +			' will be written . . . continuing.'
C#	END IF
C*
	idnn = ndepth (1)
	DO it = 1, ntrace
	    ok = ( ndatap (it) .gt. 0 )
	    lucd =
     +          ( lucd .and. ( ok .and. ( idnn .eq. ndepth (it) ) ) )
	    dopad = ( kivnpt (it) .gt. 1 )
C
C*	    Determine kind (1=time series, 0=other) of trace.  
C
	    IF ( kivncn (it) .eq. 1 .and. kivfld (it,1) .eq. 5 .and.
     +		 kivnpt (it) .eq. 1 ) THEN
		kind (it) = 1
	    ELSE
		kind (it) = 0
	    END IF
	    DO i = 1, kdvncn (it)
		IF ( kdvfld (it,i) .eq. 5 .and.
     +		     kntmax (it) .ne. 1 ) kind (it) = 0
	    END DO
C
C*	    Check for need to homogenize the trace point labels.
C
	    IF ( it .eq. 1 ) then
		hmgnz = ( kivnpt (it) .gt. 1 )
		n1 = ndatap (it)
	    ELSE
		hmgnz = ( kivnpt (it) .gt. 1 .and. ndatap (it) .eq. n1 )
	    END IF
C*
	    i = 0
	    DO WHILE ( .not. dopad .and. i .lt. kivncn (it) )
		i = i + 1
		dopad = ( kivfld (it,i) .eq. 11 )
	    END DO
	    IF ( dopad .and. padzro (it) .and. ok ) THEN
		CALL SRCH_PDZ ( it, ier )
		IF ( ier .ne. 0 ) THEN
		    CALL SRCH_ERR ( ier, ' ', ierr )
		    RETURN
		END IF
	    END IF
C
C*	    Determine most frequent data count value.
C
	    IF ( kmatch (it) .eq. 0 .and. ok ) THEN
		mstfrq (it) = kounts (it,1)
		mstart (it) = 1
	    ELSE IF ( ok ) THEN
		mstfrq (it) = 0
		icmax = 0
		nleft = ndatap (it)
		istrt = 0
		DO WHILE ( icmax .lt. nleft .and.
     +			   istrt .lt. ndatap (it) )
		    istrt = istrt + 1
		    IF ( kounts (it,istrt) .ne. mstfrq (it) ) THEN
			inum = 1
			DO ii = istrt+1, ndatap (it)
			    IF ( kounts (it,ii) .eq.
     +				 kounts (it,istrt) ) THEN
				inum = inum + 1
			    END IF
			END DO
			IF ( inum .gt. icmax ) THEN
			    icmax = inum
			    mstfrq (it) = kounts (it,istrt)
			    nleft = ndatap (it) - icmax
			    mstart (it) = istrt
			END IF
		    END IF
		END DO
		mfqeq0 = ( mstfrq (it) .eq. 0 )
		ratio (it) = FLOAT ( icmax ) /
     +				FLOAT ( ndatap (it) )
	    END IF
	END DO
C
C*	Open the output file for uncombined data (trace.ucd):
C
	IF ( .not. lucd .and. okwucd ) THEN
	    okwucd = .false.
	    WRITE (6,*)
     +	    ' A trace has zero points, or trace data depths',
     +	    ' differ:'
	    WRITE (6,*)
     +	    ' NO uncombined trace data can be written.'
	END IF

	IF ( okwucd ) THEN
C
C*	    Open the trace.ucd file and write idnn to the first line:
C
	    OPEN ( UNIT = lunucd, FILE = 'trace.ucd',
     +	    STATUS = 'UNKNOWN', FORM='UNFORMATTED',
     +      ACCESS = 'SEQUENTIAL',  IOSTAT = iostat )
	    okwucd = iostat .eq. 0
	    IF ( okwucd ) THEN
		WRITE (lunucd, IOSTAT = iostat ) idnn
	    END IF
	    okwucd = iostat .eq. 0
	    IF ( .not. okwucd ) THEN
		WRITE (6,*)
     +		     ' The trace.ucd file for uncombined data could',
     +		     ' not be opened.'
	        WRITE (6,*)
     +	        ' NO uncombined trace data can be written.'
		CLOSE ( UNIT = lunucd )
	    END IF
	END IF
C
C*	LUCD is set to false here and will be reset to true if
C*      uncombined data is actually written.
C
	lucd = .false.
C
C*	Homogenize the trace point labels if necessary.  This facilitates
C*      consistency checking.  Make character labels unique.
C
	IF ( hmgnz ) THEN
C
C*	    Determine if labels for first trace are already unique.
C
	    rsam = .false.
	    ip = 0
	    DO WHILE ( .not. rsam .and. ip .lt. n1 )
		ip = ip + 1
		jp = ip
		DO WHILE ( .not. rsam .and. jp .lt. n1 )
		    jp = jp + 1
		    rsam = ( rtrcid (1,jp) .eq. rtrcid (1,ip) .and.
     +			     rtrcid (1,ip) .gt. -1.1E30 )
		END DO
	    END DO
	    csam = .false.
	    ip = 0
	    DO WHILE ( .not. csam .and. ip .lt. n1 )
		ip = ip + 1
		jp = ip
		DO WHILE ( .not. csam .and. jp .lt. n1 )
		    jp = jp + 1
		    csam = ( ctrcid (1,jp) .eq. ctrcid (1,ip) .and.
     +			     ctrcid (1,ip) .ne. ' ' )
		END DO
	    END DO
C*
	    IF ( csam ) THEN
		WRITE (6,*) ' Differentiating text trace point IDs.'
C
C*	        Reset the character IDs for the first trace.
C
	        DO ip = 1, n1
		    CALL ST_INCH ( ip, ctrc, ier )
		    CALL ST_LSTR ( ctrc, lxn, ier )
		    ctrcid (1,ip) = ctrc(1:lxn) // ctrcid (1,ip)
	        END DO
	    END IF
	    IF ( rsam ) THEN
		WRITE (6,*) ' Differentiating numeric trace point IDs.'
C
C*	        Reset the floating point IDs for the first trace.
C
	        DO ip = 1, n1
		    rtrcid (1,ip) = FLOAT (ip)
	        END DO
	    END IF
C*
	    IF ( ntrace .gt. 1 ) THEN
	   	DO it = 2, ntrace
		    DO ip = 1, n1
			ctrcid (it,ip) = ctrcid (1,ip)
		    	rtrcid (it,ip) = rtrcid (1,ip)
		    END DO
	    	END DO
	    END IF
	END IF
C
C*	Loop over all traces.
C
	DO it = 1, ntrace
	    ok = ( ndatap (it) .gt. 0 )
	    IF ( ok ) THEN
C
C*	        Locate associated traces.
C
		icase = -999
	        no = 0
		IF ( imstr (it) .eq. 0 .and. ntrace .gt. 1 .and. ok )
     +		THEN
		    DO j = it+1, ntrace
			IF ( idnmbr (it) .eq. idnmbr (j) .and.
     +			     imstr (j) .eq. 0 .and. ndatap (j) .gt. 0 )
     +			THEN
			    no = no + 1
			    iothr (no) = j
			    imstr (j) = it
			    IF ( kind (j) .ne. kind (it) ) THEN
				iret = -48
				RETURN
			    END IF
			END IF
		    END DO
		    iothr (no+1) = it
		END IF
C
C*		Count the number of zero point to point differences
C*		among traces in a multi-trace plot.
C
		IF ( no .gt. 0 .and. kmatch (it) .ne. 0 .and.
     +		     kmcase (it) .eq. 0 ) THEN
C
C*		    Use the old method of computing ICASE.
C
		    num = no + 1
		    CALL SRCH_CSC ( num, iothr, .true., rchk, ier )
		    ratmin = 1.1E31
		    DO ii = 1, num
			jt = iothr (ii)
			IF ( ratio (jt) .lt. ratmin )
     +				ratmin = ratio (jt)
		    END DO
		    rdiff = ABS ( ratmin - rchk )
		    prct = 1. - FLOAT ( kprcnt (it) ) / 100.0
		    IF ( rchk .ge. prct .and. ratmin .ge. prct .and.
     +			 rdiff .le. (prct / 2.) ) THEN
			icase = 3
		    ELSE IF ( rchk .gt. ratmin .and.
     +			      rchk .ge. prct ) THEN
			icase = 2
		    ELSE IF ( ratmin .gt. rchk .and.
     +			      ratmin .ge. prct ) THEN
			icase = 1
		    ELSE
			icase = 0
		    END IF
		ELSE IF ( no .gt. 0 .and. kmatch (it) .ne. 0 ) THEN
		    icase = kmcase (it)
		END IF
C*
		IF ( kmatch (it) .eq. 0 ) THEN
		    WRITE (6,*) ' DCP # 01'
		    WRITE (6,*) ' NO DATA COMBINATION RESTRICTIONS'
		    CALL SRCH_NCC ( it, mstfrq (it), iret )
C
C*		Single trace data combination.
C
		ELSE IF ( no .eq. 0 .and. kmatch (it) .eq. 1 .and.
     +			  kind (it) .eq. 0 .and. .not. mfqeq0 .and.
     +			  imstr (it) .eq. 0 ) THEN
		    WRITE (6,*) ' DCP # 02'
		    WRITE (6,*)
     +			' SINGLE TRACE OF POINTS WITH ', mstfrq (1),
     +			' CONTRIBUTIONS'
		    CALL SRCH_CMC ( 1, it, mstfrq, mstart, iret )
		ELSE IF ( no .eq. 0 .and. kmatch (it) .eq. 2 .and.
     +			  kind (it) .eq. 0 .and. .not. mfqeq0 .and.
     +			  imstr (it) .eq. 0  ) THEN
		    WRITE (6,*) ' DCP # 03'
		    WRITE (6,*)
     +			' SINGLE TRACE WITH IDENTICAL VERIFICATION',
     +			' TIMES CONTRIBUTING AT ALL POINTS'
		    CALL SRCH_STT ( it, iret )
		ELSE IF ( no .eq. 0 .and. kind (it) .eq. 1 .and.
     +			  .not. mfqeq0 .and.
     +			  imstr (it) .eq. 0  ) THEN
		    WRITE (6,*) ' DCP # 04'
		    WRITE (6,*)
     +			' SINGLE TIME SERIES OF POINTS WITH ',
     +			mstfrq (1), ' CONTRIBUTIONS'
		    CALL SRCH_CMC ( 1, it, mstfrq, mstart, iret )
C
C*		Multiple time series trace data combination.
C
		ELSE IF ( no .gt. 0 .and.
     +			  kind (it) .eq. 1 .and. icase .eq. 1 .and.
     +			  .not. mfqeq0 ) THEN
		    WRITE (6,*) ' DCP # 05'
		    WRITE (6,*)
     +			' MULTIPLE TIME SERIES--EACH WITH SAME #',
     +			' OF CONTRIBUTIONS AT EACH POINT'
		    WRITE (6,*)
     +			' NUMBER OF CONTRIBUTIONS MAY DIFFER AMONG',
     +			' TRACES'
		    num = no + 1
		    CALL SRCH_CMC ( num, iothr, mstfrq, mstart, iret )
		    IF ( kmatch (it) .eq. 2 .and. iret .ge. 0 ) THEN
			WRITE (6,*)
     +			' POINTS NOT FOUND IN ALL TRACES ELIMINATED'
			CALL SRCH_TM2 ( num, iothr, iret )
		    END IF
		ELSE IF ( no .gt. 0 .and.
     +			  kind (it) .eq. 1 .and. icase .eq. 2 ) THEN
		    WRITE (6,*) ' DCP # 06'
		    WRITE (6,1001)
1001		    FORMAT (' MULTIPLE TIME SERIES--ALL TRACES HAVE',
     +			' SAME # OF CONTRIBUTIONS AT A POINT' )
		    WRITE (6,*)
     +			' NUMBER OF CONTRIBUTIONS MAY DIFFER FROM',
     +			' POINT TO POINT'
		    num = no + 1
		    CALL SRCH_DSC ( num, iothr, iret )
		    IF ( kmatch (it) .eq. 2 .and. iret .ge. 0 ) THEN
			WRITE (6,*)
     +			' POINTS NOT FOUND IN ALL TRACES ELIMINATED'
			CALL SRCH_TM2 ( num, iothr, iret )
		    END IF
		ELSE IF ( no .gt. 0 .and.
     +			  kind (it) .eq. 1 .and. icase .eq. 3 ) THEN
		    WRITE (6,*) ' DCP # 07'
		    WRITE (6,*)
     +			' MULTIPLE TIME SERIES--# OF CONTRIBUTIONS',
     +			' IS IDENTICAL AT ALL POINTS IN ALL TRACES'
		    num = no + 1
		    CALL SRCH_CMS ( num, iothr, iret )
		    IF ( kmatch (it) .eq. 2 .and. iret .ge. 0 ) THEN
			WRITE (6,*)
     +			' POINTS NOT FOUND IN ALL TRACES ELIMINATED'
			CALL SRCH_TM2 ( num, iothr, iret )
		    END IF
C
C*		Multiple non-time series trace data combination.
C
		ELSE IF ( no .gt. 0 .and. kind (it) .eq. 0 .and.
     +			  kmatch (it) .eq. 1 .and. icase .eq. 1 ) THEN
		    WRITE (6,*) ' DCP # 08'
		    WRITE (6,*)
     +			' MULTIPLE TRACES--EACH WITH SAME #',
     +			' OF CONTRIBUTIONS AT EACH POINT'
		    WRITE (6,*)
     +			' NUMBER OF CONTRIBUTIONS MAY DIFFER AMONG',
     +			' TRACES'
		    num = no + 1
		    CALL SRCH_CMC ( num, iothr, mstfrq, mstart, iret )
		ELSE IF ( no .gt. 0 .and. kind (it) .eq. 0 .and.
     +			  kmatch (it) .eq. 1 .and. icase .eq. 2 ) THEN
		    WRITE (6,*) ' DCP # 09'
		    WRITE (6,*)
     +			' MULTIPLE TRACES--ALL TRACES HAVE',
     +			' SAME # OF CONTRIBUTIONS AT A POINT'
		    WRITE (6,*)
     +			' NUMBER OF CONTRIBUTIONS MAY DIFFER FROM',
     +			' POINT TO POINT'
		    num = no + 1
		    CALL SRCH_CSC ( num, iothr, .false., rr, iret )
		ELSE IF ( no .gt. 0 .and. kind (it) .eq. 0 .and.
     +			  kmatch (it) .eq. 1 .and. icase .eq. 3 ) THEN
		    WRITE (6,*) ' DCP # 10'
		    WRITE (6,*)
     +			' MULTIPLE TRACES--# OF CONTRIBUTIONS',
     +			' IS IDENTICAL AT ALL POINTS IN ALL TRACES'
		    num = no + 1
		    CALL SRCH_CMS ( num, iothr, iret )
C*
		ELSE IF ( no .gt. 0 .and. kind (it) .eq. 0 .and.
     +			  kmatch (it) .eq. 2 .and. icase .eq. 1 ) THEN
		    WRITE (6,*) ' DCP # 11'
		    WRITE (6,*)
     +			' MULTIPLE TRACES--ALL POINTS OF EACH TRACE',
     +			' HAVE SAME CONTRIBUTING VERIFICATION TIMES'
		    WRITE (6,*)
     +			' VERIFICATION TIME DISTRIBUTION MAY VARY',
     +			' AMONG TRACES'
		    num = no + 1
C---		    CALL SRCH_DMC ( num, iothr, iret )
		    DO iqt = 1, num
			itrc = iothr (iqt)
			CALL SRCH_STT ( itrc, iret )
		    END DO
		ELSE IF ( no .gt. 0 .and. kind (it) .eq. 0 .and.
     +			  kmatch (it) .eq. 2 .and. icase .eq. 2 ) THEN
		    WRITE (6,*) ' DCP # 12'
		    WRITE (6,*)
     +			' MULTIPLE TRACES--ALL TRACES HAVE SAME',
     +			' VERIFICATIONS TIMES AT A POINT'
		    WRITE (6,*)
     +			' VERIFICATION TIMES MAY DIFFER FROM',
     +			' POINT TO POINT'
		    num = no + 1
		    CALL SRCH_DSC ( num, iothr, iret )
		    lucd = iret .eq. 0
		ELSE IF ( no .gt. 0 .and. kind (it) .eq. 0 .and.
     +			  kmatch (it) .eq. 2 .and. icase .eq. 3 .and.
     +			  .not. mfqeq0 ) THEN
		    WRITE (6,*) ' DCP # 13'
		    WRITE (6,*)
     +			' MULTIPLE TRACES--ALL HAVE THE SAME',
     +			' VERIFICATION TIMES AT ALL POINTS'
		    num = no + 1
		    CALL SRCH_DMS ( num, iothr, mstfrq, mstart, iret )
		    lucd = iret .eq. 0
		ELSE IF ( no .gt. 0 .and. mfqeq0 ) THEN
		    WRITE (6,*) ' DCP # 14'
		    WRITE (6,*) ' HIGHLY VARIABLE DATA COUNTS'
		    WRITE (6,*)
     +			' ALL DATA COMBINATION RESTRICTIONS LIFTED'
		    CALL SRCH_NCC ( it, mstfrq (it), iret )
		ELSE IF ( icase .eq. 0 ) THEN
		    iprct = 100 - kprcnt (it)
		    WRITE (6,*) ' DCP # 15'
		    WRITE (6,1002) ' LESS THAN ',
     +			iprct, '% OF DATA ON ONE OR MORE TRACES'
1002		    FORMAT ( A, I3, A )
		    WRITE (6,*)
     +			' MEETS THE DATA COMBINATION RESTRICTIONS'
		    WRITE (6,*)
     +			' ALL DATA COMBINATION RESTRICTIONS LIFTED'
		    CALL SRCH_NCC ( it, mstfrq (it), iret )
		    IF ( iret .gt. 0 ) THEN
			CALL ST_INCH ( it, ctrc, ier )
			errstr = 'For trace number ' // ctrc
			CALL SRCH_ERR ( iret, errstr, iier )
			iret = 0
		    END IF
		    i = 0
		    DO WHILE ( i .lt. no .and. iret .eq. 0 )
			i = i + 1
			itc = iothr (i)
			CALL SRCH_NCC ( itc, mstfrq (itc), iret )
			IF ( iret .gt. 0 ) THEN
			    CALL ST_INCH ( it, ctrc, ier )
			    errstr = 'For trace number ' // ctrc
			    CALL SRCH_ERR ( iret, errstr, iier )
			    iret = 0
			END IF
		     END DO
		END IF
	        IF ( iret .gt. 0 ) THEN
		    CALL ST_INCH ( it, ctrc, ier )
		    errstr = 'For trace number ' // ctrc
		    CALL SRCH_ERR ( iret, errstr, iier )
		    iret = 0
		ELSE IF ( iret .lt. 0 ) THEN
		    CALL SRCH_KNT ( jer )
		    CALL ST_INCH ( it, ctrc, ier )
		    errstr = 'For trace number ' // ctrc
		    CALL SRCH_ERR ( iret, errstr, iier )
		    iret = -36
		    RETURN
	        END IF
C*
	    ELSE
		iret = +2
		CALL ST_INCH ( it, ctrc, ier )
		errstr = 'For trace number ' // ctrc
		CALL SRCH_ERR ( iret, errstr, iier )
	    END IF
	END DO
C*
	IF ( lucd .and. okwucd ) THEN
	    WRITE (6,*) ' '
	    WRITE (6,*)  ' Uncombined trace data for significance',
     +			 ' testing was written to trace.ucd.'
	    CLOSE ( UNIT = lunucd )
	END IF
C*
	CALL SRCH_KNT ( jer )
	CALL SRCH_LMS ( jer )
C*
	RETURN
	END
