	SUBROUTINE SRCH_CSC ( nt, itrcs, jstcnt, ratio, iret )
C************************************************************************
C* SRCH_CSC								*
C*									*
C* This subroutine combines multiple trace data at point locations at	*
C* which the data count is the same for all traces at that particular	*
C* point.  The counts can vary from point to point.			*
C*									*
C* In order to effect the data combinations, JSTCNT must be .FALSE.	*
C* 									*
C* If JSTCNT is .TRUE., then only a count of the point locations meeting*
C* these conditions is done.  Then the ratio of valid points to total	*
C* points is computed and returned in RATIO.				*
C*									*
C* SRCH_CSC ( NT, ITRCS, JSTCNT, RATIO, IRET )				*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of traces		*
C*	ITRCS (NT)	INTEGER		Array of trace numbers		*
C*	JSTCNT		LOGICAL		Flag to only count points	*
C*									*
C*									*
C* Output parameters:							*
C*	RATIO		REAL		Valid points / total points	*
C*	IRET		INTEGER		Return code			*
C*					 +2 = a trace has 0 points	*
C*				 	  0 = normal return 		*
C*					 -3 = invalid combination code	*
C*					-42 = all traces have 0 points  *
C**									*
C* Log:									*
C* K. Brill/EMC		 3/98						*
C* K. Brill/EMC		 4/99	Data rejection diagnostic count		*
C* K. Brill/HPC		 8/00	DTMSV *12 -> *(NCKCHR)			*
C* K. Brill/HPC		10/02	Set the BINMTY array for conditionally	*
C*				determined ind. variable points		*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		itrcs (*)
	LOGICAL		jstcnt
C*
	INTEGER		ipont (MXTRCS)
	REAL*8		rhold (MXDPTH), r1, rn
	CHARACTER*(NCKCHR)	dtmsv
	LOGICAL		ok, found
C*-----------------------------------------------------------------------
	iret = 0
	ntotl = 0
C
C*	Find the trace with the least number of points.
C
	ijcnt = 0
	lstnu = 2 * MXDPTS
	DO it = 1, nt
	    itrc = itrcs (it)
	    IF ( ndatap (itrc) .lt. lstnu ) THEN
		lstnu = ndatap (itrc)
		mastr = itrc
	    END IF
	END DO
	itotp = ndatap (mastr)
C
C*	Go through the master trace point by point.  Check all other
C*	traces at this point for an identical count.  IF the counts all
C*	match, set KPOINT values negative in the traces.
C
	DO mtp = 1, ndatap (mastr)
	    mcnt = kounts (mastr,mtp)
	    ok = .true.
	    jt = 0
	    DO WHILE ( jt .lt. nt .and. ok )
		jt = jt + 1
		it = itrcs (jt)
		found = .false.
		ipont (jt) = 0
		IF ( it .eq. mastr ) THEN
		    ipont (jt) = mtp
		    found = .true.
		END IF
		ip = 0
		DO WHILE ( ip .lt. ndatap (it) .and. .not. found )
		    ip = ip + 1
		    IF (
     +			ctrcid (it,ip) .eq. ctrcid (mastr,mtp)
     +				.and.
     +			rtrcid (it,ip) .eq. rtrcid (mastr,mtp)
     +		    ) THEN
			IF ( kounts (it,ip) .eq. mcnt ) THEN
			    ipont (jt) = ip
			ELSE
			    ok = .false.
			END IF
			found = .true.
		    END IF
		END DO
		ok = found
	    END DO
	    IF ( ok .and. .not. jstcnt ) THEN
		DO jt = 1, nt
		    it = itrcs (jt)
		    DO i = 1, nxtelm (it)
			IF ( kpoint (it,i) .eq. ipont (jt) ) THEN
			    kpoint (it,i) = - kpoint (it,i)
			END IF
		    END DO
		END DO
	    ELSE IF ( ok ) THEN
		jt = 0
		DO WHILE ( jt .lt. nt .and. ipont (jt+1) .ne. 0 )
		    jt = jt + 1
		END DO
		IF ( jt .eq. nt ) ijcnt = ijcnt + 1
	    END IF
	END DO
C*
	ratio = FLOAT ( ijcnt ) / FLOAT ( itotp )
	IF ( jstcnt ) RETURN
C
C*	Now combine data for all points where KPOINT is negative.
C
	DO it = 1, nt
	    iaccp = 0
	    itrc = itrcs (it)
	    ndat = 0
	    DO ipnt = 1, ndatap (itrc)
		DO jd = 1, ndepth (itrc)
		    rhold (jd) = 0.0
		END DO
		in = 0
		icnt = 0
		DO WHILE ( in .lt. nxtelm (itrc) .and.
     +			   icnt .lt. kounts (itrc,ipnt) )
		    in = in + 1
		    IF ( kpoint (itrc,in) .eq. -ipnt ) THEN
			iaccp = iaccp + 1
			iswap = in
			dtmsv = conchk (itrc,in)
			icnt = icnt + 1
			IF ( kdvcmb (itrc) .eq. 0 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 1 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = rhold (jd) +
     +						 dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 2 ) THEN
			    DO jd = 1, ndepth (itrc)
				IF ( jd .eq. indxdc (itrc) ) THEN
				    rhold (jd) = rhold (jd) +
     +						     dtrace (itrc,jd,in)
				ELSE
				    r1 = dtrace (itrc,indxdc(itrc),in)
				    rn = dtrace (itrc,jd,in)
				    rhold (jd) = rhold (jd) + r1 * rn
				END IF
			    END DO
			ELSE 
			    iret = -3
			    RETURN
			END IF
		    END IF
		END DO
		IF ( icnt .gt. 0 ) THEN
		    ndat = ndat + 1
		    DO jd = 1, ndepth (itrc)
			dtrace (itrc,jd,iswap) = dtrace (itrc,jd,ndat)
			dtrace (itrc,jd,ndat) = rhold (jd)
		    END DO
		    conchk (itrc,iswap) = conchk (itrc,ndat)
		    conchk (itrc,ndat) = dtmsv
		    kpoint (itrc,iswap) = kpoint (itrc,ndat)
		    kpoint (itrc,ndat) = ipnt
C
C*		    Set counts and labels for this point.
C
		    kounts (itrc,ndat) = icnt
		    ctrcid (itrc,ndat) = ctrcid (itrc,ipnt)
		    rtrcid (itrc,ndat) = rtrcid (itrc,ipnt)
		ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
		    binmty (itrc,ipnt) = .true.
		END IF
	    END DO
C
C*	    Set final data count for this trace.
C
	    ndatap (itrc) = ndat
	    ntotl = ntotl + ndat
	    IF ( ndat .eq. 0 ) iret = +2
	    kaccpt (itrc) = iaccp
	END DO
	IF ( ntotl .eq. 0 ) iret = -42
C*
	RETURN
	END
