	SUBROUTINE SRCH_DMC ( nt, itrcs, iret )
C************************************************************************
C* SRCH_DMC								*
C*									*
C* This subroutine combines trace data in such a way that all points	*
C* contain the same number of each contributing verification times.	*
C* The verification time distribution can vary from one trace to the	*
C* next.								*
C* 									*
C*									*
C* SRCH_DMC ( NT, ITRCS, IRET )						*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of traces		*
C*	ITRCS (NT)	INTEGER		Array of trace numbers		*
C*									*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +2 = a trace has 0 points	*
C*				 	  0 = normal return 		*
C*					 -3 = invalid combination code	*
C*					-43 = all traces have 0 points  *
C**									*
C* Log:									*
C* K. Brill/EMC		 3/98						*
C* K. Brill/EMC		 4/98	Took out MFQ and MSTRT input parms	*
C* K. Brill/EMC		 4/99	Data rejection diagnostic count		*
C* K. Brill/HPC		 8/00	DTMSV *12 -> *(NCKCHR)			*
C* K. Brill/HPC		10/02	Set the BINMTY array for conditionally	*
C*				determined ind. variable points		*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		itrcs (*)
C*
	REAL*8		rhold (MXDPTH), r1, rn
	CHARACTER*(NCKCHR)	dtmsv
	LOGICAL		ok
C*-----------------------------------------------------------------------
	iret = 0
	ntotl = 0 
C*
	DO kt = 1, nt
	    iaccp = 0
	    it = itrcs (kt)
	    ndat = 0
C
C*	    Find the point on this trace which has a set of conchks that
C*	    is most frequent throughout the trace.  This becomes the
C*	    template point.
C
	    mxfnd = 0
	    mpoin = 0
	    DO ipnt = 1, ndatap (it)
		IF ( kounts (it,ipnt) .gt. 0 ) THEN
		    lfnd = 0
		    DO iop = 1, ndatap (it)
			IF ( iop .ne. ipnt ) THEN
			    ok = .true.
			    inxm = 0
			    DO WHILE ( inxm .lt. nxtelm (it) .and.
     +					ok )
				inxm = inxm + 1
				IF ( kpoint (it,inxm) .eq. ipnt ) THEN
				    dtmsv = conchk (it,inxm)
				    kpoint (it,inxm) =
     +						-kpoint (it,inxm)
				    icnt = 1
				    DO inxm2 = (inxm+1), nxtelm (it)
					IF ( kpoint (it,inxm2) .eq.
     +					     ipnt .and.
     +					     conchk (it,inxm2) .eq.
     +					     dtmsv )
     +					THEN
					    icnt = icnt + 1
					    kpoint (it,inxm2) =
     +						-kpoint (it,inxm2)
					END IF
				    END DO
				    jcnt = 0
				    DO inxs = 1, nxtelm (it)
					IF ( kpoint (it,inxs) .eq. iop
     +						.and.
     +					   conchk (it,inxs) .eq. dtmsv )
     +					THEN
					    jcnt = jcnt + 1
					END IF
				    END DO
				    ok = jcnt .eq. icnt
				END IF
			    END DO
			    IF ( ok ) lfnd = lfnd + 1
			END IF
		    END DO
		    IF ( lfnd .gt. mxfnd ) THEN
			mxfnd = lfnd
			mpoin = ipnt
		    END IF
C
C*		    Reset the flagged points.
C
		    DO inxm = 1, nxtelm (it)
			IF ( kpoint (it,inxm) .lt. 0 )
     +			    kpoint (it,inxm) = -kpoint (it,inxm)
		    END DO
		END IF
	    END DO
C
C*	    Set negative flags at MPOIN.
C
	    DO inxm = 1, nxtelm (it)
		IF ( kpoint (it,inxm) .eq. mpoin ) kpoint (it,inxm) =
     +						    -kpoint (it,inxm)
	    END DO
C
C*	    Now set the flag points, using the master point.
C
	    mtp = mpoin
	    DO iop = 1, ndatap (it)
		IF ( iop .ne. mtp ) THEN
		    ok = .true.
		    inxm = 0
		    DO WHILE ( inxm .lt. nxtelm (it) .and. ok )
			inxm = inxm + 1
			IF ( kpoint (it,inxm) .eq. -mtp ) THEN
			    dtmsv = conchk (it,inxm)
			    kpoint (it,inxm) = -kpoint (it,inxm)
			    icnt = 1
			    inxm2 = inxm
			    DO WHILE ( inxm2 .lt. nxtelm (it) )
				inxm2 = inxm2 + 1
				IF ( kpoint (it,inxm2) .eq. -mtp
     +						.and.
     +				     conchk (it,inxm2) .eq. dtmsv )
     +				THEN
				    icnt = icnt + 1
				    kpoint (it,inxm2) =
     +						-kpoint (it,inxm2)
				END IF
			    END DO
			    jcnt = 0
			    DO inxs = 1, nxtelm (it)
				IF ( kpoint (it,inxs) .eq. iop
     +					 .and.
     +				     conchk (it,inxs) .eq. dtmsv ) THEN
				    jcnt = jcnt + 1
				END IF
			    END DO
			    ok = jcnt .eq. icnt
			END IF
		    END DO
		    IF ( ok ) THEN
			DO inxm = 1, nxtelm (it)
			    IF ( kpoint (it,inxm) .eq. mtp ) THEN
				dtmsv = conchk (it,inxm)
				kpoint (it,inxm) =
     +					-kpoint (it,inxm)
				inxm2 = inxm
				DO WHILE ( inxm2 .lt. nxtelm (it) )
				    inxm2 = inxm2 + 1
				    IF ( kpoint (it,inxm) .eq. mtp
     +						.and.
     +				       conchk (it,inxm2) .eq. dtmsv
     +				    ) THEN
					kpoint (it,inxm2) =
     +						-kpoint (it,inxm2)
				    END IF
				END DO
				DO inxs = 1, nxtelm (it)
				    IF ( kpoint (it,inxs).eq. iop
     +						.and.
     +					 conchk (it,inxs) .eq. dtmsv )
     +				    THEN
					kpoint (it,inxs) =
     +						-kpoint (it,inxs)
				    END IF
				END DO
			    END IF
			END DO
		    ELSE
C
C*		 	Set any positive KPOINT values at the
C*			trace template point back to negative.
C
			DO inxm = 1, nxtelm (it)
			    IF ( kpoint (it,inxm) .eq. mtp )
     +			    kpoint (it,inxm) = - kpoint (it,inxm)
			END DO
		    END IF
		END IF
	    END DO
C
C*	    Now combine data for all points where KPOINT is negative.
C
	    itrc = it
	    DO ipnt = 1, ndatap (itrc)
		DO jd = 1, ndepth (itrc)
		    rhold (jd) = 0.0
		END DO
		in = 0
		icnt = 0
		DO WHILE ( in .lt. nxtelm (itrc) .and.
     +			   icnt .lt. kounts (itrc,ipnt) )
		    in = in + 1
		    IF ( kpoint (itrc,in) .eq. -ipnt ) THEN
			iaccp = iaccp + 1
			iswap = in
			dtmsv = conchk (itrc,in)
			icnt = icnt + 1
			IF ( kdvcmb (itrc) .eq. 0 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 1 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = rhold (jd) +
     +						 dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 2 ) THEN
			    DO jd = 1, ndepth (itrc)
				IF ( jd .eq. indxdc (itrc) ) THEN
				    rhold (jd) = rhold (jd) +
     +						     dtrace (itrc,jd,in)
				ELSE
				    r1 = dtrace (itrc,indxdc(itrc),in)
				    rn = dtrace (itrc,jd,in)
				    rhold (jd) = rhold (jd) + r1 * rn
				END IF
			    END DO
			ELSE 
			    iret = -3
			    RETURN
			END IF
		    END IF
		END DO
		IF ( icnt .gt. 0 ) THEN
		    ndat = ndat + 1
		    DO jd = 1, ndepth (itrc)
			dtrace (itrc,jd,iswap) = dtrace (itrc,jd,ndat)
			dtrace (itrc,jd,ndat) = rhold (jd)
		    END DO
		    conchk (itrc,iswap) = conchk (itrc,ndat)
		    conchk (itrc,ndat) = dtmsv
		    kpoint (itrc,iswap) = kpoint (itrc,ndat)
		    kpoint (itrc,ndat) = ipnt
C
C*		    Set counts and labels for this point.
C
		    kounts (itrc,ndat) = icnt
		    ctrcid (itrc,ndat) = ctrcid (itrc,ipnt)
		    rtrcid (itrc,ndat) = rtrcid (itrc,ipnt)
		ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
		    binmty (itrc,ipnt) = .true.
		END IF
	    END DO
C
C*	    Set final data count for this trace.
C
	    ndatap (itrc) = ndat
	    ntotl = ntotl + ndat
	    IF ( ndat .eq. 0 ) iret = +2
	    kaccpt (itrc) = iaccp
	END DO
	IF ( ntotl .eq. 0 ) iret = -43
C*
	RETURN
	END
