	SUBROUTINE SRCH_DRV ( filnam, nflnm, lun, quiet, ntrcs, iret )
C************************************************************************
C* SRCH_DRV								*
C*									*
C* This subroutine applies a set of search conditions to all records in	*
C* a set of Verification Statistic Database (VSDB) files.  The output	*
C* is a set of traces, each retrievable by calling SRCH_GET.		*
C*									*
C* Set QUIET to .true. to suppress error messages about records that	*
C* were not parsed successfully.					*
C*									*
C* SRCH_DRV ( FILNAM, NFLNM, LUN, QUIET, NTRCS, IRET )			*
C*									*
C* Input parameters:							*
C*	FILNAM (NFLNM)	CHAR*		Array of VSDB file names	*
C*	NFLNM		INTEGER		Number of files			*
C*	LUN		INTEGER		Unit number to use for files	*
C*	QUIET		LOGICAL		Flag to suppress error mesgs	*
C*									*
C* Output parameters:							*
C*	NTRCS		INTEGER		Number of traces available	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-14 = file open failure		*
C*					-15 = no traces are requested	*
C*					-35 = inconsistent IND VAR conds*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		11/97	Changes for post-search data combination*
C* K. Brill/EMC		 2/98	Moved data combination to SRCH_GET	*
C* K. Brill/HPC		 8/05	Increase NRECR to 512			*
C* K. Brill/WPC      20141114   WRITE warning for IFILLD(i) .ne. 0      *
C************************************************************************
	PARAMETER	( NRECR = 512 )
	INCLUDE		'srch.cmn'
C*
	CHARACTER*(*)	filnam (*)
	LOGICAL		quiet
C*
	CHARACTER*(NRECR)	rcrd (NRECR)
C*
C*------------------------------------------------------------------------
	iret = 0
	ntrcs = ntrace
	IF ( ntrcs .eq. 0 ) THEN
	    iret = -15
	    RETURN
	END IF
C
C*	Check to see that traces with the same plot ID number have the
C*	same independent variable checks.
C
	CALL SRCH_IVC ( iret )
	IF ( iret .ne. 0 ) RETURN
C*
	DO i = 1, nflnm
C
C*	    Open the VSDB file.
C
	    CALL VSDB_OPN ( lun, filnam (i), 'r', ier )
	    IF ( ier .ne. 0 ) THEN
		CALL VSDB_ERR ( ier, filnam (i), iii )
		iret = -14
		RETURN
	    END IF
	    CALL ST_LSTR ( filnam (i), lng, ier )
	    WRITE (6,*) ' Searching in ', filnam (i) (1:lng)
	    ierr = 0
	    DO WHILE ( ierr .eq. 0 )
C
C*		Read a set of records.
C
		CALL VSDB_RDD ( lun, NRECR, rcrd, nread, ierr )
		IF ( nread .gt. 0 ) THEN
		    DO irec = 1, nread
C
C*			Check record and add to trace data if search
C*			conditions permit.
C
			record = rcrd (irec)
			CALL SRCH_ADD ( quiet, ier )
			IF ( ier .ne. 0 .and. .not. quiet ) THEN
			    CALL SRCH_ERR ( ier, rcrd, iii )
			END IF
		    END DO
		END IF
	    END DO
	    CLOSE ( lun )
	END DO
        DO i = 1, ntrace
            IF ( ifilld (i) .gt. 0 ) THEN
                ifld = ifilld (i)
                WRITE (6,*) ' '
                WRITE (6,*) ' WARNING:  Trace # ', i, ' had ', ifld,
     +          ' short data record(s) -- zero assigned.'
                WRITE (6,*) ' '
            END IF
        END DO
C*
	RETURN
	END
