	SUBROUTINE SRCH_DSC ( nt, itrcs, iret )
C************************************************************************
C* SRCH_DSC								*
C*									*
C* This subroutine combines multiple trace data at point locations at	*
C* which the data count is the same for all traces and the date/times	*
C* of verification exactly match at that particular point.  The counts	*
C* and verification times can vary from point to point.			*
C* 									*
C*									*
C* SRCH_DSC ( NT, ITRCS, IRET )						*
C*									*
C* Input parameters:							*
C*	NT		INTEGER		Number of traces		*
C*	ITRCS (NT)	INTEGER		Array of trace numbers		*
C*									*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					 +3 = uncombined data IO failed *
C*					 +2 = a trace has 0 points	*
C*				 	  0 = normal return 		*
C*					 -3 = invalid combination code	*
C*					-45 = all traces have 0 points	*
C**									*
C* Log:									*
C* K. Brill/EMC		 3/98						*
C* K. Brill/EMC		 4/99	Data rejection diagnostic count		*
C* K. Brill/HPC		 8/00	DTMSV *12 -> *(NCKCHR)			*
C* K. Brill/HPC		10/02	Set the BINMTY array for conditionally	*
C*				determined ind. variable points		*
C* K. Brill/HPC		12/03	Use trace with most pts as master trace;*
C*				Do not consider traces with 0 count at	*
C*				a point					*
C* K. Brill/HPC         02/12   Write out uncombined data		*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	INTEGER		itrcs (*)
C*
	REAL*8		rhld (MXDPTH), rhold (MXDPTH), r1, rn
	CHARACTER*(NCKCHR)	dtmsv
	LOGICAL		ok, found
C*-----------------------------------------------------------------------
	iret = 0
	ntotl = 0
C
C*	Find the trace with the most number of points.
C
	lstnu = 0
	DO it = 1, nt
	    itrc = itrcs (it)
	    IF ( ndatap (itrc) .gt. lstnu ) THEN
		lstnu = ndatap (itrc)
		mastr = itrc
	    END IF
	END DO
C
C*	Go through the master trace point by point.  Find the trace
C*	with the least non-zero counts at each point.  Loop over the
C*      verification times in this least-counts trace, counting the
C*	occurrence of each.  Check all other non-zero count traces at
C*	this point for an identical count of each verification time.
C*	If the count is identical, set KPOINT values negative in the
C*	other traces.
C
	DO mtp = 1, ndatap (mastr)
	    lt = 0
	    lp = 0
	    lstcnt = MAXNXT
	    DO jt = 1, nt
		it = itrcs (jt)
		ip = 0
		found = .false.
		DO WHILE ( ip .lt. ndatap (it) .and. .not. found )
		    ip = ip + 1
		    IF (
     +			ctrcid (it,ip) .eq. ctrcid (mastr,mtp)
     +				.and.
     +			rtrcid (it,ip) .eq. rtrcid (mastr,mtp)
     +		    ) THEN
			IF ( kounts (it,ip) .gt. 0 .and.
     +			     kounts (it,ip) .lt. lstcnt ) THEN
			    lstcnt = kounts (it,ip)
			    lt = it
			    lp = ip
			END IF
			found = .true.
		    END IF
		END DO
	    END DO
	    IF ( lp .gt. 0 .and. lt .gt. 0 ) THEN
		DO id = 1, nxtelm (lt)
		    IF ( kpoint (lt,id) .eq. lp ) THEN
			dtmsv = conchk (lt,id)
			kpoint (lt,id) = kpoint (lt,id) + MXDPTS
			icnt = 1
			DO kd = (id+1), nxtelm (lt)
			    IF ( kpoint (lt,kd) .eq. lp .and.
     +			         conchk (lt,kd) .eq. dtmsv ) THEN
				icnt = icnt + 1
				kpoint (lt,kd) = kpoint (lt,kd) +
     +						 MXDPTS
			    END IF
			END DO
			ok = .true.
			jt = 0
			DO WHILE ( jt .lt. nt .and. ok )
			    jt = jt + 1
			    it = itrcs (jt)
			    IF ( it .ne. lt ) THEN
				jcnt = 0
				kcnt = 0
				found = .false.
				ip = 0
				DO WHILE ( ip .lt. ndatap (it) .and.
     +					   .not. found )
				    ip = ip + 1
				    IF ( ctrcid (it,ip) .eq.
     +					 ctrcid (mastr,mtp) .and.
     +					 rtrcid (it,ip) .eq.
     +					 rtrcid (mastr,mtp) ) THEN
					found = .true.
					DO jd = 1, nxtelm (it)
					    IF ( kpoint (it,jd) .eq. ip
     +						 .and. conchk (it,jd)
     +						 .eq. dtmsv ) THEN
						jcnt = jcnt + 1
						kpoint (it,jd) =
     +						  kpoint (it,jd) +
     +					          MXDPTS
					    ELSE IF
     +					      ( kpoint (it,jd) .eq. ip )
     +					      THEN
						kcnt = kcnt + 1
					    END IF
					END DO
				    END IF
				END DO
				ok = jcnt .eq. icnt .or. ( jcnt .eq. 0
     +				     .and. kcnt .eq. 0 )
			    END IF
			END DO
			IF ( ok ) THEN
C
C*			    Loop through all traces and set - flags.
C
			    DO jt = 1, nt
				it = itrcs (jt)
				DO in = 1, nxtelm (it)
				    IF ( kpoint (it,in) .gt. MXDPTS )
     +					kpoint (it,in) = - (
     +					    kpoint (it,in) - MXDPTS )
				END DO
			    END DO
			ELSE
C
C*			    Loop through traces and set reject flags.
C
			    DO jt = 1, nt
				it = itrcs (jt)
				DO in = 1, nxtelm (it)
				    IF ( kpoint (it,in) .gt. MXDPTS )
     +					kpoint (it,in) = 0
				END DO
			    END DO
			END IF
		    END IF
		END DO
	    END IF
	END DO
C
C*	Now combine data for all points where KPOINT is negative.
C
	DO it = 1, nt
	    iaccp = 0
	    itrc = itrcs (it)
	    ndat = 0
	    DO ipnt = 1, ndatap (itrc)
		DO jd = 1, ndepth (itrc)
		    rhold (jd) = 0.0
		END DO
		in = 0
		icnt = 0
		DO WHILE ( in .lt. nxtelm (itrc) .and.
     +			   icnt .lt. kounts (itrc,ipnt) )
		    in = in + 1
		    IF ( kpoint (itrc,in) .eq. -ipnt ) THEN
		        iaccp = iaccp + 1
			iswap = in
			dtmsv = conchk (itrc,in)
			icnt = icnt + 1
			IF ( kdvcmb (itrc) .eq. 0 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = dtrace (itrc,jd,in)
				rhld (jd) = dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 1 ) THEN
			    DO jd = 1, ndepth (itrc)
				rhold (jd) = rhold (jd) +
     +						 dtrace (itrc,jd,in)
				rhld (jd) = dtrace (itrc,jd,in)
			    END DO
			ELSE IF ( kdvcmb (itrc) .eq. 2 ) THEN
			    DO jd = 1, ndepth (itrc)
				IF ( jd .eq. indxdc (itrc) ) THEN
				    rhold (jd) = rhold (jd) +
     +						     dtrace (itrc,jd,in)
				    rhld (jd) = dtrace (itrc,jd,in)
				ELSE
				    r1 = dtrace (itrc,indxdc(itrc),in)
				    rn = dtrace (itrc,jd,in)
				    rhold (jd) = rhold (jd) + r1 * rn
				    rhld (jd) = r1 * rn
				END IF
			    END DO
			ELSE 
			    iret = -3
			    RETURN
			END IF
			IF ( iret .eq. 0 .and. okwucd ) THEN
			    WRITE (lunucd, IOSTAT = ios) idnmbr (itrc),
     +			    itrc, ipnt, (rhld(jj),jj=1,ndepth(itrc))
			    IF ( ios .ne. 0 ) iret = 3
			END IF
		    END IF
		END DO
		IF ( icnt .gt. 0 ) THEN
		    ndat = ndat + 1
		    DO jd = 1, ndepth (itrc)
			dtrace (itrc,jd,iswap) = dtrace (itrc,jd,ndat)
			dtrace (itrc,jd,ndat) = rhold (jd)
		    END DO
		    conchk (itrc,iswap) = conchk (itrc,ndat)
		    conchk (itrc,ndat) = dtmsv
		    kpoint (itrc,iswap) = kpoint (itrc,ndat)
		    kpoint (itrc,ndat) = ipnt
C
C*		    Set counts and labels for this point.
C
		    kounts (itrc,ndat) = icnt
		    ctrcid (itrc,ndat) = ctrcid (itrc,ipnt)
		    rtrcid (itrc,ndat) = rtrcid (itrc,ipnt)
		ELSE IF ( kivnpt (itrc) .gt. 1 ) THEN
		    binmty (itrc,ipnt) = .true.
		END IF
	    END DO
C
C*	    Set final data count for this trace.
C
	    ndatap (itrc) = ndat
	    ntotl = ntotl + ndat
	    IF ( ndat .eq. 0 ) iret = +2
	    kaccpt (itrc) = iaccp
	END DO
	IF ( ntotl .eq. 0 ) iret = -45
C*
	RETURN
	END
