	SUBROUTINE SRCH_FNP ( icmb, icode, ncdip, ymdhn, rymdhw, clist,
     +			      ok, clbl, iret )
C************************************************************************
C* SRCH_FNC								*
C*									*
C* This subroutine performs a time period type data check.		*
C*									*
C* The period information is a string of single character period	*
C* designations.							*
C*									*
C* The values of ICODE and ICMB determine the type of CLBL generated	*
C* for the value.  If a time series is indicated by ICMB (=0), then a	*
C* full time stamp is returned. If data combining is indicated, a	*
C* categorical time stamp is returned.  The table below describes the	*
C* action taken for values of ICODE and ICMB:				*
C*									*
C*    ICODE   ICMB			Action				*
C*									*
C*     19       0   Find existing period; CLBL = YYYYMMDDHHNN		*
C*     19      >0   Find existing period; CLBL = categorical time stamp *
C*     20	0   Make period; CLBL = appropriate YYMMDDHHNN/w	*
C*     20      >0   Make period; CLBL = categorical time stamp		*
C*									*
C*									*
C* NCDIP is the number of conditionally determined independent varible	*
C* points and is used to set the correct label values for checks on	*
C* independent variable conditions.  When only one independent variable	*
C* condition is being applied, the value found is that needed for a	*
C* label when range checking is in effect.  NCDIP = 0 if checking is	*
C* for a dependent variable.						*
C*									*
C* If OK is .TRUE., then this data must be accepted.			*
C*									*
C* SRCH_FNP ( ICMB, ICODE, NCDIP, YMDHN, RYMDHW, CLIST,			*
C*	      OK, CLBL, IRET )						*
C*									*
C* Input parameters:							*
C*	ICMB		INTEGER		Data combining code		*
C*	ICODE		INTEGER		Comparison condition type #	*
C*	NCDIP		INTEGER		# of conditionally determined	*
C*					  indep variable points		*
C*	YMDHN		CHAR*12		YYYYMMDDHHNN date time string	*
C*	RYMDHW		REAL		Verifying time window		*
C*	CLIST 		CHAR*		CHAR date values to match	*
C*									*
C* Output parameters:							*
C*	OK		LOGICAL		Acceptance flag			*
C*	CLBL		CHAR*		CHAR label value		*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-33 = invalid search condition	*
C**									*
C* Log:									*
C* K. Brill/EMC		 9/97						*
C* K. Brill/EMC		 1/99	No -33 error for ICODE = 20		*
C* K. Brill/HPC		 5/01	Fix ( ) grouping errors in ICODE = 20	*
C* K. Brill/HPC		 5/01	Fix for season period creating		*
C* K. Brill/HPC		 2/03	Allow HHNN to vary in period averages	*
C************************************************************************
	CHARACTER*(*)	clist,  ymdhn, clbl
	LOGICAL		ok
C*
	CHARACTER	cxlbl*12, nudate*24
	CHARACTER*1	tpd
	CHARACTER*2	mm
C*------------------------------------------------------------------------
	iret = 0
	clbl = ' '
	ok = .false.
	CALL ST_LSTR ( clist, ntps, ier )
C*
	IF ( ymdhn .eq. ' ' ) RETURN
C*
	IF ( icode .eq. 19 ) THEN
	    itp = 0
	    iw = NINT ( rymdhw )
	    DO WHILE ( .not. ok .and. itp .lt. ntps )
		itp = itp + 1
		tpd = clist (itp:itp)
		IF ( tpd .eq. 'D' .or. tpd .eq. 'd' ) THEN
		    IF ( ymdhn (9:12) .eq. '1200' .and.
     +			 iw .eq. 24 ) ok = .true.
		    cxlbl = ymdhn (5:6) // '/' // ymdhn (7:8)
		ELSE IF ( tpd .eq. 'M' .or. tpd .eq. 'm' ) THEN
		    IF ( ymdhn (7:8) .eq. '15' .and.
     +			 iw .eq. 730 ) ok = .true.
		    cxlbl = ymdhn (5:6)
		ELSE IF ( tpd .eq. 'A' .or. tpd .eq. 'a' ) THEN
		    IF ( ymdhn (5:8) .eq. '0401' .and.
     +			 iw .eq. 4380 ) ok = .true.
		    cxlbl = 'HALF_1'
		ELSE IF ( tpd .eq. 'B' .or. tpd .eq. 'b' ) THEN
		    IF ( ymdhn (5:8) .eq. '1001' .and.
     +			 iw .eq. 4380 ) ok = .true.
		    cxlbl = 'HALF_2'
		ELSE IF ( tpd .eq. 'Y' .or. tpd .eq. 'y' ) THEN
		    IF ( ymdhn (5:8) .eq. '0701' .and.
     +			 iw .eq. 8760 ) ok = .true.
		    cxlbl = ymdhn (1:4)
		ELSE IF ( tpd .eq. 'W' .or. tpd .eq. 'w' ) THEN
		    IF ( ymdhn (5:8) .eq. '0115' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = 'WNTR'
		ELSE IF ( tpd .eq. 'V' .or. tpd .eq. 'v' ) THEN
		    IF ( ymdhn (5:8) .eq. '0415' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = 'SPRG'
		ELSE IF ( tpd .eq. 'S' .or. tpd .eq. 's' ) THEN
		    IF ( ymdhn (5:8) .eq. '0715' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = 'SUMR'
		ELSE IF ( tpd .eq. 'F' .or. tpd .eq. 'f' ) THEN
		    IF ( ymdhn (5:8) .eq. '1015' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = 'FALL'
		ELSE IF ( tpd .eq. '1' ) THEN
		    IF ( ymdhn (5:8) .eq. '0215' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = '1ST_QTR'
		ELSE IF ( tpd .eq. '2' ) THEN
		    IF ( ymdhn (5:8) .eq. '0515' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = '2ND_QTR'
		ELSE IF ( tpd .eq. '3' ) THEN
		    IF ( ymdhn (5:8) .eq. '0815' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = '3RD_QTR'
		ELSE IF ( tpd .eq. '4' ) THEN
		    IF ( ymdhn (5:8) .eq. '1115' .and.
     +			 iw .eq. 2190 ) ok = .true.
		    cxlbl = '4TH_QTR'
		ELSE
		    iret = -33
		    RETURN
		END IF
	    END DO
	    IF ( ok ) THEN
		IF ( icmb .eq. 0 .or. ncdip .eq. 1 ) THEN
		    clbl = ymdhn (1:12)
		ELSE
		    clbl = cxlbl
		END IF
	    END IF
	ELSE IF ( icode .eq. 20 ) THEN
	    itp = 0
	    iw = NINT ( rymdhw )
	    mm = ymdhn (5:6)
	    DO WHILE ( .not. ok .and. itp .lt. ntps .and.
     +			iw .eq. 0 )
		itp = itp + 1
		tpd = clist (itp:itp)
		IF ( tpd .eq. 'D' .or. tpd .eq. 'd' ) THEN
		    ok = .true.
		    nudate = ymdhn (1:8) // '1200/24'
		    cxlbl = ymdhn (5:6) // '/' // ymdhn (7:8)
		ELSE IF ( tpd .eq. 'M' .or. tpd .eq. 'm' ) THEN
		    ok = .true.
		    nudate = ymdhn (1:6) // '150000/730'
		    cxlbl = ymdhn (5:6)
		ELSE IF ( ( tpd .eq. 'A' .or. tpd .eq. 'a' ) .and.
     +			( ymdhn (5:12) .ge. '01010000' .and.
     +			  ymdhn (5:12) .le. '05312359' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '04010000/4380'
		    cxlbl = 'HALF_1'
		ELSE IF ( ( tpd .eq. 'B' .or. tpd .eq. 'b' ) .and.
     +			( ymdhn (5:12) .ge. '06010000' .and.
     +			  ymdhn (5:12) .le. '12312359' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '10010000/4380'
		    cxlbl = 'HALF_2'
		ELSE IF ( tpd .eq. 'Y' .or. tpd .eq. 'y' ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '07010000/8760'
		    cxlbl = ymdhn (1:4)
		ELSE IF ( ( tpd .eq. 'W' .or. tpd .eq. 'w' ) .and.
     +			  ( mm .eq. '12' .or. mm .eq. '01' .or.
     +			    mm .eq. '02' ) ) THEN
		    IF ( mm .eq. '12' ) THEN
		        CALL ST_NUMB ( ymdhn (1:4), iyyyy, ier )
			iyyyy = iyyyy + 1
			CALL ST_INCH ( iyyyy, nudate (1:4), ier )
		    ELSE
			nudate (1:4) = ymdhn (1:4)
		    END IF
		    ok = .true.
		    nudate = nudate (1:4) // '01150000/2190'
		    cxlbl = 'WNTR'
		ELSE IF ( ( tpd .eq. 'V' .or. tpd .eq. 'v' ) .and.
     +			  ( mm .eq. '03' .or. mm .eq. '04' .or.
     +			    mm .eq. '05' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '04150000/2190'
		    cxlbl = 'SPRG'
		ELSE IF ( ( tpd .eq. 'S' .or. tpd .eq. 's' ) .and.
     +			  ( mm .eq. '06' .or. mm .eq. '07' .or.
     +			    mm .eq. '08' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '07150000/2190'
		    cxlbl = 'SUMR'
		ELSE IF ( ( tpd .eq. 'F' .or. tpd .eq. 'f' ) .and.
     +			  ( mm .eq. '09' .or. mm .eq. '10' .or.
     +			    mm .eq. '11' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '10150000/2190'
		    cxlbl = 'FALL'
		ELSE IF ( tpd .eq. '1' .and.
     +			( ymdhn (5:12) .ge. '01010000' .and.
     +			  ymdhn (5:12) .le. '03312359' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '02150000/2190'
		    cxlbl = '1ST_QTR'
		ELSE IF ( tpd .eq. '2' .and.
     +			( ymdhn (5:12) .ge. '04010000' .and.
     +			  ymdhn (5:12) .le. '06302359' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '05150000/2190'
		    cxlbl = '2ND_QTR'
		ELSE IF ( tpd .eq. '3' .and.
     +			( ymdhn (5:12) .ge. '07010000' .and.
     +			  ymdhn (5:12) .le. '09302359' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '08150000/2190'
		    cxlbl = '3RD_QTR'
		ELSE IF ( tpd .eq. '4' .and.
     +			( ymdhn (5:12) .ge. '10010000' .and.
     +			  ymdhn (5:12) .le. '12312359' ) ) THEN
		    ok = .true.
		    nudate = ymdhn (1:4) // '11150000/2190'
		    cxlbl = '4TH_QTR'
		END IF
	    END DO
	    IF ( ok ) THEN
		IF ( icmb .eq. 0 .or. ncdip .eq. 1 ) THEN
		    clbl = nudate
		ELSE
		    clbl = cxlbl
		END IF
	    END IF
	END IF
C*
	RETURN
	END
