	SUBROUTINE SRCH_GET ( mtrc, mdpth, mxpts, msrti, mkndx,
     +			      trace, mknts, clbls, rlbls, srtyp, iret )
C************************************************************************
C* SRCH_GET								*
C*									*
C* This subroutine gets information about a trace or the trace data	*
C* itself, depending on the value of the inputs.			*
C*									*
C* If MTRC = 0, then only the number of traces is returned, in MTRC.	*
C* MXPTS and MDPTH are returned with zero values.			*
C*									*
C* If 0 < MTRC <= NTRACE, and MDPTH = 0, then the number of values	*
C* stored at each point along the trace is returned in MDPTH.  Also,	*
C* the data record index values from KINDEX are returned in MKNDX and	*
C* the number of data points along the trace is returned in MXPTS.	*
C* In this particular case, on input, MXPTS gives the maximum number	*
C* of index values that are allowed to be returned in MKNDX.  Note that	*
C* when a trace is returned, MKNDX only returns one value.  MXPTS 	*
C* always returns the number of points in a trace, unless MTRC = 0 on	*
C* inputs.								*
C*									*
C* If both MTRC and MDPTH are positive integers with valid values,	*
C* then values from DTRACE ( MTRC, MDPTH, * ) are returned.  These	*
C* values maybe sorted either by using the sorted index values stored	*
C* in MSRTI from a previous call or by creating a new array of MSRTI	*
C* values.  To trigger a new sort, set MSRTI (1) = 0; otherwise, the	*
C* index values in MSRTI (*) will be assumed to be set already.  To	*
C* guarantee that no sort is done, set the elements of MSRTI to values	*
C* equal to the corresponding array index (ranging from 1 to MXPTS).	*
C* No sort will be done on data whose independent points along the	*
C* trace are determined by search conditions; so, in those cases, the	*
C* values returned in MSRTI will be a sequence of counting numbers	*
C* ranging from 1 to MXPTS.						*
C*									*
C* MKNDX (1) returns the VSDB data record index associated with the	*
C* requested trace (MDPTH>0).  MKNDX returns an array of values when	*
C* MDPTH=0 on calling SRCH_GET.  In this case, on input, MXPTS sets	*
C* the limit for the maximum number of values that can be place in	*
C* MKNDX, but MDPTH returns the number of values returned in MKNDX.	*
C* MKNDX effectively indicates from where the data has come in the	*
C* VSDB record.								*
C*									*
C* MKNTS always returns the number of trace elements combined at each	*
C* point on the trace.							*
C*									*
C* When necessary, the data is sorted on the basis of the CTRCID or	*
C* RTRCID label data.  SRTYP returns the type of data sort.  If SRTYP	*
C* is c on return, then CTRCID was used in the sort.  If SRTYP is r,	*
C* then RTRCID was used in the sort.  If no sort is appropriate, then	*
C* SRTYP = n.  When SRTYP is n, CLBLS (1) = ' ' indicates real type	*
C* labels.								*
C*									*
C* Note that TRACE is a REAL*8 (64bit word) array.			*
C*									*
C*									*
C* SRCH_GET ( MTRC, MDPTH, MXPTS, MSRTI, MKNDX, TRACE, MKNTS, CLBLS,	*
C*	      RLBLS, SRTYP, IRET )					*
C*									*
C* Input and output parameters:						*
C*	MTRC		INTEGER		Input = trace number to get	*
C*					Output = number of traces	*
C*	MDPTH		INTEGER		Input = data depth # to get	*
C*					Output = # of data depth layers	*
C*	MXPTS		INTEGER		Input when MDPTH is 0 =		*
C*					  max # of index values		*
C*					Input when MDPTH is not 0 =	*
C*					  max #	of pts along trace	*
C*					Output = # of points along trace*
C*	MSRTI (MXPTS)	INTEGER		Sorting indexes for a trace	*
C*									*
C* Output parameters:							*
C*	MKNDX (1/MXPTS) INTEGER		Index of value in VSDB record	*
C*	TRACE (MXPTS)	REAL*8		Data for a single trace		*
C*	MKNTS (MXPTS)	INTEGER		Number combined at each point	*
C*	CLBLS (MXPTS)	CHAR*24		Char lbls for pts along trace	*
C*	RLBLS (MXPTS)	CHAR*24		Real lbls for pts along trace	*
C*	SRTYP		CHAR*1		Type of sort:			*
C*					  c = character			*
C*					  r = real			*
C*					  n = no sort needed		*
C*					' ' = sort routine not called	*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-28 = MKNDX array too small	*
C*					-29 = invalid trace number	*
C*					-30 = MXPTS is too small	*
C*					-31 = Sort index out of range	*
C*					-46 = trace has 0 points	*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		 2/98	Do data combination here		*
C* K. Brill/EMC		 3/98	Return IRET=-46 for trace with 0 pts	*
C* K. Brill/EMC		 7/98	Check for duplicate point labels	*
C* K. Brill/HPC		10/02	Use BINMTY to insert missing values	*
C* K. Brill/HPC		 1/03	Use BINLBL when CTRCID is blank		*
C* K. Brill/HPC		12/03	Initialize entire TRACE to missing	*
C* K. Brill/HPC		 3/05	Generalize duplicate label check	*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	REAL*8		trace (*)
	REAL		rlbls (*)
	INTEGER		mkndx (*), mknts (*), msrti (*)
	CHARACTER*1	srtyp
	CHARACTER*(*)	clbls (*)
C*
	LOGICAL		dupc, dupr
C*------------------------------------------------------------------------
	iret = 0
C
C*	Do the combination of the data.
C
	IF ( .not. cmbind ) THEN
	    CALL SRCH_CBN ( iret )
	    IF ( iret .lt. 0 ) THEN
		CALL SRCH_ERR ( iret,
     +		        ' RETURN CODE from data combination:', iii )
		RETURN
	    END IF
	    cmbind = .true.
	END IF
C*
	srtyp = ' '
	IF ( mxpts .lt. 1 ) THEN
	    kmx = 1
	ELSE
	    kmx = mxpts
	END IF
	DO i = 1, kmx
	    trace (i) = -1.1D31
	END DO
	IF ( mtrc .gt. ntrace .or. mtrc .lt. 0 ) THEN
	    iret = -29
	    RETURN
	ELSE IF ( mtrc .eq. 0 ) THEN
	    mtrc = ntrace
	    mdpth = 0
	    mxpts = 0
	    RETURN
	END IF
C*
	IF ( mdpth .eq. 0 ) THEN
	    IF ( mxpts .lt. ndepth (mtrc) ) THEN
		iret = -28
		RETURN
	    END IF
	    mdpth = ndepth ( mtrc )
	    mxpts = ndatap ( mtrc )
	    DO i = 1, mdpth
		mkndx (i) = kindex (mtrc, i)
	    END DO
	    RETURN
	END IF
C*
	IF ( mxpts .lt. ndatap (mtrc) ) THEN
	    iret = -30
	    RETURN
	END IF
	mxpts = ndatap (mtrc)
	IF ( mxpts .le. 0 ) THEN
	    iret = -46
	    RETURN
	END IF
C*
	mkndx (1) = kindex (mtrc,mdpth)
	IF ( msrti (1) .eq. 0 ) THEN
	    CALL SRCH_SRT ( mtrc, mxpts, msrti, srtyp, iret )
	    IF ( iret .ne. 0 ) RETURN
	END IF
C*
	IF ( kivnpt (mtrc) .eq. 1 ) THEN
	    DO i = 1, mxpts
		IF ( msrti (i) .le. 0 .or. msrti (i) .gt. mxpts ) THEN
		    iret = -31
		    RETURN
		END IF
		trace (i) = dtrace (mtrc, mdpth, msrti (i) )
		mknts (i) = kounts (mtrc, msrti (i) )
		clbls (i) = ctrcid (mtrc, msrti (i) )
		rlbls (i) = rtrcid (mtrc, msrti (i) )
	    END DO
	ELSE
	    indx = 0
	    DO i = 1, kivnpt (mtrc)
		IF ( binmty (mtrc,i) ) THEN
		    trace (i) = -1.1E31
		    clbls (i) = binlbl (mtrc,i)
		    CALL  ST_CRNM ( binlbl (mtrc,i), valu, ier )
		    IF ( ier .eq. 0 ) THEN
			rlbls (i) = valu
		    ELSE
			rlbls (i) = -1.1E31
		    END IF
		    mknts (i) = 0
		ELSE
		    indx = indx + 1
		    trace (i) = dtrace (mtrc, mdpth, msrti (indx) )
		    mknts (i) = kounts (mtrc, msrti (indx) )
		    clbls (i) = ctrcid (mtrc, msrti (indx) )
		    IF ( clbls (i) .eq. ' ' ) THEN
			clbls (i) = binlbl (mtrc,i)
		    END IF
		    rlbls (i) = rtrcid (mtrc, msrti (indx) )
		END IF
		IF ( kivncn (mtrc) .gt. 1 ) THEN
		    clbls (i) = binlbl (mtrc,i)
		    rlbls (i) = -1.1E31
		END IF
	    END DO
C
C*	    Use floating point lables when possible.
C
	    icnt = 0
	    DO i = 1, kivnpt (mtrc)
		IF ( rlbls (i) .gt. -1.E30 ) icnt = icnt + 1
	    END DO
	    IF ( icnt .eq. kivnpt (mtrc) ) srtyp = 'r'
	    mxpts = kivnpt (mtrc)
	END IF
C
C*	Check for duplicate character and real labels.
C
	dupc = .false.
	dupr = .false.
	i = 0
	DO WHILE ( .not. ( dupc .and. dupr ) .and. i .lt. mxpts )
	    i = i + 1
	    j = i
	    DO WHILE ( .not. ( dupc .and. dupr ) .and. j .lt. mxpts )
		j = j + 1
		IF ( .not. dupc ) dupc = clbls (i) .eq. clbls (j)
		IF ( .not. dupr )
     +		    dupr = ABS ( rlbls (i) - rlbls (j) ) .lt. .00001
	    END DO
	END DO
	IF ( dupc .and. .not. dupr ) THEN
	    IF ( rlbls (1) .lt. -1.E30 ) THEN
		iret = -52
		RETURN
	    END IF
	    clbls (1) = ' '
	    srtyp = 'r'
	ELSE IF ( dupr .and. .not. dupc ) THEN
	    rlbls (1) = -1.1E31
	    srtyp = 'c'
	ELSE IF ( dupc .and. dupr ) THEN
	    iret = -52
	END IF
C*
	RETURN
	END
