	SUBROUTINE SRCH_INI ( iret )
C************************************************************************
C* SRCH_INI								*
C*									*
C* This subroutine initializes the search data structure.		*
C*									*
C* SRCH_INI should be called before each call to SRCH_SET, which sets	*
C* search conditions.							*
C*									*
C* SRCH_INI enables debug output when the file srch_debug_in exists	*
C* in the local directory.  Output goes into the file srch_debug_out.	*
C* The file srch_debug_in contains a single integer value which gives	*
C* the trace point index at which to dump out data.  All records found	*
C* for that point are printed.  If the integer value = -1, all trace	*
C* points are dumped.  Units 97 and 98 are used. 	 		*
C*									*
C* SRCH_INI ( IRET )							*
C*									*
C* Input parameters:							*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C**									*
C* Log:									*
C* K. Brill/EMC		 7/97						*
C* K. Brill/EMC		10/97	Add IFDMAP (15); init DTRACE to missing	*
C* K. Brill/EMC		11/97	Changes for post-search combination	*
C* K. Brill/EMC		 2/98	Initialize CMBIND			*
C* K. Brill/EMC		 4/98	Make CHKLST a function of trace #	*
C* K. Brill/EMC		 8/98	Initialize the debug structure		*
C* K. Brill/EMC		10/98	Initialize KPRCNT			*
C* K. Brill/EMC		 1/99	Initialize KMCASE			*
C* K. Brill/EMC		 4/99   Set KNTTRC, KNTPAD, KACCPT, KREJCT	*
C* K. Brill/HPC		 1/00	Initialize CATBIN			*
C* K. Brill/HPC		 8/00	Initialize KDVCHK and KDVNCK		*
C* K. Brill/HPC		10/02	Initialize BINLBL and BINMTY		*
C* K. Brill/HPC		 5/03	Initialize MAXKNT, MAXTRC, MAXPNT	*
C* K. Brill/HPC		 6/03	Remove MAXKNT, MAXTRC, MAXPNT		*
C* K. Brill/HPC		12/03	Initialize LBLSET			*
C* K. Brill/HPC          2/12   Initialize lunucd=96			*
C* K. Brill/WPC      20141114   Initialize IFILLD = 0                   *
C* K. Brill/IMSG        01/16   Initialize ifdndx = 0                   *
C* K. Brill/IMSG     20170922   Initialize setc17 to false              *
C************************************************************************
	INCLUDE		'srch.cmn'
C*
C*------------------------------------------------------------------------
	iret = 0
C
C*	Set the mapping between header fields and search data elements.
C
	ifdmap (1) = 1
	ifdmap (2) = 2
	ifdmap (3) = 3
	ifdmap (4) = 3
	ifdmap (5) = 4
	ifdmap (6) = 4
	ifdmap (7) = 4
	ifdmap (8) = 5
	ifdmap (9) = 6
	ifdmap (10) = 7
	ifdmap (11) = 7
	ifdmap (12) = 8
	ifdmap (13) = 9
	ifdmap (14) = 9
	ifdmap (15) = 5
	DO i = 16, MXDFDS
	    ifdmap (i) = 0
	END DO
        ifdndx = 0
C
C*	Set the fast check rough screening string list to blanks.
C
	DO i = 1, MXTRCS
	    DO j = 1, MXCHKX
		chklst (i,j) = ' '
		ifdlst (i,j) = 0
		lngthl (i,j) = 0
	    END DO
	    nchckx (i) = 0
	    ickpar (i) = 0
	END DO
C
C*	Initialize the independent variable search arrays.
C
	DO l = 1, 2
	    DO k = 1, MXIVPT
		DO j = 1, MXIVCN
		    DO i = 1, MXTRCS
			civcnd (i,j,k,l) = ' '
			rivcnd (i,j,k,l) = 0.0
		    END DO
		END DO
	    END DO
	END DO
	DO k = 1, MXIVPT
	    DO i = 1, MXTRCS
		binmty (i,k) = .false.
		binlbl (i,k) = ' '
		DO j = 1, MXIVCN
		    kivcod (i,j,k) = 0
		END DO
	    END DO
	END DO
	DO j = 1, MXIVCN
	    DO i = 1, MXTRCS
		kivfld (i,j) = 0
	    END DO
	END DO
	DO i = 1, MXTRCS
	    kivncn (i) = 0
	    kivnpt (i) = 0
	END DO
C
C*	Initialize the dependent variable search arrays.
C
	DO k = 1, MXDVLS
	    DO j = 1, MXDVCN
		DO i = 1, MXTRCS
		    cdvcnd (i,j,k) = ' '
		    rdvcnd (i,j,k) = 0.0
		END DO
	    END DO
	END DO
	DO j = 1, MXDVCN
	    DO i = 1, MXTRCS
		kdvcod (i,j) = 0
		kdvfld (i,j) = 0
		kdvnls (i,j) = 0
		kdvchk (i,j) = 0
	    END DO
	END DO
	DO i = 1, MXTRCS
	    kdvncn (i) = 0
	    kdvcmb (i) = -9999
	    kdvnck (i) = 0
            setc17 (i) = .false.
	END DO
C
C*	Initialize trace tracking arrays.
C
	DO k = 1, MAXNXT
	    DO j = 1, MXDPTH
		DO i = 1, MXTRCS
		    dtrace (i,j,k) = -1.1D31
		END DO
	    END DO
	END DO
	DO j = 1, MAXNXT
	    DO i = 1, MXTRCS
		kpoint (i,j) = 0
		conchk (i,j) = ' '
	    END DO
	END DO
	DO j = 1, MXDPTS
	    DO i = 1, MXTRCS
		kounts (i,j) = 0
		ctrcid (i,j) = ' '
		rtrcid (i,j) = -1.1E31
	    END DO
	END DO
	DO j = 1, MXDPTH
	    DO i = 1, MXTRCS
		kindex (i,j) = 0
	    END DO
	END DO
	DO i = 1, MXTRCS
	    ndepth (i) = 0
	    ndatap (i) = 0
	    nxtelm (i) = 0
	    knttrc (i) = 0
	    kntpad (i) = 0
	    kaccpt (i) = 0
	    krejct (i) = 0
	    indxdc (i) = 0
	    idnmbr (i) = -9999
	    kntmax (i) = 0
	    kmatch (i) = -9999
	    kprcnt (i) = -9999
	    kmcase (i) = -9999
	    padzro (i) = .false.
            ifilld (i) = 0
	    catbin (i) = .false.
	    lblset (i) = .false.
	END DO
	cmbind = .false.
	ntrace = 0
	lunout = 0
	lunucd = 96
C
C*	Set the debug data structure elements.
C
	lundbi = 97
	lundbo = 98
	kntdmp = 0
	ichkpt = 0
	INQUIRE ( FILE = 'srch_debug_in', EXIST = ldebug )
	IF ( ldebug ) THEN
	    WRITE (6,*) ' Debug mode enabled.'
	    OPEN ( FILE = 'srch_debug_out', STATUS = 'unknown',
     +		   UNIT = lundbo, IOSTAT = ios )
	    IF ( ios .ne. 0 ) THEN
		ldebug = .false.
		WRITE (6,*) ' Cannot open srch_debug_out.'
		WRITE (6,*) ' Debug mode disabled.'
	    ELSE
		OPEN ( FILE = 'srch_debug_in', STATUS = 'OLD',
     +			UNIT = lundbi, IOSTAT = ios )
		READ (lundbi,*, IOSTAT=ios) ichkpt
		IF ( ios .ne. 0 ) THEN
		    WRITE (6,*) ' Cannot read srch_debug_in.'
		    WRITE (6,*) ' Debug mode disabled.'
		    ldebug = .false.
		    CLOSE ( UNIT = lundbo, STATUS = 'DELETE' )
		    CLOSE ( UNIT = lunbdi )
		END IF
	    END IF
	END IF
C*
	RETURN
	END
