	SUBROUTINE SRCH_IVC ( iret )
C************************************************************************
C* SRCH_IVC								*
C*									*
C* This subroutine performs a check to assure that independent variable	*
C* search conditions are the same for plots bearing the same plot ID	*
C* number.								*
C*									*
C* If all checks are OK, IRET = 0; otherwise, IRET = -35.		*
C*									*
C* SRCH_IVC ( IRET )							*
C*									*
C* Input parameters:							*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-35 = ind var conds inconsistent*
C**									*
C* Log:									*
C* K. Brill/EMC		11/97						*
C* K. Brill/HPC		12/03	Changes for allowing ind var conditions	*
C*				to vary among traces on same plot	*
C* K. Brill/HPC		12/03	Process all traces; add relbl, warn flgs*
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	LOGICAL		chkd (MXTRCS), ok, relbl, warn
C*-----------------------------------------------------------------------
	iret = 0
	warn = .false.
C*
	DO i = 1, ntrace
	    chkd (i) = .false.
	END DO
C
C*	Check the traces against one another.
C
	i = 0
	DO WHILE ( i .lt. (ntrace-1) )
	    i = i + 1
	    IF ( .not. chkd (i) ) THEN
		j = i
		DO WHILE ( j .lt. ntrace )
		    j = j+1
		    IF ( .not. chkd (j) .and.
     +			 idnmbr (j) .eq. idnmbr (i) ) THEN
			chkd (j) = .true.
			IF ( kivnpt (i) .ne. kivnpt (j) ) THEN
			    iret = -35
			    RETURN
			END IF
			relbl = ( kivncn (i) .ne. kivncn (j) )
			IF ( .not. relbl ) THEN
			    ncn = 0
			    ok = .true.
			    DO WHILE ( ncn .lt. kivncn (j) .and. ok )
				ncn = ncn + 1
				IF ( kivfld (i,ncn) .ne.
     +				     kivfld (j,ncn) ) ok = .false.
				IF ( ok ) THEN
				    npt = 0
				    DO WHILE ( npt .lt. kivnpt (j)
     +						.and. ok )
					npt = npt + 1
					IF ( kivcod (i,ncn,npt) .ne.
     +					     kivcod (j,ncn,npt) )
     +					    ok = .false.
					ii = 0
					DO WHILE ( ii .lt. 2 .and. ok )
					    ii = ii + 1
					    IF ( civcnd (i,ncn,npt,ii)
     +					    .ne. civcnd (j,ncn,npt,ii) )
     +					    ok = .false.
					    IF ( rivcnd (i,ncn,npt,ii)
     +					    .ne. rivcnd (j,ncn,npt,ii) )
     +					    ok = .false.
					END DO
				    END DO
				END IF
			    END DO
			    relbl = ( .not. ok )
			END IF
			IF ( relbl ) THEN
C
C*			    Set the trace point labels from first condition
C*			    for first trace when independent variable
C*			    conditions differ.
C
			    DO npt = 1, kivnpt (j)
				IF ( ctrcid (i,npt) .eq. ' ' ) THEN
				    ctrcid (i,npt) = civcnd (i,1,npt,1)
				END IF
				IF ( rtrcid (i,npt) .lt. -1.E30 ) THEN
				    rtrcid (i,npt) = rivcnd (i,1,npt,1)
				END IF
				ctrcid (j,npt) = ctrcid (i,npt)
				rtrcid (j,npt) = rtrcid (i,npt)
				binlbl (j,npt) = binlbl (i,npt)
			    END DO
			    lblset (i) = .true.
			    lblset (j) = .true.
			    warn = .true.
			END IF
		    END IF
		END DO
	    END IF
	END DO
	IF ( warn ) THEN
	    iret = 3
	    CALL SRCH_ERR ( iret, ' ', ier )
	    iret = 0
	END IF
C*
	RETURN
	END
