	SUBROUTINE SRCH_LOD ( itrc, ipnt, clbl, rlbl, iret )
C************************************************************************
C* SRCH_LOD								*
C*									*
C* This subroutine loads newly found trace data into internal storage.	*
C*									*
C* The data from the record has been parsed out and stored in the	*
C* COMMON area.								*
C*									*
C* SRCH_LOD ( ITRC, IPNT, CLBL, RLBL, IRET )				*
C*									*
C* Input parameters:							*
C*	ITRC		INTEGER		Trace number for this data	*
C*	IPNT		INTEGER		Point number on the trace	*
C*	CLBL (*)	CHAR*		Character trace point ID	*
C*	RLBL (*)	REAL		Real trace point ID		*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*					+ 1 = > MXDPTH # of data values *
C*				 	  0 = normal return 		*
C*					-22 = MXDPTS exceeded		*
C*					-23 = t series char lbl exists	*
C*					-24 = t series real lbl exists	*
C*					-25 = no char or real label	*
C*					-37 = MXDPTH too small		*
C*					-38 = no data defined by conds	*
C**									*
C* Log:									*
C* K. Brill/EMC		11/97						*
C* K. Brill/EMC		11/97	Always put the count in dtrace(*,1,*)	*
C* K. Brill/EMC		 4/99	Count records accepted			*
C* K. Brill/HPC		 1/00	Do not reject records with missing data *
C* K. Brill/EMC		 8/00	Build consistency check string		*
C* K. Brill/HPC		 5/03	Set MAXKNT, MAXTRC, and MAXPNT		*
C* K. Brill/HPC		 6/03	Remove MAXKNT, MAXTRC, and MAXPNT	*
C* K. Brill/HPC		12/03	Check LBLSET before changing trc pt ID	*
C* K. Brill/WPC      20141114   Check for short data record and assign  *
C*                              zero, increment IFILLD                  *
C* K. Brill/IMSG     20170407   Compare reldat(*) to REAL*8 (D) constant*
C* K. Brill/IMSG     20170922   Check the setc17 flag for check string *
C************************************************************************
	INCLUDE		'srch.cmn'
C*
	CHARACTER*(*)		clbl (MXIVCN)
	REAL			rlbl (MXIVCN)
C*
	CHARACTER*(NCKCHR)	cdum
C*------------------------------------------------------------------------
	iret = 0
C
C*	Localize the data for this trace.
C
	ndt = ndatap ( itrc )
	IF ( ndt .ge. MXDPTS ) THEN
	    iret = -22
	    RETURN
	END IF
	ndp = ndepth ( itrc )
	ipt = ipnt
	icmb = kdvcmb ( itrc )
C
C*	If the depth (number of data values per trace point) is zero,
C*	determine what it is.
C
	IF ( ndp .eq. 0 ) THEN
	    IF ( numrel .gt. MXDPTH ) THEN
C
C*		Make sure that count is in first position.
C
		ndp = 1
		indxdc (itrc) = 1
		kindex (itrc,ndp) = 1
C*
		DO icn = 1, kdvncn (itrc)
		    IF ( kdvfld (itrc,icn) .gt. 100 ) THEN
			ndp = ndp + 1
			IF ( ndp .le. MXDPTH ) THEN
			    ndepth (itrc) = ndp
			    kindex (itrc,ndp) = kdvfld (itrc,icn) - 100
			ELSE
			    iret = -37
			END IF
		    END IF
		END DO
		IF ( ndp .eq. 1 ) THEN
		    iret = -38
		    RETURN
		END IF
	    ELSE
		indxdc (itrc) = 1
		DO idp = 1, numrel
		    kindex ( itrc, idp ) = idp
		END DO
		ndepth ( itrc ) = numrel
		ndp = numrel
	    END IF
	END IF
C
C*	Set the label arrays.
C
	IF ( kivnpt (itrc) .eq. 1 ) THEN
C
C*	    Time-series like trace searching.
C
	    IF ( clbl (1) .ne. ' ' ) THEN
		ipt = 0
		DO i = 1, ndt
		    IF ( ctrcid (itrc,i) .eq. clbl (1) .and.
     +			 icmb .eq. 0 ) THEN
			iret = -23
			RETURN
		    ELSE IF ( ctrcid (itrc,i) .eq. clbl (1) ) THEN
			ipt = i
		    END IF
		END DO
		IF ( ipt .eq. 0 ) THEN
		    ipt = ndt + 1
		    ctrcid (itrc,ipt) = clbl (1)
		    ndatap (itrc) = ipt
		END IF
	    ELSE IF ( rlbl (1) .gt. -1.E30 ) THEN
		ipt = 0
		DO i = 1, ndt
		    IF ( rtrcid (itrc,i) .eq. rlbl (1) .and.
     +			 icmb .eq. 0 ) THEN
			iret = -24
			RETURN
		    ELSE IF ( rtrcid (itrc,i) .eq. rlbl (1) ) THEN
			ipt = i
		    END IF
		END DO
		IF ( ipt .eq. 0 ) THEN
		    ipt = ndt + 1
		    rtrcid (itrc,ipt) = rlbl (1)
		    ndatap (itrc) = ipt
		END IF
	    ELSE
		iret = -25
		RETURN
	    END IF
	ELSE
	    IF ( ndt .eq. 0 ) THEN
C
C*		Set the number of points in the trace.
C
		ndatap ( itrc ) = kivnpt (itrc)
	    END IF
C
C*	    Conditionally defined trace points are given
C*	    labels based on conditions.
C
	    IF ( kounts (itrc,ipt) .eq. 0 .and.
     +		 .not. lblset (itrc) ) THEN
		lnmx = LEN ( ctrcid (itrc,ipt) )
		DO i = 1, kivncn ( itrc )
		    IF ( clbl (i) .ne. ' ' .and.
     +			 ctrcid (itrc,ipt) .ne. ' ' ) THEN
			CALL ST_LSTR ( clbl (i), lnc, ier )
			IF ( lnt .lt. lnmx ) THEN
			    ctrcid (itrc,ipt) = ctrcid (itrc,ipt)
     +						(1:lnt) // ' ' //
     +						clbl (i) (1:lnc)
			    lnt = lnt + 1 + lnc
			END IF
		    ELSE IF ( clbl (i) .ne. ' ' .and.
     +			 ctrcid (itrc,ipt) .eq. ' ' ) THEN
			CALL ST_LSTR ( clbl (i), lnc, ier )
			ctrcid (itrc,ipt) = clbl (i) (1:lnc)
			lnt = lnc
		    END IF
		    IF ( rlbl (i) .gt. -1.E30 ) THEN
			rtrcid (itrc,ipt) = rlbl (i)
		    END IF
		END DO
	    END IF
	END IF
C
C*	Now store the data values in DTRACE in COMMON.
C
	nxtelm (itrc) = nxtelm (itrc) + 1
	IF ( nxtelm (itrc) .gt. MAXNXT ) THEN
	    iret = -34
	    RETURN
	END IF
	knttrc (itrc) = knttrc (itrc) + 1
	id = 0
	ibad = 0
        idup = 0
	DO WHILE ( id .lt. ndp )
	    id = id + 1
            IF ( id .gt. numrel ) THEN
		dtrace (itrc,id,nxtelm (itrc)) = 0.0
                IF ( idup .eq. 0 ) THEN
                    ifilld (itrc) = ifilld (itrc) + 1
                    idup = idup + 1
                END IF
	    ELSE IF ( reldat ( kindex (itrc,id) ) .gt. -1.D30 ) THEN
		dtrace (itrc,id,nxtelm (itrc)) =
     +				reldat ( kindex (itrc,id) )
	    ELSE
		dtrace (itrc,id,nxtelm (itrc)) =
     +				reldat ( kindex (itrc,id) )
		ibad = ibad + 1
	    END IF
	END DO
	IF ( ibad .eq. ndp .or.
     +       reldat ( kindex (itrc,1) ) .lt. -1.D30 ) THEN
	    nxtelm (itrc) = nxtelm (itrc) - 1
	ELSE
C
C*	    Build consistency check string.
C
	    conchk (itrc,nxtelm (itrc)) = cymdhn
	    CALL ST_LSTR ( conchk (itrc,nxtelm(itrc)), nln, ier )
	    idvc = 0
	    DO WHILE ( nln .lt. NCKCHR .and. idvc .lt. kdvnck (itrc) )
		idvc = idvc + 1
C
C*              Do not add forecast hour to the check string if
C*              the initial time is included as a search condition.
C*              Different forecast hours are allowed in that case.
C
                IF ( .not. setc17 (itrc) .or. 
     +               kdvchk(itrc,idvc) .ne. 3 ) THEN
		  CALL ST_LSTR ( hfield (kdvchk(itrc,idvc)), ln, ier )
		  cdum = conchk (itrc,nxtelm (itrc)) (1:nln) //
     +			  hfield (kdvchk(itrc,idvc)) (1:ln)
		  nln = nln + ln
		  conchk (itrc,nxtelm (itrc)) = cdum (1:nln)
                END IF
C*
	    END DO
C*
	    kpoint (itrc,nxtelm (itrc)) = ipt
	    kounts (itrc,ipt) = kounts (itrc,ipt) + 1
	    IF ( kounts (itrc,ipt) .gt. kntmax (itrc) )
     +		kntmax (itrc) = kounts (itrc,ipt)
	END IF
C*
	RETURN
	END
