	SUBROUTINE VSDB_FLD ( rcrd, nfld, field, ivrsn, cdata, iret )
C************************************************************************
C* VSDB_FLD								*
C*									*
C* This subroutine parses a record from a Verification Statistic Data	*
C* Base and returns all of the component character string fields on	*
C* the left of the = sign delimiter.  No values are returned, only the	*
C* descriptor fields.							*
C*									*
C* VSDB_FLD  ( RCRD, NFLD, FIELD, IVRSN, CDATA, IRET )			*
C*									*
C* Input parameters:							*
C*	RCRD		CHAR*		Record from a VSDB file		*
C*									*
C* Input and output parameter:						*
C*	NFLD		INTEGER		On input = max # of fields	*
C*					On output = # of fields found	*
C*									*
C* Output parameters:							*
C*	FIELD (NFLD)	CHAR*		Descriptor fields		*
C*	IVRSN		INTEGER		VSDB version number		*
C*	CDATA		CHAR*		Data field			*
C*	IRET		INTEGER		Return code			*
C*				 	  0 = normal return 		*
C*					-05 = invalid record		*
C*					-06 = invalid version number	*
C*					-07 = invalid number of fields  *
C*					-16 = 0 fields requested	*
C**									*
C* Log:									*
C* K. Brill/NMC		 7/97						*
C* K. Brill/HPC		 3/04	Use VSDB_SLN instead of ST_CLST		*
C* K. Brill/HPC		 8/05	Increase 256 to 512			*
C************************************************************************
	CHARACTER*(*)	rcrd, field (*), cdata
C*
	CHARACTER*512	cdesc
C*------------------------------------------------------------------------
	iret = 0
	IF ( nfld .eq. 0 ) THEN
	    iret = -16
	    RETURN
	END IF
C
C*	Split into identifiers versus values using = separator.
C
	iequal = INDEX ( rcrd, '=' )
	IF ( iequal .eq. 0 ) THEN
	    iret = -5
	    RETURN
	END IF
	cdesc = rcrd ( 1:(iequal-1) )
	cdata = rcrd ( (iequal+1): )
C
C*	Get the version number.
C
	iv = INDEX ( rcrd, 'V' )
	IF ( iv .eq. 0 ) THEN
	    iret = -6
	    RETURN
	ELSE
	    CALL ST_NUMB ( rcrd (iv+1:iv+2), ivrsn, ier )
	    IF ( ier .ne. 0 ) THEN
		iret = -6
		RETURN
	    END IF
	END IF
C
C*	Split description into identifier fields.
C
	IF ( ivrsn .eq. 1 ) THEN
	    nexp = 9
	END IF
	CALL VSDB_SLN ( cdesc, ' ', ' ', nfld, field, nfnd, ier )
	IF ( ier .lt. 0 .or. nfnd .ne. nexp ) THEN
	    iret = -7
	    nfld = 0
	    RETURN
	END IF 
	nfld = nexp
C*
	RETURN
	END
