	SUBROUTINE VSDB_OPN ( lun, filnam, iotype, iret )
C************************************************************************
C* VSDB_OPN								*
C*									*
C* This subroutine opens a Verification Statistic Database (VSDB) file	*
C* for read or write access.						*
C*									*
C* If IOTYPE = r, the file is opened for read only.  If IOTYPE = w,	*
C* the file opened as a new file for read or write access.  If		*
C* IOTYPE = a, the file is opened for appending write access.		*
C*									*
C* VSDB_OPN  ( LUN, FILNAM, IOTYPE, IRET )				*
C*									*
C* Input parameters:							*
C*	LUN		INTEGER		Unit number for file connection *
C*	FILNAM		CHAR*		VSDB file name			*
C*	IOTYPE		CHAR*1		I/O action for the file		*
C*						a = append write	*
C*						r = read only		*
C*						w = write new file	*
C*									*
C* Output parameters:							*
C*	IRET		INTEGER		Return code			*
C*				 	 0 = normal return 		*
C*					-1 = invalid I/O type		*
C*					-2 = file does not exist	*
C*					-3 = error opening existing file*
C*					-4 = error opening new file	*
C**									*
C* Log:									*
C* K. Brill/NMC		 7/97						*
C* K. Brill/HPC		 2/04	Set last record read to blank		*
C* K. Brill/HPC		 3/04	Initialize svflds array			*
C************************************************************************
	INCLUDE		'vsdb.cmn'
C*
	CHARACTER*(*)	filnam, iotype*1
C*
	CHARACTER*1	dummy
	LOGICAL		exist
C*------------------------------------------------------------------------
	iret = 0
	recfst = .true.
	DO i = 1, NIDFLD
	    svflds (i) = ' '
	END DO
	IF ( iotype .eq. 'a' .or. iotype .eq. 'r' ) THEN
	    INQUIRE ( FILE = filnam, EXIST = exist )
	    IF ( exist ) THEN
		OPEN ( UNIT = lun, FILE = filnam, STATUS = 'OLD',
     +		       IOSTAT = iostat )
		IF ( iostat .ne. 0 ) THEN
		    iret = -3
		    RETURN
		END IF
		IF ( iotype .eq. 'a' ) THEN
		    DO WHILE ( iostat .eq. 0 )
			READ ( lun, '(A)', IOSTAT=iostat ) dummy
		    END DO
		END IF
	    ELSE IF ( iotype .eq. 'a' ) THEN
		OPEN ( UNIT = lun, FILE = filnam, STATUS = 'UNKNOWN',
     +		       IOSTAT = iostat )
		IF ( iostat .ne. 0 ) THEN
		    iret = -4
		    RETURN
		END IF
	    ELSE
		iret = -2
		RETURN
	    END IF
	ELSE IF ( iotype .eq. 'w' ) THEN
	    OPEN ( UNIT = lun, FILE = filnam, STATUS = 'UNKNOWN',
     +		   IOSTAT = iostat )
	    IF ( iostat .ne. 0 ) THEN
		iret = -4
		RETURN
	    END IF
	ELSE
	    iret = -1
	END IF
C*
	RETURN
	END
