	SUBROUTINE VSDB_RDD ( lun, nrecs, rcrd, nrecrd, iret )
C************************************************************************
C* VSDB_RDD								*
C*									*
C* This subroutine reads a Verification Statistic Database (VSDB) file.	*
C*									*
C* The file is not rewound before or after the read.  The next NRECS	*
C* number of records are read and returned in RCRD.  NRECRD gives the	*
C* actual number of records that were read.  IRET indicates whether an	*
C* error or end-of-file condition occurred if NRECRD < NRECS.		*
C*									*
C* The file must be opened by VSDB_OPN before calling VSDB_RDD.		*
C*									*
C* VSDB_RDD  ( LUN, NRECS, RCRD, NRECRD, IRET )				*
C*									*
C* Input parameters:							*
C*	LUN		INTEGER		Unit number for file connection *
C*	NRECS		INTEGER		Number of records requested	*
C*									*
C* Output parameters:							*
C*	RCRD (NRECS)	CHAR*512	Array of records read		*
C*	NRECRD		INTEGER		Number of records actually read *
C*	IRET		INTEGER		Return code			*
C*					+02 = End of file encountered	*
C*				 	  0 = normal return 		*
C*					-14 = read error		*
C*					-15 = LUN has not been opened	*
C*				   	-17 = no subst in 1st record	*
C**									*
C* Log:									*
C* K. Brill/NMC		 7/97						*
C* K. Brill/HPC		 2/04	Allow fields substitution		*
C* K. Brill/HPC		 3/04	Make field substitution more efficient  *
C* K. Brill/HPC		 8/05	Increase 256 to 512			*
C************************************************************************
	INCLUDE		'vsdb.cmn'
C*
	CHARACTER*(*)	rcrd (*)
C*
	CHARACTER	rdfld(NIDFLD)*(MXFDSZ)
	CHARACTER*512	reco
	LOGICAL		opn
C*------------------------------------------------------------------------
	iret = 0
	nrecrd = 0
C*
	INQUIRE ( UNIT = lun, OPENED = opn )
	IF ( .not. opn ) THEN
	    iret = -15
	    RETURN
	END IF
C*
	DO i = 1, nrecs
	    READ ( lun, '(A)', END=101, ERR=202 ) rcrd (i)
	    nrecrd = nrecrd + 1
	    iquo = INDEX ( rcrd (i), '"' )
	    IF ( iquo .ne. 0 ) THEN
		IF ( recfst ) THEN
		    iret = -17
		    RETURN
		END IF
		ieq = INDEX ( rcrd (i), '=' )
		ie = ieq - 2
		CALL VSDB_SLN ( rcrd (i)(1:ie), ' ', ' ', NIDFLD,
     +			        rdfld, nrd, ier )
		IF ( ier .lt. 0 .or. nrd .ne. NIDFLD ) THEN
		    iret = -5
		    RETURN
		END IF
		indx = 1
		reco = ' '
		DO k = 1, NIDFLD
		    IF ( rdfld (k) .eq. '"' ) THEN
			reco (indx: ) = svflds (k)
		    ELSE
			reco (indx: ) = rdfld (k)
			svflds (k) = rdfld (k)
		    END IF
		    CALL ST_LSTR ( reco, lnr, ier )
		    reco = reco (1:lnr ) // ' '
		    indx = lnr + 2
		END DO
		reco (indx:) = rcrd (i)(ieq:)
		rcrd (i) = reco
	    END IF
	    IF ( recfst ) THEN
		ieq = INDEX ( rcrd (i), '=' )
		ie = ieq - 2
		CALL VSDB_SLN ( rcrd (i) (1:ie), ' ', ' ', NIDFLD,
     +		 	       svflds, nsv, ier )
		IF ( ier .lt. 0 .or. nsv .ne. NIDFLD ) THEN
		    iret = -5
		    RETURN
		END IF
	    END IF
	    recfst = .false.
	END DO
C*
	RETURN
C*
101	CONTINUE
	    iret = 2
	    RETURN
202	CONTINUE
	    iret = -14
	    RETURN
C*
	END
