	SUBROUTINE VSDB_RLN ( string, sep, rdef, nexp, rarr, num, iret )
C************************************************************************
C* VSDB_RLN								*
C*									*
C* This subroutine breaks a string containing a list of reals into an	*
C* array of real values.  The separator for the reals is input as 	*
C* SEP.  Repeated separators are regarded as a single separator.	*
C* If a value cannot be determined from the substring between two	*
C* separators, the default value is assigned.				*
C*									*
C* VSDB_RLN  ( STRING, SEP, RDEF, NEXP, RARR, NUM, IRET )		*
C*									*
C* Input parameters:							*
C*	STRING		CHAR*		String				*
C*	SEP		CHAR*1		Separator			*
C*	RDEF		REAL*8		Default value			*
C*	NEXP		INTEGER		Number of expected values 	*
C*									*
C* Output parameters:							*
C*	RARR  (NUM)	REAL*8		Array of real values		*
C*	NUM		INTEGER		Number of values returned	*
C*	IRET		INTEGER		Return code			*
C*				   	  1 = too many values 		*
C*				   	  0 = normal return		*
C*				  	 -3 = invalid substring		*
C**									*
C* Log:									*
C* M. Goodman/RDS	10/84	Original source for STLIST		*
C* M. desJardins/GSFC	11/84						*
C* M. desJardins/GSFC	 2/85	Modified for ST_RLST			*
C* M. desJardins/GSFC	 6/88	Documentation				*
C* L. Sager/NCEP         2/96   Increased size of strbuf                *
C* K. Brill/HPC		 3/04	Completely rewrote			*
C* K. Brill/IMSG         4/17   Accommodate REAL*8 data                 *
C************************************************************************
	CHARACTER*(*)	string, sep
	REAL*8		rarr (*), rdef
C*
	CHARACTER	cchar*1
	LOGICAL		more
C------------------------------------------------------------------------
	iret = 0
	num  = 0
	cchar = sep
C
C*	Initialize output array.
C
	DO  i = 1, nexp
	    rarr (i) = rdef
	END DO
C
C*	Get the length of the input string.
C
	CALL ST_LSTR ( string, lns, ier )
	IF ( lns .eq. 0 ) RETURN
C
C*	Loop over all substrings bounded by the separater.
C
	indx = 1
	DO WHILE ( string (indx:indx) .eq. cchar .and. indx .lt. lns )
	    indx = indx + 1
	END DO
	is = indx
	next = INDEX ( string(is:lns), cchar )
	next = is + next - 1
	more = .true.
	DO WHILE ( more .and. is .le. lns )
	    num = num + 1
	    nm1 = next - 1
	    iq = INDEX ( string (is:nm1), '1.1E31' ) +
     +		 INDEX ( string (is:nm1), '1.1E+31' ) +
     +           INDEX ( string (is:nm1), '1.1D31' ) +
     +           INDEX ( string (is:nm1), '1.1D+31' )
	    IF ( iq .eq. 0 ) THEN
		READ ( string (is:nm1), *, iostat=ios ) rarr (num)
		IF ( ios .ne. 0 ) THEN
		    rarr (num) = rdef
		END IF
	    ELSE
		rarr (num) = -1.1D31
	    END IF
	    is = next + 1
	    DO WHILE ( string (is:is) .eq. cchar .and. is .lt. lns )
		is = is + 1
	    END DO
	    IF ( is .le. lns ) THEN
		next = INDEX ( string (is:lns), cchar )
		IF ( next .ne. 0 ) THEN
		    next = is + next - 1
		ELSE
		    next = lns + 1
		END IF
	    END IF
	    IF ( num .eq. nexp ) THEN
		more = .false.
	    END IF
	END DO
C*
	RETURN
	END
