	SUBROUTINE VSDB_WRT ( lun, luno, nrecrd, iret )
C************************************************************************
C* VSDB_WRT								*
C*									*
C* This subroutine reads a Verification Statistic Database (VSDB) file 	*
C* and writes out records with substition character " replacing the	*
C* names of duplicated ID fields.					*
C*									*
C* The file is not rewound before or after the read.  NRECRD gives the  *
C* actual number of records that were read.  IRET indicates whether an	*
C* error or end-of-file condition occurred.				*
C*									*
C* The input file must be opened by VSDB_OPN before calling VSDB_WRT.   *
C* The output file must be opened by the user.				*
C*									*
C* VSDB_WRT  ( LUN, LUNO, NRECS, RCRD, NRECRD, IRET )			*
C*									*
C* Input parameters:							*
C*	LUN		INTEGER		Unit number for file connection *
C*	LUNO		INTEGER		Unit number for output		*
C*									*
C* Output parameters:							*
C*	NRECRD		INTEGER		Number of records actually read *
C*	IRET		INTEGER		Return code			*
C*					+02 = End of file encountered	*
C*				 	  0 = normal return 		*
C*					-14 = read error		*
C*					-15 = LUN has not been opened	*
C*				   	-17 = no subst in 1st record	*
C**									*
C* Log:									*
C* K. Brill/HPC		 2/04	Created from VSDB_RDD			*
C* K. Brill/HPC		 3/04	Use VSDB_SLN instead of ST_CLST		*
C* K. Brill/HPC		 8/05	Increase 256 to 512			*
C************************************************************************
	INCLUDE		'vsdb.cmn'
C*
	CHARACTER	rdfld(NIDFLD)*(MXFDSZ)
	CHARACTER*512	reco, rcrd
	LOGICAL		opn
C*------------------------------------------------------------------------
	iret = 0
	nrecrd = 0
C*
	INQUIRE ( UNIT = lun, OPENED = opn )
	IF ( .not. opn ) THEN
	    iret = -15
	    RETURN
	END IF
	INQUIRE ( UNIT = luno, OPENED = opn )
	IF ( .not. opn ) THEN
	    iret = -15
	    WRITE (6,*) 'Output file is not opened.'
	    RETURN
	END IF
C*
	recfst = .true.
	DO WHILE ( opn )
	    READ ( lun, '(A)', END=101, ERR=202 ) rcrd
	    nrecrd = nrecrd + 1
	    iquo = INDEX ( rcrd, '"' )
	    IF ( iquo .ne. 0 ) THEN
		reco = rcrd
		recfst = .true.
	    ELSE IF ( recfst ) THEN
		ieq = INDEX ( rcrd, '=' )
		ie = ieq - 2
		CALL VSDB_SLN ( rcrd (1:ie), ' ', ' ', NIDFLD,
     +			        svflds, nsv, ier )
		IF ( ier .lt. 0 .or. nsv .ne. NIDFLD ) THEN
		    iret = -5
		    RETURN
		END IF
		reco = rcrd
		recfst = .false.
	    ELSE
		ieq = INDEX ( rcrd, '=' )
		ie = ieq - 2
		CALL VSDB_SLN ( rcrd(1:ie), ' ', ' ', NIDFLD,
     +		 	        rdfld, nrd, ier )
		IF ( ier .lt. 0 .or. nrd .ne. NIDFLD ) THEN
		    iret = -5
		    RETURN
		END IF
		indx = 1
		reco = ' '
		DO k = 1, NIDFLD
		    IF ( rdfld (k) .eq. svflds (k) ) THEN
			reco (indx: ) = '"'
		    ELSE
			reco (indx: ) = rdfld (k)
			svflds (k) = rdfld (k)
		    END IF
		    CALL ST_LSTR ( reco, lnr, ier )
		    reco = reco (1:lnr ) // ' '
		    indx = lnr + 2
		END DO
		reco (indx:) = rcrd (ieq:)
	    END IF
	    CALL VSDB_RXS ( reco, reco, lnr, ier )
	    WRITE (luno,'(A)') reco (1:lnr)
	END DO
C*
	RETURN
C*
101	CONTINUE
	    iret = 2
	    RETURN
202	CONTINUE
	    iret = -14
	    RETURN
C*
	END
